@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -69,6 +69,23 @@ bear::audio::sample::~sample()
     m_manager->sample_deleted(this);
 } // sample::~sample()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create a copy of this sample.
+ */
+bear::audio::sample* bear::audio::sample::clone() const
+{
+  sample* result = NULL;
+
+  if ( m_manager != NULL )
+    {
+      result = m_manager->new_sample( get_sound_name() );
+      result->set_effect(get_effect());
+    }
+
+  return result;
+} // sample::clone()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the identifier of the sample.
