@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -70,7 +70,7 @@ bear::audio::sdl_sound::sdl_sound
   delete[] buffer;
 
   if (!m_sound)
-    throw CLAW_EXCEPTION( Mix_GetError() );
+    throw claw::exception( Mix_GetError() );
 } // sdl_sound::sdl_sound()
 
 /*----------------------------------------------------------------------------*/
