@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -198,8 +198,9 @@ std::size_t bear::audio::sound_manager::play_music
 /**
  * \brief Stop a music.
  * \param id The identifier of the music.
+ * \param fadeout The duration of the fadeout, if any.
  */
-void bear::audio::sound_manager::stop_music( std::size_t id )
+void bear::audio::sound_manager::stop_music( std::size_t id, double fadeout )
 {
   sample* m(NULL);
 
@@ -216,7 +217,7 @@ void bear::audio::sound_manager::stop_music( std::size_t id )
 
   if ( m != NULL )
     // calls sample_finished()
-    m->stop();
+    m->stop(fadeout);
 } // sound_manager::stop_music()
 
 /*----------------------------------------------------------------------------*/
