@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -48,7 +48,7 @@ namespace bear
   {
     class layer;
     class level;
-    class script_context;
+    class world;
 
     /**
      * \brief The basic physical item of our game.
@@ -72,7 +72,7 @@ namespace bear
      */
     class ENGINE_EXPORT base_item:
       public universe::physical_item,
-      public text_interface::base_exportable<script_context>,
+      public text_interface::base_exportable,
       virtual public level_object
     {
     public:
@@ -86,7 +86,7 @@ namespace bear
       typedef universe::physical_item super;
 
       TEXT_INTERFACE_DECLARE_METHOD_LIST
-      (text_interface::base_exportable<script_context>, init_exported_methods);
+      (text_interface::base_exportable, init_exported_methods);
 
     public:
       static void print_allocated();
@@ -97,6 +97,8 @@ namespace bear
 
       virtual base_item* clone() const;
 
+      void build_item();
+
       virtual void pre_cache();
       virtual void build();
       virtual void destroy();
@@ -149,7 +151,9 @@ namespace bear
       void kill();
       bool is_dead() const;
 
+      void clear_environment();
       void set_environment( layer& owner );
+      bool is_in_layer( const layer& the_layer ) const;
 
       void set_z_position( int z );
       int get_z_position() const;
@@ -160,6 +164,13 @@ namespace bear
       void set_insert_as_static();
       bool get_insert_as_static() const;
 
+      bool has_world() const;
+      const world& get_world() const;
+      /* public only for engine::world. */
+      void set_world( const world& w );
+
+      layer& get_layer() const;
+
     protected:
       void set_always_displayed(bool b);
 
@@ -168,9 +179,6 @@ namespace bear
 
       void to_string( std::string& str ) const;
 
-      const layer& get_layer() const;
-      layer& get_layer();
-
       void new_item( base_item& item ) const;
       static void init_exported_methods();
 
@@ -198,6 +206,9 @@ namespace bear
       /** \brief Tell if the kill() method has been called. */
       bool m_dying;
 
+      /** \brief The world in which the item is. */
+      world const* m_world;
+
       /** \brief Next item identifier. */
       static id_type s_next_id;
 
