@@ -2,7 +2,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -82,7 +82,7 @@ void bear::engine::base_item::print_allocated()
  */
 bear::engine::base_item::base_item()
   : m_id( s_next_id ), m_layer(NULL), m_z_position(0),
-    m_flags(item_flag_z_fixed), m_dying(false)
+    m_flags(item_flag_z_fixed), m_dying(false), m_world(NULL)
 {
   ++s_next_id;
 #ifndef NDEBUG
@@ -125,6 +125,19 @@ bear::engine::base_item* bear::engine::base_item::clone() const
   return new base_item(*this);
 } // base_item::clone()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Build the item if it has never been built.
+ */
+void bear::engine::base_item::build_item()
+{
+  if ( (m_flags & item_flag_built) == item_flag_none )
+    {
+      m_flags |= item_flag_built;
+      build();
+    }
+} // base_item::build_item()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Pre-cache the resources you need. This method is called automatically
@@ -558,7 +571,7 @@ const char* bear::engine::base_item::get_class_name() const
 void bear::engine::base_item::kill()
 {
   claw::logger << claw::log_verbose
-               << "Killing id #" << m_id << ' ' << this << std::endl;
+               << "Killing id #" << m_id << ' ' << *this << std::endl;
 
   CLAW_PRECOND( m_layer != NULL );
   CLAW_PRECOND( !get_insert_as_static() );
@@ -568,6 +581,7 @@ void bear::engine::base_item::kill()
       m_dying = true;
       destroy();
       m_layer->remove_item(*this);
+      m_world = NULL;
     }
 } // base_item::kill()
 
@@ -580,6 +594,20 @@ bool bear::engine::base_item::is_dead() const
   return m_dying;
 } // base_item::is_dead()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove the data about the environment of the item.
+ * \post m_layer == NULL
+ *
+ * This method is called automatically when the item is removed from a layer.
+ */
+void bear::engine::base_item::clear_environment()
+{
+  clear_level();
+
+  m_layer = NULL;
+} // base_item::clear_environment()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell the environment in which the item is.
@@ -597,6 +625,17 @@ void bear::engine::base_item::set_environment( layer& the_layer )
   m_layer = &the_layer;
 } // base_item::set_environment()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the item is in a given layer.
+ * \param the_layer The layer where the item could be.
+ */
+bool bear::engine::base_item::is_in_layer
+( const bear::engine::layer& the_layer ) const
+{
+  return m_layer == &the_layer;
+} // base_item::is_in_layer()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set the position of the item on the Z axis.
@@ -657,6 +696,47 @@ bool bear::engine::base_item::get_insert_as_static() const
   return m_flags & item_flag_insert_as_static;
 } // base_item::get_insert_as_static()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if this item is in a world.
+ */
+bool bear::engine::base_item::has_world() const
+{
+  return m_world != NULL;
+} // base_item::has_world()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the world in which this item is.
+ */
+const bear::engine::world& bear::engine::base_item::get_world() const
+{
+  CLAW_PRECOND( has_world() );
+  return *m_world;
+} // base_item::get_world()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set the world in which this item is.
+ * \param w The world.
+ */
+void bear::engine::base_item::set_world( const world& w )
+{
+  m_world = &w;
+} // base_item::set_world()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the layer in which the item is.
+ * \pre m_layer != NULL
+ */
+bear::engine::layer& bear::engine::base_item::get_layer() const
+{
+  CLAW_PRECOND( m_layer != NULL );
+
+  return *m_layer;
+} // base_item::get_layer()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell that this item is always displayed.
@@ -701,30 +781,6 @@ void bear::engine::base_item::to_string( std::string& str ) const
   str = oss.str() + str;
 } // base_item::to_string()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get the layer in which the item is.
- * \pre m_layer != NULL
- */
-const bear::engine::layer& bear::engine::base_item::get_layer() const
-{
-  CLAW_PRECOND( m_layer != NULL );
-
-  return *m_layer;
-} // base_item::get_layer()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get the layer in which the item is.
- * \pre m_layer != NULL
- */
-bear::engine::layer& bear::engine::base_item::get_layer()
-{
-  CLAW_PRECOND( m_layer != NULL );
-
-  return *m_layer;
-} // base_item::get_layer()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add an item in the same environment of \a this.
@@ -743,6 +799,12 @@ void bear::engine::base_item::new_item( base_item& item ) const
  */
 void bear::engine::base_item::init_exported_methods()
 {
+  TEXT_INTERFACE_CONNECT_METHOD_1
+    ( base_item, set_z_position, void, int );
+
+  TEXT_INTERFACE_CONNECT_METHOD_0
+    ( base_item, kill, void );
+
   TEXT_INTERFACE_CONNECT_PARENT_METHOD_0
     ( base_item, universe::physical_item_state,
       remove_position_constraint_x, void );
@@ -759,13 +821,60 @@ void bear::engine::base_item::init_exported_methods()
     ( base_item, universe::physical_item_state,
       add_position_constraint_y, void );
 
-  TEXT_INTERFACE_CONNECT_METHOD_1
-    ( base_item, set_z_position, void, int );
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
+    ( base_item, universe::physical_item_state,
+      set_speed, void, double, double );
 
   TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
     ( base_item, universe::physical_item_state,
       set_center_of_mass, void,
       const universe::coordinate_type&, const universe::coordinate_type& );
+
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
+    ( base_item, universe::physical_item_state,
+      set_top_left, void,
+      const universe::coordinate_type&, const universe::coordinate_type& );
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
+    ( base_item, universe::physical_item_state,
+      set_top_middle, void,
+      const universe::coordinate_type&, const universe::coordinate_type& );
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
+    ( base_item, universe::physical_item_state,
+      set_top_right, void,
+      const universe::coordinate_type&, const universe::coordinate_type& );
+
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
+    ( base_item, universe::physical_item_state,
+      set_bottom_left, void,
+      const universe::coordinate_type&, const universe::coordinate_type& );
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
+    ( base_item, universe::physical_item_state,
+      set_bottom_middle, void,
+      const universe::coordinate_type&, const universe::coordinate_type& );
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
+    ( base_item, universe::physical_item_state,
+      set_bottom_right, void,
+      const universe::coordinate_type&, const universe::coordinate_type& );
+
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
+    ( base_item, universe::physical_item_state,
+      set_left_middle, void,
+      const universe::coordinate_type&, const universe::coordinate_type& );
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_2
+    ( base_item, universe::physical_item_state,
+      set_right_middle, void,
+      const universe::coordinate_type&, const universe::coordinate_type& );
+
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_1
+    ( base_item, universe::physical_item_state,
+      set_horizontal_middle, void, universe::coordinate_type );
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_1
+    ( base_item, universe::physical_item_state,
+      set_vertical_middle, void, universe::coordinate_type );
+
+  TEXT_INTERFACE_CONNECT_PARENT_METHOD_1
+    ( base_item, universe::physical_item_state, set_center_on, void,
+      const universe::physical_item_state& );
 } // god::init_exported_methods()
 
 /*----------------------------------------------------------------------------*/
@@ -799,4 +908,3 @@ void bear::engine::base_item::time_step( universe::time_type elapsed_time )
 
 /*----------------------------------------------------------------------------*/
 TEXT_INTERFACE_IMPLEMENT_METHOD_LIST( bear::engine::base_item )
-
