@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -32,6 +32,8 @@
 
 #include <claw/exception.hpp>
 
+#include <limits>
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
@@ -52,45 +54,56 @@ bear::engine::bitmap_font_loader::bitmap_font_loader
 bear::visual::font bear::engine::bitmap_font_loader::run()
 {
   visual::bitmap_font::symbol_table cs;
-  bool valid = false;
-  unsigned int n;
+  unsigned int n = 0;
+  cs.size.x = 0;
+  cs.size.y = 0;
 
-  if ( m_file >> cs.size.x >> cs.size.y >> n )
-    if ( n > 0 )
-      {
-        std::string image_name;
+  std::istringstream parser(get_next_line());
 
-        cs.font_images.reserve(n);
+  parser >> cs.size.x >> cs.size.y;
 
-        for (unsigned int i=0; i!=n; ++i)
-          if ( m_file >> image_name )
-            cs.font_images.push_back( m_level_globals.get_image(image_name) );
+  parser.clear();
+  parser.str( get_next_line() );
 
-        if ( cs.font_images.size() == n )
-          {
-            int x, y;
-            unsigned int i;
-            char c;
+  if( parser >> n )
+    cs.font_images.reserve(n);
 
-            valid = true;
+  for ( std::size_t i=0; i!=n; ++i )
+    cs.font_images.push_back( m_level_globals.get_image(get_next_line()) );
 
-            do
-              {
-                m_file.ignore(1, '\n');
+  std::string line = get_next_line();
+  while ( !line.empty() )
+    {
+      unsigned int x, y;
+      std::size_t i;
+      char c;
+      parser.clear();
+      parser.str(line);
 
-                if ( m_file.get(c) >> x >> y >> i )
-                  if ( i < n )
-                    {
-                      cs.characters[c].image_index = i;
-                      cs.characters[c].position.set(x, y);
-                    }
-              }
-            while ( m_file );
-          }
-      }
+      if ( (parser.get(c) >> x >> y >> i) && (i < n) )
+        {
+          cs.characters[c].image_index = i;
+          cs.characters[c].position.set(x, y);
+        }
 
-  if (valid)
+      line = get_next_line();
+    }
+
+  if ((cs.font_images.size() == n) && m_file.eof())
     return new visual::bitmap_font(cs);
   else
-    throw CLAW_EXCEPTION( "Bad font" );
+    throw claw::exception( "Bad font" );
 } // bitmap_font_loader::run()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * Get the next non empty line from the file, if any.
+ */
+std::string bear::engine::bitmap_font_loader::get_next_line() const
+{
+  std::string result;
+
+  while ( result.empty() && getline(m_file, result) );
+
+  return result;
+} // bitmap_font_loader::get_next_line()
