@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -41,19 +41,25 @@
 #include "engine/resource_pool.hpp"
 #include "engine/version.hpp"
 #include "engine/variable/base_variable.hpp"
+#include "engine/variable/variable_eraser.hpp"
+#include "engine/variable/variable_copy.hpp"
 
 #include "bear_gettext.hpp"
 
 #include "debug/timing_log.hpp"
 
 #include <boost/filesystem/convenience.hpp>
+#include <boost/uuid/uuid.hpp>
+#include <boost/uuid/uuid_generators.hpp>
+#include <boost/uuid/uuid_io.hpp>
+
 #include <claw/exception.hpp>
 #include <claw/logger.hpp>
+#include <claw/socket_traits.hpp>
 #include <claw/string_algorithm.hpp>
 #include <claw/system_info.hpp>
 #include <sstream>
 
-
 /*----------------------------------------------------------------------------*/
 const std::string
 bear::engine::game_local_client::s_init_game_function_prefix("init_");
@@ -120,6 +126,7 @@ void bear::engine::game_local_client::run()
 {
   if ( m_status != status_quit )
     {
+      init_stats();
       init_game();
 
       load_level( m_game_description.start_level() );
@@ -129,6 +136,8 @@ void bear::engine::game_local_client::run()
       end_game();
 
       clear();
+      m_stats.send();
+
       close_environment();
     }
 } // game_local_client::run()
@@ -367,7 +376,7 @@ std::string bear::engine::game_local_client::get_custom_game_file
     result = name;
 
   return result;
-} // game_local_client::get_full_user_path()
+} // game_local_client::get_custom_game_file()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -380,6 +389,19 @@ bear::engine::game_local_client::get_game_variable( base_variable& val ) const
   val.get_value_from(m_game_variables);
 } // game_local_client::get_game_variable()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the game variables whose name match a given regular
+ *        expression;
+ * \param vars The list of matched game variables.
+ * \param pattern The expression that has to be matched by the variable names.
+ */
+void bear::engine::game_local_client::get_game_variables
+( var_map& vars, const std::string& pattern )
+{
+  m_game_variables.for_each( variable_copy(vars, boost::regex(pattern)) );
+} // game_local_client::get_game_variables()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set the value of a global variable.
@@ -391,6 +413,28 @@ void bear::engine::game_local_client::set_game_variable
   val.assign_value_to(m_game_variables);
 } // game_local_client::set_game_variable()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set several game variables at once.
+ * \param vars The variables.
+ */
+void bear::engine::game_local_client::set_game_variables( const var_map& vars )
+{
+  m_game_variables.set(vars);
+} // game_local_client::set_game_variables()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Erase the variables whose name match a given pattern.
+ * \param pattern The pattern to match.
+ */
+void bear::engine::game_local_client::erase_game_variables
+( const std::string& pattern )
+{
+  m_game_variables.for_each
+    ( variable_eraser( m_game_variables, boost::regex(pattern) ) );
+} // game_local_client::erase_game_variables()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell if a given variable exists in the game.
@@ -402,6 +446,83 @@ bool bear::engine::game_local_client::game_variable_exists
   return val.exists(m_game_variables);
 } // game_local_client::game_variable_exists()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get all the game variables.
+ * \param vars (in/out) All the variables.
+ */
+void
+bear::engine::game_local_client::get_all_game_variables( var_map& vars ) const
+{
+  vars = m_game_variables;
+} // game_local_client::get_all_game_variables()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add a listener to follow the change on a game variable of type int.
+ * \param name The name of the variable.
+ * \param f The listener.
+ */
+boost::signals::connection
+bear::engine::game_local_client::listen_int_variable_change
+( const std::string& name, const boost::function<void (int)>& f )
+{
+  return listen_variable_change<int>( name, f );
+} // game_local_client::listen_int_variable_change()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add a listener to follow the change on a game variable of type
+ *        unsigned int.
+ * \param name The name of the variable.
+ * \param f The listener.
+ */
+boost::signals::connection
+bear::engine::game_local_client::listen_uint_variable_change
+( const std::string& name, const boost::function<void (unsigned int)>& f )
+{
+  return listen_variable_change<unsigned int>( name, f );
+} // game_local_client::listen_uint_variable_change()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add a listener to follow the change on a game variable of type bool.
+ * \param name The name of the variable.
+ * \param f The listener.
+ */
+boost::signals::connection
+bear::engine::game_local_client::listen_bool_variable_change
+( const std::string& name, const boost::function<void (bool)>& f )
+{
+  return listen_variable_change<bool>( name, f );
+} // game_local_client::listen_bool_variable_change()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add a listener to follow the change on a game variable of type double.
+ * \param name The name of the variable.
+ * \param f The listener.
+ */
+boost::signals::connection
+bear::engine::game_local_client::listen_double_variable_change
+( const std::string& name, const boost::function<void (double)>& f )
+{
+  return listen_variable_change<double>( name, f );
+} // game_local_client::listen_double_variable_change()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add a listener to follow the change on a game variable of type string.
+ * \param name The name of the variable.
+ * \param f The listener.
+ */
+boost::signals::connection
+bear::engine::game_local_client::listen_string_variable_change
+( const std::string& name, const boost::function<void (std::string)>& f )
+{
+  return listen_variable_change<std::string>( name, f );
+} // game_local_client::listen_string_variable_change()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the name of the game.
@@ -411,6 +532,30 @@ const std::string& bear::engine::game_local_client::get_name() const
   return m_game_description.game_name();
 } // game_local_client::get_name()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Initialize the game statistics.
+ */
+void bear::engine::game_local_client::init_stats()
+{
+  std::string file_name( get_custom_game_file( "engine-stats" ) );
+  std::ifstream f(file_name.c_str());
+  boost::uuids::uuid id;
+
+  if ( !f )
+    {
+      id = boost::uuids::random_generator()();
+      std::ofstream of( file_name.c_str() );
+      of << id;
+    }
+  else
+    f >> id;
+
+  std::ostringstream oss;
+  oss << id;
+  m_stats.set_user_id( oss.str() );
+} // game_local_client::init_stats()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Call the game specific function for initialisation.
@@ -626,6 +771,10 @@ void bear::engine::game_local_client::init_environment() const
                << std::endl;
 
   audio::sound_manager::initialize();
+
+  if ( !claw::socket_traits::init() )
+    claw::logger << claw::log_error << "Failed to initialize the network."
+		 << std::endl;
 } // game_local_client::init_environment()
 
 /*----------------------------------------------------------------------------*/
@@ -648,6 +797,8 @@ void bear::engine::game_local_client::close_environment() const
                << std::endl;
 
   audio::sound_manager::release();
+
+  claw::socket_traits::release();
 } // game_local_client::close_environment()
 
 /*----------------------------------------------------------------------------*/
@@ -732,6 +883,24 @@ void bear::engine::game_local_client::set_current_level( level* the_level )
  */
 void bear::engine::game_local_client::load_level( const std::string& path )
 {
+#ifdef _WIN32
+  // This, combined with the level dummy.cl, is a unexplained solution to the
+  // OpenGL problem we have otherwise (ie. the game starts with invalid
+  // textures).
+
+  // The function is called for dummy.cl, then gamned.cl, then the title screen.
+  // Thus we force the call to screen::fullscreen() at the title screen.
+
+  static int resize = 0;
+
+  if ( resize <= 2 )
+    {
+      ++resize;
+
+      if ( resize == 3 )
+	m_screen->fullscreen( m_fullscreen );
+    }   
+#endif
   claw::logger << claw::log_verbose << "------------ Loading level '"
                << path << "'... ------------" << std::endl;
 
@@ -744,7 +913,7 @@ void bear::engine::game_local_client::load_level( const std::string& path )
   /// \todo test the file to see if it's text or binary
   compiled_file level_file( f, true );
 
-  level_loader loader(level_file);
+  level_loader loader(level_file, path);
   loader.complete_run();
 
   set_current_level( loader.drop_level() );
@@ -805,6 +974,10 @@ void bear::engine::game_local_client::do_pop_level()
   m_level_in_abeyance = NULL;
 
   m_current_level->unset_pause();
+  set_music_muted(get_music_muted());
+  set_sound_muted(get_sound_muted());
+  set_music_volume(get_music_volume());
+  set_sound_volume(get_sound_volume());
 } // game_local_client::do_pop_level()
 
 /*----------------------------------------------------------------------------*/
@@ -874,6 +1047,8 @@ bool bear::engine::game_local_client::check_arguments( int& argc, char** &argv )
   if ( arg.has_value("--game-name") )
     m_game_description.set_game_name( arg.get_string("--game-name") );
 
+  m_stats.set_destination( arg.get_string("--stats-destination") );
+
   if ( arg.has_value("--active-area") )
     {
       if ( arg.only_integer_values("--active-area") )
@@ -945,7 +1120,7 @@ bool bear::engine::game_local_client::check_arguments( int& argc, char** &argv )
   if ( !help.empty() )
     {
       std::cout << bear_gettext("Bad argument value: '") << help
-        	<< bear_gettext("'\n");
+                << bear_gettext("'\n");
       arg.help();
     }
   else if ( !auto_exit )
@@ -1001,6 +1176,20 @@ bool bear::engine::game_local_client::set_game_variable_from_arg
   return result;
 } // game_local_client::set_game_variable_from_arg()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add a listener on the changes of a game variable.
+ * \param name The name of the variable to listen.
+ * \param f The function to call when the value of the variable change.
+ */
+template<typename T>
+boost::signals::connection
+bear::engine::game_local_client::listen_variable_change
+( const std::string& name, boost::function<void (T)> f )
+{
+  return m_game_variables.variable_changed<T>(name).connect(f);
+} // game_local_client::listen_variable_change()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the arguments table with the arguments of the engine.
@@ -1063,6 +1252,11 @@ claw::arguments_table bear::engine::game_local_client::get_arguments_table()
       ("Change the delimiter used in --set-game-var-<type> to separate the name"
        " and the value of the variable."), true,
       bear_gettext("character") );
+  arg.add_long
+    ( "--stats-destination",
+      bear_gettext
+      ("Set the value of the destination to which game statistics are sent."),
+      true );
   arg.add
     ( "-v", "--version",
       bear_gettext("Print the version of the engine and exit."),
