@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,12 +28,16 @@
  */
 #include "engine/item_factory.hpp"
 
+/*----------------------------------------------------------------------------*/
+bear::engine::item_factory::factory_type
+bear::engine::item_factory::s_factory_instance;
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the single instance of the factory.
  */
-bear::engine::item_factory::super&
+bear::engine::item_factory::factory_type&
 bear::engine::item_factory::get_instance()
 {
-  return super::get_instance();
+  return s_factory_instance;
 } // item_factory::get_instance()
