@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -41,15 +41,16 @@
 /**
  * \brief Constructor.
  * \param name The name of the level.
+ * \param filename The filename of the level.
  * \param level_size The size of the level.
  * \param level_music The default music of the level.
  */
 bear::engine::level::level
-( const std::string& name, const universe::size_box_type& level_size,
-  const std::string& level_music )
-  : m_name(name), m_camera(NULL), m_level_size(level_size),
-    m_level_globals(new level_globals), m_music(level_music), m_music_id(0),
-    m_paused(0)
+( const std::string& name, const std::string& filename,
+  const universe::size_box_type& level_size, const std::string& level_music )
+  : m_name(name),  m_filename(filename), m_camera(NULL),
+    m_level_size(level_size), m_level_globals(new level_globals),
+    m_music(level_music), m_music_id(0), m_paused(0)
 {
   set_pause();
 
@@ -225,6 +226,15 @@ const std::string& bear::engine::level::get_name() const
   return m_name;
 } // level::get_name()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the filename of the level.
+ */
+const std::string& bear::engine::level::get_filename() const
+{
+  return m_filename;
+} // level::get_filename()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the globals resources of the level.
@@ -297,6 +307,7 @@ void bear::engine::level::push_layer( gui_layer* the_layer )
   m_gui.push_layer(the_layer);
 
   the_layer->set_level(*this);
+  the_layer->pre_cache();
   the_layer->build();
 } // level::set_gui_layer()
 
@@ -451,7 +462,7 @@ void bear::engine::level::render_layers( visual::screen& screen ) const
     {
       // get four times the area covered by the camera
       region_type r;
-      add_region( r, get_camera_focus(), get_camera_size() );
+      add_region( r, get_camera_focus(), get_camera_size() / 2 );
 
       universe::rectangle_type active( r.front() );
       std::list<scene_visual> visuals;
@@ -608,7 +619,6 @@ bear::engine::level::get_active_regions( region_type& active_regions )
       }
     else
       {
-        universe::position_type region = it->first->get_center_of_mass();
         add_region
           ( active_regions, it->first->get_bounding_box(), it->second );
         ++it;
