@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -379,10 +379,11 @@ std::size_t bear::engine::level_globals::play_music
 /**
  * \brief Stop the music.
  * \param id The identifier of the music.
+ * \param fadeout The duration of the fadeout, if any.
  */
-void bear::engine::level_globals::stop_music( std::size_t id )
+void bear::engine::level_globals::stop_music( std::size_t id, double fadeout )
 {
-  m_sound_manager.stop_music(id);
+  m_sound_manager.stop_music(id, fadeout);
 } // level_globals::stop_music()
 
 /*----------------------------------------------------------------------------*/
