@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -48,32 +48,33 @@
 /**
  * \brief Constructor.
  * \param f The file from which we load the level.
+ * \param path The path of the level to load.
  */
-bear::engine::level_loader::level_loader( compiled_file& f )
+bear::engine::level_loader::level_loader
+( compiled_file& f, const std::string& path )
   : m_level(NULL), m_layer(NULL), m_file(f), m_current_item(NULL),
     m_items_count(0), m_item_index(0)
 {
   unsigned int maj(0), min(0), rel(0);
 
-  m_file >> maj >> min >> rel;
+  if ( !(m_file >> maj >> min >> rel) )
+    throw claw::exception( "Can't read the version of the level file." );
 
   if ( (maj != 0) || (min <= 4) )
-    throw CLAW_EXCEPTION( "This version of the level file is not supported." );
-  else
-    {
-      unsigned int layers_count;
-      std::string level_music;
-      universe::size_box_type level_size;
-      std::string name("Anonymous");
+    throw claw::exception( "This version of the level file is not supported." );
 
-      if ( (maj == 0) && (min >= 5) )
-        m_file >> name;
+  unsigned int layers_count;
+  std::string level_music;
+  universe::size_box_type level_size;
+  std::string name("Anonymous");
 
-      m_file >> level_size.x >> level_size.y >> level_music >> m_items_count
-             >> layers_count >> m_next_code;
+  if ( (maj == 0) && (min >= 5) )
+    m_file >> name;
 
-      m_level = new level(name, level_size, level_music);
-    }
+  m_file >> level_size.x >> level_size.y >> level_music >> m_items_count
+         >> layers_count >> m_next_code;
+
+  m_level = new level(name, path, level_size, level_music);
 } // level_loader::level_loader()
 
 /*----------------------------------------------------------------------------*/
@@ -354,6 +355,7 @@ void bear::engine::level_loader::load_item_field_int()
 
   if ( !m_current_item->set_integer_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_int()
 
@@ -369,6 +371,7 @@ void bear::engine::level_loader::load_item_field_u_int()
 
   if ( !m_current_item->set_u_integer_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_u_int()
 
@@ -384,6 +387,7 @@ void bear::engine::level_loader::load_item_field_real()
 
   if ( !m_current_item->set_real_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_real()
 
@@ -399,6 +403,7 @@ void bear::engine::level_loader::load_item_field_bool()
 
   if ( !m_current_item->set_bool_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_bool()
 
@@ -416,6 +421,7 @@ void bear::engine::level_loader::load_item_field_string()
 
   if ( !m_current_item->set_string_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_string()
 
@@ -436,6 +442,7 @@ void bear::engine::level_loader::load_item_field_sprite()
 
   if ( !m_current_item->set_sprite_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_sprite()
 
@@ -455,6 +462,7 @@ void bear::engine::level_loader::load_item_field_animation()
 
   if ( !m_current_item->set_animation_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_animation()
 
@@ -470,6 +478,7 @@ void bear::engine::level_loader::load_item_field_item()
   m_file >> field_name >> index >> m_next_code;
   if ( !m_current_item->set_item_field( field_name, m_referenced[index] ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_item()
 
@@ -487,6 +496,7 @@ void bear::engine::level_loader::load_item_field_sample()
 
   if ( !m_current_item->set_sample_field( field_name, s ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_sample()
 
@@ -501,6 +511,7 @@ void bear::engine::level_loader::load_item_field_int_list()
 
   if ( !m_current_item->set_integer_list_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_int_list()
 
@@ -515,6 +526,7 @@ void bear::engine::level_loader::load_item_field_u_int_list()
 
   if ( !m_current_item->set_u_integer_list_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_u_int_list()
 
@@ -529,6 +541,7 @@ void bear::engine::level_loader::load_item_field_real_list()
 
   if ( !m_current_item->set_real_list_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_real_list()
 
@@ -543,6 +556,7 @@ void bear::engine::level_loader::load_item_field_bool_list()
 
   if ( !m_current_item->set_bool_list_field( field_name, val ) )
     claw::logger << claw::log_warning << "field '" << field_name
+                 << "' of item '" << m_current_item->get_class_name()
                  << "' has not been set." << std::endl;
 } // level_loader::load_item_field_bool_list()
 
@@ -742,34 +756,9 @@ bear::engine::layer* bear::engine::level_loader::create_layer_from_string
 void bear::engine::level_loader::escape( std::string& str ) const
 {
   std::string result;
-  unsigned int ref = 0;
-  unsigned int prev = 0;
-  unsigned int current = 1;
-
-  while ( current < str.size() )
-    if ( str[prev] == '\\' )
-      {
-        switch( str[current] )
-          {
-          case 'n' : result += str.substr(ref, prev - ref) + '\n'; break;
-          case 't' : result += str.substr(ref, prev - ref) + '\t'; break;
-          case '\\' : result += str.substr(ref, prev - ref) + '\\'; break;
-          default : result += str.substr(ref, current - ref + 1);
-          }
-        ref = current + 1;
-        prev = ref;
-        current = prev + 1;
-      }
-    else
-      {
-        ++prev;
-        ++current;
-      }
-
-  if ( ref < str.size() )
-    result += str.substr(ref);
-
-  str = result;
+  result.reserve(str.size());
+  claw::text::c_escape( str.begin(), str.end(), std::back_inserter(result) );
+  str.swap(result);
 } // level_loader::escape()
 
 /*----------------------------------------------------------------------------*/
