@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -55,6 +55,25 @@ bear::engine::level_object::level_object( const level_object& that )
   // just ignore
 } // level_object::level_object()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Destructor.
+ */
+bear::engine::level_object::~level_object()
+{
+  // do nothing
+} // level_object::~level_object()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove the data related to the level containing the object.
+ * \post m_level == NULL
+ */
+void bear::engine::level_object::clear_level()
+{
+  m_level = NULL;
+} // level_object::clear_level()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell the level in which this object is.
@@ -66,7 +85,7 @@ void bear::engine::level_object::set_level( level& the_level )
   CLAW_PRECOND( (m_level == NULL) || (m_level == &the_level) );
 
   m_level = &the_level;
-} // level_object::set_level)
+} // level_object::set_level()
 
 /*----------------------------------------------------------------------------*/
 /**
