@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -34,6 +34,8 @@
 #include "engine/model/model_snapshot.hpp"
 #include "universe/types.hpp"
 
+#include "easing.hpp"
+
 #include <claw/assert.hpp>
 #include <claw/exception.hpp>
 
@@ -64,7 +66,7 @@ bear::engine::model_actor* bear::engine::model_loader::run()
 
   if ( !m_file )
     throw claw::exception("Can't read the version of the model file.");
-  else if ( (maj != 0) || (min <= 4) )
+  else if ( (maj != 0) || (min < 6) )
     throw claw::exception("This version of the model file is not supported.");
   else
     {
@@ -139,6 +141,8 @@ bear::engine::model_loader::load_sound( std::string& sound_name, bool& glob )
   if ( !(m_file >> sound_name >> glob) )
     claw::logger << claw::log_error << "Invalid sound description."
                  << std::endl;
+  else if ( !sound_name.empty() )
+    m_level_globals.load_sound(sound_name);
 } // model_loader::load_sound()
 
 /*----------------------------------------------------------------------------*/
@@ -200,13 +204,13 @@ void bear::engine::model_loader::load_snapshot( model_action& a )
   universe::coordinate_type x_align_value, y_align_value;
   universe::size_type width, height;
 
-  if ( m_file >> date >> func  >> width >> height >> x_align
+  if ( m_file >> date >> func >> width >> height >> x_align
        >> y_align >> x_align_value >> y_align_value )
     {
       bool glob;
       load_sound(sound_name, glob);
 
-      model_snapshot s(a.get_marks_count(), func, sound_name, glob);
+      model_snapshot s(date, a.get_marks_count(), func, sound_name, glob);
       s.set_size(width, height);
       s.set_x_alignment
         (model_snapshot::horizontal_alignment::from_string(x_align));
@@ -216,7 +220,7 @@ void bear::engine::model_loader::load_snapshot( model_action& a )
       s.set_y_alignment_value(y_align_value);
 
       load_mark_placements(s);
-      a.add_snapshot(date, s);
+      a.add_snapshot(s);
     }
   else
     claw::logger << claw::log_error << "The snapshot is incomplete."
@@ -242,14 +246,39 @@ void bear::engine::model_loader::load_mark_placements( model_snapshot& s )
 void bear::engine::model_loader::load_mark_placement( model_snapshot& s )
 {
   unsigned int id;
-  universe::coordinate_type x, y;
+  universe::coordinate_type x, y, w, h;
   int z;
   double angle;
   bool visible;
+  std::string collision_function;
 
-  if ( m_file >> id >> x >> y >> z >> angle >> visible )
+  bear::easing::function::function_type
+    x_func, y_func, width_func, height_func, angle_func;
+  bear::easing::direction::direction_type
+    x_dir, y_dir, width_dir, height_dir, angle_dir;
+
+  if ( m_file >> id >> x >> x_func >> x_dir
+       >> y >> y_func >> y_dir
+       >> w >> width_func >> width_dir
+       >> h >> height_func >> height_dir
+       >> z
+       >> angle >> angle_func >> angle_dir
+       >> visible >> collision_function )
     {
-      model_mark_placement m(id, x, y, z, angle, visible);
+      model_mark_placement m
+        (id, x, y, w, h, z, angle, visible, collision_function);
+
+      m.set_x_position_easing
+        ( easing(x_func, x_dir).to_claw_easing_function() );
+      m.set_y_position_easing
+        ( easing(y_func, y_dir).to_claw_easing_function() );
+      m.set_width_easing
+        ( easing(width_func, width_dir).to_claw_easing_function() );
+      m.set_height_easing
+        ( easing(height_func, height_dir).to_claw_easing_function() );
+      m.set_angle_easing
+        ( easing(angle_func, angle_dir).to_claw_easing_function() );
+
       s.set_mark_placement(m);
     }
   else
