@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -48,7 +48,12 @@ bear::engine::population::~population()
 void bear::engine::population::insert( base_item* item )
 {
   CLAW_PRECOND( item != NULL );
-  CLAW_PRECOND( !exists( item->get_id() ) );
+  CLAW_PRECOND( !exists( item->get_id() )
+                || ( m_dropped_items.find(item->get_id())
+                    != m_dropped_items.end() ) );
+
+  if ( m_dropped_items.find(item->get_id()) != m_dropped_items.end() )
+    m_dropped_items.erase(item->get_id());
 
   m_items[ item->get_id() ] = item;
 } // population::insert()
@@ -62,14 +67,23 @@ void bear::engine::population::kill( const base_item* item )
 {
   CLAW_PRECOND( item != NULL );
 
-  if ( !exists(item->get_id()) )
-    claw::logger << claw::log_warning << "Killing unknown item #"
-                 << item->get_id() << ": '" << item->get_class_name() << "'."
-                 << std::endl;
-
   m_dead_items.insert( item->get_id() );
+  m_dropped_items.erase( item->get_id() );
 } // population::kill()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Drop an item.
+ * \param item The item to drop.
+ */
+void bear::engine::population::drop( const base_item* item )
+{
+  CLAW_PRECOND( item != NULL );
+
+  if ( m_dead_items.find( item->get_id() ) == m_dead_items.end() )
+    m_dropped_items.insert( item->get_id() );
+} // population::drop()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell if an item exists.
@@ -96,6 +110,11 @@ void bear::engine::population::remove_dead_items()
       }
 
   m_dead_items.clear();
+
+  for ( it=m_dropped_items.begin(); it!=m_dropped_items.end(); ++it )
+    m_items.erase(*it);
+
+  m_dropped_items.clear();
 } // population::remove_dead_items()
 
 /*----------------------------------------------------------------------------*/
@@ -113,3 +132,21 @@ void bear::engine::population::clear()
 
   m_items.clear();
 } // population::clear()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get an iterator on the beginning of the items.
+ */
+bear::engine::population::const_iterator bear::engine::population::begin() const
+{
+  return m_items.begin();
+} // population::begin()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get an iterator on the end of the items.
+ */
+bear::engine::population::const_iterator bear::engine::population::end() const
+{
+  return m_items.end();
+} // population::end()
