@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -72,7 +72,7 @@ void bear::engine::resource_pool::get_file
       f.close();
     }
   else
-    throw CLAW_EXCEPTION( "Can't find file '" + name + "'" );
+    throw claw::exception( "Can't find file '" + name + "'" );
 
 } // resource_pool::get_file()
 
