@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -71,7 +71,7 @@ bear::visual::animation bear::engine::sprite_loader::load_animation
   f >> maj >> min >> rel;
 
   if ( (maj != 0) || (min <= 4) )
-    throw CLAW_EXCEPTION
+    throw claw::exception
       ( "This version of the animation file is not supported." );
   else
     return load_animation_v0_5(f, glob);
@@ -106,7 +106,7 @@ bear::visual::animation bear::engine::sprite_loader::load_any_animation
   else if ( content_type == "content_animation" )
     result = load_animation_data(f, glob);
   else
-    throw CLAW_EXCEPTION
+    throw claw::exception
       ( "Unknown animation content type: '" + content_type + "'." );
 
   return result;
