@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -107,7 +107,7 @@ bear::engine::world::~world()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Call the "start()" method on all items.
+ * \brief Initialize the world.
  */
 void bear::engine::world::start()
 {
@@ -126,6 +126,7 @@ void bear::engine::world::progress_entities
 {
   universe::world::progress_entities(regions, elapsed_time);
   m_population.remove_dead_items();
+  //print_item_stats();
 } // world::progress_entities()
 
 /*----------------------------------------------------------------------------*/
@@ -157,19 +158,42 @@ void bear::engine::world::get_visual
     }
 } // world::get_visual()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get an iterator on the beginning of the living items.
+ */
+bear::engine::world::const_item_iterator
+bear::engine::world::living_items_begin() const
+{
+  return m_population.begin();
+} // world::living_items_begin()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get an iterator on the end of the living items.
+ */
+bear::engine::world::const_item_iterator
+bear::engine::world::living_items_end() const
+{
+  return m_population.end();
+} // world::living_items_end()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add a permanent and fixed item in the world.
+ * \param who The item to add.
  */
 void bear::engine::world::add_static( base_item* const& who )
 {
-  universe::world::add_static(who);
+  who->set_world(*this);
+  universe::world::add_static( who );
   m_static_items.push_front( who );
 } // world::add_static()
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add an item in the world.
+ * \param who The item to add.
  */
 void bear::engine::world::register_item( base_item* const& who )
 {
@@ -183,17 +207,58 @@ void bear::engine::world::register_item( base_item* const& who )
   m_population.insert( who );
 
   if ( !who->is_dead() )
-    universe::world::register_item(who);
+    {
+      who->set_world(*this);
+      universe::world::register_item(who);
+    }
   else
     m_population.kill( who );
 } // world::register_item()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Call universe::world::release_item(who)
+ * \brief Kill and remove an item from the world.
+ * \param who The item to kill.
  */
 void bear::engine::world::release_item( base_item* const& who )
 {
   m_population.kill(who);
   universe::world::release_item(who);
 } // world::release_item()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove an item from the world without killing him.
+ * \param who The item to remove.
+ */
+void bear::engine::world::drop_item( base_item* const& who )
+{
+  m_population.drop(who);
+  universe::world::release_item(who);
+} // world::drop_item()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Print some statistics about the living items in the console.
+ */
+void bear::engine::world::print_item_stats() const
+{
+  std::map<std::string, std::size_t> items;
+  for ( const_item_iterator it=living_items_begin(); it!=living_items_end();
+        ++it )
+    {
+      const std::string name(it->get_class_name());
+      std::map<std::string, std::size_t>::iterator c = items.find(name);
+      if ( c != items.end() )
+        ++c->second;
+      else
+        items[name] = 1;
+    }
+
+  for ( std::map<std::string, std::size_t>::const_iterator it=items.begin();
+        it!=items.end(); ++it )
+    std::cout << get_world_time() << '\t' << it->first << '\t' << it->second
+              << std::endl;
+
+  std::cout << "----------------------------------------" << std::endl;
+} // world::print_item_stats()
