@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,6 +29,7 @@
 #ifndef __ENGINE_GAME_HPP__
 #define __ENGINE_GAME_HPP__
 
+#include "engine/variable/var_map.hpp"
 #include "engine/class_export.hpp"
 
 #include "time/time.hpp"
@@ -36,6 +37,8 @@
 #include <claw/image.hpp>
 #include <claw/coordinate_2d.hpp>
 
+#include <boost/function.hpp>
+
 namespace bear
 {
   namespace engine
@@ -91,9 +94,34 @@ namespace bear
       std::string get_custom_game_file( const std::string& name ) const;
 
       void get_game_variable( base_variable& val ) const;
+      void get_game_variables
+      (var_map& vars, const std::string& pattern = ".*" );
       void set_game_variable( const base_variable& val );
+      void set_game_variables( const var_map& vars );
+      void erase_game_variables( const std::string& pattern );
       bool game_variable_exists( const base_variable& val ) const;
 
+      void save_game_variables
+        ( std::ostream& os, const std::string& pattern = ".*" );
+
+      boost::signals::connection
+        listen_int_variable_change
+        ( const std::string& name, const boost::function<void (int)>& f );
+      boost::signals::connection
+        listen_uint_variable_change
+        ( const std::string& name,
+          const boost::function<void (unsigned int)>& f );
+      boost::signals::connection
+        listen_bool_variable_change
+        ( const std::string& name, const boost::function<void (bool)>& f );
+      boost::signals::connection
+        listen_double_variable_change
+        ( const std::string& name, const boost::function<void (double)>& f );
+      boost::signals::connection
+        listen_string_variable_change
+        ( const std::string& name,
+          const boost::function<void (const std::string)>& f );
+
       const std::string& get_name() const;
 
     private:
