@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -42,8 +42,19 @@ bear::engine::with_rendering_attributes::get_rendering_attributes()
 /**
  * \brief Get the rendering attributes.
  */
-bear::visual::bitmap_rendering_attributes
+const bear::visual::bitmap_rendering_attributes&
 bear::engine::with_rendering_attributes::get_rendering_attributes() const
 {
   return m_rendering_attributes;
 } // with_rendering_attributes::get_rendering_attributes()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set the rendering attributes.
+ * \param attr The rendering attributes.
+ */
+void bear::engine::with_rendering_attributes::set_rendering_attributes
+( const visual::bitmap_rendering_attributes& attr )
+{
+  m_rendering_attributes = attr;
+} // with_rendering_attributes::set_rendering_attributes()
