@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,6 +29,7 @@
 #ifndef __ENGINE_ITEM_WITH_TOGGLE_HPP__
 #define __ENGINE_ITEM_WITH_TOGGLE_HPP__
 
+#include "audio/sample.hpp"
 #include "engine/item_brick/with_toggle.hpp"
 #include "universe/types.hpp"
 
@@ -59,14 +60,19 @@ namespace bear
 
     public:
       item_with_toggle();
+      item_with_toggle( const item_with_toggle<Base>& that );
+      ~item_with_toggle();
 
       bool set_real_field( const std::string& name, double value );
       bool set_bool_field( const std::string& name, bool value );
+      bool set_sample_field( const std::string& name, audio::sample* value );
 
       void build();
       void progress( universe::time_type elapsed_time );
 
       void set_delay( universe::time_type d );
+      void set_sample( audio::sample* s );
+      void set_fadeout( universe::time_type d );
 
       bool is_on() const;
       void toggle_on( base_item* activator );
@@ -82,6 +88,15 @@ namespace bear
       virtual void progress_on( universe::time_type elapsed_time );
       virtual void progress_off( universe::time_type elapsed_time );
 
+    private:
+      // not implemented
+      item_with_toggle<Base>& operator=( const item_with_toggle<Base>& that );
+
+    private:
+      void play_sound() const;
+      void stop_sound() const;
+      void progress_sound() const;
+
     private:
       /** \brief Tell if the item is turned on. */
       bool m_is_on;
@@ -92,6 +107,12 @@ namespace bear
       /** \brief Delay before turning the item off. */
       universe::time_type m_delay;
 
+      /** \brief Fade out the sample during this duration when stopping. */
+      universe::time_type m_fadeout;
+
+      /** \brief The sample played when the toggle is on. */
+      audio::sample* m_sample;
+
     }; // class item_with_toggle
   } // namespace engine
 } // namespace bear
