@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -45,7 +45,11 @@ namespace bear
     {
     public:
       visual::bitmap_rendering_attributes& get_rendering_attributes();
-      visual::bitmap_rendering_attributes get_rendering_attributes() const;
+      const visual::bitmap_rendering_attributes&
+        get_rendering_attributes() const;
+
+      void set_rendering_attributes
+        ( const visual::bitmap_rendering_attributes& attr );
 
     private:
       /** \brief Global rendering attributes of the item. */
