@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -40,6 +40,15 @@ bear::engine::gui_layer::gui_layer()
 
 } // gui_layer::gui_layer()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Load the media required by this class.
+ */
+void bear::engine::gui_layer::pre_cache()
+{
+  // nothing to do
+} // gui_layer::pre_cache()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Initialise the layer.
