@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -91,7 +91,7 @@ void bear::engine::layer::get_visual
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Add an item in the layer and call item.build().
+ * \brief Add an item in the layer and call item.build_item().
  * \param item The item to add.
  * \pre item.is_valid() && !item.is_fixed()
  */
@@ -105,7 +105,7 @@ void bear::engine::layer::add_item( base_item& item )
 
   item.set_environment(*this);
   item.pre_cache();
-  item.build();
+  item.build_item();
 
   if ( item.get_insert_as_static() )
     {
@@ -118,7 +118,7 @@ void bear::engine::layer::add_item( base_item& item )
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Remove an item from the layer.
+ * \brief Remove an item from the layer and delete it.
  * \param item The item to remove.
  */
 void bear::engine::layer::remove_item( base_item& item )
@@ -128,6 +128,19 @@ void bear::engine::layer::remove_item( base_item& item )
   do_remove_item(item);
 } // layer::remove_item()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove an item from the layer without deleting it.
+ * \param item The item to remove.
+ */
+void bear::engine::layer::drop_item( base_item& item )
+{
+  m_always_displayed.erase(&item);
+
+  do_drop_item(item);
+  item.clear_environment();
+} // layer::drop_item()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell that an item is always displayed.
@@ -197,6 +210,16 @@ void bear::engine::layer::do_remove_item( base_item& item )
   // nothing to do
 } // layer::do_remove_item()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Effectively drop an item from the layer.
+ * \param item The item to remove.
+ */
+void bear::engine::layer::do_drop_item( base_item& item )
+{
+  // nothing to do
+} // layer::do_drop_item()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the world.
