@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -74,6 +74,7 @@ namespace bear
 
       void add_item( base_item& item );
       void remove_item( base_item& item );
+      void drop_item( base_item& item );
 
       void set_always_displayed( base_item& item );
       void unset_always_displayed( base_item& item );
@@ -85,6 +86,7 @@ namespace bear
     private:
       virtual void do_add_item( base_item& item );
       virtual void do_remove_item( base_item& item );
+      virtual void do_drop_item( base_item& item );
 
       virtual void do_get_visual
       ( std::list<scene_visual>& visuals,
