@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -62,7 +62,8 @@ namespace bear
 
     public:
       level
-      ( const std::string& name, const universe::size_box_type& level_size,
+      ( const std::string& name, const std::string& filename,
+        const universe::size_box_type& level_size,
         const std::string& level_music );
       ~level();
 
@@ -79,6 +80,7 @@ namespace bear
       const universe::size_box_type& get_size() const;
       unsigned int get_depth() const;
       const std::string& get_name() const;
+      const std::string& get_filename() const;
       level_globals& get_globals();
 
       void set_camera( base_item& cam );
@@ -133,6 +135,9 @@ namespace bear
       /** \brief The name of the level. */
       const std::string m_name;
 
+      /** \brief The filename of the level. */
+      const std::string m_filename;
+
       /** \brief Visible/active part of the level. */
       universe::item_handle m_camera;
 
