@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -72,7 +72,7 @@ namespace bear
       audio::sample* new_sample( const std::string& name );
       audio::sample* new_sample( const audio::sample& s );
       std::size_t play_music( const std::string& name, unsigned int loops = 0 );
-      void stop_music( std::size_t id );
+      void stop_music( std::size_t id, double fadeout = 0 );
       void stop_all_musics();
 
       void pause_audio();
