@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -51,7 +51,7 @@ namespace bear
     class ENGINE_EXPORT level_loader
     {
     public:
-      explicit level_loader( compiled_file& f );
+      explicit level_loader( compiled_file& f, const std::string& path );
       ~level_loader();
 
       unsigned int get_item_index() const;
