@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -47,7 +47,9 @@ namespace bear
     public:
       level_object();
       level_object( const level_object& that );
+      virtual ~level_object();
 
+      void clear_level();
       void set_level( level& lvl );
       level& get_level() const;
 
