@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -34,12 +34,15 @@
 #include "engine/item_brick/basic_renderable_item.hpp"
 #include "engine/model/model_action.hpp"
 #include "engine/model/model_actor.hpp"
+#include "engine/model/model_snapshot_tweener.hpp"
+
+#include "text_interface/base_exportable.hpp"
 
 namespace bear
 {
   namespace engine
   {
-    class model_mark_placement;
+    class base_item;
 
     /**
      * \brief This class manage some basic informations on items: actions with
@@ -61,6 +64,9 @@ namespace bear
       /** \brief The type of the parent class. */
       typedef basic_renderable_item<Base> super;
 
+    private:
+      TEXT_INTERFACE_DECLARE_METHOD_LIST(super, init_exported_methods)
+
     public:
       model();
       model( const model<Base>& that );
@@ -76,14 +82,19 @@ namespace bear
       void switch_to_model_action(const std::string& name);
       const std::string& get_current_action_name() const;
       model_action const* get_action( const std::string& name ) const;
+      model_action const* get_current_action() const;
+
+      universe::position_type get_mark_world_position( std::size_t i ) const;
+      universe::position_type
+      get_mark_world_position( const std::string& mark_name ) const;
 
       bool get_mark_placement
       ( const std::string& mark_name, model_mark_placement& m ) const;
+      model_mark_item* get_model_mark_item( const std::string& name ) const;
+
       void set_mark_visibility_in_action( const std::string& name, bool b );
 
     protected:
-      virtual void execute_function( const std::string& name );
-
       void progress_model( universe::time_type elapsed_time );
 
       void set_global_substitute
@@ -97,6 +108,12 @@ namespace bear
       void to_string( std::string& str ) const;
 
     private:
+      void progress_to_snapshot
+      ( universe::time_type initial_time, universe::time_type elapsed_time,
+        const model_action::const_snapshot_iterator& eit );
+
+      void execute_function( const std::string& name );
+
       scene_visual get_mark_visual
       ( const model_mark& mark, const model_mark_placement& p ) const;
 
@@ -112,12 +129,26 @@ namespace bear
         bool only_finite = false );
       void execute_snapshot();
 
+      void update_mark_items();
+      void update_mark_items_positions();
+
       void update_bounding_box();
       void update_bounding_box_width();
       void update_bounding_box_height();
 
       void clear();
 
+      void remove_all_mark_items_from_layer() const;
+
+      void add_mark_item_in_layer( std::size_t i );
+      void remove_mark_item_from_layer( base_item& item ) const;
+
+      void create_tweeners();
+      void create_tweeners_to_snapshot( const model_snapshot& s );
+      void create_tweeners_to_action( const model_action& a );
+
+      static void init_exported_methods();
+
     private:
       /** \brief The model_actor (the actions) of this model. */
       model_actor m_actor;
@@ -137,6 +168,9 @@ namespace bear
       /** \brief The sound played during the action. */
       audio::sample* m_sample;
 
+      /** \brief The tweeners for the current snapshot. */
+      model_snapshot_tweener* m_current_snapshot;
+
     }; // class model
   } // namespace engine
 } // namespace bear
