@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -34,48 +34,6 @@
 #include <limits>
 #include <claw/real_number.hpp>
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get the alignment from its string representation.
- */
-bear::engine::model_action::horizontal_alignment::value
-bear::engine::model_action::horizontal_alignment::from_string
-( const std::string& str )
-{
-  if ( str == "align_left" )
-    return align_left;
-  else if  ( str == "align_right" )
-    return align_right;
-  else if  ( str == "align_center" )
-    return align_center;
-  else
-    throw std::invalid_argument("not a horizontal alignment '" + str + '\'');
-} // model_action::horizontal_alignment::from_string()
-
-
-
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get the alignment from its string representation.
- */
-bear::engine::model_action::vertical_alignment::value
-bear::engine::model_action::vertical_alignment::from_string
-( const std::string& str )
-{
-  if ( str == "align_top" )
-    return align_top;
-  else if  ( str == "align_bottom" )
-    return align_bottom;
-  else if  ( str == "align_center" )
-    return align_center;
-  else
-    throw std::invalid_argument("not a vertical alignment '" + str + '\'');
-} // model_action::vertical_alignment::from_string()
-
-
-
-
 /*----------------------------------------------------------------------------*/
 const std::size_t bear::engine::model_action::not_an_id
 ( std::numeric_limits<std::size_t>::max() );
@@ -149,10 +107,9 @@ bear::engine::model_action::~model_action()
  * \param that The instance to copy from.
  */
 bear::engine::model_action&
-bear::engine::model_action::operator=( const model_action& that )
+bear::engine::model_action::operator=( model_action that )
 {
-  model_action tmp(that);
-  std::swap(*this, tmp);
+  swap(that);
   return *this;
 } // model_action::operator=()
 
@@ -186,12 +143,14 @@ bear::engine::model_action::get_mark( std::size_t i ) const
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Get the count of marks in the action.
+ * \brief Get a mark given his name.
+ * \param n The label of the mark.
  */
-std::size_t bear::engine::model_action::get_marks_count() const
+bear::engine::model_mark&
+bear::engine::model_action::get_mark( const std::string& n ) const
 {
-  return m_mark.size();
-} // model_action::get_marks_count()
+  return get_mark( get_mark_id(n) );
+} // model_action::get_mark()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -215,6 +174,15 @@ bear::engine::model_action::get_mark_id( const std::string& n ) const
     return not_an_id;
 } // model_action::get_mark_id()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the count of marks in the action.
+ */
+std::size_t bear::engine::model_action::get_marks_count() const
+{
+  return m_mark.size();
+} // model_action::get_marks_count()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the duration of the action.
@@ -227,15 +195,13 @@ bear::universe::time_type bear::engine::model_action::get_duration() const
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add a snapshot in the action.
- * \param d The date.
  * \param s The snapshot.
  */
-void bear::engine::model_action::add_snapshot
-( universe::time_type d, const model_snapshot& s )
+void bear::engine::model_action::add_snapshot( const model_snapshot& s )
 {
-  CLAW_PRECOND( m_snapshot.find(d) == m_snapshot.end() );
+  CLAW_PRECOND( m_snapshot.find(s.get_date()) == m_snapshot.end() );
 
-  m_snapshot[d] = new model_snapshot(s);
+  m_snapshot[s.get_date()] = new model_snapshot(s);
 } // model_action::add_snapshot()
 
 /*----------------------------------------------------------------------------*/
@@ -454,7 +420,8 @@ bear::engine::model_action::get_snapshot_const_iterator_at
  * \param a The first action.
  * \param b The second action.
  */
-void bear::swap( engine::model_action& a, engine::model_action& b ) throw()
+void
+bear::engine::swap( engine::model_action& a, engine::model_action& b ) throw()
 {
   a.swap(b);
 } // bear::swap()
@@ -467,7 +434,7 @@ void bear::swap( engine::model_action& a, engine::model_action& b ) throw()
  */
 template<>
 void std::swap
-( bear::engine::model_action& a, bear::engine::model_action& b ) throw()
+( bear::engine::model_action& a, bear::engine::model_action& b )
 {
   a.swap(b);
 } // std::swap()
