@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -111,10 +111,9 @@ bear::engine::model_actor::~model_actor()
  * \param that The instance to copy from.
  */
 bear::engine::model_actor&
-bear::engine::model_actor::operator=( const model_actor& that )
+bear::engine::model_actor::operator=( model_actor that )
 {
-  model_actor tmp(that);
-  std::swap(tmp, *this);
+  swap(that);
   return *this;
 } // model_actor::operator=()
 
@@ -160,30 +159,6 @@ void bear::engine::model_actor::add_action
     }
 } // model_actor::add_action()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Swap two actors.
- * \param a The first actor.
- * \param b The second actor.
- */
-void bear::swap( engine::model_actor& a, engine::model_actor& b ) throw()
-{
-  a.swap(b);
-} // bear::swap()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Swap two actors.
- * \param a The first actor.
- * \param b The second actor.
- */
-template<>
-void
-std::swap( bear::engine::model_actor& a, bear::engine::model_actor& b ) throw()
-{
-  a.swap(b);
-} // std::swap()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set a substitute for the animation of all marks with a given name.
@@ -222,3 +197,47 @@ void bear::engine::model_actor::remove_global_substitute
         it->second->get_mark(i).remove_substitute();
     }
 } // model_actor::remove_global_substitute()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get an iterator on the beginning of the actions.
+ */
+bear::engine::model_actor::const_action_iterator
+bear::engine::model_actor::action_begin() const
+{
+  return m_actions.begin();
+} // model_actor::action_begin()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get an iterator on the end of the actions.
+ */
+bear::engine::model_actor::const_action_iterator
+bear::engine::model_actor::action_end() const
+{
+  return m_actions.end();
+} // model_actor::action_end()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Swap two actors.
+ * \param a The first actor.
+ * \param b The second actor.
+ */
+void
+bear::engine::swap( engine::model_actor& a, engine::model_actor& b ) throw()
+{
+  a.swap(b);
+} // bear::swap()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Swap two actors.
+ * \param a The first actor.
+ * \param b The second actor.
+ */
+template<>
+void std::swap( bear::engine::model_actor& a, bear::engine::model_actor& b )
+{
+  a.swap(b);
+} // std::swap()
