@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,12 +28,15 @@
  */
 #include "engine/model/model_mark.hpp"
 
+#include "engine/model/model_mark_item.hpp"
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
  */
 bear::engine::model_mark::model_mark()
-  : m_apply_angle_to_animation(false), m_pause_when_hidden(false)
+  : m_apply_angle_to_animation(false), m_pause_when_hidden(false),
+    m_box_item( new model_mark_item )
 {
 
 } // model_mark::model_mark()
@@ -50,11 +53,48 @@ bear::engine::model_mark::model_mark
 ( const std::string& label, const model_animation& anim, bool apply_angle,
   bool pause_hidden )
   : m_label(label), m_animation(anim), m_apply_angle_to_animation(apply_angle),
-    m_pause_when_hidden(pause_hidden)
+    m_pause_when_hidden(pause_hidden), m_box_item( new model_mark_item )
 {
 
 } // model_mark::model_mark()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * Copy constructor.
+ * \param that The instance to copy from.
+ */
+bear::engine::model_mark::model_mark( const model_mark& that )
+  : m_label(that.m_label), m_animation(that.m_animation),
+    m_apply_angle_to_animation(that.m_apply_angle_to_animation),
+    m_box_item(that.m_box_item->clone())
+{
+
+} // model_mark::model_mark()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * Assignment.
+ * \param that The instance to assign from.
+ */
+bear::engine::model_mark& bear::engine::model_mark::operator=( model_mark that )
+{
+  swap(that);
+  return *this;
+} // model_mark::operator=()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * Swap the mark with an other mark.
+ * \param that The mark to swap with.
+ */
+void bear::engine::model_mark::swap( model_mark& that ) throw()
+{
+  std::swap(m_label, that.m_label);
+  std::swap(m_animation, that.m_animation);
+  std::swap(m_apply_angle_to_animation, that.m_apply_angle_to_animation);
+  std::swap(m_box_item, that.m_box_item);
+} // model_mark::swap()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the label of the mark.
@@ -169,3 +209,35 @@ void bear::engine::model_mark::remove_substitute()
 {
   m_substitute = NULL;
 } // model_mark::remove_substitute()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * Get the item to keep centered on this mark.
+ */
+bear::engine::model_mark_item& bear::engine::model_mark::get_box_item()
+{
+  return *m_box_item;
+} // model_mark::get_box_item()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Swap two marks.
+ * \param a The first mark.
+ * \param b The second mark.
+ */
+void bear::engine::swap( engine::model_mark& a, engine::model_mark& b ) throw()
+{
+  a.swap(b);
+} // bear::swap()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Swap two marks.
+ * \param a The first mark.
+ * \param b The second mark.
+ */
+template<>
+void std::swap( bear::engine::model_mark& a, bear::engine::model_mark& b )
+{
+  a.swap(b);
+} // std::swap()
