@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -74,18 +74,30 @@ bear::engine::model_snapshot::vertical_alignment::from_string
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
+ * \param d The date at which the snapshot is in the action.
  * \param n The count of marks in the model.
  * \param func The function to call when passing on the snapshot.
  * \param snd The sound to play when passing on the snapshot.
  * \param glob Tell if the sound is played globally.
  */
 bear::engine::model_snapshot::model_snapshot
-( std::size_t n, const std::string& func, const std::string& snd, bool glob )
-  : m_placement(n), m_function(func), m_sound_name(snd), m_sound_is_global(glob)
+( universe::time_type d, std::size_t n, const std::string& func,
+  const std::string& snd, bool glob )
+  : m_date(d), m_placement(n), m_function(func), m_sound_name(snd),
+    m_sound_is_global(glob)
 {
 
 } // model_snapshot::model_snapshot()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the date at which the snapshot is in the action.
+ */
+bear::universe::time_type bear::engine::model_snapshot::get_date() const
+{
+  return m_date;
+} // model_snapshot::get_date()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set a mark placement.
