@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -79,34 +79,6 @@ namespace bear
         claw::dereference<model_mark> >
       ::iterator_type mark_iterator;
 
-      /** \brief How to align the action, horizontally, with the previous
-          action. */
-      struct horizontal_alignment
-      {
-        enum value
-          {
-            align_left,
-            align_right,
-            align_center
-          }; // enum value
-
-        static value from_string( const std::string& str );
-      }; // horizontal_alignment
-
-      /** \brief How to align the action, vertically, with the previous
-          action. */
-      struct vertical_alignment
-      {
-        enum value
-          {
-            align_top,
-            align_bottom,
-            align_center
-          }; // enum value
-
-        static value from_string( const std::string& str );
-      }; // vertical_alignment
-
     public:
       model_action();
       model_action
@@ -116,15 +88,16 @@ namespace bear
       model_action( const model_action& that );
       ~model_action();
 
-      model_action& operator=( const model_action& that );
+      model_action& operator=( model_action that );
       void swap( model_action& that ) throw();
 
       model_mark& get_mark( std::size_t i ) const;
+      model_mark& get_mark( const std::string& n ) const;
       std::size_t get_mark_id( const std::string& n ) const;
       std::size_t get_marks_count() const;
 
       universe::time_type get_duration() const;
-      void add_snapshot( universe::time_type d, const model_snapshot& s );
+      void add_snapshot( const model_snapshot& s );
 
       const_snapshot_iterator get_snapshot_at( universe::time_type t ) const;
       const_snapshot_iterator snapshot_begin() const;
@@ -173,16 +146,15 @@ namespace bear
       bool m_sound_is_global;
 
     }; // class model_action
-  } // namespace engine
 
-  void swap( engine::model_action& a, engine::model_action& b ) throw();
+    void swap( engine::model_action& a, engine::model_action& b ) throw();
+  } // namespace engine
 } // namespace bear
 
 namespace std
 {
   template<>
-  void swap
-  ( bear::engine::model_action& a, bear::engine::model_action& b ) throw();
+  void swap( bear::engine::model_action& a, bear::engine::model_action& b );
 } // namespace std
 
 #endif // __ENGINE_MODEL_ACTION_HPP__
