@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -34,6 +34,8 @@
 
 #include <map>
 #include <string>
+#include <claw/iterator.hpp>
+#include <claw/functional.hpp>
 
 namespace bear
 {
@@ -51,12 +53,22 @@ namespace bear
       /** \brief A map of actions. */
       typedef std::map<std::string, model_action*> action_map;
 
+    public:
+      /** \brief Iterators on the actions of the actor. */
+      typedef claw::wrapped_iterator
+      < const model_action,
+        action_map::const_iterator,
+        claw::unary_compose
+        < claw::const_dereference<model_action>,
+          claw::const_pair_second<action_map::value_type> > >
+      ::iterator_type const_action_iterator;
+
     public:
       model_actor();
       model_actor( const model_actor& that );
       ~model_actor();
 
-      model_actor& operator=( const model_actor& that );
+      model_actor& operator=( model_actor that );
       void swap( model_actor& that ) throw();
 
       model_action* get_action( const std::string& action_name ) const;
@@ -66,21 +78,23 @@ namespace bear
       ( const std::string& mark_name, const model_animation& anim );
       void remove_global_substitute( const std::string& mark_name );
 
+      const_action_iterator action_begin() const;
+      const_action_iterator action_end() const;
+
     private:
       /** \brief The actions. */
       action_map m_actions;
 
     }; // class model_actor
-  } // namespace engine
 
-  void swap( engine::model_actor& a, engine::model_actor& b ) throw();
+    void swap( engine::model_actor& a, engine::model_actor& b ) throw();
+  } // namespace engine
 } // namespace bear
 
 namespace std
 {
   template<>
-  void swap
-  ( bear::engine::model_actor& a, bear::engine::model_actor& b ) throw();
+  void swap( bear::engine::model_actor& a, bear::engine::model_actor& b );
 } // namespace std
 
 #endif // __ENGINE_MODEL_ACTOR_HPP__
