@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -37,6 +37,8 @@ namespace bear
 {
   namespace engine
   {
+    class model_mark_item;
+
     /**
      * \brief A placement for a mark in a snapshot.
      * \author Julien Jorge
@@ -48,6 +50,10 @@ namespace bear
       model_mark
       ( const std::string& label, const model_animation& anim,
         bool apply_angle, bool pause_hidden );
+      model_mark( const model_mark& that );
+
+      model_mark& operator=( model_mark that );
+      void swap( model_mark& that ) throw();
 
       const std::string& get_label() const;
       bool has_animation() const;
@@ -64,6 +70,8 @@ namespace bear
       void set_substitute( const model_animation& anim );
       void remove_substitute();
 
+      model_mark_item& get_box_item();
+
     private:
       /** \brief The label of the mark. */
       std::string m_label;
@@ -80,8 +88,19 @@ namespace bear
       /** \brief Tell if the animation must be paused when hidden. */
       bool m_pause_when_hidden;
 
+      /** \brief The item centered on this mark. */
+      model_mark_item* m_box_item;
+
     }; // class model_mark
+
+    void swap( engine::model_mark& a, engine::model_mark& b ) throw();
   } // namespace engine
 } // namespace bear
 
+namespace std
+{
+  template<>
+  void swap( bear::engine::model_mark& a, bear::engine::model_mark& b );
+} // namespace std
+
 #endif // __ENGINE_MODEL_MARK_HPP__
