@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -79,8 +79,10 @@ namespace bear
 
     public:
       model_snapshot
-      ( std::size_t n, const std::string& func, const std::string& snd,
-        bool glob );
+      ( universe::time_type d, std::size_t n, const std::string& func,
+        const std::string& snd, bool glob );
+
+      universe::time_type get_date() const;
 
       void set_mark_placement( const model_mark_placement& m );
       const model_mark_placement& get_mark_placement( std::size_t i ) const;
@@ -108,6 +110,9 @@ namespace bear
       universe::coordinate_type get_y_alignment_value() const;
 
     private:
+      /** \brief The date of this snapshot in the action. */
+      const universe::time_type m_date;
+
       /** \brief The placement of the marks in this snapshot. */
       std::vector<model_mark_placement> m_placement;
 
