@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -31,7 +31,8 @@
 
 #include <map>
 #include <set>
-#include <stack>
+#include <claw/functional.hpp>
+#include <claw/iterator.hpp>
 
 #include "engine/base_item.hpp"
 #include "engine/class_export.hpp"
@@ -50,24 +51,43 @@ namespace bear
       /** brief The type of the map containing the items. */
       typedef std::map<base_item::id_type, base_item*> item_map;
 
+    public:
+      /** \brief Iterator on the living items. */
+      typedef claw::wrapped_iterator
+        < base_item,
+          item_map::const_iterator,
+          claw::unary_compose
+          < claw::dereference<base_item>,
+            claw::const_pair_second<item_map::value_type> > >
+      ::iterator_type const_iterator;
+
     public:
       ~population();
 
       void insert( base_item* item );
       void kill( const base_item* item );
+      void drop( const base_item* item );
 
       bool exists( base_item::id_type id ) const;
 
       void remove_dead_items();
       void clear();
 
+      const_iterator begin() const;
+      const_iterator end() const;
+
     private:
       /** \brief All items currently in the game. */
       item_map m_items;
 
-      /** \brief The dead items. */
+      /** \brief The items that will be deleted by calling
+          remove_dead_items(). */
       std::set<base_item::id_type> m_dead_items;
 
+      /** \brief The items that will be removed by calling
+          remove_dead_items(). */
+      std::set<base_item::id_type> m_dropped_items;
+
     }; // class population
   } // namespace engine
 } // namespace bear
