@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -94,6 +94,9 @@ namespace bear
 
       }; // class msg_pick_items_in_region
 
+      /** \brief The type of the iterator on the living items. */
+      typedef population::const_iterator const_item_iterator;
+
     public:
       world( const universe::size_box_type& size );
       ~world();
@@ -107,18 +110,16 @@ namespace bear
       ( std::list<scene_visual>& visuals,
         const universe::rectangle_type& camera_box ) const;
 
-      #if 0
-      void pick_items( std::list<base_item*>& items,
-                       const universe::position_type& pos ) const;
-
-      void pick_items( std::list<base_item*>& items,
-                       const universe::rectangle_type& r ) const;
-#endif
+      const_item_iterator living_items_begin() const;
+      const_item_iterator living_items_end() const;
 
       void add_static( base_item* const& who );
 
       void register_item( base_item* const& who );
       void release_item( base_item* const& who );
+      void drop_item( base_item* const& who );
+
+      void print_item_stats() const;
 
     private:
       /** \brief The static items won't be deleted when cleaning the
