@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -33,41 +33,37 @@
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
- * \param owner The owner of the frame.
  */
-bear::gui::frame::frame( visual_component* owner )
-  : visual_component(owner), m_content_frame(new visual_component(this)),
-    m_font_size(0)
+bear::gui::frame::frame()
+  : visual_component(), m_content_frame(new visual_component()), m_font_size(0)
 {
-
+  insert(m_content_frame);
 } // frame::frame()
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
- * \param owner The owner of the frame.
  * \param title The title of the frame.
  */
-bear::gui::frame::frame( visual_component* owner, const std::string& title )
-  : visual_component(owner), m_content_frame(new visual_component(this)),
-    m_font_size(0)
+bear::gui::frame::frame( const std::string& title )
+  : visual_component(), m_content_frame(new visual_component()), m_font_size(0)
 {
+  insert(m_content_frame);
   set_title( title );
 } // frame::frame()
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
- * \param owner The owner of the frame.
  * \param title The title of the frame.
  * \param f The font used to display the title.
  * \param font_size The size of the font.
  */
 bear::gui::frame::frame
-( visual_component* owner, const std::string& title, const visual::font& f,
-  visual::size_type font_size )
-  : visual_component(owner), m_content_frame(new visual_component(this))
+( const std::string& title, const visual::font& f, visual::size_type font_size )
+  : visual_component(), m_content_frame(new visual_component())
 {
+  insert(m_content_frame);
   set_font(f);
   set_font_size(font_size);
   set_title( title );
@@ -185,17 +181,6 @@ void bear::gui::frame::fit( size_type margin )
             + 2 * get_border_size() );
 } // frame::fit()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Method called after the component has been resized.
- */
-void bear::gui::frame::on_resized()
-{
-  m_content_frame->set_size
-    ( width() - 2 * get_border_size(),
-      height() - 2 * get_border_size() - compute_title_height() );
-} // frame::on_resized()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the scene elements of the component.
@@ -207,17 +192,26 @@ void bear::gui::frame::display( std::list<visual::scene_element>& e ) const
     ( left() + get_border_size(),
       top() - compute_title_height() - get_border_size(), m_displayed_title );
 
-  double factor(1);
-
   if ( m_font != NULL )
     {
-      factor = m_font_size / m_font->get_max_glyph_height();
+      double factor = m_font_size / m_font->get_max_glyph_height();
       t.set_scale_factor( factor, factor );
     }
 
   e.push_back(t);
 } // frame::display()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Method called after the component has been resized.
+ */
+void bear::gui::frame::on_resized()
+{
+  m_content_frame->set_size
+    ( width() - 2 * get_border_size(),
+      height() - 2 * get_border_size() - compute_title_height() );
+} // frame::on_resized()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the scene elements for the background of the frame.
