@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -33,15 +33,16 @@
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
- * \param owner The component containing this component.
  * \param f The font used to draw the text.
- * \remark \a f will be deleted in the destructor.
  */
-bear::gui::multi_page::multi_page( visual_component* owner, font_type f )
-  : visual_component(owner), m_current_mark(0)
+bear::gui::multi_page::multi_page( font_type f )
+  : visual_component(), m_current_mark(0)
 {
-  m_static_text = new static_text( this, f );
-  m_dots_text = new static_text( this, f );
+  m_static_text = new static_text(f);
+  m_dots_text = new static_text(f);
+
+  insert( m_static_text );
+  insert( m_dots_text );
 
   m_dots_text->set_auto_size(true);
   m_dots_text->set_text("[...]");
@@ -100,7 +101,7 @@ void bear::gui::multi_page::set_text( const std::string& text )
 void bear::gui::multi_page::on_resized()
 {
   size_box_type size;
-  position_type pos(0,0);
+  position_type pos(0, 0);
   const size_type font_height
     ( m_static_text->get_font()->get_max_glyph_height() );
 
