@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -35,12 +35,10 @@
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
- * \param owner The component containing this picture.
  * \param pict The sprite to display.
  */
-bear::gui::picture::picture
-( visual_component* owner, const visual::sprite& pict )
-  : scene_element(owner, visual::scene_sprite(0, 0, pict))
+bear::gui::picture::picture( const visual::sprite& pict )
+  : scene_element(visual::scene_sprite(0, 0, pict))
 {
 
 } // picture::picture()
