@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -112,10 +112,9 @@ void bear::gui::static_text::arrange_max_size::operator()
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
- * \param owner The component containing this component.
  */
-bear::gui::static_text::static_text( visual_component* owner )
-  : visual_component(owner), m_auto_size(false), m_margin(1, 1)
+bear::gui::static_text::static_text()
+  : visual_component(), m_auto_size(false), m_margin(1, 1)
 {
   set_size(m_margin);
 } // static_text::static_text()
@@ -123,11 +122,10 @@ bear::gui::static_text::static_text( visual_component* owner )
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
- * \param owner The component containing this component.
  * \param f The font used to draw the text.
  */
-bear::gui::static_text::static_text( visual_component* owner, font_type f )
-  : visual_component(owner), m_font(f), m_auto_size(false), m_margin(1, 1)
+bear::gui::static_text::static_text( font_type f )
+  : visual_component(), m_font(f), m_auto_size(false), m_margin(1, 1)
 {
   CLAW_PRECOND( f != NULL );
 } // static_text::static_text()
