@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -34,16 +34,16 @@
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
- * \param owner The component containing this component.
  * \param f The font used to draw the text.
  * \param cursor_color The color of the cursor.
  */
 bear::gui::text_input::text_input
-( visual_component* owner, font_type f, visual::color_type cursor_color )
-  : visual_component(owner), m_cursor(0), m_cursor_color(cursor_color),
-    m_first(0), m_last(0), m_line_length(0)
+( font_type f, visual::color_type cursor_color )
+  : visual_component(), m_cursor(0), m_cursor_color(cursor_color), m_first(0),
+    m_last(0), m_line_length(0)
 {
-  m_static_text = new static_text(this, f);
+  m_static_text = new static_text(f);
+  insert(m_static_text);
 } // text_input::text_input()
 
 /*----------------------------------------------------------------------------*/
@@ -80,13 +80,13 @@ const std::string& bear::gui::text_input::get_text() const
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Set the callback called when enter is pressed.
+ * \brief Add callback called when enter is pressed.
  * \param c The callback.
  */
-void bear::gui::text_input::set_enter_callback( const callback& c )
+void bear::gui::text_input::add_enter_callback( const callback& c )
 {
-  m_enter_callback = c;
-} // text_input::set_enter_callback()
+  m_enter_callback.add(c);
+} // text_input::add_enter_callback()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -219,7 +219,7 @@ bool bear::gui::text_input::special_code( const input::key_info& key )
       m_cursor = m_text.size();
       adjust_text_by_right();
     }
-  else if ( key.is_enter() && (m_enter_callback != callback()) )
+  else if ( key.is_enter() && !m_enter_callback.empty() )
     m_enter_callback.execute();
   else
     result = false;
