@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -43,16 +43,14 @@
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
- * \param owner The component containing this component.
  */
-bear::gui::visual_component::visual_component( visual_component* owner )
-  : m_box(0, 0, 0, 0), m_owner(owner), m_focused_component(-1),
-    m_visible(true), m_input_priority(false), m_enabled(true),
+bear::gui::visual_component::visual_component()
+  : m_box(0, 0, 0, 0), m_owner(NULL), m_focused_component(-1), m_visible(true),
+    m_input_priority(false), m_enabled(true),
     m_top_left_border_color(0, 0, 0, 0),
     m_bottom_right_border_color(0, 0, 0, 0), m_background_color(0, 0, 0, 0)
 {
-  if (m_owner)
-    m_owner->add_component(this);
+
 } // visual_component::visual_component()
 
 /*----------------------------------------------------------------------------*/
@@ -61,10 +59,81 @@ bear::gui::visual_component::visual_component( visual_component* owner )
  */
 bear::gui::visual_component::~visual_component()
 {
-  std::for_each( m_components.begin(), m_components.end(),
-                 claw::delete_function<visual_component*>() );
+  clear();
 } // visual_component::~visual_component()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set this component as the owner of an other component.
+ * \param child The component that becomes a child of this component.
+ */
+void bear::gui::visual_component::insert( visual_component* child )
+{
+  if ( child->m_owner != NULL )
+    child->m_owner->remove(child);
+
+  m_components.push_back(child);
+  child->m_owner = this;
+
+  if (m_focused_component < 0)
+    m_focused_component = 0;
+
+  child->stay_in_owner();
+  on_child_inserted(child);
+} // visual_component::insert()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove a child component of this component.
+ * \param child The component to remove.
+ * \pre child is effectively a child of this component.
+ * \remark The child will not be deleted.
+ */
+void bear::gui::visual_component::remove( visual_component* child )
+{
+  CLAW_PRECOND( std::find( m_components.begin(), m_components.end(), child )
+                != m_components.end() );
+
+  m_components.erase
+    ( std::find( m_components.begin(), m_components.end(), child ) );
+
+  if ( m_focused_component >= (int)m_components.size() )
+    --m_focused_component;
+
+  on_child_removed(child);
+} // visual_component::remove()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove all children components of this component.
+ * \remark The children will not be deleted.
+ */
+void bear::gui::visual_component::remove_all()
+{
+  while ( !m_components.empty() )
+    remove( m_components.back() );
+} // visual_component::remove_all()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get an iterator on the beginning of the children.
+ */
+bear::gui::visual_component::iterator
+bear::gui::visual_component::begin() const
+{
+  return m_components.begin();
+} // visual_component::begin()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get an iterator on the beginning of the children.
+ */
+bear::gui::visual_component::iterator
+bear::gui::visual_component::end() const
+{
+  return m_components.end();
+} // visual_component::end()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Draw the component and its sub components on a screen.
@@ -874,19 +943,15 @@ bear::gui::visual_component* bear::gui::visual_component::get_focus() const
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Add a component in this component.
- * \param that The component to add.
+ * \brief Remove all the children of the component.
  */
-void bear::gui::visual_component::add_component( visual_component* that )
+void bear::gui::visual_component::clear()
 {
-  CLAW_PRECOND( std::find(m_components.begin(), m_components.end(), that)
-                == m_components.end() );
-
-  m_components.push_back(that);
-
-  if (m_focused_component < 0)
-    m_focused_component = 0;
-} // visual_component::add_component()
+  std::for_each( m_components.begin(), m_components.end(),
+                 claw::delete_function<visual_component*>() );
+  m_components.clear();
+  m_focused_component = -1;
+} // visual_component::clear()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -918,13 +983,32 @@ void bear::gui::visual_component::on_resized()
   // nothing to do
 } // visual_component::on_resized()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Method called after the insertion of a child.
+ * \param child The child inserted in this component.
+ */
+void bear::gui::visual_component::on_child_inserted( visual_component* child )
+{
+  // nothing to do
+} // visual_component::on_child_inserted()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Method called after the removal of a child.
+ * \param child The child removed from this component.
+ */
+void bear::gui::visual_component::on_child_removed( visual_component* child )
+{
+  // nothing to do
+} // visual_component::on_child_removed()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the scene elements of the component.
  * \param e (out) The scene elements.
  */
-void bear::gui::visual_component::display
-( std::list<visual::scene_element>& e ) const
+void bear::gui::visual_component::display( scene_element_list& e ) const
 {
   // nothing to do
 } // visual_component::display()
