@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -46,10 +46,10 @@ namespace bear
       public visual_component
     {
     public:
-      explicit frame( visual_component* owner );
-      frame( visual_component* owner, const std::string& title );
-      frame( visual_component* owner, const std::string& title,
-             const visual::font& f, visual::size_type font_size = 0 );
+      frame();
+      explicit frame( const std::string& title );
+      frame( const std::string& title, const visual::font& f,
+             visual::size_type font_size = 0 );
 
       void set_title( const std::string& t );
       const std::string& get_title() const;
@@ -67,11 +67,10 @@ namespace bear
 
       visual_component& get_content();
       void fit( size_type margin = 10 );
+      void display( scene_element_list& e ) const;
 
     private:
       void on_resized();
-      void display( scene_element_list& e ) const;
-
       visual::size_type compute_title_height() const;
       void update_displayed_title();
 
