@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -54,7 +54,7 @@ namespace bear
       typedef visual::font font_type;
 
     public:
-      multi_page( visual_component* owner, font_type f );
+      explicit multi_page( font_type f );
 
       void previous();
       void next();
