@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -48,9 +48,8 @@ namespace bear
       public scene_element
     {
     public:
-      picture
-      ( visual_component* owner,
-        const visual::sprite& pict = visual::sprite() );
+      explicit picture
+      ( const visual::sprite& pict = visual::sprite() );
 
       void set_picture( const visual::sprite& pict );
 
