@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,7 +29,7 @@
 #ifndef __GUI_SLIDER_HPP__
 #define __GUI_SLIDER_HPP__
 
-#include "gui/callback.hpp"
+#include "gui/callback_group.hpp"
 #include "gui/visual_component.hpp"
 
 #include "visual/sprite.hpp"
@@ -47,9 +47,10 @@ namespace bear
       public visual_component
     {
     public:
-      slider( visual_component* owner, const visual::sprite& bar,
-              const visual::sprite& slider, T min, T max, T value,
-              const callback& value_changed = callback() );
+      slider( const visual::sprite& bar, const visual::sprite& slider,
+              T min, T max, T value );
+      slider( const visual::sprite& bar, const visual::sprite& slider,
+              T min, T max, T value, const callback& value_changed );
 
       void set_delta( T v );
       void set_value( T v );
@@ -58,6 +59,8 @@ namespace bear
     private:
       void display( std::list<visual::scene_element>& e ) const;
 
+      void set_slider_at( unsigned int x );
+
       void on_resized();
       bool on_key_press( const input::key_info& key );
       bool on_button_press
@@ -92,7 +95,7 @@ namespace bear
       T m_delta;
 
       /** \brief Callback executed when the value changed. */
-      callback m_value_changed_callback;
+      callback_group m_value_changed_callback;
 
     }; // class slider
   } // namespace gui
