@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -99,8 +99,8 @@ namespace bear
       }; // class arrange_max_size
 
     public:
-      static_text( visual_component* owner );
-      static_text( visual_component* owner, font_type f );
+      static_text();
+      explicit static_text( font_type f );
 
       void set_font( font_type f );
       void set_auto_size( bool b );
