@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,7 +29,7 @@
 #ifndef __GUI_TEXT_INPUT_HPP__
 #define __GUI_TEXT_INPUT_HPP__
 
-#include "gui/callback.hpp"
+#include "gui/callback_group.hpp"
 #include "gui/visual_component.hpp"
 #include "input/keyboard.hpp"
 #include "visual/font.hpp"
@@ -54,14 +54,13 @@ namespace bear
       typedef visual::font font_type;
 
     public:
-      text_input( visual_component* owner, font_type f,
-                  visual::color_type cursor_color );
+      text_input( font_type f, visual::color_type cursor_color );
 
       void clear();
       void set_text( const std::string& text );
       const std::string&  get_text() const;
 
-      void set_enter_callback( const callback& c );
+      void add_enter_callback( const callback& c );
 
     private:
       bool on_key_press( const input::key_info& key );
@@ -105,7 +104,7 @@ namespace bear
       std::string::size_type m_line_length;
 
       /** \brief Callback executed when enter is pressed. */
-      callback m_enter_callback;
+      callback_group m_enter_callback;
 
     }; // class text_input
   } // namespace gui
