@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -35,6 +35,8 @@
 
 #include <vector>
 
+#include <claw/iterator.hpp>
+#include <claw/functional.hpp>
 #include <claw/non_copyable.hpp>
 
 #include "gui/class_export.hpp"
@@ -58,9 +60,24 @@ namespace bear
       typedef std::vector<visual_component*> component_list;
 
     public:
-      visual_component( visual_component* owner );
+      /** The type of the iterators on the children components. */
+      typedef claw::wrapped_iterator
+        <
+          visual_component, component_list::const_iterator,
+          claw::dereference<visual_component>
+        >::iterator_type iterator;
+
+    public:
+      visual_component();
       virtual ~visual_component();
 
+      void insert( visual_component* child );
+      void remove( visual_component* child );
+      void remove_all();
+
+      iterator begin() const;
+      iterator end() const;
+
       void render( scene_element_list& e ) const;
 
       bool key_pressed( const input::key_info& key );
@@ -134,13 +151,17 @@ namespace bear
       void set_focus();
       visual_component* get_focus() const;
 
+      void clear();
+
     protected:
-      void add_component( visual_component* that );
       void
       change_tab_position( const visual_component* that, unsigned int pos );
 
       virtual void on_resized();
 
+      virtual void on_child_inserted( visual_component* child );
+      virtual void on_child_removed( visual_component* child );
+
       virtual void display( scene_element_list& e ) const;
 
       virtual bool on_key_press( const input::key_info& key );
