@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -63,7 +63,7 @@ bear::input::joystick::joystick( unsigned int joy_id )
   m_joystick = SDL_JoystickOpen(joy_id);
 
   if (!m_joystick)
-    throw CLAW_EXCEPTION( SDL_GetError() );
+    throw claw::exception( SDL_GetError() );
 } // joystick::joystick()
 
 /*----------------------------------------------------------------------------*/
