@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -45,10 +45,10 @@ void bear::input::system::initialize()
 {
   if ( !SDL_WasInit(SDL_INIT_VIDEO) )
     if ( SDL_InitSubSystem(SDL_INIT_VIDEO) != 0 )
-      throw CLAW_EXCEPTION( SDL_GetError() );
+      throw claw::exception( SDL_GetError() );
 
   if ( SDL_InitSubSystem(SDL_INIT_JOYSTICK) != 0 )
-    throw CLAW_EXCEPTION( SDL_GetError() );
+    throw claw::exception( SDL_GetError() );
 
   SDL_EnableKeyRepeat(0, 0);
   SDL_EnableUNICODE(1);
