@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -38,10 +38,13 @@ namespace bear
   namespace systime
   {
     typedef unsigned long milliseconds_type;
+    typedef unsigned long seconds_type;
 
     void TIME_EXPORT sleep( milliseconds_type ms );
     milliseconds_type TIME_EXPORT get_date_ms();
 
+    seconds_type TIME_EXPORT get_unix_time();
+
     std::string TIME_EXPORT format_time_s
     ( unsigned long t, const std::string& format );
 
