@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -101,16 +101,7 @@ bear::universe::collision_info::reference_previous_state() const
 /**
  * \brief Get the other item.
  */
-bear::universe::physical_item& bear::universe::collision_info::other_item()
-{
-  return m_other;
-} // collision_info::other_item()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get the other item.
- */
-const bear::universe::physical_item&
+bear::universe::physical_item&
 bear::universe::collision_info::other_item() const
 {
   return m_other;
