@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -46,8 +46,7 @@
  * \brief Constructor.
  */
 bear::universe::physical_item::physical_item()
-  : m_handles(new handle_list), m_const_handles(new const_handle_list),
-    m_owner(NULL), m_world_progress_structure(*this)
+  : m_owner(NULL), m_world_progress_structure(*this)
 {
 
 } // physical_item::physical_item()
@@ -59,9 +58,7 @@ bear::universe::physical_item::physical_item()
  * \remark Links are not copied.
  */
 bear::universe::physical_item::physical_item( const physical_item& that )
-  : physical_item_state(that),
-    m_handles(new handle_list), m_const_handles(new const_handle_list),
-    m_owner(NULL), m_world_progress_structure(*this)
+  : physical_item_state(that), m_owner(NULL), m_world_progress_structure(*this)
 {
   set_forced_movement( that.m_forced_movement );
 } // physical_item::physical_item()
@@ -72,19 +69,9 @@ bear::universe::physical_item::physical_item( const physical_item& that )
  */
 bear::universe::physical_item::~physical_item()
 {
-  // force a call to remove_handle, that will remove the handle from the list
-  while ( !m_handles->empty() )
-    *m_handles->front() = NULL;
-
-  // force a call to remove_handle, that will remove the handle from the list
-  while ( !m_const_handles->empty() )
-    *m_const_handles->front() = NULL;
-
-  delete m_handles;
-  delete m_const_handles;
-
+  remove_all_handles();
   remove_all_links();
-} // physical_item::~physical_item() [destructor]
+} // physical_item::~physical_item()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -298,6 +285,18 @@ void bear::universe::physical_item::set_owner(world& owner)
   m_owner = &owner;
 } // physical_item::set_owner()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove the item from its owner.
+ */
+void bear::universe::physical_item::quit_owner()
+{
+  clear_forced_movement();
+  remove_all_links();
+  remove_all_handles();
+  m_owner = NULL;
+} // physical_item::quit_owner()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the world's selection structure for this item.
@@ -387,65 +386,65 @@ void bear::universe::physical_item::remove_all_links()
 /**
  * \brief Add an handle to the item.
  * \pre (h != NULL)
- *      && (std::find(m_handles->begin(), m_handles->end(), h)
- *         == m_handles->end())
+ *      && (std::find(m_handles.begin(), m_handles.end(), h)
+ *         == m_handles.end())
  */
 void bear::universe::physical_item::add_handle( item_handle* h ) const
 {
   CLAW_PRECOND( h != NULL );
-  CLAW_PRECOND( std::find(m_handles->begin(), m_handles->end(), h)
-                == m_handles->end() );
+  CLAW_PRECOND( std::find(m_handles.begin(), m_handles.end(), h)
+                == m_handles.end() );
 
-  m_handles->push_front( h );
+  m_handles.push_front( h );
 } // physical_item::add_handle()
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add an handle to the item.
  * \pre (h != NULL)
- *      && (std::find(m_const_handles->begin(), m_const_handles->end(), h)
- *          == m_const_handles->end())
+ *      && (std::find(m_const_handles.begin(), m_const_handles.end(), h)
+ *          == m_const_handles.end())
  */
 void bear::universe::physical_item::add_handle( const_item_handle* h ) const
 {
   CLAW_PRECOND( h != NULL );
-  CLAW_PRECOND( std::find(m_const_handles->begin(), m_const_handles->end(), h)
-                == m_const_handles->end() );
+  CLAW_PRECOND( std::find(m_const_handles.begin(), m_const_handles.end(), h)
+                == m_const_handles.end() );
 
-  m_const_handles->push_front( h );
+  m_const_handles.push_front( h );
 } // physical_item::add_handle()
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Remove an handle to the item.
  * \pre (h != NULL)
- *      && (std::find(m_handles->begin(), m_handles->end(), h)
- *         != m_handles->end())
+ *      && (std::find(m_handles.begin(), m_handles.end(), h)
+ *         != m_handles.end())
  */
 void bear::universe::physical_item::remove_handle( item_handle* h ) const
 {
   CLAW_PRECOND( h != NULL );
-  CLAW_PRECOND( std::find(m_handles->begin(), m_handles->end(), h)
-                != m_handles->end() );
+  CLAW_PRECOND( std::find(m_handles.begin(), m_handles.end(), h)
+                != m_handles.end() );
 
-  m_handles->erase( std::find( m_handles->begin(), m_handles->end(), h ) );
+  m_handles.erase( std::find( m_handles.begin(), m_handles.end(), h ) );
 } // physical_item::remove_handle()
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Remove an handle to the item.
  * \pre (h != NULL)
- *      && (std::find(m_const_handles->begin(), m_const_handles->end(), h)
- *         != m_const_handles->end())
+ *      && (std::find(m_const_handles.begin(), m_const_handles.end(), h)
+ *         != m_const_handles.end())
  */
 void bear::universe::physical_item::remove_handle( const_item_handle* h ) const
 {
   CLAW_PRECOND( h != NULL );
-  CLAW_PRECOND( std::find(m_const_handles->begin(), m_const_handles->end(), h)
-                != m_const_handles->end() );
+  CLAW_PRECOND( std::find(m_const_handles.begin(), m_const_handles.end(), h)
+                != m_const_handles.end() );
 
-  m_const_handles->erase
-    ( std::find( m_const_handles->begin(), m_const_handles->end(), h ) );
+  m_const_handles.erase
+    ( std::find( m_const_handles.begin(), m_const_handles.end(), h ) );
 } // physical_item::remove_handle()
 
 /*----------------------------------------------------------------------------*/
@@ -492,20 +491,6 @@ const bear::universe::world& bear::universe::physical_item::get_owner() const
   return *m_owner;
 } // physical_item::get_owner()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Apply the default movement of the item (forced_movement or
- *        acceleration and speed).
- * \param elapsed_time Elasped time since the last progress.
- */
-void bear::universe::physical_item::default_move( time_type elapsed_time )
-{
-  if ( has_forced_movement() )
-    m_forced_movement.next_position(elapsed_time);
-  else
-    update_position(elapsed_time);
-} // physical_item::default_move()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Align the other item of the collision.
@@ -544,6 +529,20 @@ bool bear::universe::physical_item::default_collision( collision_info& info )
   return result;
 } // physical_item::default_collision()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Apply the default movement of the item (forced_movement or
+ *        acceleration and speed).
+ * \param elapsed_time Elasped time since the last progress.
+ */
+void bear::universe::physical_item::default_move( time_type elapsed_time )
+{
+  if ( has_forced_movement() )
+    m_forced_movement.next_position(elapsed_time);
+  else
+    update_position(elapsed_time);
+} // physical_item::default_move()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Align the other item of the collision on the left of \a this.
@@ -841,3 +840,19 @@ void bear::universe::physical_item::update_position( time_type elapsed_time )
   set_internal_force( force_type(0, 0) );
   set_external_force( force_type(0, 0) );
 } // physical_item::update_position()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove (invalidates) all the handles on this item.
+ */
+void bear::universe::physical_item::remove_all_handles() const
+{
+  // force a call to remove_handle, that will remove the handle from the list
+  while ( !m_handles.empty() )
+    *m_handles.front() = NULL;
+
+  // force a call to remove_handle, that will remove the handle from the list
+  while ( !m_const_handles.empty() )
+    *m_const_handles.front() = NULL;
+
+} // physical_item::remove_all_handles()
