@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -40,10 +40,9 @@ bear::universe::physical_item_attributes::physical_item_attributes()
     m_internal_force(0, 0), m_external_force(0, 0), m_self_friction(0.98),
     m_contact_friction(1), m_elasticity(0), m_hardness(1), m_position(0, 0),
     m_size(0, 0), m_system_angle(0), m_can_move_items(true),
-    m_contact_after_collision(false), m_left_contact(false),
-    m_right_contact(false), m_top_contact(false), m_bottom_contact(false),
-    m_middle_contact(false), m_is_phantom(false), m_is_artificial(false),
-    m_weak_collisions(false)
+    m_left_contact(false), m_right_contact(false), m_top_contact(false),
+    m_bottom_contact(false), m_middle_contact(false), m_is_phantom(false),
+    m_is_artificial(false), m_weak_collisions(false)
 {
 
 } // physical_item_attributes::physical_item_attributes()
