@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -277,16 +277,28 @@ bear::universe::physical_item_state::get_speed() const
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set the current speed of the item.
+ * \param speed The speed.
  */
 void bear::universe::physical_item_state::set_speed( const speed_type& speed )
+{
+  set_speed( speed.x, speed.y );
+} // physical_item_state::set_speed()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set the current speed of the item.
+ * \param x The speed on the x-axis.
+ * \param y The speed on the y-axis.
+ */
+void bear::universe::physical_item_state::set_speed( double x, double y )
 {
   if (!m_fixed)
     {
       if (m_x_fixed == 0)
-        m_speed.x = speed.x;
+        m_speed.x = x;
 
       if (m_y_fixed == 0)
-        m_speed.y = speed.y;
+        m_speed.y = y;
     }
 } // physical_item_state::set_speed()
 
@@ -573,6 +585,110 @@ void bear::universe::physical_item_state::set_right_middle
   set_vertical_middle(pos.y);
 } // physical_item_state::set_right_middle()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set (force) the position of the top left corner of the item.
+ * \param x The new x-position.
+ * \param y The new y-position.
+ */
+void bear::universe::physical_item_state::set_top_left
+( const coordinate_type& x, const coordinate_type& y )
+{
+  set_left(x);
+  set_top(y);
+} // physical_item_state::set_top_left()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set (force) the position of the middle of the top edge of the item.
+ * \param x The new x-position.
+ * \param y The new y-position.
+ */
+void bear::universe::physical_item_state::set_top_middle
+( const coordinate_type& x, const coordinate_type& y )
+{
+  set_horizontal_middle(x);
+  set_top(y);
+} // physical_item_state::set_top_middle()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set (force) the position of the top right corner of the item.
+ * \param x The new x-position.
+ * \param y The new y-position.
+ */
+void bear::universe::physical_item_state::set_top_right
+( const coordinate_type& x, const coordinate_type& y )
+{
+  set_right(x);
+  set_top(y);
+} // physical_item_state::set_top_right()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set (force) the position of the bottom left corner of the item.
+ * \param x The new x-position.
+ * \param y The new y-position.
+ */
+void bear::universe::physical_item_state::set_bottom_left
+( const coordinate_type& x, const coordinate_type& y )
+{
+  set_left(x);
+  set_bottom(y);
+} // physical_item_state::set_bottom_left()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set (force) the position of the middle of the bottom edge of the item.
+ * \param x The new x-position.
+ * \param y The new y-position.
+ */
+void bear::universe::physical_item_state::set_bottom_middle
+( const coordinate_type& x, const coordinate_type& y )
+{
+  set_horizontal_middle(x);
+  set_bottom(y);
+} // physical_item_state::set_bottom_middle()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set (force) the position of the bottom right corner of the item.
+ * \param x The new x-position.
+ * \param y The new y-position.
+ */
+void bear::universe::physical_item_state::set_bottom_right
+( const coordinate_type& x, const coordinate_type& y )
+{
+  set_right(x);
+  set_bottom(y);
+} // physical_item_state::set_bottom_right()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set (force) the position of the middle of the left edge of the item.
+ * \param x The new x-position.
+ * \param y The new y-position.
+ */
+void bear::universe::physical_item_state::set_left_middle
+( const coordinate_type& x, const coordinate_type& y )
+{
+  set_left(x);
+  set_vertical_middle(y);
+} // physical_item_state::set_left_middle()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set (force) the position of the middle of the right edge of the item.
+ * \param x The new x-position.
+ * \param y The new y-position.
+ */
+void bear::universe::physical_item_state::set_right_middle
+( const coordinate_type& x, const coordinate_type& y )
+{
+  set_right(x);
+  set_vertical_middle(y);
+} // physical_item_state::set_right_middle()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the lowest X-coordinate covered by the bounding box of this item.
@@ -734,6 +850,18 @@ void bear::universe::physical_item_state::set_center_of_mass
   set_bottom_left( pos - m_size / 2 );
 } // physical_item_state::set_center_of_mass()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set (force) the position of the center of the item on the center of
+ *        mass of an other item.
+ * \param pos The item on which the center will be aligned.
+ */
+void bear::universe::physical_item_state::set_center_on
+( const physical_item_state& that )
+{
+  set_center_of_mass( that.get_center_of_mass() );
+} // physical_item_state::set_center_on()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set (force) the position of the center of the item.
@@ -743,7 +871,7 @@ void bear::universe::physical_item_state::set_center_of_mass
 void bear::universe::physical_item_state::set_center_of_mass
 ( const coordinate_type& x, const coordinate_type& y )
 {
-  set_center_of_mass( position_type(x,y) );
+  set_center_of_mass( position_type(x, y) );
 } // physical_item_state::set_center_of_mass()
 
 /*----------------------------------------------------------------------------*/
@@ -863,25 +991,6 @@ void bear::universe::physical_item_state::set_global( bool global )
   m_global = global;
 } // physical_item_state::set_global()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Tell if the item has a contact after collision detection.
- */
-bool bear::universe::physical_item_state::has_contact_after_collision() const
-{
-  return m_contact_after_collision;
-} // physical_item_state::has_contact_after_collision()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Set the field has_contact_after_collision.
- */
-void
-bear::universe::physical_item_state::set_contact_after_collision( bool contact )
-{
-  m_contact_after_collision = contact;
-} // physical_item_state::set_contact_after_collision()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell if the item has a contact on its left.
@@ -933,10 +1042,19 @@ bool bear::universe::physical_item_state::has_middle_contact() const
  */
 bool bear::universe::physical_item_state::has_contact() const
 {
-  return m_bottom_contact || m_top_contact ||
-    m_right_contact || m_left_contact || m_middle_contact;
+  return has_side_contact() || m_middle_contact;
 } // physical_item_state::has_contact()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the item has a contact on one of his sides.
+ */
+bool bear::universe::physical_item_state::has_side_contact() const
+{
+  return m_bottom_contact || m_top_contact
+    || m_right_contact || m_left_contact;
+} // physical_item_state::has_side_contact()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell that the item has a contact on its left.
@@ -995,7 +1113,6 @@ void bear::universe::physical_item_state::clear_contacts()
 {
   m_left_contact = m_right_contact = m_top_contact = m_bottom_contact = false;
   m_middle_contact = false;
-  m_contact_after_collision = false;
   m_contact_friction = 1;
 } // physical_item_state::clear_contacts()
 
@@ -1143,9 +1260,8 @@ void bear::universe::physical_item_state::to_string( std::string& str ) const
   oss << "\ndensity: " << m_density;
   oss << "\nangle: " << m_system_angle;
   oss << "\nfixed: " << m_fixed << ' ' << m_x_fixed << ' ' << m_y_fixed;
-  oss << "\nphantom/c.m.i./art.: " << m_is_phantom << ' ' << m_can_move_items
-      << ' ' << m_is_artificial;
-  oss << "\ncontact after collision: " << m_contact_after_collision;
+  oss << "\nphantom/c.m.i./art./weak.: " << m_is_phantom << ' '
+      << m_can_move_items << ' ' << m_is_artificial << ' ' << m_weak_collisions;
   oss << "\ncontact: { ";
 
   if ( m_left_contact )
