@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -51,7 +51,8 @@ const unsigned int bear::universe::world::s_map_compression = 256;
  * \param size Size of the world.
  */
 bear::universe::world::world( const size_box_type& size )
-  : m_static_surfaces( (unsigned int)size.x + 1, (unsigned int)size.y + 1,
+  : m_time(0),
+    m_static_surfaces( (unsigned int)size.x + 1, (unsigned int)size.y + 1,
                        s_map_compression ),
     m_size(size), m_unit(50), m_gravity(0, -9.81*m_unit), m_default_friction(1),
     m_default_environment(air_environment), m_default_density(0),
@@ -91,11 +92,12 @@ void bear::universe::world::progress_entities
 ( const region_type& regions, time_type elapsed_time )
 {
   item_list items;
+  item_list potential_collision;
 
   lock();
 
   // search each item in the active zone and global item
-  search_interesting_items(regions, items);
+  search_interesting_items(regions, items, potential_collision);
   assert
     ( std::set<physical_item*>(items.begin(), items.end()).size()
       == items.size() );
@@ -107,15 +109,17 @@ void bear::universe::world::progress_entities
   progress_physic( elapsed_time, items );
 
   // collision detection
-  detect_collision_all( items );
+  detect_collision_all( items, potential_collision );
 
   // inform living_item if they go out the active zone
-  active_region_traffic( regions, items );
+  active_region_traffic( items );
 
   while ( !items.empty() )
     unselect_item( items, items.begin() );
 
   unlock();
+
+  m_time += elapsed_time;
 } // world::progress_entities()
 
 /*----------------------------------------------------------------------------*/
@@ -137,6 +141,15 @@ void bear::universe::world::add_static(physical_item* who)
   m_static_surfaces.insert( who );
 } // world::add_static()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the elapsed time since the creation of the world.
+ */
+bear::universe::time_type bear::universe::world::get_world_time() const
+{
+  return m_time;
+} // get_world_time()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the size of the world.
@@ -199,7 +212,8 @@ void bear::universe::world::set_scaled_gravity( const force_type& g )
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Get the current speed of the item.
+ * \brief Get the value under which the absolute value of the speed is
+ *        considered equals to zero.
  */
 const bear::universe::speed_type&
 bear::universe::world::get_speed_epsilon() const
@@ -209,7 +223,9 @@ bear::universe::world::get_speed_epsilon() const
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Set the current speed of the item.
+ * \brief Set the value under which the absolute value of the speed is
+ *        considered equals to zero.
+ * \param speed The minimum absolute speed.
  */
 void bear::universe::world::set_speed_epsilon( const speed_type& speed )
 {
@@ -218,8 +234,10 @@ void bear::universe::world::set_speed_epsilon( const speed_type& speed )
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Set the current speed of the item, call to_world_unit() on the given
+ * \brief Set the value under which the absolute value of the speed is
+ *        considered equals to zero. to_world_unit() is called on the given
  *        value.
+ * \param speed The minimum absolute speed.
  */
 void bear::universe::world::set_scaled_speed_epsilon( const speed_type& speed )
 {
@@ -316,7 +334,7 @@ bear::universe::force_type
 bear::universe::world::get_average_force( const rectangle_type& r ) const
 {
   const double r_area( r.area() );
-  force_type result(0,0);
+  force_type result(0, 0);
 
   if (r_area != 0)
     {
@@ -680,20 +698,23 @@ void bear::universe::world::list_active_items
 /**
  * \brief Detect and correct the collisions.
  * \param items (in/out) The items on which we detect the collisions.
+ * \param potential_collision The items in the world that can be involved in
+ *        collisions.
  */
-void bear::universe::world::detect_collision_all( item_list& items )
+void bear::universe::world::detect_collision_all
+( item_list& items, const item_list& potential_collision )
 {
   item_list pending;
 
   for (item_list::iterator it=items.begin(); it!=items.end(); ++it)
     if ( !(*it)->is_fixed() )
-      add_to_collision_queue(pending, *it);
+      add_to_collision_queue(pending, *it, potential_collision);
 
   while ( !pending.empty() )
     {
       physical_item* item(pick_next_collision(pending));
       item->get_world_progress_structure().unset_waiting_for_collision();
-      detect_collision( item, pending, items );
+      detect_collision( item, pending, items, potential_collision );
     }
 } // world::detect_collision_all()
 
@@ -745,9 +766,12 @@ bear::universe::world::pick_next_collision( item_list& pending ) const
  * \param pending (out) A list in which are added the items in collision.
  * \param all_items (out) The set of all items processed in the iteration of the
  *        current world::progress() call.
+ * \param potential_collision The items in the world that can be involved in
+ *        collisions.
  */
 void bear::universe::world::detect_collision
-( physical_item* item, item_list& pending, item_list& all_items ) const
+( physical_item* item, item_list& pending, item_list& all_items,
+  const item_list& potential_collision ) const
 {
   CLAW_PRECOND( !item->has_weak_collisions() );
 
@@ -769,13 +793,13 @@ void bear::universe::world::detect_collision
           item->get_world_progress_structure().meet(it);
 
           if ( it->get_bounding_box() != it_box )
-            add_to_collision_queue(pending, it);
+            add_to_collision_queue(pending, it, potential_collision);
         }
 
       if ( item->get_bounding_box() == item_box )
         add_to_collision_queue_no_neighborhood(pending, item);
       else
-        add_to_collision_queue(pending, item);
+        add_to_collision_queue(pending, item, potential_collision);
     }
 } // world::detect_collision()
 
@@ -820,14 +844,16 @@ bool bear::universe::world::process_collision
 /**
  * \brief Search all items interesting for a collision with an other item.
  * \param item The item for which we search the collisions.
+ * \param potential_collision The items in the world that can be involved
+ *        in collisions.
  * \param colliding (out) The colliding items.
  * \param mass (in/out) The largest mass of the items found in the collision.
  * \param area (in/out) The largest area of the collision with the items of mass
  *        \a mass.
  */
 void bear::universe::world::search_items_for_collision
-( const physical_item& item, item_list& colliding, double& mass,
-  double& area ) const
+( const physical_item& item, const item_list& potential_collision,
+  item_list& colliding, double& mass, double& area ) const
 {
   const rectangle_type r(item.get_bounding_box());
 
@@ -844,9 +870,8 @@ void bear::universe::world::search_items_for_collision
   item_list::const_iterator it;
 
   // add living item
-  for ( it=m_entities.begin(); it!=m_entities.end(); ++it )
-    if ( !(*it)->is_artificial() && (*it!=&item)
-         && (*it)->get_bounding_box().intersects(r)
+  for ( it=potential_collision.begin(); it!=potential_collision.end(); ++it )
+    if ( (*it!=&item) && (*it)->get_bounding_box().intersects(r)
          && !item.get_world_progress_structure().has_met(*it) )
       item_found_in_collision( item, *it, colliding, mass, area );
 } // world::search_items_for_collision()
@@ -918,9 +943,12 @@ void bear::universe::world::search_pending_items_for_collision
  *  and add dependent items.
  * \param regions The active regions.
  * \param items (out) The items in the region.
+ * \param potential_collision (out) The items in the world that can be involved
+ *        in collisions.
  */
 void bear::universe::world::search_interesting_items
-( const region_type& regions, item_list& items ) const
+( const region_type& regions, item_list& items,
+  item_list& potential_collision ) const
 {
   item_list::const_iterator it;
 
@@ -937,8 +965,13 @@ void bear::universe::world::search_interesting_items
 
   // add living item of the active zone and global living item
   for ( it=m_entities.begin(); it!=m_entities.end(); ++it )
-    if ( (*it)->is_global() || item_in_regions(**it, regions) )
-      select_item(items, *it);
+    {
+      if ( (*it)->is_global() || item_in_regions(**it, regions) )
+        select_item(items, *it);
+
+      if ( !(*it)->is_artificial() )
+        potential_collision.push_back(*it);
+    }
 
   // add dependent item
   stabilize_dependent_items(items);
@@ -1093,11 +1126,9 @@ void bear::universe::world::apply_links(const item_list& items) const
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell items if they leave the active region.
- * \param regions A list of regions in which we take the items.
  * \param items The items to verify.
  */
-void bear::universe::world::active_region_traffic
-( const region_type& regions, const item_list& items )
+void bear::universe::world::active_region_traffic( const item_list& items )
 {
   item_list::const_iterator it;
 
@@ -1159,7 +1190,13 @@ void bear::universe::world::remove(physical_item* const& who)
   item_list::iterator it = std::find( m_entities.begin(), eit, who );
 
   if ( it != eit )
-    m_entities.erase(it);
+    {
+      m_entities.erase(it);
+      (*it)->quit_owner();
+    }
+  else
+    claw::logger << claw::log_warning << "Can't remove unknown item " << *who
+                 << std::endl;
 
   eit = m_last_interesting_items.end();
   it = std::find( m_last_interesting_items.begin(), eit, who );
@@ -1211,12 +1248,15 @@ void bear::universe::world::unselect_item
  * \brief Add an item in the queue for collision detection.
  * \param pending (out) List of items to which is added the item.
  * \param item The item to add.
+ * \param potential_collision The items in the world that can be involved in
+ *        collisions.
  */
 void bear::universe::world::add_to_collision_queue
-( item_list& pending, physical_item* item ) const
+( item_list& pending, physical_item* item,
+  const item_list& potential_collision ) const
 {
   if ( !item->has_weak_collisions() && !item->is_artificial() )
-    if ( create_neighborhood(*item) )
+    if ( create_neighborhood(*item, potential_collision) )
       if ( !item->get_world_progress_structure().is_waiting_for_collision() )
         {
           item->get_world_progress_structure().set_waiting_for_collision();
@@ -1246,14 +1286,17 @@ void bear::universe::world::add_to_collision_queue_no_neighborhood
 /**
  * \brief Find the neighborhood of an item.
  * \param item The item for which we want the neighborhood.
+ * \param potential_collision The items in the world that can be involved in
+ *        collisions.
  */
-bool bear::universe::world::create_neighborhood( physical_item& item ) const
+bool bear::universe::world::create_neighborhood
+( physical_item& item, const item_list& potential_collision ) const
 {
   item_list n;
   double area(0);
   double mass(0);
 
-  search_items_for_collision( item, n, mass, area );
+  search_items_for_collision( item, potential_collision, n, mass, area );
 
   bool result(!n.empty());
   item.get_world_progress_structure().set_collision_neighborhood(n, mass, area);
