@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -75,3 +75,25 @@ bear::universe::zone::find
 
   return result;
 } // zone::find()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the opposite side of a given side.
+ * \param side The side from which we want the opposite.
+ */
+bear::universe::zone::position
+bear::universe::zone::opposite_of( position side )
+{
+  switch(side)
+  {
+  case top_left_zone: return bottom_right_zone;
+  case top_zone: return bottom_zone;
+  case top_right_zone: return bottom_left_zone;
+  case middle_left_zone: return middle_right_zone;
+  case middle_zone: return middle_zone;
+  case middle_right_zone: return middle_left_zone;
+  case bottom_left_zone: return top_right_zone;
+  case bottom_zone: return top_zone;
+  case bottom_right_zone: return top_left_zone;
+  }
+} // zone::opposite_of()
