@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -60,8 +60,7 @@ namespace bear
       const physical_item_state& other_previous_state() const;
       const physical_item_state& reference_previous_state() const;
 
-      physical_item& other_item();
-      const physical_item& other_item() const;
+      physical_item& other_item() const;
 
       collision_repair& get_collision_repair() const;
 
