@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -36,40 +36,6 @@ namespace bear
 {
   namespace universe
   {
-    /**
-     * \brief Utility class to find the adequate item handle type from a item
-     *        type.
-     *
-     * This class defines a type named handle_type which is const_item_handle
-     * for 'const' types, or item_handle otherwise.
-     *
-     * \author Julien Jorge
-     */
-    template<typename ItemType>
-    class item_handle_maker
-    {
-    public:
-      typedef item_handle handle_type;
-
-    }; // class handle_maker
-
-    /**
-     * \brief Utility class to find the adequate item handle type from a item
-     *        type.
-     *
-     * This class defines a type named handle_type which is const_item_handle
-     * for 'const' types, or item_handle otherwise.
-     *
-     * \author Julien Jorge
-     */
-    template<typename ItemType>
-    class item_handle_maker<const ItemType>
-    {
-    public:
-      typedef const_item_handle handle_type;
-
-    }; // class handle_maker
-
     /**
      * \brief Safe way to point an item that could die between two uses.
      * \author Julien Jorge
@@ -109,12 +75,12 @@ namespace bear
      *
      * \sa derived_item_handle_maker, const_derived_item_handle_maker
      */
-    template<typename DerivedType, typename ItemType>
+    template<typename DerivedType, typename ItemType = physical_item>
     class derived_item_handle
     {
     public:
       typedef derived_item_handle<DerivedType, ItemType> self_type;
-      typedef typename item_handle_maker<ItemType>::handle_type handle_type;
+      typedef item_handle handle_type;
       typedef ItemType item_type;
       typedef DerivedType derived_type;
 
@@ -160,12 +126,12 @@ namespace bear
      *
      * \sa derived_item_handle, const_derived_item_handle_maker
      */
-    template<typename DerivedType, typename ItemType>
+    template<typename DerivedType, typename ItemType = const physical_item>
     class const_derived_item_handle
     {
     public:
       typedef const_derived_item_handle<DerivedType, ItemType> self_type;
-      typedef typename item_handle_maker<ItemType>::handle_type handle_type;
+      typedef const_item_handle handle_type;
       typedef ItemType item_type;
       typedef DerivedType derived_type;
 
@@ -210,32 +176,41 @@ namespace bear
      *        constant class type inheriting from physical_item.
      */
     template<typename DerivedType>
-    struct derived_item_handle_maker
-    {
-      typedef derived_item_handle<DerivedType, physical_item> handle_type;
-
-      static handle_type make_from( DerivedType* item );
-
-    }; // struct derived_item_handle_maker
+    derived_item_handle<DerivedType> item_handle_from( DerivedType* item );
 
     /**
      * \brief A wrapper to easily create a derived_item_handle for a constant
      *        class type inheriting from physical_item.
      */
     template<typename DerivedType>
-    struct const_derived_item_handle_maker
-    {
-      typedef
-      const_derived_item_handle<const DerivedType, const physical_item>
-      handle_type;
-
-      static handle_type make_from( DerivedType* item );
-
-    }; // struct const derived_item_handle_maker
+    const_derived_item_handle<DerivedType>
+    const_item_handle_from( const DerivedType* item );
 
   } // namespace universe
 } // namespace bear
 
+template<typename DerivedType, typename ItemType>
+bool operator==
+( const DerivedType* item,
+  const bear::universe::derived_item_handle<DerivedType, ItemType>& handle );
+
+template<typename DerivedType, typename ItemType>
+bool operator!=
+( const DerivedType* item,
+  const bear::universe::derived_item_handle<DerivedType, ItemType>& handle );
+
+template<typename DerivedType, typename ItemType>
+bool operator==
+( const DerivedType* item,
+  const bear::universe::const_derived_item_handle<DerivedType, ItemType>&
+  handle );
+
+template<typename DerivedType, typename ItemType>
+bool operator!=
+( const DerivedType* item,
+  const bear::universe::const_derived_item_handle<DerivedType, ItemType>&
+  handle );
+
 #include "universe/impl/derived_item_handle.tpp"
 
 #endif // __UNIVERSE_DERIVED_ITEM_HANDLE_HPP__
