@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,7 +30,7 @@
 #define __UNIVERSE_BASE_FORCED_MOVEMENT_HPP__
 
 #include "universe/item_handle.hpp"
-#include "universe/types.hpp"
+#include "universe/forced_movement/reference_point.hpp"
 
 #include "universe/class_export.hpp"
 
@@ -59,7 +59,12 @@ namespace bear
 
       void clear_item();
       void set_item( physical_item& item );
-      void set_reference_item( physical_item& item );
+
+      bool has_reference_point() const;
+      void set_reference_point( const reference_point& r );
+      position_type get_reference_position() const;
+
+      void set_reference_point_on_center( physical_item& item );
       bool has_reference_item() const;
       physical_item& get_reference_item() const;
 
@@ -80,8 +85,8 @@ namespace bear
       /** \brief The item currently moving. */
       item_handle m_moving_item;
 
-      /** \brief An item used as a reference in the movement. */
-      item_handle m_reference_item;
+      /** \brief An computation of the reference point. */
+      reference_point m_reference_point;
 
       /** \brief Tell if the movement removes himself from the moving item when
           finished. */
