@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,6 +28,7 @@
  */
 #include "universe/forced_movement/base_forced_movement.hpp"
 
+#include "universe/forced_movement/center_of_mass_reference_point.hpp"
 #include "universe/physical_item.hpp"
 
 #include <claw/assert.hpp>
@@ -38,7 +39,7 @@
  * \brief Constructor.
  */
 bear::universe::base_forced_movement::base_forced_movement()
-  : m_moving_item(NULL), m_reference_item(NULL), m_auto_remove(false)
+  : m_moving_item(NULL), m_auto_remove(false)
 {
 
 } // base_forced_movement::base_forced_movement()
@@ -86,14 +87,45 @@ void bear::universe::base_forced_movement::set_item( physical_item& item )
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Set the item used as a reference by this movement.
- * \param item The item used as a reference by this movement.
+ * \brief Tell if the reference point used by this movement is valid.
  */
-void bear::universe::base_forced_movement::set_reference_item
+bool bear::universe::base_forced_movement::has_reference_point() const
+{
+  return m_reference_point.is_valid();
+} // base_forced_movement::has_reference_point()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set the reference point used by this movement.
+ * \param r The reference point.
+ */
+void bear::universe::base_forced_movement::set_reference_point
+( const reference_point& r )
+{
+  m_reference_point = r;
+} // base_forced_movement::set_reference_point()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the point used as the reference for the movement.
+ */
+bear::universe::position_type
+bear::universe::base_forced_movement::get_reference_position() const
+{
+  CLAW_PRECOND( has_reference_item() );
+  return m_reference_point.get_point();
+} // base_forced_movement::get_reference_position()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set the reference point on the center of mass of a given item.
+ * \param item The item of which we use the center of mass.
+ */
+void bear::universe::base_forced_movement::set_reference_point_on_center
 ( physical_item& item )
 {
-  m_reference_item = &item;
-} // base_forced_movement::set_reference_item()
+  set_reference_point( center_of_mass_reference_point(item) );
+} // base_forced_movement::set_reference_point_on_center()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -101,7 +133,7 @@ void bear::universe::base_forced_movement::set_reference_item
  */
 bool bear::universe::base_forced_movement::has_reference_item() const
 {
-  return m_reference_item != NULL;
+  return m_reference_point.has_item();
 } // base_forced_movement::has_reference_item()
 
 /*----------------------------------------------------------------------------*/
@@ -114,7 +146,7 @@ bear::universe::base_forced_movement::get_reference_item() const
 {
   CLAW_PRECOND( has_reference_item() );
 
-  return *m_reference_item;
+  return m_reference_point.get_item();
 } // base_forced_movement::get_reference_item()
 
 /*----------------------------------------------------------------------------*/
