@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -122,7 +122,7 @@ void bear::universe::forced_aiming::set_total_time( time_type length )
  */
 bool bear::universe::forced_aiming::is_finished() const
 {
-  return !has_reference_item() || (m_remaining_time == 0);
+  return !has_reference_point() || (m_remaining_time == 0);
 } // forced_aiming::is_finished()
 
 /*----------------------------------------------------------------------------*/
@@ -145,7 +145,7 @@ bear::universe::forced_aiming::do_next_position( time_type elapsed_time )
 {
   time_type remaining_time(0);
 
-  if ( has_reference_item() )
+  if ( has_reference_point() )
     {
       remaining_time = compute_remaining_time(elapsed_time);
 
@@ -220,11 +220,14 @@ bear::universe::forced_aiming::compute_direction( vector_type& dir ) const
 
   dir = vector_type
     ( get_item().get_center_of_mass(),
-      get_reference_item().get_center_of_mass() );
+      get_reference_position() );
 
   current_dir.normalize();
   dir.normalize();
 
+  if ( current_dir == vector_type(0, 0) )
+    current_dir = dir;
+
   double v = dir.dot_product(current_dir);
 
   if ( v > 1 )
