@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -66,7 +66,7 @@ void bear::universe::forced_join::set_total_time( time_type length )
  */
 bool bear::universe::forced_join::is_finished() const
 {
-  return !has_reference_item() || (m_remaining_time == 0);
+  return !has_reference_point() || (m_remaining_time == 0);
 } // forced_join::is_finished()
 
 /*----------------------------------------------------------------------------*/
@@ -89,10 +89,9 @@ bear::universe::forced_join::do_next_position( time_type elapsed_time )
 {
   time_type remaining_time(0);
 
-  if ( has_reference_item() )
+  if ( has_reference_point() )
     {
-      const position_type target_center =
-        get_reference_item().get_center_of_mass();
+      const position_type target_center = get_reference_position();
       const position_type item_center = get_item().get_center_of_mass();
       position_type dp = target_center - item_center;
 
