@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -139,16 +139,50 @@ void bear::universe::forced_movement::set_item( physical_item& item )
   m_movement->set_item(item);
 } // forced_movement::set_item()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the reference point used by this movement is valid.
+ */
+bool bear::universe::forced_movement::has_reference_point() const
+{
+  CLAW_PRECOND( !is_null() );
+  return m_movement->has_reference_point();
+} // forced_movement::has_reference_point()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set the reference point used by this movement.
+ * \param r The reference point.
+ */
+void bear::universe::forced_movement::set_reference_point
+( const reference_point& r )
+{
+  CLAW_PRECOND( !is_null() );
+  m_movement->set_reference_point(r);
+} // forced_movement::set_reference_point()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the point used as the reference for the movement.
+ */
+bear::universe::position_type
+bear::universe::forced_movement::get_reference_position() const
+{
+  CLAW_PRECOND( !is_null() );
+  return m_movement->get_reference_position();
+} // forced_movement::get_reference_position()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set the item used as a reference by this movement.
  * \param item The item used as a reference by this movement.
  */
-void bear::universe::forced_movement::set_reference_item( physical_item& item )
+void bear::universe::forced_movement::set_reference_point_on_center
+( physical_item& item )
 {
   CLAW_PRECOND( !is_null() );
-  m_movement->set_reference_item(item);
-} // forced_movement::set_reference_item()
+  m_movement->set_reference_point_on_center( item );
+} // forced_movement::set_reference_point_on_center()
 
 /*----------------------------------------------------------------------------*/
 /**
