@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -159,9 +159,9 @@ bool bear::universe::forced_rotation::is_finished() const
 void bear::universe::forced_rotation::do_init()
 {
   if ( m_radius == std::numeric_limits<double>::infinity() )
-    if ( has_reference_item() )
+    if ( has_reference_point() )
       m_radius =
-        get_reference_item().get_center_of_mass().distance
+        get_reference_position().distance
         ( get_item().get_center_of_mass() );
 
   m_speed_generator.set_distance(m_end_angle - m_start_angle);
@@ -173,6 +173,8 @@ void bear::universe::forced_rotation::do_init()
   m_angle = m_start_angle;
   m_loop_count = 0;
   m_is_playing_forward = true;
+
+  set_item_position();
 } // forced_rotation::do_init()
 
 /*----------------------------------------------------------------------------*/
@@ -273,10 +275,10 @@ void bear::universe::forced_rotation::start_reached()
  */
 void bear::universe::forced_rotation::set_item_position()
 {
-  if ( has_reference_item() )
+  if ( has_reference_point() )
     {
       position_type pos;
-      pos = get_reference_item().get_center_of_mass();
+      pos = get_reference_position();
 
       pos.x += (m_radius * cos( m_angle ));
       pos.y += (m_radius * sin( m_angle ));
