@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -103,7 +103,7 @@ bear::universe::forced_tracking::get_distance() const
  */
 bool bear::universe::forced_tracking::is_finished() const
 {
-  return !has_reference_item() || (m_remaining_time == 0);
+  return !has_reference_point() || (m_remaining_time == 0);
 } // forced_tracking::is_finished()
 
 /*----------------------------------------------------------------------------*/
@@ -114,15 +114,15 @@ void bear::universe::forced_tracking::do_init()
 {
   m_remaining_time = m_total_time;
 
-  if ( has_reference_item() )
+  if ( has_reference_point() )
     {
       if ( m_distance.x == std::numeric_limits<coordinate_type>::infinity() )
         m_distance.x = get_item().get_center_of_mass().x
-          - get_reference_item().get_center_of_mass().x;
+          - get_reference_position().x;
 
       if ( m_distance.y == std::numeric_limits<coordinate_type>::infinity() )
         m_distance.y = get_item().get_center_of_mass().y
-          - get_reference_item().get_center_of_mass().y;
+          - get_reference_position().y;
     }
 
   next_position(0);
@@ -139,10 +139,9 @@ bear::universe::forced_tracking::do_next_position( time_type elapsed_time )
 {
   time_type result(0);
 
-  if ( has_reference_item() )
+  if ( has_reference_point() )
     {
-      get_item().set_center_of_mass
-        ( get_reference_item().get_center_of_mass() + m_distance );
+      get_item().set_center_of_mass( get_reference_position() + m_distance );
 
       if ( m_remaining_time < elapsed_time )
         {
