@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,6 +29,7 @@
 #ifndef __UNIVERSE_FORCED_MOVEMENT_HPP__
 #define __UNIVERSE_FORCED_MOVEMENT_HPP__
 
+#include "universe/forced_movement/reference_point.hpp"
 #include "universe/types.hpp"
 
 #include "universe/class_export.hpp"
@@ -43,7 +44,7 @@ namespace bear
     /**
      * \brief An interface to the forced movements.
      *
-     * If an item have a forced movement, the physical rules won't apply to him.
+     * If an item has a forced movement, the physical rules won't apply to him.
      *
      * \author Julien Jorge
      */
@@ -64,7 +65,12 @@ namespace bear
 
       void clear_item();
       void set_item( physical_item& item );
-      void set_reference_item( physical_item& item );
+
+      bool has_reference_point() const;
+      void set_reference_point( const reference_point& r );
+      position_type get_reference_position() const;
+
+      void set_reference_point_on_center( physical_item& item );
       bool has_reference_item() const;
       physical_item& get_reference_item() const;
 
