@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -76,4 +76,11 @@ namespace bear
   } // namespace universe
 } // namespace bear
 
+bool operator==
+( const bear::universe::physical_item* a,
+  const bear::universe::item_handle& b );
+bool operator!=
+( const bear::universe::physical_item* a,
+  const bear::universe::item_handle& b );
+
 #endif // __UNIVERSE_ITEM_HANDLE_HPP__
