@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -105,6 +105,7 @@ namespace bear
 
       // public only for world
       void set_owner(world& owner);
+      void quit_owner();
       world_progress_structure& get_world_progress_structure();
       const world_progress_structure& get_world_progress_structure() const;
       // -end- public only for world
@@ -130,9 +131,10 @@ namespace bear
       bool has_owner() const;
       const world& get_owner() const;
 
+      bool default_collision( collision_info& info );
+
     protected:
       void default_move( time_type elapsed_time );
-      bool default_collision( collision_info& info );
 
       bool collision_align( collision_info& info );
 
@@ -161,6 +163,9 @@ namespace bear
 
       void update_position( time_type elapsed_time );
 
+      void remove_all_handles() const;
+
+      // not implemented
       physical_item& operator=(const physical_item&);
 
     private:
@@ -174,10 +179,10 @@ namespace bear
       link_list_type m_links;
 
       /** \brief The handles on me. */
-      handle_list* m_handles;
+      mutable handle_list m_handles;
 
       /** \brief The handles on me. */
-      const_handle_list* m_const_handles;
+      mutable const_handle_list m_const_handles;
 
       /** \brief The world in which this item lives. */
       world* m_owner;
