@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -93,9 +93,6 @@ namespace bear
       /** \brief Tell if the item can move an other item. */
       bool m_can_move_items;
 
-      /** \brief Tell if the item has a contact after collision detection. */
-      bool m_contact_after_collision;
-
       /** \brief Tell if the item is in contact with an other item on its
           left. */
       bool m_left_contact;
