@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -75,6 +75,7 @@ namespace bear
 
       const speed_type& get_speed() const;
       void set_speed( const speed_type& speed );
+      void set_speed( double x, double y );
 
       double get_angular_speed() const;
       void set_angular_speed( double speed );
@@ -111,6 +112,20 @@ namespace bear
       void set_left_middle( const position_type& pos );
       void set_right_middle( const position_type& pos );
 
+      void set_top_left( const coordinate_type& x, const coordinate_type& y );
+      void set_top_middle( const coordinate_type& x, const coordinate_type& y );
+      void set_top_right( const coordinate_type& x, const coordinate_type& y );
+      void set_bottom_left
+        ( const coordinate_type& x, const coordinate_type& y );
+      void set_bottom_middle
+        ( const coordinate_type& x, const coordinate_type& y );
+      void set_bottom_right
+        ( const coordinate_type& x, const coordinate_type& y );
+      void set_left_middle
+        ( const coordinate_type& x, const coordinate_type& y );
+      void set_right_middle
+        ( const coordinate_type& x, const coordinate_type& y );
+
       coordinate_type get_left() const;
       coordinate_type get_top() const;
       coordinate_type get_right() const;
@@ -131,6 +146,7 @@ namespace bear
       void set_center_of_mass
         ( const coordinate_type& x, const coordinate_type& y );
       void set_center_of_mass( const position_type& pos );
+      void set_center_on( const physical_item_state& that );
 
       bool is_fixed() const;
       void fix();
@@ -147,15 +163,13 @@ namespace bear
       bool is_global() const;
       void set_global( bool global );
 
-      bool has_contact_after_collision() const;
-      void set_contact_after_collision(bool contact);
-
       bool has_left_contact() const;
       bool has_right_contact() const;
       bool has_top_contact() const;
       bool has_bottom_contact() const;
       bool has_middle_contact() const;
       bool has_contact() const;
+      bool has_side_contact() const;
 
       void set_left_contact(bool contact = true);
       void set_right_contact(bool contact = true);
