@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -81,6 +81,8 @@ namespace bear
 
       void add_static(physical_item* who);
 
+      time_type get_world_time() const;
+
       const size_box_type& get_size() const;
       void print_stats() const;
 
@@ -137,17 +139,19 @@ namespace bear
         const item_picking_filter& filter = item_picking_filter() ) const;
 
     private:
-      void detect_collision_all(  item_list& items );
+      void detect_collision_all
+        ( item_list& items, const item_list& potential_collision );
       physical_item* pick_next_collision( item_list& pending ) const;
 
       void detect_collision
-      ( physical_item* item, item_list& pending, item_list& all_items ) const;
+      ( physical_item* item, item_list& pending, item_list& all_items,
+        const item_list& potential_collision ) const;
 
       bool process_collision( physical_item& self, physical_item& that ) const;
 
       void search_items_for_collision
-      ( const physical_item& item, item_list& colliding, double& mass,
-        double& area ) const;
+        ( const physical_item& item, const item_list& potential_collision,
+          item_list& colliding, double& mass, double& area ) const;
 
       void item_found_in_collision
       ( const physical_item& item, physical_item* it, item_list& colliding,
@@ -158,7 +162,8 @@ namespace bear
         std::list<item_list::iterator>& colliding ) const;
 
       void search_interesting_items
-      ( const region_type& regions, item_list& items ) const;
+      ( const region_type& regions, item_list& items,
+        item_list& potential_collision ) const;
 
       void stabilize_dependent_items( item_list& items ) const;
 
@@ -171,8 +176,7 @@ namespace bear
       ( time_type elapsed_time, physical_item& item ) const;
       void apply_links(const item_list& items) const;
 
-      void active_region_traffic
-      ( const region_type& regions, const item_list& items );
+      void active_region_traffic( const item_list& items );
 
       void list_static_items
       ( const region_type& regions, item_list& items ) const;
@@ -186,16 +190,21 @@ namespace bear
       bool select_item( item_list& items, physical_item* it ) const;
       void unselect_item( item_list& items, item_list::iterator it ) const;
 
-      void
-      add_to_collision_queue( item_list& items, physical_item* item ) const;
+      void add_to_collision_queue
+        ( item_list& items, physical_item* item,
+          const item_list& potential_collision ) const;
       void add_to_collision_queue_no_neighborhood
       ( item_list& items, physical_item* item ) const;
-      bool create_neighborhood( physical_item& item ) const;
+      bool create_neighborhood
+        ( physical_item& item, const item_list& potential_collision ) const;
 
     private:
       /** \brief Size of the parts of m_static_surfaces. */
       static const unsigned int s_map_compression;
 
+      /** \brief The elapsed time since the creation of the world. */
+      time_type m_time;
+
       /** \brief The living entities. Can be added and deleted any time. */
       item_list m_entities;
 
