@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -68,7 +68,7 @@ namespace bear
 
       virtual void draw_line
       ( const color_type& color,
-        const std::vector<position_type>& p, double w ) = 0;
+        const std::vector<position_type>& p, double w, bool close = false ) = 0;
       virtual void draw_polygon
       ( const color_type& color,
         const std::vector<position_type>& p ) = 0;
