@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,6 +28,8 @@
  */
 #include "visual/base_scene_element.hpp"
 
+#include "visual/scene_element.hpp"
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
@@ -77,7 +79,11 @@ bear::visual::base_scene_element::get_opaque_box() const
 bear::visual::rectangle_type
 bear::visual::base_scene_element::get_bounding_box() const
 {
-  return rectangle_type(0, 0, 0, 0);
+  return
+    rectangle_type
+    ( m_position.x, m_position.y,
+      m_position.x + m_rendering_attributes.width() * get_scale_factor_x(),
+      m_position.y + m_rendering_attributes.height() * get_scale_factor_y() );
 } // base_scene_element::get_bounding_box()
 
 /*----------------------------------------------------------------------------*/
@@ -89,7 +95,7 @@ bear::visual::base_scene_element::get_bounding_box() const
 void bear::visual::base_scene_element::burst
 ( const rectangle_list& boxes, scene_element_list& output ) const
 {
-  // nothing to do
+  output.push_back( scene_element(*this) );
 } // base_scene_element::burst()
 
 /*----------------------------------------------------------------------------*/
