@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -333,3 +333,20 @@ void bear::visual::bitmap_rendering_attributes::combine
   set_opacity( that.get_opacity() * get_opacity() );
   set_angle( that.get_angle() + get_angle() );
 } // bitmap_rendering_attributes::combine()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Apply the intensity and the opacities to a given color.
+ * \param c The color.
+ */
+bear::visual::color_type
+bear::visual::bitmap_rendering_attributes::convert_color
+( const color_type& c ) const
+{
+  return
+    color_type
+    ( c.components.red * get_red_intensity(),
+      c.components.green * get_green_intensity(),
+      c.components.blue * get_blue_intensity(),
+      c.components.alpha * get_opacity() );
+} // bitmap_rendering_attributes::convert_color()
