@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -104,7 +104,7 @@ void bear::visual::gl_image::create_texture()
                GL_UNSIGNED_BYTE, NULL );
 
   if ( glGetError() != GL_NO_ERROR )
-    throw CLAW_EXCEPTION( "OpenGL error" );
+    throw claw::exception( "OpenGL error" );
 } // gl_image::create_texture()
 
 /*----------------------------------------------------------------------------*/
