@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -48,12 +48,12 @@ void bear::visual::gl_screen::initialize()
 {
   if ( !SDL_WasInit(SDL_INIT_VIDEO) )
     if ( SDL_InitSubSystem(SDL_INIT_VIDEO) != 0 )
-      throw CLAW_EXCEPTION( SDL_GetError() );
+      throw claw::exception( SDL_GetError() );
 
   if ( SDL_GL_SetAttribute( SDL_GL_DOUBLEBUFFER, 1 ) != 0 )
     {
       SDL_QuitSubSystem(SDL_INIT_VIDEO);
-      throw CLAW_EXCEPTION( SDL_GetError() );
+      throw claw::exception( SDL_GetError() );
     }
 
   for (unsigned int i=0; i!=SDL_USEREVENT; ++i)
@@ -84,7 +84,7 @@ void bear::visual::gl_screen::release()
 bear::visual::gl_screen::gl_screen
 ( const claw::math::coordinate_2d<unsigned int>& size,
   const std::string& title, bool full )
-  : m_size(size), m_screenshot_buffer(NULL)
+  : m_size(size), m_screenshot_buffer(NULL), m_title(title)
 {
   fullscreen(full);
   m_need_restoration = false;
@@ -92,6 +92,14 @@ bear::visual::gl_screen::gl_screen
   SDL_WM_SetCaption( title.c_str(), NULL );
   glEnable(GL_TEXTURE_2D);
 
+#ifdef BEAR_USE_GL_DEPTH_TEST
+  glEnable(GL_DEPTH_TEST);
+  glDepthFunc(GL_LEQUAL);
+#endif
+
+  glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_FASTEST);
+  glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
   resize_view(m_size.x, m_size.y);
 } // gl_screen::gl_screen() [constructor]
 
@@ -117,7 +125,7 @@ bear::visual::gl_screen::resize_view(unsigned int width, unsigned int height)
   glViewport(0, 0, width, height );
   glMatrixMode(GL_PROJECTION);
   glLoadIdentity();
-  glOrtho( 0, m_size.x, 0, m_size.y, 0, 1 );
+  glOrtho( 0, m_size.x, 0, m_size.y, -1, 0 );
   glMatrixMode(GL_MODELVIEW);
 
   delete[] m_screenshot_buffer;
@@ -207,7 +215,8 @@ bear::visual::color_type bear::visual::gl_screen::get_background_color() const
  */
 void bear::visual::gl_screen::begin_render()
 {
-  glClear( GL_COLOR_BUFFER_BIT );
+  glClear( GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT );
+  m_z_position = 0;
 } // gl_screen::begin_render()
 
 /*----------------------------------------------------------------------------*/
@@ -220,10 +229,7 @@ void bear::visual::gl_screen::render
 ( const position_type& pos, const sprite& s )
 {
   if ( s.has_transparency() )
-    {
-      glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
-      glEnable(GL_BLEND);
-    }
+    glEnable(GL_BLEND);
 
   glColor4f( s.get_red_intensity(), s.get_green_intensity(),
              s.get_blue_intensity(), s.get_opacity() );
@@ -270,10 +276,11 @@ bool bear::visual::gl_screen::end_render()
  * \param color The color of the line.
  * \param p The points of the line.
  * \param w The width of the line.
+ * \param close Tell if the line come back to the first coordinate.
  */
 void bear::visual::gl_screen::draw_line
 ( const color_type& color, const std::vector<position_type>& p,
-  double w )
+  double w, bool close )
 {
   glBindTexture( GL_TEXTURE_2D, 0 );
   glLineWidth(w);
@@ -292,10 +299,15 @@ void bear::visual::gl_screen::draw_line
          (GLfloat)color.components.alpha / max );
 
     for ( unsigned int i=0; i!=p.size(); ++i )
-      glVertex2f( p[i].x, p[i].y );
+      glVertex3f( p[i].x, p[i].y, m_z_position );
+
+    if ( close )
+      glVertex3f( p[0].x, p[0].y, m_z_position );
   }
   glEnd();
 
+  update_z_position();
+
   if (color.components.alpha != max)
     glDisable(GL_BLEND);
 
@@ -326,10 +338,12 @@ void bear::visual::gl_screen::draw_polygon
          (GLfloat)color.components.alpha / max );
 
     for ( unsigned int i=0; i!=p.size(); ++i )
-      glVertex2f( p[i].x, p[i].y );
+      glVertex3f( p[i].x, p[i].y, m_z_position );
   }
   glEnd();
 
+  update_z_position();
+
   if (color.components.alpha != max)
     glDisable(GL_BLEND);
 
@@ -427,22 +441,24 @@ void bear::visual::gl_screen::render_image
   {
     // Top-left corner
     glTexCoord2d( clip.first_point.x, clip.first_point.y );
-    glVertex2d(render_coord[0].x, render_coord[0].y);
+    glVertex3d(render_coord[0].x, render_coord[0].y, m_z_position);
 
     // Top-right corner
     glTexCoord2d( clip.second_point.x, clip.first_point.y );
-    glVertex2d(render_coord[1].x, render_coord[1].y);
+    glVertex3d(render_coord[1].x, render_coord[1].y, m_z_position);
 
     // Bottom-right corner
     glTexCoord2d( clip.second_point.x, clip.second_point.y );
-    glVertex2d(render_coord[2].x, render_coord[2].y);
+    glVertex3d(render_coord[2].x, render_coord[2].y, m_z_position);
 
     // Bottom-left corner
     glTexCoord2d( clip.first_point.x, clip.second_point.y );
-    glVertex2d(render_coord[3].x, render_coord[3].y);
+    glVertex3d(render_coord[3].x, render_coord[3].y, m_z_position);
   }
   glEnd();
 
+  update_z_position();
+
   failure_check( __FUNCTION__ );
 } // gl_screen::render_image()
 
@@ -451,11 +467,8 @@ claw::math::coordinate_2d<GLdouble> bear::visual::gl_screen::rotate
 ( const claw::math::coordinate_2d<GLdouble>& pos, GLdouble a,
   const claw::math::coordinate_2d<GLdouble>& center ) const
 {
-  claw::math::coordinate_2d<GLdouble> result(center);
-
-  result.x += (pos.x - center.x) * cos(a) - (pos.y - center.y) * sin(a);
-  result.y += (pos.x - center.x) * sin(a) + (pos.y - center.y) * cos(a);
-
+  claw::math::coordinate_2d<GLdouble> result(pos);
+  result.rotate(center, a);
   return result;
 } // gl_screen::rotate()
 
@@ -529,7 +542,7 @@ void bear::visual::gl_screen::set_video_mode
   SDL_Surface* s = SDL_SetVideoMode( w, h, 32, flags );
 
   if (!s)
-    throw CLAW_EXCEPTION( SDL_GetError() );
+    throw claw::exception( SDL_GetError() );
 
   SDL_ShowCursor(0);
 
@@ -540,6 +553,10 @@ void bear::visual::gl_screen::set_video_mode
 
 #ifdef _WIN32
   glEnable(GL_TEXTURE_2D);
+  glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
+
+  SDL_WM_SetCaption( m_title.c_str(), NULL );
+
   m_need_restoration = true;
 #endif
 } // gl_screen::set_video_mode()
@@ -569,3 +586,12 @@ bool bear::visual::gl_screen::is_closed()
 
   return result;
 } // gl_screen::is_closed()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Update the z position at with the next element will be rendered.
+ */
+void bear::visual::gl_screen::update_z_position()
+{
+  m_z_position += std::numeric_limits<GLdouble>::epsilon();
+} // gl_screen::update_z_position()
