@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -85,7 +85,7 @@ void bear::visual::image::restore(const claw::graphic::image& data)
       *m_impl = new gl_image(data);
       break;
     case screen::screen_undef:
-      CLAW_EXCEPTION("screen sub system has not been set.");
+      claw::exception("screen sub system has not been set.");
     }
 } // image::restore()
 
