@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -110,7 +110,7 @@ bear::visual::screen::screen
       m_impl = new gl_screen(size, title, full);
       break;
     case screen_undef:
-      CLAW_EXCEPTION("screen sub system has not been set.");
+      claw::exception("screen sub system has not been set.");
     }
 } // screen::screen()
 
@@ -274,12 +274,12 @@ void bear::visual::screen::shot( claw::graphic::image& img ) const
  */
 void bear::visual::screen::render_elements()
 {
-#if 0 // dumb rendering
+#ifdef BEAR_DUMB_RENDERING
   for ( ; !m_scene_element.empty(); m_scene_element.pop_front() )
     m_scene_element.front().render(*m_impl);
 #else
-  scene_element_list final_elements; // elements to render, finally
-  rectangle_list boxes;              // empty parts of the screen
+  scene_element_list final_elements; // Elements to render, finally.
+  rectangle_list boxes;              // Empty parts of the screen.
 
   boxes.push_front( rectangle_type(0, 0, get_size().x, get_size().y) );
 
