@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -85,6 +85,15 @@ void bear::visual::sprite_sequence::next()
     }
 } // sprite_sequence::next()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the sequence is empty.
+ */
+bool bear::visual::sprite_sequence::empty() const
+{
+  return m_sprites.empty();
+} // sprite_sequence::empty()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the current frame.
