@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -66,7 +66,7 @@ namespace bear
 
       void draw_line
       ( const color_type& color,
-        const std::vector<position_type>& p, double w = 1.0 );
+        const std::vector<position_type>& p, double w = 1.0, bool close=false );
 
       void draw_polygon
       ( const color_type& color,
@@ -90,6 +90,8 @@ namespace bear
       void set_video_mode( unsigned int w, unsigned int y, bool f );
       bool is_closed();
 
+      void update_z_position();
+
     private:
       /** \brief The width and height of the screen. */
       claw::math::coordinate_2d<unsigned int> m_size;
@@ -101,6 +103,12 @@ namespace bear
           at each call. */
       claw::graphic::rgba_pixel_8* m_screenshot_buffer;
 
+      /** \brief The z position of the next item to render. */
+      GLdouble m_z_position;
+
+      /** \brief The title of the window. */
+      const std::string m_title;
+
     }; // class gl_screen
   } // namespace visual
 } // namespace bear
