@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -59,23 +59,6 @@ namespace bear
 
   public:
     ambient_sound();
-    ~ambient_sound();
-
-    bool set_sample_field( const std::string& name, audio::sample* value );
-    bool set_real_field( const std::string& name, double value );
-
-    bool is_valid() const;
-
-  private:
-    void on_toggle_on( engine::base_item* activator );
-    void on_toggle_off( engine::base_item* activator );
-
-  private:
-    /** \brief Fade out the sample during this duration when stopping. */
-    universe::time_type m_fadeout;
-
-    /** \brief The sample played. */
-    audio::sample* m_sample;
 
   }; // class ambient_sound
 } // namespace bear
