@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -50,6 +50,16 @@ namespace bear
    * - collision_threshold: unsigned integer, a threshold for the collisions in
    *   the corners of the item, to choose if the other item is aligned on the
    *   collided side or the nearest adjacent one (default = 10).
+   * - top_sets_contact: boolean, tell if a collision on the top side sets the
+   *   contact flag of the colliding item (default = true).
+   * - bottom_sets_contact: boolean, tell if a collision on the bottom side sets
+   *   the contact flag of the colliding item (default = true).
+   * - left_sets_contact: boolean, tell if a collision on the left side sets the
+   *   contact flag of the colliding item (default = true).
+   * - right_sets_contact: boolean, tell if a collision on the right side sets
+   *   the contact flag of the colliding item (default = true).
+   * - middle_sets_contact: boolean, tell if a collision on the middle sets the
+   *   contact flag of the colliding item (default = true).
    *
    * \author Sebastien Angibaud
    */
@@ -83,10 +93,11 @@ namespace bear
   public:
     block();
 
+    bool set_bool_field( const std::string& name, bool value );
     bool set_u_integer_field( const std::string& name, unsigned int value );
 
   protected:
-    void collision_check_and_align
+    bool collision_check_and_align
     ( engine::base_item& that, universe::collision_info& info );
 
   private:
@@ -97,12 +108,37 @@ namespace bear
     void collision
     ( engine::base_item& that, universe::collision_info& info );
 
+    bool align_bottom
+      ( engine::base_item& that, universe::collision_info& info );
+    bool align_top( engine::base_item& that, universe::collision_info& info );
+    bool align_left( engine::base_item& that, universe::collision_info& info );
+    bool align_right( engine::base_item& that, universe::collision_info& info );
+    bool align_middle
+      ( engine::base_item& that, universe::collision_info& info );
+
+    void post_alignment( engine::base_item& that, double f );
+
   private:
     /** \brief A threshold for the collisions in the corners of the item, to
         choose if the other item is aligned on the collided side or the nearest
         adjacent one. */
     universe::coordinate_type m_collision_threshold;
 
+    /** \brief Tell if the contact is set when colliding on the top side. */
+    bool m_top_sets_contact;
+
+    /** \brief Tell if the contact is set when colliding on the bottom side. */
+    bool m_bottom_sets_contact;
+
+    /** \brief Tell if the contact is set when colliding on the left side. */
+    bool m_left_sets_contact;
+
+    /** \brief Tell if the contact is set when colliding on the right side. */
+    bool m_right_sets_contact;
+
+    /** \brief Tell if the contact is set when colliding on the middle. */
+    bool m_middle_sets_contact;
+
   }; // class block
 } // namespace bear
 
