@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -50,6 +50,13 @@ namespace bear
    *    (default = the height of the level,
    *  - \a max_move_length: (real) the maximum movement of the camera
    *    (default = infinity),
+   *  - \a size.min_width: (real) the minimum width of the camera (default = 0),
+   *  - \a size.min_height: (real) the minimum height of the camera
+   *    (default = 0),
+   *  - \a size.max_width: (real) the maximum width of the camera
+   *    (default = infinity),
+   *  - \a size.min_width: (real) the minimum width of the camera
+   *    (default = infinity),
    *  - any field supported by the parent classes.
    *
    * \author Julien Jorge
@@ -67,6 +74,8 @@ namespace bear
   public:
     camera();
 
+    bool is_valid() const;
+
     void build();
     void progress( universe::time_type elapsed_time );
 
@@ -76,6 +85,8 @@ namespace bear
     void set_wanted_size( const universe::size_box_type& s );
     void set_shaker_force( double agitation_force );
     const universe::size_box_type& get_default_size() const;
+
+    void set_active_on_build();
     void activate();
     void smooth_activate( universe::time_type d );
 
@@ -117,11 +128,18 @@ namespace bear
     /** \brief The size to attain. */
     universe::size_box_type m_wanted_size;
 
+    /** \brief The minimum size of the camera. */
+    universe::size_box_type m_min_size;
+
+    /** \brief The maximum size of the camera. */
+    universe::size_box_type m_max_size;
+
     /** \brief The force of the shaker. */
     double m_shaker_force;
 
     /** \brief Indicates if the camera start in active mode/ */
     bool m_active;
+
   }; // class camera
 } // namespace bear
 
