@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -41,6 +41,8 @@ namespace bear
    *
    * The valid fields for this item are
    *  - \a shaker_force: (real) force of the shaker (default = 10),
+   *  - \a check_camera_intersection: (bool) Indicates if the shaker checks
+   * camera intersection.
    *  - any field supported by the parent classes.
    *
    * \author Sebastien Angiabud
@@ -56,14 +58,25 @@ namespace bear
   public:
     camera_shaker();
 
+    static void shake_around
+      ( const engine::base_item& item, double force,
+        universe::time_type duration, audio::sample* s = NULL );
+
     bool set_real_field( const std::string& name, double value );
+    bool set_bool_field( const std::string& name, bool value );
+
     void set_shaker_force(double force);
+    void check_camera_intersection(bool value);
 
     void progress_on( universe::time_type elapsed_time );
 
   private:
     /** \brief The force of the agitation. */
     double m_shaker_force;
+
+    /** \brief Indicates if the shaker checks camera intersection. */
+    bool m_camera_intersection;
+
   }; // class camera_shaker
 } // namespace bear
 
