@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,7 +29,6 @@
 #include "generic_items/camera.hpp"
 
 #include "engine/level.hpp"
-#include "engine/script/string_to_arg.hpp"
 #include "universe/forced_movement/forced_goto.hpp"
 
 #include "engine/export.hpp"
@@ -43,21 +42,35 @@ BASE_ITEM_EXPORT( camera, bear )
  * \brief Constructor.
  */
 bear::camera::camera()
-  : m_valid_area
-  (0, 0,
-   std::numeric_limits<bear::universe::coordinate_type>::infinity(),
-   std::numeric_limits<bear::universe::coordinate_type>::infinity()),
-    m_max_move_length
+: m_valid_area
+(0, 0,
+ std::numeric_limits<bear::universe::coordinate_type>::infinity(),
+ std::numeric_limits<bear::universe::coordinate_type>::infinity()),
+  m_max_move_length
   ( std::numeric_limits<bear::universe::coordinate_type>::infinity() ),
-    m_max_zoom_length
+  m_max_zoom_length
   ( std::numeric_limits<bear::universe::coordinate_type>::infinity() ),
-    m_shaker_force(0), m_active(false)
+  m_min_size(0, 0),
+  m_max_size
+  ( std::numeric_limits<bear::universe::coordinate_type>::infinity(),
+    std::numeric_limits<bear::universe::coordinate_type>::infinity() ),
+  m_shaker_force(0), m_active(false)
 {
   set_phantom(true);
   set_can_move_items(false);
   set_artificial(true);
 } // camera::camera()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the camera is well initialized.
+ */
+bool bear::camera::is_valid() const
+{
+  return (m_max_size.x >= m_min_size.x) && (m_max_size.y >= m_min_size.y)
+    && super::is_valid();
+} // camera::is_valid()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Initialize the item.
@@ -90,6 +103,7 @@ void bear::camera::build()
   m_valid_area.set(left, bottom, right, top);
 
   m_default_size = m_wanted_size = get_size();
+
   if ( m_active )
     activate();
 } // camera::build()
@@ -104,7 +118,7 @@ void bear::camera::progress( bear::universe::time_type elapsed_time )
   progress_zoom(elapsed_time);
 
   if ( m_shaker_force != 0 )
-    adjust_position(get_center_of_mass(),elapsed_time);
+    adjust_position(get_center_of_mass(), elapsed_time);
 } // camera::progress()
 
 /*----------------------------------------------------------------------------*/
@@ -128,6 +142,14 @@ bool bear::camera::set_real_field( const std::string& name, double value )
     m_max_move_length = value;
   else if ( name == "camera.max_zoom_length" )
     m_max_zoom_length = value;
+  else if ( name == "camera.size.max_width" )
+    m_max_size.x = value;
+  else if ( name == "camera.size.max_height" )
+    m_max_size.y = value;
+  else if ( name == "camera.size.min_width" )
+    m_min_size.x = value;
+  else if ( name == "camera.size.min_height" )
+    m_min_size.y = value;
   else
     result = super::set_real_field(name, value);
 
@@ -158,7 +180,8 @@ bool bear::camera::set_bool_field( const std::string& name, bool value )
  */
 void bear::camera::set_wanted_size( const universe::size_box_type& s )
 {
-  m_wanted_size = s;
+  m_wanted_size.x = std::min( std::max( s.x, m_min_size.x ), m_max_size.x );
+  m_wanted_size.y = std::min( std::max( s.y, m_min_size.y ), m_max_size.y );
 
   const universe::coordinate_type w
     ( m_valid_area.second_point.x - m_valid_area.first_point.x );
@@ -166,16 +189,12 @@ void bear::camera::set_wanted_size( const universe::size_box_type& s )
     ( m_valid_area.second_point.y - m_valid_area.first_point.y );
 
   if ( m_wanted_size.x > w )
-    {
-      set_wanted_size
-      ( universe::size_box_type(w,w/(m_wanted_size.x / m_wanted_size.y)) );
-    }
+    set_wanted_size
+      ( universe::size_box_type(w, w/(m_wanted_size.x / m_wanted_size.y)) );
 
   if (  m_wanted_size.y > h )
-    {
-      set_wanted_size
-      ( universe::size_box_type(h*(m_wanted_size.x / m_wanted_size.y),h) );
-    }
+    set_wanted_size
+      ( universe::size_box_type(h*(m_wanted_size.x / m_wanted_size.y), h) );
 } // camera::set_wanted_size()
 
 /*----------------------------------------------------------------------------*/
@@ -197,6 +216,15 @@ const bear::universe::size_box_type& bear::camera::get_default_size() const
   return m_default_size;
 } // camera::get_default_size()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell that the camera must be activated by default when built.
+ */
+void bear::camera::set_active_on_build()
+{
+  m_active = true;
+} // camera::set_active_on_build()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Activate the camera.
