@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -101,10 +101,7 @@ void bear::crossfade_sequence::build()
 {
   super::build();
 
-  std::vector<
-  bear::universe::derived_item_handle_maker
-    < bear::engine::with_rendering_attributes >::handle_type
-    >::iterator it;
+  item_list_type::iterator it;
 
   for ( it = m_items_sequence.begin(); it != m_items_sequence.end(); ++it )
     (*it)->get_rendering_attributes().set_opacity(0);
@@ -128,7 +125,7 @@ bear::crossfade_sequence::set_bool_field
   else if (name == "crossfade_sequence.fadeout_for_last_item")
     m_fadeout_for_last_sprite = value;
   else
-    ok = super::set_bool_field(name,value);
+    ok = super::set_bool_field(name, value);
 
   return ok;
 } // croosfade_sequence::set_bool_field()
@@ -149,7 +146,7 @@ bear::crossfade_sequence::set_real_field
   if (name == "crossfade_sequence.fadeout_duration")
     m_fadeout_duration = value;
   else
-    ok = super::set_real_field(name,value);
+    ok = super::set_real_field(name, value);
 
   return ok;
 } // croosfade_sequence::set_real_field()
@@ -170,7 +167,7 @@ bear::crossfade_sequence::set_real_list_field
   if (name == "crossfade_sequence.duration_sequence")
     m_duration_sequence = value;
   else
-    ok = super::set_real_list_field(name,value);
+    ok = super::set_real_list_field(name, value);
 
   return ok;
 } // croosfade_sequence::set_real_list_field()
@@ -190,17 +187,10 @@ bool bear::crossfade_sequence::set_item_list_field
   if ( name == "crossfade_sequence.item_sequence" )
     {
       m_items_sequence.clear();
-      unsigned int index;
-      for ( index = 0; index != value.size(); ++index )
-        {
-          bear::universe::physical_item*
-            item = dynamic_cast<bear::universe::physical_item*>(value[index]);
 
-          bear::universe::derived_item_handle_maker
-            < bear::engine::with_rendering_attributes >::handle_type handle
-            (item);
-          m_items_sequence.push_back(handle);
-        }
+      for ( std::size_t index = 0; index != value.size(); ++index )
+        m_items_sequence.push_back(value[index]);
+
       result = true;
     }
   else
@@ -217,5 +207,5 @@ bool bear::crossfade_sequence::is_valid() const
 {
   return super::is_valid() &&
     ( m_duration_sequence.size() == m_items_sequence.size()) &&
-    ( !m_duration_sequence.empty()) ;
+    ( !m_duration_sequence.empty());
 } // crossfade_sequence::is_valid()
