@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -42,6 +42,7 @@ bear::delayed_kill_item::delayed_kill_item()
   set_phantom(true);
   set_can_move_items(false);
   set_global(true);
+  set_artificial(true);
 } // delayed_kill_item::delayed_kill_item()
 
 /*----------------------------------------------------------------------------*/
@@ -109,3 +110,23 @@ bool bear::delayed_kill_item::set_real_field
 
   return result;
 } // delayed_kill_item::set_real_field()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set duration until kill item.
+ * \param value The value of duration.
+ */
+void bear::delayed_kill_item::set_duration( double value )
+{
+  m_duration = value;
+} // delayed_kill_item::set_duration()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add an item to kill.
+ * \param item The item to kill.
+ */
+void bear::delayed_kill_item::add_item( base_item* item )
+{
+  m_items.push_back(item);
+} // delayed_kill_item::add_item()
