@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -85,7 +85,7 @@ bear::descending_ceiling::set_bool_field( const std::string& name, bool value )
   else if ( name == "descending_ceiling.apply_angle" )
     m_apply_angle = value;
   else
-    result = super::set_u_integer_field(name, value);
+    result = super::set_bool_field(name, value);
 
   return result;
 } // descending_ceiling::set_bool_field()
