@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -49,9 +49,17 @@ namespace bear
   {
     DECLARE_BASE_ITEM(crossfade_sequence);
 
+  public:
     /** \brief The type of the parent class. */
     typedef engine::base_item super;
 
+  private:
+    /** \brief The type of the list of the handles on the items. */
+    typedef std::vector
+      < bear::universe::derived_item_handle
+        < bear::engine::with_rendering_attributes >
+      > item_list_type;
+
   public:
     crossfade_sequence();
 
@@ -72,10 +80,7 @@ namespace bear
     std::vector<double> m_duration_sequence;
 
     /** \brief The list of items to reveal. */
-    std::vector<
-      bear::universe::derived_item_handle_maker
-      < bear::engine::with_rendering_attributes >::handle_type >
-      m_items_sequence;
+    item_list_type m_items_sequence;
 
     /** \brief The duration since the beginning of the current sprite. */
     double m_last_sprite;
