@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -58,8 +58,7 @@ namespace bear
 
   private:
     /** \brief The type of the handles on the items to kill. */
-    typedef universe::derived_item_handle_maker<engine::base_item>::handle_type
-    handle_type;
+    typedef universe::derived_item_handle<engine::base_item> handle_type;
 
   public:
     delayed_kill_item();
@@ -69,6 +68,8 @@ namespace bear
     virtual bool set_item_list_field
       ( const std::string& name, const std::vector<base_item*>& value );
     virtual bool set_real_field( const std::string& name, double value );
+    void set_duration(double value);
+    void add_item( base_item* item );
 
   private:
     /** \brief The list of items to kill. */
