@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -39,6 +39,9 @@
 
 namespace bear
 {
+  template<typename Result, typename LeftOperand, typename RightOperand>
+  class binary_expression_creator;
+
   /**
    * \brief Template class to create items that can be use as a binary
    *        expression.
@@ -54,18 +57,28 @@ namespace bear
    *
    * \author Julien Jorge
    */
-  template<typename Expression>
+  template<typename Result, typename LeftOperand, typename RightOperand>
   class binary_expression_creator:
     public engine::base_item,
-    public engine::with_expression_creation<Expression>::creation_class_type
+    public engine::with_expression_creation<Result>::creation_class_type
   {
   public:
     /** \brief The type of the parent class. */
     typedef engine::base_item super;
 
+    /** \brief The type of the class to use to instanciate the left operand. */
+    typedef
+    typename engine::with_expression_creation<LeftOperand>::creation_class_type
+    left_creation_class_type;
+
+    /** \brief The type of the class to use to instanciate the right operand. */
+    typedef
+    typename engine::with_expression_creation<RightOperand>::creation_class_type
+    right_creation_class_type;
+
     /** \brief The type of the class to use to instanciate the expression. */
     typedef
-    typename engine::with_expression_creation<Expression>::creation_class_type
+    typename engine::with_expression_creation<Result>::creation_class_type
     creation_class_type;
 
     /** \brief The type of the expression created. */
@@ -81,7 +94,7 @@ namespace bear
 
   private:
     /** \brief The expression created by this item. */
-    Expression m_expr;
+    Result m_expr;
 
   }; // class binary_expression_creator
 
@@ -90,7 +103,8 @@ namespace bear
    * \author Julien Jorge
    */
   class GENERIC_ITEMS_EXPORT boolean_equality_creator:
-    public binary_expression_creator<expr::boolean_equality>
+    public binary_expression_creator
+  <expr::boolean_equality, expr::boolean_expression, expr::boolean_expression>
   {
     DECLARE_BASE_ITEM(boolean_equality_creator);
   }; // class boolean_equality_creator
@@ -100,7 +114,9 @@ namespace bear
    * \author Julien Jorge
    */
   class GENERIC_ITEMS_EXPORT boolean_disequality_creator:
-    public binary_expression_creator<expr::boolean_disequality>
+    public binary_expression_creator
+  < expr::boolean_disequality, expr::boolean_expression,
+    expr::boolean_expression >
   {
     DECLARE_BASE_ITEM(boolean_disequality_creator);
   }; // class boolean_disequality_creator
@@ -110,7 +126,8 @@ namespace bear
    * \author Julien Jorge
    */
   class GENERIC_ITEMS_EXPORT logical_and_creator:
-    public binary_expression_creator<expr::logical_and>
+    public binary_expression_creator
+  <expr::logical_and, expr::boolean_expression, expr::boolean_expression>
   {
     DECLARE_BASE_ITEM(logical_and_creator);
   }; // class logical_and_creator
@@ -120,17 +137,30 @@ namespace bear
    * \author Julien Jorge
    */
   class GENERIC_ITEMS_EXPORT logical_or_creator:
-    public binary_expression_creator<expr::logical_or>
+    public binary_expression_creator
+  <expr::logical_or, expr::boolean_expression, expr::boolean_expression>
   {
     DECLARE_BASE_ITEM(logical_or_creator);
   }; // class logical_or_creator
 
+  /**
+   * \brief This class is a linear expression of type "equality".
+   * \author Sbastien Angibaud
+   */
+  class GENERIC_ITEMS_EXPORT linear_equality_creator:
+    public binary_expression_creator
+  <expr::linear_equality, expr::linear_expression, expr::linear_expression>
+  {
+    DECLARE_BASE_ITEM(linear_equality_creator);
+  }; // class linear_equality_creator
+
   /**
    * \brief This class is a linear expression of type "plus".
    * \author Julien Jorge
    */
   class GENERIC_ITEMS_EXPORT linear_plus_creator:
-    public binary_expression_creator<expr::linear_plus>
+    public binary_expression_creator
+  <expr::linear_plus, expr::linear_expression, expr::linear_expression>
   {
     DECLARE_BASE_ITEM(linear_plus_creator);
   }; // class linear_plus_creator
@@ -140,7 +170,8 @@ namespace bear
    * \author Julien Jorge
    */
   class GENERIC_ITEMS_EXPORT linear_minus_creator:
-    public binary_expression_creator<expr::linear_minus>
+    public binary_expression_creator
+  <expr::linear_minus, expr::linear_expression, expr::linear_expression>
   {
     DECLARE_BASE_ITEM(linear_minus_creator);
   }; // class linear_minus_creator
@@ -150,7 +181,8 @@ namespace bear
    * \author Julien Jorge
    */
   class GENERIC_ITEMS_EXPORT linear_multiplies_creator:
-    public binary_expression_creator<expr::linear_multiplies>
+    public binary_expression_creator
+  <expr::linear_multiplies, expr::linear_expression, expr::linear_expression>
   {
     DECLARE_BASE_ITEM(linear_multiplies_creator);
   }; // class linear_multiplies_creator
@@ -160,7 +192,8 @@ namespace bear
    * \author Julien Jorge
    */
   class GENERIC_ITEMS_EXPORT linear_divides_creator:
-    public binary_expression_creator<expr::linear_divides>
+    public binary_expression_creator
+  <expr::linear_divides, expr::linear_expression, expr::linear_expression>
   {
     DECLARE_BASE_ITEM(linear_divides_creator);
   }; // class linear_divides_creator
