@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -90,7 +90,7 @@ bool bear::forced_aiming_creator::set_item_field
   bool result = true;
 
   if ( (name == "forced_aiming_creator.target") && (value != NULL) )
-    m_movement.set_reference_item(*value);
+    m_movement.set_reference_point_on_center(*value);
   else
     result = super::set_item_field(name, value);
 
