@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -61,8 +61,7 @@ namespace bear
 
   private:
     /** \brief The type of the handles on the items to kill. */
-    typedef universe::derived_item_handle_maker<engine::base_item>::handle_type
-    handle_type;
+    typedef universe::derived_item_handle<engine::base_item> handle_type;
 
   public:
     killer();
