@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -102,6 +102,16 @@ void bear::action_layer::do_remove_item( engine::base_item& that )
   m_world.release_item( &that );
 } // action_layer::do_remove_item()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove an item from the layer without deleting it.
+ * \param that The item to remove.
+ */
+void bear::action_layer::do_drop_item( engine::base_item& that )
+{
+  m_world.drop_item( &that );
+} // action_layer::do_drop_item()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add a static item in the layer.
