@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -170,3 +170,13 @@ void bear::decoration_layer::do_remove_item( engine::base_item& that )
 {
   CLAW_PRECOND( false );
 } // decoration_layer::do_remove_item()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove an item from the layer without deleting it.
+ * \param that The item to remove.
+ */
+void bear::decoration_layer::do_drop_item( engine::base_item& that )
+{
+  CLAW_PRECOND( false );
+} // decoration_layer::do_drop_item()
