@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -48,18 +48,6 @@ bear::pattern_layer::pattern_layer
 
 } // pattern_layer::pattern_layer()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Destructor.
- */
-bear::pattern_layer::~pattern_layer()
-{
-  std::list<engine::base_item*>::iterator it;
-
-  for ( it=m_items.begin(); it!=m_items.end(); ++it )
-    delete *it;
-} // pattern_layer::~pattern_layer()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Progress all the items in the layer.
@@ -69,14 +57,10 @@ bear::pattern_layer::~pattern_layer()
 void bear::pattern_layer::progress
 ( const region_type& active_area, universe::time_type elapsed_time  )
 {
-  std::list<engine::base_item*>::iterator it;
-
-  lock();
+  engine::population::const_iterator it;
 
   for ( it=m_items.begin(); it!=m_items.end(); ++it )
-    (*it)->progress(elapsed_time);
-
-  unlock();
+    it->progress(elapsed_time);
 } // pattern_layer::progress()
 
 /*----------------------------------------------------------------------------*/
@@ -89,12 +73,12 @@ void bear::pattern_layer::do_get_visual
 ( std::list<engine::scene_visual>& visuals,
   const universe::rectangle_type& visible_area ) const
 {
-  std::list<engine::base_item*>::const_iterator it;
+  engine::population::const_iterator it;
 
   for ( it=m_items.begin(); it!=m_items.end(); ++it )
     {
       std::list<engine::scene_visual> local_visuals;
-      (*it)->get_visual( local_visuals );
+      it->get_visual( local_visuals );
 
       repeat_visual( visuals, local_visuals, visible_area );
     }
@@ -107,7 +91,7 @@ void bear::pattern_layer::do_get_visual
  */
 void bear::pattern_layer::do_add_item( engine::base_item& that )
 {
-  register_item( &that );
+  m_items.insert(&that);
 } // pattern_layer::do_add_item()
 
 /*----------------------------------------------------------------------------*/
@@ -117,9 +101,19 @@ void bear::pattern_layer::do_add_item( engine::base_item& that )
  */
 void bear::pattern_layer::do_remove_item( engine::base_item& that )
 {
-  release_item( &that );
+  m_items.kill(&that);
 } // pattern_layer::do_remove_item()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove an item from the layer without deleting it.
+ * \param that The item to remove.
+ */
+void bear::pattern_layer::do_drop_item( engine::base_item& that )
+{
+  m_items.drop(&that);
+} // pattern_layer::do_drop_item()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Repeat the sprites from a list of visuals.
@@ -173,29 +167,3 @@ void bear::pattern_layer::repeat_sprite
       v_pos.x += v_size.x;
     }
 } // pattern_layer::repeat_sprite()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Add an item in the layer.
- * \param that The item to add.
- */
-void bear::pattern_layer::add(engine::base_item* const& that)
-{
-  m_items.push_front( that );
-} // pattern_layer::add()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Remove an item from the layer.
- * \param that The item to remove.
- */
-void bear::pattern_layer::remove(engine::base_item* const& that)
-{
-  std::list<engine::base_item*>::iterator it =
-    std::find(m_items.begin(), m_items.end(), that);
-
-  CLAW_PRECOND( it != m_items.end() );
-
-  delete *it;
-  m_items.erase( it );
-} // pattern_layer::remove()
