@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,9 +29,8 @@
 #ifndef __BEAR_PATTERN_LAYER_HPP__
 #define __BEAR_PATTERN_LAYER_HPP__
 
-#include "concept/item_container.hpp"
+#include "engine/population.hpp"
 #include "engine/layer/layer.hpp"
-#include "visual/animation.hpp"
 
 #include "generic_items/class_export.hpp"
 
@@ -42,12 +41,10 @@ namespace bear
    * \author Julien Jorge
    */
   class GENERIC_ITEMS_EXPORT pattern_layer:
-    public engine::layer,
-    public concept::item_container<engine::base_item*>
+    public engine::layer
   {
   public:
     pattern_layer( const universe::size_box_type& size );
-    ~pattern_layer();
 
     void progress
     ( const region_type& active_area, universe::time_type elapsed_time  );
@@ -58,6 +55,7 @@ namespace bear
 
     void do_add_item( engine::base_item& that );
     void do_remove_item( engine::base_item& item );
+    void do_drop_item( engine::base_item& item );
 
     void repeat_visual
     ( std::list<engine::scene_visual>& visuals,
@@ -73,7 +71,7 @@ namespace bear
 
   private:
     /** \brief The items repeated in the screen. */
-    std::list<engine::base_item*> m_items;
+    engine::population m_items;
 
   }; // class pattern_layer
 } // namespace bear
