@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -45,7 +45,7 @@ namespace bear
    * The custom fields of this class are the fields of the parent classes.
    */
   class GENERIC_ITEMS_EXPORT trigger:
-    public engine::item_with_trigger< engine::base_item >
+    public engine::item_with_trigger<engine::base_item>
   {
     DECLARE_BASE_ITEM(trigger);
 
@@ -53,8 +53,7 @@ namespace bear
 
   public:
     /** \brief The type of the parent class. */
-    typedef
-    engine::item_with_trigger< engine::base_item > super;
+    typedef engine::item_with_trigger<engine::base_item> super;
 
     /** \brief The different behaviours of the trigger. */
     enum mode
@@ -75,9 +74,7 @@ namespace bear
 
   private:
     /** \brief The type of an handle on a toggle. */
-    typedef
-      universe::derived_item_handle_maker<engine::with_toggle>::handle_type
-      handle_type;
+    typedef universe::derived_item_handle<engine::with_toggle> handle_type;
 
     /** \brief The type of a list of toggles. */
     typedef std::list<handle_type> handle_list;
