@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -23,9 +23,13 @@
 */
 /**
  * \file main.cpp
- * \brief Implantation of the main procedure.
- * \author Sebastien Angibaud
+ * \brief Implementation of the main procedure.
+ * \author Sébastien Angibaud
  */
 #include "running_bear.hpp"
 
+#ifdef __APPLE__
+#include <SDL/SDL.h> // needed on OSX because there SDL needs to hijack 'main'
+#endif
+
 CLAW_APPLICATION_IMPLEMENT(bear::running_bear)
