@@ -1,7 +1,7 @@
 /*
   Bear Engine
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -31,6 +31,7 @@
 #include "bear_gettext.hpp"
 
 #include <claw/logger.hpp>
+#include <boost/preprocessor/stringize.hpp>
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -41,7 +42,11 @@
 bear::running_bear::running_bear( int& argc, char** &argv )
   : claw::application(argc, argv), m_game(NULL)
 {
-  bind_textdomain_codeset( "bear-engine", "UTF-8" );
+#ifdef BEAR_TEXT_DOMAIN_PATH
+  bindtextdomain( "bear-engine", BOOST_PP_STRINGIZE(BEAR_TEXT_DOMAIN_PATH) );
+#endif
+
+  bind_textdomain_codeset( "bear-engine", "ISO-8859-15" );
   textdomain( "bear-engine" );
 
   m_arguments.add
