@@ -1,7 +1,7 @@
 /*
     Bear Engine - Animation editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -94,7 +94,7 @@ void bf::animation_editor::compile( const wxString& path ) const
       compile_animation(anim, path);
     }
   else
-    throw CLAW_EXCEPTION("Can't load XML file.");
+    throw claw::exception("Can't load XML file.");
 } // animation_editor::compile()
 
 /*----------------------------------------------------------------------------*/
@@ -113,7 +113,7 @@ void bf::animation_editor::update( const wxString& path ) const
       anim = reader.load( doc.GetRoot() );
     }
   else
-    throw CLAW_EXCEPTION("Can't load XML file.");
+    throw claw::exception("Can't load XML file.");
 
   animation_file_xml_writer writer;
   std::ofstream f( wx_to_std_string(path).c_str() );
@@ -147,7 +147,7 @@ void bf::animation_editor::compile_animation
       anim.compile(cf);
     }
   else
-    throw CLAW_EXCEPTION("Can't open the animation file.");
+    throw claw::exception("Can't open the animation file.");
 } // animation_editor::compile_animation()
 
 /*----------------------------------------------------------------------------*/
