@@ -1,7 +1,7 @@
 /*
   Bear Engine - Editor library
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -46,10 +46,9 @@ namespace bf
   {
   public:
     bitmap_rendering_attributes();
-    bitmap_rendering_attributes
-    ( const claw::math::coordinate_2d<unsigned int>& s );
 
     bool operator==( const bitmap_rendering_attributes& that ) const;
+    bool operator!=( const bitmap_rendering_attributes& that ) const;
     bool operator<( const bitmap_rendering_attributes& that ) const;
 
     double get_opacity() const;
@@ -62,6 +61,9 @@ namespace bf
 
     const claw::math::coordinate_2d<unsigned int>& get_size() const;
 
+    void set_auto_size( bool a );
+    bool get_auto_size() const;
+
     void set_size( const claw::math::coordinate_2d<unsigned int>& s );
     void set_size( unsigned int w, unsigned int h );
     void set_width( unsigned int w );
@@ -111,6 +113,9 @@ namespace bf
     /** \brief The angle on the screen. */
     double m_angle;
 
+    /** \brief Tell if the size is automatically computed. */
+    bool m_auto_size;
+
   }; // class bitmap_rendering_attributes
 
 } // namespace bf
