@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -47,6 +47,13 @@ namespace bf
     public wxPanel,
     public base_edit<bitmap_rendering_attributes>
   {
+  private:
+    /** \brief The identifiers of the controls. */
+    enum control_id
+      {
+        ID_AUTO_SIZE
+      }; // enum control_id
+
   public:
     bitmap_rendering_attributes_edit
     ( wxWindow& parent, const bitmap_rendering_attributes& spr );
@@ -61,7 +68,12 @@ namespace bf
     wxSizer* create_size_and_placement_sizer();
     wxSizer* create_color_sizer();
 
+    void on_auto_size( wxCommandEvent& event );
+
   private:
+    /** \brief Tell if the size is automatically computed. */
+    wxCheckBox* m_auto_size;
+
     /** \brief The text control in which we configure the width. */
     wxSpinCtrl* m_width_spin;
 
@@ -90,6 +102,8 @@ namespace bf
     /** \brief The control for configure the transparency. */
     bf::spin_ctrl<double>* m_alpha_spin;
 
+    DECLARE_EVENT_TABLE()
+
   }; // class bitmap_rendering_attributes_edit
 } // namespace bf
 
