@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -69,6 +69,33 @@ bool bf::animation::operator!=(const animation& that) const
   return !(*this == that);
 } // animation::operator!=()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Compare with an other animation in lexicographic order of their
+ *        attributes.
+ * \param that The other animation.
+ */
+bool bf::animation::operator<(const animation& that) const
+{
+  if ( m_loops != that.m_loops )
+    return m_loops < that.m_loops;
+
+  if ( m_loop_back != that.m_loop_back )
+    return m_loop_back < that.m_loop_back;
+
+  if ( m_first_index != that.m_first_index )
+    return m_first_index < that.m_first_index;
+
+  if ( m_last_index != that.m_last_index )
+    return m_last_index < that.m_last_index;
+
+  if ( bitmap_rendering_attributes::operator!=(that) )
+    return bitmap_rendering_attributes::operator<(that);
+
+  return
+    std::lexicographical_compare( begin(), end(), that.begin(), that.end() );
+} // animation::operator<()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set the frames of the animation.
