@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -85,3 +85,17 @@ bool bf::animation_frame::operator==( const animation_frame& that ) const
 {
   return (m_sprite == that.m_sprite) && (m_duration == that.m_duration);
 } // animation_frame::operator==()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Compare with an other animation frame in lexicographic order of their
+ *        attributes.
+ * \param that The other animation frame.
+ */
+bool bf::animation_frame::operator<(const animation_frame& that) const
+{
+  if ( m_sprite != that.m_sprite )
+    return m_sprite < that.m_sprite;
+
+  return m_duration < that.m_duration;
+} // animation_frame::operator<()
