@@ -1,7 +1,7 @@
 /*
   Bear Engine - Editor library
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -39,20 +39,8 @@
  */
 bf::bitmap_rendering_attributes::bitmap_rendering_attributes()
   : m_size(0, 0), m_flip(false), m_mirror(false), m_opacity(1),
-    m_red_intensity(1), m_green_intensity(1), m_blue_intensity(1), m_angle(0)
-{
-
-} // bitmap_rendering_attributes::bitmap_rendering_attributes()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Constructor.
- * \param s The size.
- */
-bf::bitmap_rendering_attributes::bitmap_rendering_attributes
-( const claw::math::coordinate_2d<unsigned int>& s )
-  : m_size(s), m_flip(false), m_mirror(false), m_opacity(1),
-    m_red_intensity(1), m_green_intensity(1), m_blue_intensity(1), m_angle(0)
+    m_red_intensity(1), m_green_intensity(1), m_blue_intensity(1), m_angle(0),
+    m_auto_size(true)
 {
 
 } // bitmap_rendering_attributes::bitmap_rendering_attributes()
@@ -72,9 +60,21 @@ bool bf::bitmap_rendering_attributes::operator==
     && (m_red_intensity == that.m_red_intensity)
     && (m_green_intensity == that.m_green_intensity)
     && (m_blue_intensity == that.m_blue_intensity)
-    && (m_angle == that.m_angle);
+    && (m_angle == that.m_angle)
+    && (m_auto_size == that.m_auto_size);
 } // bitmap_rendering_attributes::operator==()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if two bitmap_rendering_attributes are different.
+ * \param that The instance to compare to.
+ */
+bool bf::bitmap_rendering_attributes::operator!=
+( const bitmap_rendering_attributes& that ) const
+{
+  return !(*this == that);
+} // bitmap_rendering_attributes::operator!=()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Compare two bitmap_rendering_attributes in lexicographic order.
@@ -83,45 +83,34 @@ bool bf::bitmap_rendering_attributes::operator==
 bool bf::bitmap_rendering_attributes::operator<
 ( const bitmap_rendering_attributes& that ) const
 {
-  if (m_size.x == that.m_size.x)
-    {
-      if (m_size.y == that.m_size.y)
-        {
-          if (m_flip == that.m_flip)
-            {
-              if (m_mirror == that.m_mirror)
-                {
-                  if (m_opacity == that.m_opacity)
-                    {
-                      if (m_red_intensity == that.m_red_intensity)
-                        {
-                          if (m_green_intensity == that.m_green_intensity)
-                            {
-                              if (m_blue_intensity == that.m_blue_intensity)
-                                return m_angle < that.m_angle;
-                              else
-                                return m_blue_intensity < that.m_blue_intensity;
-                            }
-                          else
-                            return m_green_intensity < that.m_blue_intensity;
-                        }
-                      else
-                        return m_red_intensity < that.m_red_intensity;
-                    }
-                  else
-                    return m_opacity < that.m_opacity;
-                }
-              else
-                return m_mirror < that.m_mirror;
-            }
-          else
-            return m_flip < that.m_flip;
-        }
-      else
-        return m_size.y < that.m_size.y;
-    }
-  else
+  if (m_size.x != that.m_size.x)
     return m_size.x < that.m_size.x;
+
+  if (m_size.y != that.m_size.y)
+    return m_size.y < that.m_size.y;
+
+  if (m_flip != that.m_flip)
+    return m_flip < that.m_flip;
+
+  if (m_mirror != that.m_mirror)
+    return m_mirror < that.m_mirror;
+
+  if (m_opacity != that.m_opacity)
+    return m_opacity < that.m_opacity;
+
+  if (m_red_intensity != that.m_red_intensity)
+    return m_red_intensity < that.m_red_intensity;
+
+  if (m_green_intensity != that.m_green_intensity)
+    return m_green_intensity < that.m_blue_intensity;
+
+  if (m_blue_intensity != that.m_blue_intensity)
+    return m_blue_intensity < that.m_blue_intensity;
+
+  if ( m_angle != that.m_angle )
+    return m_angle < that.m_angle;
+
+  return m_auto_size < that.m_auto_size;
 } // bitmap_rendering_attributes::operator<()
 
 /*----------------------------------------------------------------------------*/
@@ -202,6 +191,25 @@ void bf::bitmap_rendering_attributes::set_intensity
     m_blue_intensity = b;
 } // bitmap_rendering_attributes::set_color()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the size is automatically computed.
+ * \param a Tell if the size is automatically computed.
+ */
+void bf::bitmap_rendering_attributes::set_auto_size( bool a )
+{
+  m_auto_size = a;
+} // bitmap_rendering_attributes::set_auto_size()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the size is automatically computed.
+ */
+bool bf::bitmap_rendering_attributes::get_auto_size() const
+{
+  return m_auto_size;
+} // bitmap_rendering_attributes::get_auto_size()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the size.
