@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -57,6 +57,7 @@ bool bf::bitmap_rendering_attributes_edit::validate()
 {
   bitmap_rendering_attributes att;
 
+  att.set_auto_size( m_auto_size->IsChecked() );
   att.set_width( m_width_spin->GetValue() );
   att.set_height( m_height_spin->GetValue() );
   att.mirror( m_flip_x_box->IsChecked() );
@@ -89,6 +90,11 @@ void bf::bitmap_rendering_attributes_edit::fill_controls()
 {
   bitmap_rendering_attributes att = get_value();
 
+  m_auto_size->SetValue( att.get_auto_size() );
+
+  m_width_spin->Enable( !att.get_auto_size() );
+  m_height_spin->Enable( !att.get_auto_size() );
+
   m_width_spin->SetValue( att.width() );
   m_height_spin->SetValue( att.height() );
 
@@ -126,20 +132,22 @@ wxSizer* bf::bitmap_rendering_attributes_edit::create_size_and_placement_sizer()
   wxStaticBoxSizer* result =
     new wxStaticBoxSizer( wxVERTICAL, this, _("Size and placement") );
 
+  m_auto_size = new wxCheckBox( this, ID_AUTO_SIZE, _("Auto size") );
   m_width_spin = new wxSpinCtrl( this, wxID_ANY );
   m_height_spin = new wxSpinCtrl( this, wxID_ANY );
   m_flip_x_box = new wxCheckBox( this, wxID_ANY, _("Mirror") );
   m_flip_y_box = new wxCheckBox( this, wxID_ANY, _("Flip") );
   m_angle_spin =
-    new spin_ctrl<double>( this, wxID_ANY,wxDefaultPosition,
-         wxDefaultSize, wxEXPAND,
-                           -std::numeric_limits<double>::infinity(),
-                           std::numeric_limits<double>::infinity(), 0, 0.01 );
+    new spin_ctrl<double>
+    ( this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxEXPAND,
+      -std::numeric_limits<double>::infinity(),
+      std::numeric_limits<double>::infinity(), 0, 0.01 );
 
   m_width_spin->SetRange( 0, std::numeric_limits<int>::max() );
   m_height_spin->SetRange( 0, std::numeric_limits<int>::max() );
 
   wxBoxSizer* sub_sizer = new wxBoxSizer( wxHORIZONTAL );
+  sub_sizer->Add( m_auto_size, 0, wxEXPAND );
   sub_sizer->Add( new wxStaticText(this, wxID_ANY, _("Width:")),
                1, wxALIGN_CENTRE_VERTICAL | wxALL, 5 );
   sub_sizer->Add( m_width_spin, 0, wxALL, 5 );
@@ -151,11 +159,12 @@ wxSizer* bf::bitmap_rendering_attributes_edit::create_size_and_placement_sizer()
   result->Add( sub_sizer, 0, wxEXPAND, 0 );
   sub_sizer = new wxBoxSizer( wxHORIZONTAL );
 
-  sub_sizer->Add( m_flip_x_box, 0, wxEXPAND , 0 );
-  sub_sizer->Add( m_flip_y_box, 0, wxEXPAND , 0 );
-  sub_sizer->Add( new wxStaticText(this, wxID_ANY, _("Angle:")),
-               1, wxALIGN_CENTRE_VERTICAL | wxALL, 5 );
-  sub_sizer->Add( m_angle_spin, 1, wxEXPAND , 0 );
+  sub_sizer->Add( m_flip_x_box, 0, wxEXPAND, 0 );
+  sub_sizer->Add( m_flip_y_box, 0, wxEXPAND, 0 );
+  sub_sizer->Add
+    ( new wxStaticText(this, wxID_ANY, _("Angle:")),
+      1, wxALIGN_CENTRE_VERTICAL | wxALL, 5 );
+  sub_sizer->Add( m_angle_spin, 1, wxEXPAND, 0 );
 
   result->Add( sub_sizer, 0, wxEXPAND, 0 );
 
@@ -169,16 +178,16 @@ wxSizer* bf::bitmap_rendering_attributes_edit::create_size_and_placement_sizer()
 wxSizer* bf::bitmap_rendering_attributes_edit::create_color_sizer()
 {
   m_red_spin =
-    new spin_ctrl<double>( this, wxID_ANY,wxDefaultPosition,
+    new spin_ctrl<double>( this, wxID_ANY, wxDefaultPosition,
                            wxDefaultSize, wxEXPAND, 0, 1, 1, 0.01 );
   m_green_spin =
-    new spin_ctrl<double>( this, wxID_ANY,wxDefaultPosition,
+    new spin_ctrl<double>( this, wxID_ANY, wxDefaultPosition,
                            wxDefaultSize, wxEXPAND, 0, 1, 1, 0.01 );
   m_blue_spin =
-    new spin_ctrl<double>( this, wxID_ANY,wxDefaultPosition,
+    new spin_ctrl<double>( this, wxID_ANY, wxDefaultPosition,
                            wxDefaultSize, wxEXPAND, 0, 1, 1, 0.01 );
   m_alpha_spin =
-    new spin_ctrl<double>( this, wxID_ANY,wxDefaultPosition,
+    new spin_ctrl<double>( this, wxID_ANY, wxDefaultPosition,
                            wxDefaultSize, wxEXPAND, 0, 1, 1, 0.01 );
 
   wxStaticBoxSizer* result =
@@ -206,3 +215,20 @@ wxSizer* bf::bitmap_rendering_attributes_edit::create_color_sizer()
 
   return result;
 } // bitmap_rendering_attributes_edit::create_color_sizer()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Event sent when the auto size checkbox changes.
+ * \param event The event.
+ */
+void bf::bitmap_rendering_attributes_edit::on_auto_size( wxCommandEvent& event )
+{
+  m_width_spin->Enable( !m_auto_size->IsChecked() );
+  m_height_spin->Enable( !m_auto_size->IsChecked() );
+} // bitmap_rendering_attributes_edit::on_auto_size()
+
+/*----------------------------------------------------------------------------*/
+BEGIN_EVENT_TABLE(bf::bitmap_rendering_attributes_edit, wxPanel)
+  EVT_CHECKBOX( bf::bitmap_rendering_attributes_edit::ID_AUTO_SIZE,
+                bf::bitmap_rendering_attributes_edit::on_auto_size )
+END_EVENT_TABLE()
