@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -34,6 +34,7 @@
 
 #include <claw/assert.hpp>
 #include <claw/logger.hpp>
+#include <claw/string_algorithm.hpp>
 
 #include <wx/image.h>
 
@@ -177,6 +178,63 @@ wxBitmap bf::image_pool::get_thumbnail( const wxString& image_name ) const
   return m_thumbnail.find(image_name)->second;
 } // image_pool::get_thumbnail()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the entries of the spritepos file associated with a given image.
+ * \param image_name The name of the image.
+ */
+bf::image_pool::spritepos_entries
+bf::image_pool::get_spritepos_entries( const wxString& image_name ) const
+{
+  load_spritepos_file( wx_to_std_string(image_name) );
+
+  const spritepos_map::const_iterator it = m_spritepos.find(image_name);
+
+  if ( it == m_spritepos.end() )
+    return spritepos_entries();
+  else
+    return it->second;
+} // image_pool::get_spritepos_entries()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the rectangle of a given spritepos entry.
+ * \param image_name The name of the image to which the spritepos is associated.
+ * \param entry The name of the entry to return.
+ */
+claw::math::rectangle<unsigned int>
+bf::image_pool::get_spritepos_rectangle
+( const wxString& image_name, const wxString& entry ) const
+{
+  const spritepos_entries r = get_spritepos_entries(image_name);
+  const spritepos_entries::const_iterator it = r.find(entry);
+
+  if ( it == r.end() )
+    return claw::math::rectangle<unsigned int>(0, 0, 0, 0);
+  else
+    return it->second;
+} // image_pool::get_spritepos_rectangle()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the name of a spritepos entry from a given file with the same
+ *        rectangle than a given one.
+ * \param image_name The name of the image to which the spritepos is associated.
+ * \param r The rectangle for which we want the entry.
+ */
+wxString bf::image_pool::find_spritepos_name_from_size
+( const wxString& image_name,
+  const claw::math::rectangle<unsigned int>& r ) const
+{
+  const spritepos_entries e = get_spritepos_entries(image_name);
+
+  for ( spritepos_entries::const_iterator it=e.begin(); it!=e.end(); ++it )
+    if ( it->second == r )
+      return it->first;
+
+  return wxString();
+} // image_pool::find_spritepos_name_from_size()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get a constant iterator on the begining of the pool.
@@ -216,6 +274,69 @@ void bf::image_pool::add_image
     }
 } // image_pool::add_image()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Load the spritepos entries associated with an image.
+ * \param root The path to the directory in which the path started.
+ * \param image_path The path to the image.
+ */
+void bf::image_pool::load_spritepos_file( const std::string& image_path ) const
+{
+  const wxString key = std_to_wx_string(image_path);
+
+  if ( m_spritepos.find(key) != m_spritepos.end() )
+    return;
+
+  std::string::size_type pos = image_path.find_last_of('.');
+
+  if ( pos != std::string::npos )
+    {
+      std::string std_name( image_path.substr(0, pos) + ".spritepos" );
+
+      if ( path_configuration::get_instance().expand_file_name(std_name, 1) )
+        {
+          std::ifstream f( std_name.c_str() );
+
+          if (f)
+            m_spritepos[key] = read_spritepos_file(f);
+          else
+            m_spritepos[key] = spritepos_entries();
+        }
+    }
+} // image_pool::load_spritepos_file()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Read the content of a spritepos file.
+ * \param f The file to read from.
+ */
+bf::image_pool::spritepos_entries
+bf::image_pool::read_spritepos_file( std::istream& f ) const
+{
+  claw::math::rectangle<unsigned int> r;
+  std::string line;
+  spritepos_entries result;
+
+  while ( std::getline(f, line) )
+    if ( !line.empty() )
+      if ( line[0] != '#' )
+        {
+          std::vector<std::string> sp;
+
+          claw::text::split(sp, line, ':');
+
+          if (sp.size() != 1)
+            {
+              std::istringstream iss( sp.back() );
+
+              if ( iss >> r.position.x >> r.position.y >> r.width >> r.height )
+                result[std_to_wx_string(sp.front())] = r;
+            }
+        }
+
+  return result;
+} // image_pool::read_spritepos_file()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Load and store the data of an image.
