@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -35,6 +35,7 @@
 #include "bf/xml/item_class_inherit_node.hpp"
 
 #include <iostream>
+#include <limits>
 #include <claw/logger.hpp>
 #include <claw/string_algorithm.hpp>
 
@@ -554,28 +555,33 @@ bf::type_field* bf::item_class_xml_parser::create_field
  * \param node The node to explore.
  */
 template<typename T>
-std::pair<T,T>
+std::pair<T, T>
 bf::item_class_xml_parser::read_interval( const wxXmlNode* node ) const
 {
-  std::pair<T,T> result;
+  std::pair<T, T> result;
   wxString val;
+  std::istringstream iss;
 
   if ( !node->GetPropVal( wxT("from"), &val ) )
-    throw xml::missing_property("from");
+    result.first = std::numeric_limits<T>::min();
+  else
+    {
+      iss.str( wx_to_std_string(val) );
 
-  std::istringstream iss( wx_to_std_string(val) );
-
-  if ( !(iss >> result.first) )
-    throw xml::bad_value( wx_to_std_string(val) );
+      if ( !(iss >> result.first) )
+        throw xml::bad_value( wx_to_std_string(val) );
+    }
 
   if ( !node->GetPropVal( wxT("to"), &val ) )
-    throw xml::missing_property("to");
+    result.second = std::numeric_limits<T>::max();
+  else
+    {
+      iss.clear();
+      iss.str( wx_to_std_string(val) );
 
-  iss.clear();
-  iss.str( wx_to_std_string(val) );
-
-  if ( !(iss >> result.second) )
-    throw xml::bad_value( wx_to_std_string(val) );
+      if ( !(iss >> result.second) )
+        throw xml::bad_value( wx_to_std_string(val) );
+    }
 
   return result;
 } // item_class_xml_parser::read_interval()
