@@ -1,7 +1,7 @@
 /*
   Bear Engine - Editor library
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,6 +29,7 @@
 #include "bf/item_instance.hpp"
 
 #include "bf/call_by_field_type.hpp"
+#include "bf/item_check_result.hpp"
 #include "bf/item_class.hpp"
 
 #include <claw/assert.hpp>
@@ -214,7 +215,6 @@ void bf::item_instance::set_class( item_class const* c )
 
   m_class = c;
   m_fixed = m_class->get_fixable() && m_fixed;
-  m_rendering_parameters.set_is_valid(true);
 
   remove_invalid_values();
 
@@ -319,6 +319,34 @@ void bf::item_instance::delete_value( const type_field& f )
   m_rendering_parameters.field_changed( f.get_name() );
 } // item_instance::delete_value()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if this item instance has a reference to a given other instance.
+ * \param id The identifier of the other instance.
+ */
+bool bf::item_instance::has_a_reference_to( const std::string& id ) const
+{
+  item_reference_type_map::const_iterator it;
+
+  for ( it=m_item_reference.begin(); it!=m_item_reference.end(); ++it )
+    if ( it->second.get_value() == id )
+      return true;
+
+  item_reference_type_list_map::const_iterator it_list;
+
+  for ( it_list=m_item_reference_list.begin();
+      it_list!=m_item_reference_list.end(); ++it_list )
+    {
+      std::list<item_reference_type>::const_iterator iti;
+
+      for ( iti=it_list->second.begin(); iti!=it_list->second.end(); ++iti )
+        if ( iti->get_value() == id )
+          return true;
+    }
+
+  return false;
+} // item_instance::has_a_reference_to()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell if the item is fixed.
@@ -338,6 +366,19 @@ void bf::item_instance::set_fixed( bool b )
   m_fixed = b;
 } // item_instance::set_fixed()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Compile the fields of the item.
+ * \param f The file in which we compile.
+ * \remark The compilation will fail if a field is a reference on an other item.
+ */
+void bf::item_instance::compile( compiled_file& f ) const
+{
+  CLAW_PRECOND( m_item_reference.empty() );
+
+  compile( f, std::map<std::string, unsigned int>() );
+} // item_instance::compile()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Compile the fields of the item.
@@ -358,75 +399,44 @@ void bf::item_instance::compile
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Test if the item has a good initialization.
- * Return "true" if there are no problem.
- * Test item references and required fields.
- * \param map_id The map containing item identifiants.
+ * \brief Test if the item is well defined.
+ * \param result (out) The result of the check.
+ * \param map_id The set of all item identifiers.
  */
-bool
-bf::item_instance::check( const std::map<std::string,item_instance*>& map_id)
+void bf::item_instance::check
+( item_check_result& result, const std::set<std::string>& map_id ) const
 {
-  std::string error_msg;
-  bool result = check_required_fields(error_msg);
-
-  if ( result )
-    result = check_mass_for_fixed_item(error_msg);
-
-  if ( result )
-    result = check_id_required(error_msg, map_id);
-
-  if ( result )
-    {
-      m_rendering_parameters.clear_error();
-      m_rendering_parameters.set_is_valid(true);
-    }
-  else
-    {
-      m_rendering_parameters.set_error(error_msg);
-      m_rendering_parameters.set_is_valid(false);
-    }
-
-  return result;
+  check_required_fields( result );
+  check_mass_for_fixed_item( result );
+  check_id_required(result, map_id);
 } // item_instance::check()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Test if each required fields are setted.
- * Return "true" if there are no problem.
- * \param error_msg The string of error message.
+ * \brief Test if the fixed item has an infinite mass.
+ * \param result (out) The result of the check.
  */
-bool bf::item_instance::check_mass_for_fixed_item(std::string& error_msg) const
+void bf::item_instance::check_mass_for_fixed_item
+( item_check_result& result ) const
 {
-  bool result = true;
-
   if ( m_fixed )
     {
-      type_field field("base_item.mass",type_field::real_field_type);
-      if ( has_value(field) )
-        {
-          result = false;
-          error_msg = "Error in item of class '" + m_class->get_class_name() +
-            "': for fixed item, the field 'base_item.mass' must be" +
-            " equal to infinity";
-        }
-    }
+      const type_field field("base_item.mass", type_field::real_field_type);
 
-  return result;
+      if ( has_value(field) )
+        result.add( check_error("Fixed item must have an infinite mass.") );
+    }
 } // item_instance::check_mass_for_fixed_item()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Test if each required identifier exists.
- * Return "true" if there are no problem.
- * \param error_msg The string of error message.
- * \param map_id The map containing item identifiants.
+ * \brief Test if the referenced items exist.
+ * \param result (out) The result of the check.
+ * \param map_id The set of all item identifiers.
  */
-bool bf::item_instance::check_id_required
-(std::string& error_msg,
- const std::map<std::string,item_instance*>& map_id) const
+void bf::item_instance::check_id_required
+( item_check_result& result, const std::set<std::string>& map_id ) const
 {
-  bool result = true;
-
   std::list<std::string> fields;
   std::list<std::string>::const_iterator it;
 
@@ -435,59 +445,44 @@ bool bf::item_instance::check_id_required
   for ( it=fields.begin(); it!=fields.end(); ++it )
     {
       const type_field& f = m_class->get_field(*it);
-      if( f.get_field_type() == type_field::item_reference_field_type )
+      if( (f.get_field_type() == type_field::item_reference_field_type)
+          && has_value(f) )
         {
-          if( has_value(f) )
+          if( f.is_list() )
             {
-              if( f.is_list() )
-                {
-                  std::list<item_reference_type>::const_iterator bit =
-                    m_item_reference_list.find(f.get_name())->second.begin();
-                  const std::list<item_reference_type>::const_iterator eit =
-                    m_item_reference_list.find(f.get_name())->second.end();
+              std::list<item_reference_type>::const_iterator bit =
+                m_item_reference_list.find(f.get_name())->second.begin();
+              const std::list<item_reference_type>::const_iterator eit =
+                m_item_reference_list.find(f.get_name())->second.end();
 
-                  for ( ; bit!=eit; ++bit)
-                    if ( map_id.find(bit->get_value()) == map_id.end() )
-                      {
-                        result = false;
-                        error_msg = "Error item of class '"
-                          + m_class->get_class_name() +
-                          "': field '" + *it +
-                          "'. The identifier '" + bit->get_value()
-                          + "' does not exist";
-                      }
-                }
-              else
-                {
-                  std::string id;
-                  id = m_item_reference.find(f.get_name())->second.get_value();
+              for ( ; bit!=eit; ++bit)
+                if ( map_id.find(bit->get_value()) == map_id.end() )
+                  result.add
+                    ( check_error
+                      ( bit->get_value(),
+                        "There is no item with such identifier." ) );
+            }
+          else
+            {
+              std::string id =
+                m_item_reference.find(f.get_name())->second.get_value();
 
-                  if ( map_id.find(id) == map_id.end() )
-                    {
-                      result = false;
-                      error_msg = "Error in item of class '"
-                        + m_class->get_class_name() +
-                        "': field '" + *it +
-                        "'. The identifier '" + id + "' does not exist";
-                    }
-                }
+              if ( map_id.find(id) == map_id.end() )
+                result.add
+                  ( check_error
+                    ( id, "There is no item with such identifier." ) );
             }
         }
     }
-
-  return result;
 } // item_instance::check_id_required()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Test if each required fields are setted.
- * Return "true" if there are no problem.
- * \param error_msg The string of error message.
+ * \brief Test if all required fields are set.
+ * \param result (out) The result of the check.
  */
-bool bf::item_instance::check_required_fields(std::string& error_msg) const
+void bf::item_instance::check_required_fields( item_check_result& result ) const
 {
-  bool result = true;
-
   std::list<std::string> fields;
   std::list<std::string>::const_iterator it;
 
@@ -496,17 +491,9 @@ bool bf::item_instance::check_required_fields(std::string& error_msg) const
   for ( it=fields.begin(); it!=fields.end(); ++it )
     {
       const type_field& f = m_class->get_field(*it);
-      if( f.get_required() )
-        if( !has_value(f) )
-          {
-            result = false;
-            error_msg = "Error in item of class '"
-              + m_class->get_class_name() +
-              "': field '" + *it + "' is required";
-          }
+      if( f.get_required() && !has_value(f) )
+        result.add( check_error( *it, "Field value is required." ) );
     }
-
-  return result;
 } // item_instance::check_required_fields()
 
 /*----------------------------------------------------------------------------*/
