@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -111,6 +111,9 @@ void bf::item_reference_edit::fill_id_list()
   for (; it!=eit; ++it)
     if ( it->Matches( pat ) )
       Append( *it );
+
+  if ( GetCount() == 1 )
+    SetSelection(0);
 } // item_reference_edit::fill_id_list()
 
 /*----------------------------------------------------------------------------*/
