@@ -1,7 +1,7 @@
 /*
   Bear Engine - Editor library
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -50,6 +50,10 @@ const std::string bf::item_rendering_parameters::s_field_name_gap_x =
   "basic_renderable_item.gap.x";
 const std::string bf::item_rendering_parameters::s_field_name_gap_y =
   "basic_renderable_item.gap.y";
+const std::string bf::item_rendering_parameters::s_field_name_mirror =
+  "basic_renderable_item.mirror";
+const std::string bf::item_rendering_parameters::s_field_name_flip =
+  "basic_renderable_item.flip";
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -58,7 +62,7 @@ const std::string bf::item_rendering_parameters::s_field_name_gap_y =
  */
 bf::item_rendering_parameters::item_rendering_parameters( item_instance& item )
   : m_item(item), m_left(0), m_bottom(0), m_width(0), m_height(0), m_pos_z(0),
-    m_gap_x(0), m_gap_y(0), m_is_valid(true)
+    m_gap_x(0), m_gap_y(0), m_mirror(false), m_flip(false)
 {
   m_sprite = new sprite;
 } // item_rendering_parameters::item_rendering_parameters()
@@ -72,8 +76,8 @@ bf::item_rendering_parameters::item_rendering_parameters
 ( const item_rendering_parameters& that )
   : m_item(that.m_item), m_left(that.m_left), m_bottom(that.m_bottom),
     m_width(that.m_width), m_height(that.m_height), m_pos_z(that.m_pos_z),
-    m_gap_x(that.m_gap_x), m_gap_y(that.m_gap_x), m_is_valid(that.m_is_valid),
-    m_error(that.m_error)
+    m_gap_x(that.m_gap_x), m_gap_y(that.m_gap_x),
+    m_mirror(that.m_mirror), m_flip(that.m_flip)
 {
   m_sprite = new sprite(*that.m_sprite);
 } // item_rendering_parameters::item_rendering_parameters()
@@ -109,6 +113,10 @@ bf::item_rendering_parameters::field_changed( const std::string& field_name )
     m_width = get_field_real( field_name, 0 );
   else if (field_name == s_field_name_height)
     m_height = get_field_real( field_name, 0 );
+  else if (field_name == s_field_name_mirror)
+    m_mirror = get_field_bool( field_name, false );
+  else if (field_name == s_field_name_flip)
+    m_flip = get_field_bool( field_name, false );
   else
     {
       const item_class& c(m_item.get_class());
@@ -142,6 +150,8 @@ void bf::item_rendering_parameters::init()
   m_pos_z = get_field_int( s_field_name_depth, 0 );
   m_gap_x = get_field_int( s_field_name_gap_x, 0 );
   m_gap_y = get_field_int( s_field_name_gap_y, 0 );
+  m_mirror = get_field_bool( s_field_name_mirror, false );
+  m_flip = get_field_bool( s_field_name_flip, false );
 } // item_rendering_parameters::init()
 
 /*----------------------------------------------------------------------------*/
@@ -249,6 +259,24 @@ int bf::item_rendering_parameters::get_gap_y() const
   return m_gap_y;
 } // item_rendering_parameters::get_gap_y()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Indicates if the item is mirrored.
+ */
+bool bf::item_rendering_parameters::is_mirrored() const
+{
+  return m_mirror;
+} // item_rendering_parameters::is_mirrored()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Indicates if the item is flipped.
+ */
+bool bf::item_rendering_parameters::is_flipped() const
+{
+  return m_flip;
+} // item_rendering_parameters::is_flipped()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell if the item has a sprite.
@@ -315,53 +343,6 @@ void bf::item_rendering_parameters::set_size( double x, double y )
   set_field_real(s_field_name_height, y );
 } // item_rendering_parameters::set_size()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Return if the item is valid.
- */
-bool bf::item_rendering_parameters::is_valid() const
-{
-  return m_is_valid;
-} // item_rendering_parameters::is_valid()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Set the valid statut.
- * \param valid The new statut.
- */
- void bf::item_rendering_parameters::set_is_valid(bool valid)
-{
-  m_is_valid = valid;
-} // item_rendering_parameters::set_is_valid()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Set the error message.
- * \param error The string of error message.
- */
-void bf::item_rendering_parameters::set_error(const std::string& error)
-{
-  m_error = error;
-} // item_rendering_parameters::set_error()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get the error message.
- */
-const std::string& bf::item_rendering_parameters::get_error() const
-{
-  return m_error;
-} // item_rendering_parameters::get_error()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Clear the error message.
- */
-void bf::item_rendering_parameters::clear_error()
-{
-  m_error.clear();
-} // item_rendering_parameters::clear_error()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get a sprite of the item.
