@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -51,6 +51,16 @@ void bf::sprite::set_image_name( const std::string& name )
   m_image_name = name;
 } // sprite::set_image_name()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set the name of the entry in the spritepos file.
+ * \param name The new value.
+ */
+void bf::sprite::set_spritepos_entry( const std::string& name )
+{
+  m_spritepos_entry = name;
+} // sprite::set_spritepos_entry()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set the Y-coordinate in the image resource.
@@ -58,7 +68,11 @@ void bf::sprite::set_image_name( const std::string& name )
  */
 void bf::sprite::set_top( const unsigned int top )
 {
-  m_top = top;
+  if ( m_top != top )
+    {
+      m_top = top;
+      m_spritepos_entry.clear();
+    }
 } // sprite::set_top()
 
 /*----------------------------------------------------------------------------*/
@@ -68,7 +82,11 @@ void bf::sprite::set_top( const unsigned int top )
  */
 void bf::sprite::set_left( const unsigned int left )
 {
-  m_left = left;
+  if ( m_left != left )
+    {
+      m_left = left;
+      m_spritepos_entry.clear();
+    }
 } // sprite::set_left()
 
 /*----------------------------------------------------------------------------*/
@@ -78,7 +96,14 @@ void bf::sprite::set_left( const unsigned int left )
  */
 void bf::sprite::set_clip_width( const unsigned int width )
 {
-  m_clip_width = width;
+  if ( m_clip_width != width )
+    {
+      m_clip_width = width;
+      m_spritepos_entry.clear();
+
+      if ( get_auto_size() )
+        set_width(width);
+    }
 } // sprite::set_clip_width()
 
 /*----------------------------------------------------------------------------*/
@@ -88,9 +113,30 @@ void bf::sprite::set_clip_width( const unsigned int width )
  */
 void bf::sprite::set_clip_height( const unsigned int height )
 {
-  m_clip_height = height;
+  if ( m_clip_height != height )
+    {
+      m_clip_height = height;
+      m_spritepos_entry.clear();
+
+      if ( get_auto_size() )
+        set_height(height);
+    }
 } // sprite::set_clip_height()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set the rectangle in the image resource.
+ * \param r The rectangle.
+ */
+void
+bf::sprite::set_clip_rectangle( const claw::math::rectangle<unsigned int>& r )
+{
+  set_left(r.position.x);
+  set_top(r.position.y);
+  set_clip_width(r.width);
+  set_clip_height(r.height);
+} // sprite::set_clip_rectangle()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the left x-ccordinate of the sprite.
@@ -127,6 +173,16 @@ unsigned int bf::sprite::get_clip_height() const
   return m_clip_height;
 } // sprite::get_clip_height()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the rectangle in the image resource.
+ */
+claw::math::rectangle<unsigned int> bf::sprite::get_clip_rectangle() const
+{
+  return claw::math::rectangle<unsigned int>
+    ( get_left(), get_top(), get_clip_width(), get_clip_height() );
+} // sprite::get_clip_rectangle()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the image name of the sprite.
@@ -136,6 +192,15 @@ const std::string& bf::sprite::get_image_name() const
   return m_image_name;
 } // sprite::get_image_name()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the name of the entry in the spritepos file.
+ */
+const std::string& bf::sprite::get_spritepos_entry() const
+{
+  return m_spritepos_entry;
+} // sprite::get_spritepos_entry()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Compile the sprite.
@@ -177,3 +242,30 @@ bool bf::sprite::operator!=( const sprite& that ) const
 {
   return !(*this == that);
 } // sprite::operator!=()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Compare with an other sprite in lexicographic order of their
+ *        attributes.
+ * \param that The other sprite.
+ */
+bool bf::sprite::operator<( const sprite& that ) const
+{
+  if ( m_image_name != that.m_image_name )
+    return m_image_name < that.m_image_name;
+
+  if ( m_top != that.m_top )
+    return m_top < that.m_top;
+
+  if ( m_left != that.m_left )
+    return m_left < that.m_left;
+
+  if (m_clip_width != that.m_clip_width)
+    return m_clip_width < that.m_clip_width;
+
+  if ( m_clip_height != that.m_clip_height )
+    return m_clip_height < that.m_clip_height;
+
+  return that.bitmap_rendering_attributes::operator<(*this);
+} // sprite::operator<()
+
