@@ -1,7 +1,7 @@
 /*
   Bear Engine - Editor library
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -39,8 +39,6 @@
 #include <sstream>
 #include <fstream>
 
-#include <claw/string_algorithm.hpp>
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
@@ -80,6 +78,8 @@ bf::sprite bf::sprite_edit::make_sprite() const
 
   if ( m_rendering_attributes->validate() )
     {
+      result.set_spritepos_entry
+        ( wx_to_std_string(m_spritepos_combo->GetStringSelection()) );
       result.set_left( m_left_text->GetValue() );
       result.set_top( m_top_text->GetValue() );
       result.set_clip_width( m_clip_width_text->GetValue() );
@@ -122,6 +122,8 @@ void bf::sprite_edit::fill_controls()
   m_sprite_view->set_sprite( get_value() );
 
   fill_spritepos();
+  m_spritepos_combo->SetStringSelection
+    ( std_to_wx_string(spr.get_spritepos_entry()) );
 } // sprite_edit::fill_controls()
 
 /*----------------------------------------------------------------------------*/
@@ -240,61 +242,17 @@ wxSizer* bf::sprite_edit::create_image_name_sizer()
 void bf::sprite_edit::fill_spritepos()
 {
   m_spritepos_combo->Clear();
-  m_spritepos.clear();
 
-  claw::math::rectangle<unsigned int> r;
-  std::string file_name( wx_to_std_string(m_image_name_text->GetValue()) );
+  image_pool::spritepos_entries e =
+    image_pool::get_instance().get_spritepos_entries
+    (m_image_name_text->GetValue());
 
-  if ( !file_name.empty() )
-    {
-      std::string::size_type pos = file_name.find_last_of('.');
+  image_pool::spritepos_entries::const_iterator it;
 
-      if ( pos!=std::string::npos )
-        {
-          file_name = file_name.substr(0, pos) + ".spritepos";
-
-          if( path_configuration::get_instance().get_full_path(file_name) )
-            {
-              std::ifstream f( file_name.c_str() );
-
-              if (f)
-                read_spritepos_file(f);
-            }
-        }
-    }
+  for ( it=e.begin(); it!=e.end(); ++it )
+    m_spritepos_combo->Append( it->first );
 } // sprite_edit::fill_spritepos()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Read the content of a spritepos file.
- * \param f The file to read from.
- */
-void bf::sprite_edit::read_spritepos_file( std::istream& f )
-{
-  claw::math::rectangle<unsigned int> r;
-  std::string line;
-
-  while ( std::getline(f, line) )
-    if ( !line.empty() )
-      if ( line[0] != '#' )
-        {
-          std::vector<std::string> sp;
-
-          claw::text::split(sp, line, ':');
-
-          if (sp.size() != 1)
-            {
-              std::istringstream iss( sp.back() );
-
-              if ( iss >> r.position.x >> r.position.y >> r.width >> r.height )
-                {
-                  m_spritepos_combo->Append( std_to_wx_string(sp.front()) );
-                  m_spritepos.push_back(r);
-                }
-            }
-        }
-} // sprite_edit::read_spritepos_file()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Test validity of the sprite size.
@@ -383,17 +341,29 @@ void bf::sprite_edit::on_rectangle_clip_change( wxSpinEvent& WXUNUSED(event) )
  */
 void bf::sprite_edit::on_select_sprite_pos( wxCommandEvent& event )
 {
-  CLAW_PRECOND( (std::size_t)event.GetSelection() < m_spritepos.size() );
+  // Set the maximum size to avoid control_sprite_size() to bound the changes.
+  m_left_text->SetValue(0);
+  m_top_text->SetValue(0);
+  m_clip_width_text->SetValue(m_clip_width_text->GetMax());
+  m_clip_height_text->SetValue(m_clip_height_text->GetMax());
 
-  m_left_text->SetValue( m_spritepos[event.GetSelection()].position.x );
-  m_top_text->SetValue( m_spritepos[event.GetSelection()].position.y );
-  m_clip_width_text->SetValue( m_spritepos[event.GetSelection()].width );
-  m_clip_height_text->SetValue( m_spritepos[event.GetSelection()].height );
+  const claw::math::rectangle<unsigned int> r =
+    image_pool::get_instance().get_spritepos_entries
+    ( m_image_name_text->GetValue())
+    [m_spritepos_combo->GetStringSelection()];
+
+  m_left_text->SetValue( r.position.x );
+  m_top_text->SetValue( r.position.y );
+  m_clip_width_text->SetValue( r.width );
+  m_clip_height_text->SetValue( r.height );
 
   bitmap_rendering_attributes att(m_rendering_attributes->get_value());
 
-  att.set_width( m_spritepos[event.GetSelection()].width );
-  att.set_height( m_spritepos[event.GetSelection()].height );
+  if ( att.get_auto_size() )
+    {
+      att.set_width( r.width );
+      att.set_height( r.height );
+    }
 
   m_rendering_attributes->set_value(att);
   m_sprite_view->set_sprite( make_sprite() );
