@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -34,6 +34,7 @@
 #include <claw/basic_singleton.hpp>
 #include <claw/iterator.hpp>
 #include <claw/functional.hpp>
+#include <claw/rectangle.hpp>
 #include <map>
 
 #include <wx/bitmap.h>
@@ -70,6 +71,14 @@ namespace bf
 
     }; // struct load_thumb_func
 
+  public:
+    typedef
+      std::map< wxString, claw::math::rectangle<unsigned int> >
+      spritepos_entries;
+
+  private:
+    typedef std::map<wxString, spritepos_entries> spritepos_map;
+
   public:
     typedef claw::wrapped_iterator
     < const wxString,
@@ -86,12 +95,24 @@ namespace bf
     wxBitmap get_image( const wxString& image_name ) const;
     wxBitmap get_thumbnail( const wxString& image_name ) const;
 
+    spritepos_entries get_spritepos_entries( const wxString& image_name ) const;
+
+    claw::math::rectangle<unsigned int>
+      get_spritepos_rectangle
+      ( const wxString& image_name, const wxString& entry ) const;
+    wxString find_spritepos_name_from_size
+      ( const wxString& image_name,
+        const claw::math::rectangle<unsigned int>& r ) const;
+
     const_iterator begin() const;
     const_iterator end() const;
 
   private:
     void add_image( const std::string& root, const std::string& file_path );
 
+    void load_spritepos_file( const std::string& image_path ) const;
+    spritepos_entries read_spritepos_file( std::istream& f ) const;
+
     void load_image_data( const wxString& name ) const;
 
   public:
@@ -105,6 +126,9 @@ namespace bf
     /** \brief The thumbnails of the images. */
     mutable image_map m_thumbnail;
 
+    /** \brief The spritepos entries for each image. */
+    mutable spritepos_map m_spritepos;
+
   }; // class image_pool
 } // namespace bf
 
