@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -47,10 +47,14 @@ namespace bf
   class BEAR_EDITOR_EXPORT item_class
   {
   public:
+    /** \brief The list of parent classes. */
     typedef std::list<item_class const*> super_class_list;
 
+    /** \brief The association of a field's name with a description of his
+        name. */
     typedef std::map<std::string, const type_field*> field_map_type;
 
+    /** \brief Iterator on the fields of the class. */
     typedef claw::wrapped_iterator
     < const type_field,
       field_map_type::const_iterator,
@@ -59,6 +63,7 @@ namespace bf
         claw::const_pair_second<field_map_type::value_type> > >
     ::iterator_type field_iterator;
 
+    /** \brief Iterator on the parent classes. */
     typedef claw::wrapped_iterator
     < const item_class,
       super_class_list::const_iterator,
