@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -105,14 +105,19 @@
   }                                                                     \
                                                                         \
   private:                                                              \
-  std::map<std::string, type> m_ ## name;                               \
-  std::map< std::string, std::list<type> > m_ ## name ## _list;         \
+  typedef std::map<std::string, type> type ## _map;                     \
+  typedef std::map< std::string, std::list<type> > type ## _list_map;   \
+                                                                        \
+  private:                                                              \
+  type ## _map m_ ## name;                                              \
+  type ## _list_map m_ ## name ## _list;                                \
                                                                         \
   friend struct field_map_by_type<type>;                                \
   friend struct field_map_by_type< std::list<type> >
 
 namespace bf
 {
+  class item_check_result;
   class item_class;
 
   /**
@@ -172,23 +177,25 @@ namespace bf
     bool has_value( const type_field& f ) const;
     void delete_value( const type_field& f );
 
+    bool has_a_reference_to( const std::string& id ) const;
+
     bool get_fixed() const;
     void set_fixed( bool b );
     void rename_item_reference_fields
     ( const std::map<std::string, std::string>& map_id );
 
+    void compile( compiled_file& f ) const;
     void compile( compiled_file& f,
                   const std::map<std::string, unsigned int>& id_to_int ) const;
 
-    bool check
-    ( const std::map<std::string,item_instance*>& map_id );
+    void check
+      ( item_check_result& result, const std::set<std::string>& map_id ) const;
 
   private:
-    bool check_mass_for_fixed_item(std::string& error_msg) const;
-    bool check_id_required
-    (std::string& error_msg,
-     const std::map<std::string,item_instance*>& map_id) const;
-    bool check_required_fields(std::string& error_msg) const;
+    void check_mass_for_fixed_item( item_check_result& result ) const;
+    void check_id_required
+      ( item_check_result& result, const std::set<std::string>& map_id ) const;
+    void check_required_fields( item_check_result& result ) const;
 
     void sort_fields( std::list<std::string>& fields ) const;
     void insert_field
