@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -65,6 +65,9 @@ namespace bf
     int get_gap_x() const;
     int get_gap_y() const;
 
+    bool is_mirrored() const;
+    bool is_flipped() const;
+
     bool has_user_defined_width() const;
     bool has_user_defined_height() const;
 
@@ -76,12 +79,6 @@ namespace bf
     void set_bottom( double p );
     void set_size( double x, double y );
 
-    bool is_valid() const;
-    void set_is_valid(bool valid);
-    void set_error(const std::string& error);
-    const std::string& get_error() const;
-    void clear_error();
-
   private:
     sprite get_sprite_from_item() const;
     sprite get_sprite_from_sprites() const;
@@ -118,6 +115,12 @@ namespace bf
     /** \brief Default field name for the gap on the y-axis. */
     static const std::string s_field_name_gap_y;
 
+    /** \brief Default field name for the mirror state. */
+    static const std::string s_field_name_mirror;
+
+    /** \brief Default field name for the flipped state. */
+    static const std::string s_field_name_flip;
+
   private:
     /** \brief The instance of the item. */
     item_instance& m_item;
@@ -151,11 +154,11 @@ namespace bf
     /** \brief Gap of the sprite on the Y-axis. */
     int m_gap_y;
 
-    /** \brief Indicates if the item is valid. */
-    bool m_is_valid;
+    /** \brief Indicates if the item is mirrorred. */
+    bool m_mirror;
 
-    /** \brief The error message. */
-    std::string m_error;
+    /** \brief Indicates if the item is flipped. */
+    bool m_flip;
 
   }; // class item_rendering_parameters
 } // namespace bf
