@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -104,6 +104,8 @@ namespace bf
 
     void SetValue( value_type v );
     value_type GetValue() const;
+    value_type GetMin() const;
+    value_type GetMax() const;
     wxString GetValueText() const;
 
   private:
