@@ -1,7 +1,7 @@
 /*
   Bear Engine - Editor library
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -32,6 +32,7 @@
 #include "bf/bitmap_rendering_attributes.hpp"
 #include "bf/libeditor_export.hpp"
 
+#include <claw/rectangle.hpp>
 #include <string>
 
 namespace bf
@@ -47,26 +48,34 @@ namespace bf
     sprite();
 
     void set_image_name( const std::string& name );
+    void set_spritepos_entry( const std::string& name );
     void set_top( const unsigned int top );
     void set_left( const unsigned int left );
     void set_clip_width( const unsigned int width );
     void set_clip_height( const unsigned int height );
+    void set_clip_rectangle( const claw::math::rectangle<unsigned int>& r );
 
     unsigned int get_left() const;
     unsigned int get_top() const;
     unsigned int get_clip_width() const;
     unsigned int get_clip_height() const;
+    claw::math::rectangle<unsigned int> get_clip_rectangle() const;
     const std::string& get_image_name() const;
+    const std::string& get_spritepos_entry() const;
 
     void compile( compiled_file& f ) const;
 
     bool operator==( const sprite& that ) const;
     bool operator!=( const sprite& that ) const;
+    bool operator<( const sprite& that ) const;
 
   private:
     /** \brief The name of the image resource to use. */
     std::string m_image_name;
 
+    /** \brief The name of the entry in the spritepos file. */
+    std::string m_spritepos_entry;
+
     /** \brief Y-coordinate. */
     unsigned int m_top;
 
