@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -38,7 +38,6 @@
 #include <wx/spinctrl.h>
 
 #include <vector>
-#include <claw/rectangle.hpp>
 
 namespace bf
 {
@@ -62,9 +61,6 @@ namespace bf
         IDC_SPRITEPOS_CHOICE
       }; // enum control_id
 
-  private:
-    typedef std::vector< claw::math::rectangle<unsigned int> > rectangle_vector;
-
   public:
     sprite_edit
     ( wxWindow& parent, const sprite& spr = default_value<sprite>::get() );
@@ -112,9 +108,6 @@ namespace bf
         sprite in the image source. */
     wxSpinCtrl* m_clip_height_text;
 
-    /** \brief The list of rectangles found in a .spritepos file. */
-    rectangle_vector m_spritepos;
-
     /** \brief The control in which we configure the rendering attributes. */
     bitmap_rendering_attributes_edit* m_rendering_attributes;
 
