@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -124,7 +124,7 @@ bf::xml::reader_tool::read_string( const wxXmlNode* node, const wxString& prop )
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Convert the value of a property in a string.
+ * \brief Convert the value of a property in a real number.
  * \param node The node in which we take the property.
  * \param prop The name of the property to get.
  */
@@ -145,7 +145,7 @@ bf::xml::reader_tool::read_real( const wxXmlNode* node, const wxString& prop )
     throw xml::bad_value( "unsigned integer", wx_to_std_string(val) );
 
   return result;
-} // reader_tool::read_string()
+} // reader_tool::read_real()
 
 /*----------------------------------------------------------------------------*/
 /**
