@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -38,7 +38,14 @@ void
 bf::xml::base_sprite_animation_value_to_xml::bitmap_rendering_attributes_xml
 ( std::ostream& os, const bitmap_rendering_attributes& att )
 {
-  os << "width='" << att.width() << "' height='" << att.height()
+  os << "auto_size='";
+
+  if ( att.get_auto_size() )
+    os << "true";
+  else
+    os << "false";
+
+  os << "' width='" << att.width() << "' height='" << att.height()
      << "' mirror='";
 
   if ( att.is_mirrored() )
@@ -46,7 +53,7 @@ bf::xml::base_sprite_animation_value_to_xml::bitmap_rendering_attributes_xml
   else
     os << "false";
 
-  os << "' flip='" ;
+  os << "' flip='";
 
   if ( att.is_flipped() )
     os << "true";
@@ -143,7 +150,8 @@ void bf::xml::value_to_xml<bf::sprite>::write
      << util::replace_special_characters(spr.get_image_name()) << "' x='"
      << spr.get_left() << "' y='" << spr.get_top() << "' clip_width='"
      << spr.get_clip_width() << "' clip_height='"
-     << spr.get_clip_height() << "' ";
+     << spr.get_clip_height() << "' spritepos='"
+     << util::replace_special_characters(spr.get_spritepos_entry()) << "' ";
 
   bitmap_rendering_attributes_xml(os, spr);
   os << "/>\n";
