@@ -1,7 +1,7 @@
 /*
     Bear Engine - Editor library
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -28,6 +28,7 @@
  */
 #include "bf/xml/xml_to_value.hpp"
 
+#include "bf/image_pool.hpp"
 #include "bf/wx_facilities.hpp"
 #include "bf/xml/reader_tool.hpp"
 
@@ -45,6 +46,9 @@ bf::xml::bitmap_rendering_attributes_xml_to_value::load_rendering_attributes
 {
   CLAW_PRECOND( node != NULL );
 
+  att.set_auto_size
+    ( xml::reader_tool::read_bool_opt
+      (node, wxT("auto_size"), att.get_auto_size()) );
   att.set_width
     ( xml::reader_tool::read_uint_opt(node, wxT("width"), att.width()) );
   att.set_height
@@ -80,23 +84,56 @@ void bf::xml::xml_to_value<bf::sprite>::operator()
 {
   CLAW_PRECOND( node != NULL );
 
-  wxString image_name;
+  spr.set_image_name( xml::reader_tool::read_string(node, wxT("image")) );
+  const std::string spritepos =
+    xml::reader_tool::read_string_opt(node, wxT("spritepos"), std::string());
 
-  if ( !node->GetPropVal( wxT("image"), &image_name ) )
-    throw missing_property("image");
-
-  spr.set_image_name( wx_to_std_string(image_name) );
-
-  spr.set_left( xml::reader_tool::read_uint(node, wxT("x")) );
-  spr.set_top( xml::reader_tool::read_uint(node, wxT("y")) );
-  spr.set_clip_width( xml::reader_tool::read_uint(node, wxT("clip_width")) );
-  spr.set_clip_height( xml::reader_tool::read_uint(node, wxT("clip_height")) );
-  spr.set_width( spr.get_clip_width() );
-  spr.set_height( spr.get_clip_height() );
+  if ( spritepos.empty() )
+    {
+      spr.set_left( xml::reader_tool::read_uint(node, wxT("x")) );
+      spr.set_top( xml::reader_tool::read_uint(node, wxT("y")) );
+      spr.set_clip_width
+        ( xml::reader_tool::read_uint(node, wxT("clip_width")) );
+      spr.set_clip_height
+        ( xml::reader_tool::read_uint(node, wxT("clip_height")) );
+      spr.set_spritepos_entry
+        ( wx_to_std_string
+          (image_pool::get_instance().find_spritepos_name_from_size
+           ( std_to_wx_string(spr.get_image_name()),
+             spr.get_clip_rectangle() )) );
+    }
+  else
+    {
+      spr.set_clip_rectangle
+        ( image_pool::get_instance().get_spritepos_rectangle
+          ( std_to_wx_string(spr.get_image_name()),
+            std_to_wx_string(spritepos) ) );
+      spr.set_spritepos_entry( spritepos );
+    }
 
   load_rendering_attributes(spr, node);
+
+  if ( spr.get_auto_size() )
+    {
+      spr.set_width( spr.get_clip_width() );
+      spr.set_height( spr.get_clip_height() );
+    }
+  else if ( (spr.width() == spr.get_clip_width())
+            && (spr.height() == spr.get_clip_height()) )
+    spr.set_auto_size(true);
 } // xml_to_value::operator()() [sprite]
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the reader can process a node with a given name.
+ * \param node_name The name of the node.
+ */
+bool bf::xml::xml_to_value<bf::animation>::supported_node
+( const wxString& node_name )
+{
+  return node_name == wxT("animation");
+} // xml_to_value::supported_node() [animation]
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Read the value from a xml value node.
@@ -118,10 +155,15 @@ void bf::xml::xml_to_value<bf::animation>::operator()
 
   load_frames(anim, node->GetChildren());
 
-  anim.set_width( anim.get_max_size().x );
-  anim.set_height( anim.get_max_size().y );
-
   load_rendering_attributes(anim, node);
+
+  if ( anim.get_auto_size() )
+    {
+      anim.set_width( anim.get_max_size().x );
+      anim.set_height( anim.get_max_size().y );
+    }
+  else if ( anim.get_size() == anim.get_max_size() )
+    anim.set_auto_size(true);
 } // xml_to_value::operator()() [animation]
 
 /*----------------------------------------------------------------------------*/
@@ -168,7 +210,7 @@ void bf::xml::xml_to_value<bf::animation>::load_frame
       if ( children->GetName() == wxT("sprite") )
         {
           xml::xml_to_value<sprite> xml_conv;
-          xml_conv(spr,children);
+          xml_conv(spr, children);
           frame.set_sprite(spr);
           anim.add_frame() = frame;
         }
@@ -181,6 +223,17 @@ void bf::xml::xml_to_value<bf::animation>::load_frame
     throw missing_node("sprite");
 } // bf::xml::xml_to_value<bf::animation>::load_frame()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the reader can process a node with a given name.
+ * \param node_name The name of the node.
+ */
+bool bf::xml::xml_to_value<bf::animation_file_type>::supported_node
+( const wxString& node_name )
+{
+  return node_name == wxT("animation_file");
+} // xml_to_value::supported_node() [animation_file_type]
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Read the value from a xml value node.
@@ -202,6 +255,18 @@ void bf::xml::xml_to_value<bf::animation_file_type>::operator()
   load_rendering_attributes(anim, node);
 } // xml_to_value::operator()() [animation_file_type]
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the reader can process a node with a given name.
+ * \param node_name The name of the node.
+ */
+bool bf::xml::xml_to_value<bf::any_animation>::supported_node
+( const wxString& node_name )
+{
+  return xml_to_value<animation_file_type>::supported_node(node_name)
+    || xml_to_value<animation>::supported_node(node_name);
+} // xml_to_value::supported_node() [any_animation]
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Read the value from a xml value node.
@@ -213,14 +278,14 @@ void bf::xml::xml_to_value<bf::any_animation>::operator()
 {
   wxString name = node->GetName();
 
-  if ( name == wxT("animation_file") )
+  if ( xml_to_value<animation_file_type>::supported_node(name) )
     {
       animation_file_type data;
       xml_to_value<animation_file_type> reader;
       reader(data, node);
       anim.set_animation_file(data);
     }
-  else if ( name == wxT("animation") )
+  else if ( xml_to_value<animation>::supported_node(name) )
     {
       animation data;
       xml_to_value<animation> reader;
