@@ -1,7 +1,7 @@
 /*
   Bear Engine - Level editor
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -355,18 +355,7 @@ void bf::gui_level::set_active_layer( unsigned int layer_index )
 /**
  * \brief Get the layer on which we are working.
  */
-bf::layer& bf::gui_level::get_active_layer()
-{
-  CLAW_PRECOND( m_active_layer < layers_count() );
-
-  return get_layer(m_active_layer);
-} // gui_level::get_active_layer()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get the layer on which we are working.
- */
-const bf::layer& bf::gui_level::get_active_layer() const
+bf::layer& bf::gui_level::get_active_layer() const
 {
   CLAW_PRECOND( m_active_layer < layers_count() );
 
@@ -385,14 +374,16 @@ unsigned int bf::gui_level::get_active_layer_index() const
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add a layer in the level, at the top of the layer stack.
- * \param width The width of the new layer.
- * \param height The height of the new layer.
- * \param type The type of the new layer.
+ * \param class_name The name of the class of the layer.
+ * \param fit_level Tell if the layer size is the same than the level.
+ * \param width The width of the layer.
+ * \param height The height of the layer.
  */
 bf::layer& bf::gui_level::add_layer
-( unsigned int width, unsigned int height, const std::string& class_name )
+( const std::string& class_name, bool fit_level, unsigned int width,
+  unsigned int height )
 {
-  layer& result = level::add_layer( width, height, class_name );
+  layer& result = level::add_layer( class_name, fit_level, width, height );
 
   m_active_layer = layers_count()-1;
 
