@@ -1,7 +1,7 @@
 /*
   Bear Engine - Level editor
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -282,7 +282,7 @@ void bf::ingame_view::set_active_index( unsigned int index )
 /**
  * \brief Get the layer on which we are working.
  */
-const bf::layer& bf::ingame_view::get_active_layer() const
+bf::layer& bf::ingame_view::get_active_layer() const
 {
   return m_history.get_level().get_active_layer();
 } // ingame_view::get_active_layer()
@@ -543,6 +543,28 @@ bool bf::ingame_view::add_item( const std::string& class_name )
   return add_item( class_name, GetSize().x / 2, GetSize().y / 2 );
 } // ingame_view::add_item()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Check the validity of level.
+ * \return true if the level is ok.
+ */
+bool bf::ingame_view::check_level()
+{
+  m_check_result.clear();
+  get_level().check( m_check_result );
+  Refresh();
+  return m_check_result.is_ok();
+} // ingame_view::check_level()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the errors reported during the last check.
+ */
+const bf::level_check_result& bf::ingame_view::get_check_result() const
+{
+  return m_check_result;
+} // ingame_view::get_check_result()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Save the current level.
@@ -619,13 +641,9 @@ void bf::ingame_view::update_layout()
  */
 bool bf::ingame_view::has_selection() const
 {
-  if ( empty() )
-    return false;
-  else
-    return get_level().has_selection();
+  return get_level().has_selection();
 } // ingame_view::has_selection()
 
-/*----------------------------------------------------------------------------*/
 /**
  * \brief Set the selection to nothing.
  */
@@ -654,9 +672,13 @@ void bf::ingame_view::select_all()
  * \param item The item to select.
  * \param index The index of layer.
  */
-void bf::ingame_view::select_item_and_layer
-( item_instance* item, const unsigned int index)
+void bf::ingame_view::select_item_and_layer( item_instance* item )
 {
+  const std::size_t index = get_level().get_layer_by_item(*item);
+
+  if ( index == get_level().layers_count() )
+    return;
+
   // select the layer
   set_active_index( index );
   get_level().set_layer_visibility(index, true);
@@ -673,7 +695,7 @@ void bf::ingame_view::select_item_and_layer
                    (wxCoord)item->get_rendering_parameters().get_height()/2)
     - GetSize().y/2;
 
-  set_view_position(x,y);
+  set_view_position(x, y);
 } // ingame_view::set_item_and_layer()
 
 /*----------------------------------------------------------------------------*/
@@ -740,7 +762,7 @@ void bf::ingame_view::paste_from_clipboard()
 void bf::ingame_view::get_structure_sprites
 ( std::list<sprite_with_position>& s ) const
 {
-  layer::const_item_iterator it;
+  layer::item_iterator it;
 
   for (unsigned int i=0; i!=get_level().layers_count(); ++i)
     if ( get_level().layer_is_visible(i) )
@@ -765,16 +787,32 @@ void bf::ingame_view::get_structure_sprites
                 sprite_with_position spr;
 
                 spr.spr = zit->second->get_rendering_parameters().get_sprite();
-                spr.pos.x =
-                  (wxCoord)
-                  (zit->second->get_rendering_parameters().get_left()
-                   + zit->second->get_rendering_parameters().get_gap_x());
-                spr.pos.y =
-                  (wxCoord)
-                  ( m_history.get_level().get_height()
-                    - zit->second->get_rendering_parameters().get_bottom()
-                    - zit->second->get_rendering_parameters().get_height()
-                    + zit->second->get_rendering_parameters().get_gap_y() );
+                if (zit->second->get_rendering_parameters().is_mirrored() )
+                  spr.pos.x =
+                    (wxCoord)
+                    (zit->second->get_rendering_parameters().get_left()
+                     - zit->second->get_rendering_parameters().get_gap_x());
+                else
+                  spr.pos.x =
+                    (wxCoord)
+                    (zit->second->get_rendering_parameters().get_left()
+                     + zit->second->get_rendering_parameters().get_gap_x());
+
+                if ( zit->second->get_rendering_parameters().is_flipped() )
+                  spr.pos.y =
+                    (wxCoord)
+                    ( m_history.get_level().get_height()
+                      - zit->second->get_rendering_parameters().get_bottom()
+                      - zit->second->get_rendering_parameters().get_height()
+                      - zit->second->get_rendering_parameters().get_gap_y() );
+                else
+                  spr.pos.y =
+                    (wxCoord)
+                    ( m_history.get_level().get_height()
+                      - zit->second->get_rendering_parameters().get_bottom()
+                      - zit->second->get_rendering_parameters().get_height()
+                      + zit->second->get_rendering_parameters().get_gap_y() );
+
                 s.push_back( spr );
               }
           }
@@ -836,8 +874,8 @@ void bf::ingame_view::render_layers( wxDC& dc ) const
 void bf::ingame_view::render_layer( wxDC& dc, unsigned int i ) const
 {
   const layer& the_layer = m_history.get_level().get_layer(i);
-  layer::const_item_iterator it;
-  std::multimap<int, const item_instance*> z_order;
+  layer::item_iterator it;
+  std::multimap<int, item_instance*> z_order;
 
   const wxRect vis_box( unzoom(m_view), unzoom(GetSize()) );
 
@@ -847,7 +885,7 @@ void bf::ingame_view::render_layer( wxDC& dc, unsigned int i ) const
 
       if ( box.Intersects(vis_box)  )
         z_order.insert
-          ( std::pair<int, const item_instance*>
+          ( std::pair<int, item_instance*>
             (it->get_rendering_parameters().get_pos_z(), &(*it)) );
     }
 
@@ -862,10 +900,10 @@ void bf::ingame_view::render_layer( wxDC& dc, unsigned int i ) const
  * \param i The index of the layer in which the items are.
  */
 void bf::ingame_view::render_items
-( wxDC& dc, const std::multimap<int, const item_instance*>& z_order,
+( wxDC& dc, const std::multimap<int, item_instance*>& z_order,
   unsigned int i ) const
 {
-  std::multimap<int, const item_instance*>::const_iterator it;
+  std::multimap<int, item_instance*>::const_iterator it;
   std::list<const item_instance*> wireframe_forced;
 
   if ( m_graphic_drawing )
@@ -883,7 +921,7 @@ void bf::ingame_view::render_items
       render_item_wireframe(dc, *wireframe_forced.front(), i );
 
   for (it=z_order.begin(); it!=z_order.end(); ++it)
-    if ( !it->second->get_rendering_parameters().is_valid() )
+    if ( m_check_result.contains(&get_level().get_layer(i), it->second) )
       render_non_valid_item(dc, *it->second);
 
   if ( m_display_id )
@@ -904,7 +942,7 @@ void bf::ingame_view::render_items
  */
 void bf::ingame_view::render_relationship
 ( wxDC& dc, const item_instance& item,
-  const std::multimap<int, const item_instance*>& z_order ) const
+  const std::multimap<int, item_instance*>& z_order ) const
 {
   std::list<item_class const*> h;
   item_class::field_iterator itf;
@@ -927,7 +965,7 @@ void bf::ingame_view::render_relationship
                 ref.push_front(r);
               }
 
-            std::multimap<int, const item_instance*>::const_iterator itz;
+            std::multimap<int, item_instance*>::const_iterator itz;
 
             for ( ; !ref.empty(); ref.pop_front() )
               for (itz=z_order.begin(); itz!=z_order.end(); ++itz)
@@ -1070,10 +1108,18 @@ void bf::ingame_view::render_item_as_sprite
   wxPoint p(pos);
 
   // the y coordinate of the ingame_view and the level are opposed
-  p.x += zoom( wxCoord(item.get_rendering_parameters().get_gap_x()) );
+  if ( item.get_rendering_parameters().is_mirrored() )
+    p.x -= zoom( wxCoord(item.get_rendering_parameters().get_gap_x()) );
+  else
+    p.x += zoom( wxCoord(item.get_rendering_parameters().get_gap_x()) );
+
   p.y += zoom(item.get_rendering_parameters().get_height())
-    - zoom(item.get_rendering_parameters().get_sprite().height())
-    - zoom(item.get_rendering_parameters().get_gap_y());
+    - zoom(item.get_rendering_parameters().get_sprite().height());
+
+  if ( item.get_rendering_parameters().is_flipped() )
+    p.y += zoom(item.get_rendering_parameters().get_gap_y());
+  else
+    p.y -= zoom(item.get_rendering_parameters().get_gap_y());
 
   render_sprite(dc, item, p);
 } // ingame_view::render_item_as_sprite()
@@ -1892,12 +1938,34 @@ wxRect bf::ingame_view::get_bounding_box( const item_instance& item ) const
 wxRect bf::ingame_view::get_presence_box( const item_instance& item ) const
 {
   wxRect result = get_bounding_box(item);
-  wxPoint gap( item.get_rendering_parameters().get_gap_x(),
-               item.get_rendering_parameters().get_gap_y() );
 
+  wxPoint pos_gap( result.GetPosition() );
+
+  if ( item.get_rendering_parameters().is_mirrored() )
+    pos_gap.x -= item.get_rendering_parameters().get_gap_x();
+  else
+    pos_gap.x += item.get_rendering_parameters().get_gap_x();
+
+  if ( item.get_rendering_parameters().is_flipped() )
+    pos_gap.y -= item.get_rendering_parameters().get_gap_y();
+  else
+    pos_gap.y += item.get_rendering_parameters().get_gap_y();
+
+  wxPoint pos_min( std::min(result.GetPosition().x, pos_gap.x),
+                   std::min(result.GetPosition().y, pos_gap.y) );
+
+  wxPoint pos_max( std::max(result.GetPosition().x, pos_gap.x),
+                   std::max(result.GetPosition().y, pos_gap.y) );
+
+  result.SetPosition( pos_min );
+  result.width += pos_max.x - pos_min.x;
+  result.height += pos_max.y - pos_min.y;
+
+  /*
   result.SetPosition( result.GetPosition() + gap );
   result.width += std::abs( gap.x );
   result.height += std::abs( gap.y );
+  */
 
   return result;
 } // ingame_view::get_presence_box()
@@ -1913,6 +1981,7 @@ void bf::ingame_view::copy_selection(bool add)
   do_action
     ( new action_copy_selection
       ( get_level(), m_drag_info->delta().x, m_drag_info->delta().y, add ) );
+  m_parent.update_toolbar();
 } // ingame_view::copy_selection()
 
 /*----------------------------------------------------------------------------*/
@@ -2103,6 +2172,8 @@ void bf::ingame_view::write_mouse_position(const wxPoint& point)
     }
   else
     {
+      SetToolTip(NULL);
+
       m_parent.GetStatusBar()->SetStatusText
         ( wxString::Format( _("x=%d"), point.x), 1 );
       m_parent.GetStatusBar()->SetStatusText
@@ -2113,6 +2184,7 @@ void bf::ingame_view::write_mouse_position(const wxPoint& point)
 
       if ( item != NULL )
         {
+          set_tooltip(item);
           class_str = std_to_wx_string(item->get_class().get_class_name());
 
           if ( !item->get_id().empty() )
@@ -2120,10 +2192,6 @@ void bf::ingame_view::write_mouse_position(const wxPoint& point)
               wxString::Format
               ( _("id = '%s'"), std_to_wx_string(item->get_id()).c_str() );
 
-          if ( !item->get_rendering_parameters().is_valid() )
-            class_str += wxT("  ") +
-              std_to_wx_string(item->get_rendering_parameters().get_error());
-
           if ( m_history.get_level().has_selection() )
             {
               const item_rendering_parameters& r1
@@ -2146,6 +2214,44 @@ void bf::ingame_view::write_mouse_position(const wxPoint& point)
     }
 } // ingame_view::write_mouse_position()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set the tooltip according to the check result of a given item.
+ * \param item The item.
+ */
+void bf::ingame_view::set_tooltip( item_instance* item )
+{
+  wxString tooltip;
+
+  if ( m_check_result.contains( &get_active_layer(), item ) )
+    {
+      tooltip =
+          wxString::Format
+          ( _("%s:"),
+              std_to_wx_string(item->get_class().get_class_name()).c_str() );
+
+      item_check_result::const_iterator it;
+      const item_check_result result =
+        m_check_result.get_layer_result
+        ( &get_active_layer() ).get_item_result(item);
+
+      for ( it=result.begin(); it!=result.end(); ++it )
+        if ( it->get_cause().empty() )
+          tooltip +=
+            wxString::Format
+            ( _("\n%s"),
+              wxGetTranslation( std_to_wx_string(it->get_message()) ) );
+        else
+          tooltip +=
+            wxString::Format
+            ( _("\n%s: %s"),
+              wxGetTranslation( std_to_wx_string(it->get_cause()) ),
+              wxGetTranslation( std_to_wx_string(it->get_message()) ) );
+    }
+
+  SetToolTip(tooltip);
+} // ingame_view::set_tooltip()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Check if the user tries to resize an item and set the drag mode if it
@@ -2459,6 +2565,8 @@ void bf::ingame_view::apply_action( Action* action )
       m_parent.set_changed( true );
       m_parent.set_layer_info();
 
+      m_layout.get_layer_list_frame().refresh();
+
       if ( !m_history.get_level().empty()
            && !old_sel.same_group_than(m_history.get_level().get_selection()) )
         update_layout();
@@ -2624,6 +2732,7 @@ void bf::ingame_view::on_mouse_left_up(wxMouseEvent& event)
       delete m_drag_info;
       m_drag_info = NULL;
     }
+  m_parent.update_toolbar();
 } // ingame_view::on_mouse_left_up()
 
 /*----------------------------------------------------------------------------*/
@@ -2645,6 +2754,7 @@ void bf::ingame_view::on_mouse_middle_up(wxMouseEvent& event)
 
       do_action( new action_copy_selection( get_level(), dx, dy, false ) );
     }
+  m_parent.update_toolbar();
 } // ingame_view::on_mouse_middle_up()
 
 /*----------------------------------------------------------------------------*/
@@ -2679,7 +2789,7 @@ void bf::ingame_view::on_mouse_wheel_rotation(wxMouseEvent& event)
         ( m_view.x - m_parent.get_h_scrollbar().GetPageSize() / 4, m_view.y );
     else if ( event.ControlDown() )
       {
-        set_zoom( get_zoom() + 5,point );
+        set_zoom( get_zoom() + 5, point );
         m_parent.update_zoom();
       }
     else
