@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -39,11 +39,13 @@
 #include "bf/level_overview_frame.hpp"
 #include "bf/level_properties_frame.hpp"
 #include "bf/main_frame.hpp"
+#include "bf/new_layer_from_image_dialog.hpp"
 #include "bf/offset_selection_dialog.hpp"
 #include "bf/properties_frame.hpp"
 #include "bf/windows_layout.hpp"
 #include "bf/wx_facilities.hpp"
 
+#include "bf/history/action_add_layer.hpp"
 #include "bf/history/action_align_selection_bottom.hpp"
 #include "bf/history/action_align_selection_center_x.hpp"
 #include "bf/history/action_align_selection_center_y.hpp"
@@ -52,9 +54,11 @@
 #include "bf/history/action_align_selection_top.hpp"
 #include "bf/history/action_clone_selection.hpp"
 #include "bf/history/action_delete_selection.hpp"
+#include "bf/history/action_group.hpp"
 #include "bf/history/action_move_down.hpp"
 #include "bf/history/action_move_selection.hpp"
 #include "bf/history/action_move_up.hpp"
+#include "bf/history/action_remove_layer.hpp"
 #include "bf/history/action_resize_level.hpp"
 
 #include "bf/icon/compile.xpm"
@@ -69,13 +73,13 @@
 #include "bf/icon/clone.xpm"
 #include "bf/icon/graphism.xpm"
 #include "bf/icon/grid.xpm"
-#include "bf/icon/id.xpm"
 #include "bf/icon/magnetism.xpm"
 #include "bf/icon/move_backward.xpm"
 #include "bf/icon/move_forward.xpm"
 #include "bf/icon/offset.xpm"
 #include "bf/icon/overview.xpm"
 #include "bf/icon/relationship.xpm"
+#include "bf/icon/text.xpm"
 #include "bf/icon/wireframe.xpm"
 #include "bf/icon/zoom_in.xpm"
 #include "bf/icon/zoom_out.xpm"
@@ -107,6 +111,7 @@ bf::ingame_view_frame::ingame_view_frame
   m_layout.add_level_view(*this);
 
   m_overview = new level_overview_frame(*this);
+  m_errors = new error_check_level_dialog(this, ID_ERROR_FRAME);
 
   set_changed(false);
   set_layer_info();
@@ -156,6 +161,7 @@ void bf::ingame_view_frame::set_changed( bool b )
 {
   m_changed = b;
   make_title();
+  update_toolbar();
 } // ingame_view_frame::set_changed()
 
 /*----------------------------------------------------------------------------*/
@@ -284,11 +290,10 @@ const wxScrollBar& bf::ingame_view_frame::get_v_scrollbar()
 /**
  * \brief Update the zoom.
  */
-void bf::ingame_view_frame::update_zoom()
+void bf::ingame_view_frame::update_zoom() const
 {
-  update_toolbar();
+  m_zoom_spin->SetValue(m_ingame_view->get_zoom());
 } // ingame_view_frame::update_zoom()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Make the title of the window.
@@ -321,7 +326,7 @@ bool bf::ingame_view_frame::effective_save()
     {
       m_ingame_view->save(f);
       result = true;
-      m_changed = false;
+      set_changed(false);
       make_title();
     }
   else
@@ -467,7 +472,7 @@ wxMenu* bf::ingame_view_frame::create_edit_menu()
   result->Append
     ( wxID_UNDO, _("&Undo\tCTRL+Z"), _("Undo the last operation.") );
   result->Append
-    ( wxID_REDO, _("&Redo\tCTRL+Y"),_("Redo the last undone operation.") );
+    ( wxID_REDO, _("&Redo\tCTRL+Y"), _("Redo the last undone operation.") );
   result->AppendSeparator();
 
   result->Append
@@ -532,6 +537,13 @@ wxMenu* bf::ingame_view_frame::create_edit_menu()
     ( ID_CHANGE_LAYER, _("C&hange layer..."), sub_menu,
       _("Move the selection in an other layer.") );
 
+#if 0
+  result->AppendSeparator();
+  result->Append
+    ( ID_NEW_LAYER_FROM_IMAGE, _("New layer from image…"),
+      _("Create a new layer from image.") );
+#endif
+
   return result;
 } // ingame_view_frame::create_edit_menu()
 
@@ -646,7 +658,7 @@ void bf::ingame_view_frame::create_toolbar()
     ( ID_GRID_MAGNETISM, _("&Magnetism"), wxBitmap(magnetism_xpm),
       wxBitmap(magnetism_xpm), _("Magnetism") );
   bar->AddCheckTool
-    ( ID_ID_VISIBLE, _("&Identifiers"), wxBitmap(id_xpm), wxBitmap(id_xpm),
+    ( ID_ID_VISIBLE, _("&Identifiers"), wxBitmap(text_xpm), wxBitmap(text_xpm),
       _("Identifiers") );
   bar->AddCheckTool
     ( ID_WIREFRAME, _("&Wireframe"), wxBitmap(wireframe_xpm),
@@ -684,7 +696,7 @@ void bf::ingame_view_frame::create_toolbar()
 /**
  * \brief Update the content of the toolbar.
  */
-void bf::ingame_view_frame::update_toolbar()
+void bf::ingame_view_frame::update_toolbar() const
 {
   wxToolBar* bar = GetToolBar();
 
@@ -698,7 +710,28 @@ void bf::ingame_view_frame::update_toolbar()
   bar->ToggleTool(ID_WIREFRAME, m_ingame_view->get_wireframe_drawing());
   bar->ToggleTool(ID_RELATIONSHIP, m_ingame_view->get_relationship_drawing());
   bar->ToggleTool(ID_LEVEL_OVERVIEW, m_overview->IsVisible());
+
   m_zoom_spin->SetValue(m_ingame_view->get_zoom());
+  if(m_ingame_view->get_zoom()==1)
+    bar->EnableTool(wxID_ZOOM_OUT, false);
+  else
+    bar->EnableTool(wxID_ZOOM_OUT, true);
+
+  bar->EnableTool(wxID_SAVE, is_changed());
+
+  bool has_selection = m_ingame_view->has_selection();
+  bar->EnableTool(wxID_CUT, has_selection);
+  bar->EnableTool(wxID_COPY, has_selection);
+  bar->EnableTool(wxID_DELETE, has_selection);
+  bar->EnableTool(ID_CLONE, has_selection);
+  bar->EnableTool(ID_OFFSET, has_selection);
+  bar->EnableTool(ID_ALIGN, has_selection);
+
+  bar->EnableTool
+    (wxID_PASTE, !m_ingame_view->get_clipboard().items.empty());
+
+  bar->EnableTool(wxID_UNDO, m_ingame_view->get_history().can_undo());
+  bar->EnableTool(wxID_REDO, m_ingame_view->get_history().can_redo());
 } // ingame_view_frame::update_toolbar()
 
 /*----------------------------------------------------------------------------*/
@@ -832,27 +865,11 @@ void bf::ingame_view_frame::show_grid_configuration()
  */
 bool bf::ingame_view_frame::check_level()
 {
-  bool result = true;
-  std::list< std::pair<item_instance*, unsigned int> > items;
+  bool result = m_ingame_view->check_level();
 
-  m_ingame_view->get_level().check(items);
-
-  if ( !items.empty() )
-    {
-      error_check_level_dialog dlg(*this, items);
-
-      dlg.ShowModal();
-
-      unsigned int index = dlg.get_index_selected();
-      unsigned int i = 0;
-      std::list< std::pair<item_instance*, unsigned int> >::const_iterator it;
-      for ( it = items.begin();
-            (i != index) && (it != items.end()); ++i, ++it);
-
-      m_ingame_view->select_item_and_layer(it->first, it->second);
-
-      result = false;
-    }
+  level_check_result errors = m_ingame_view->get_check_result();
+  m_errors->set_errors(errors);
+  m_errors->Show(!result);
 
   return result;
 } // ingame_view_frame::check_level()
@@ -942,6 +959,7 @@ void bf::ingame_view_frame::update_menu( MenuType& m ) const
   m.Enable
     (wxID_PASTE, !m_ingame_view->get_clipboard().items.empty());
   m.Enable(wxID_DELETE, m_ingame_view->has_selection());
+  m.Enable(ID_SELECT_NONE, m_ingame_view->has_selection());
 
   if ( m_ingame_view->get_history().can_undo() )
     m.SetLabel
@@ -1156,7 +1174,7 @@ void bf::ingame_view_frame::on_level_statistics
       text += wxString::Format
         ( _("Layer %d has %d items.\n"), i, lay.get_items_count() );
 
-      layer::const_item_iterator it;
+      layer::item_iterator it;
 
       for (it=lay.item_begin(); it!=lay.item_end(); ++it)
         if ( it->get_rendering_parameters().has_sprite() )
@@ -1189,6 +1207,7 @@ void bf::ingame_view_frame::on_level_statistics
 void bf::ingame_view_frame::on_undo( wxCommandEvent& WXUNUSED(event) )
 {
   m_ingame_view->undo();
+  update_toolbar();
 } // ingame_view_frame::on_undo()
 
 /*----------------------------------------------------------------------------*/
@@ -1199,6 +1218,7 @@ void bf::ingame_view_frame::on_undo( wxCommandEvent& WXUNUSED(event) )
 void bf::ingame_view_frame::on_redo( wxCommandEvent& WXUNUSED(event) )
 {
   m_ingame_view->redo();
+  update_toolbar();
 } // ingame_view_frame::on_redo()
 
 /*----------------------------------------------------------------------------*/
@@ -1209,6 +1229,7 @@ void bf::ingame_view_frame::on_redo( wxCommandEvent& WXUNUSED(event) )
 void bf::ingame_view_frame::on_cut( wxCommandEvent& WXUNUSED(event) )
 {
   m_ingame_view->cut_to_clipboard();
+  update_toolbar();
 } // ingame_view_frame::on_cut()
 
 /*----------------------------------------------------------------------------*/
@@ -1229,6 +1250,7 @@ void bf::ingame_view_frame::on_copy( wxCommandEvent& WXUNUSED(event) )
 void bf::ingame_view_frame::on_paste( wxCommandEvent& WXUNUSED(event) )
 {
   m_ingame_view->paste_from_clipboard();
+  update_toolbar();
 } // ingame_view_frame::on_paste()
 
 /*----------------------------------------------------------------------------*/
@@ -1240,6 +1262,7 @@ void bf::ingame_view_frame::on_delete( wxCommandEvent& WXUNUSED(event) )
 {
   m_ingame_view->do_action
     ( new action_delete_selection(m_ingame_view->get_level()) );
+  update_toolbar();
 } // ingame_view_frame::on_delete()
 
 /*----------------------------------------------------------------------------*/
@@ -1250,6 +1273,7 @@ void bf::ingame_view_frame::on_delete( wxCommandEvent& WXUNUSED(event) )
 void bf::ingame_view_frame::on_select_all( wxCommandEvent& WXUNUSED(event) )
 {
   m_ingame_view->select_all();
+  update_toolbar();
 } // ingame_view_frame::on_select_all()
 
 /*----------------------------------------------------------------------------*/
@@ -1260,6 +1284,7 @@ void bf::ingame_view_frame::on_select_all( wxCommandEvent& WXUNUSED(event) )
 void bf::ingame_view_frame::on_select_none( wxCommandEvent& WXUNUSED(event) )
 {
   m_ingame_view->clear_selection();
+  update_toolbar();
 } // ingame_view_frame::on_select_none()
 
 /*----------------------------------------------------------------------------*/
@@ -1272,6 +1297,16 @@ void bf::ingame_view_frame::on_check_level( wxCommandEvent& WXUNUSED(event) )
   check_level_verbose();
 } // ingame_view_frame::on_check_level()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Answer to a click on the menu "Save level".
+ * \param event This event occured.
+ */
+void bf::ingame_view_frame::on_save( wxCommandEvent& WXUNUSED(event) )
+{
+  save();
+} // ingame_view_frame::on_save()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Answer to a click on the menu "Compile level".
@@ -1657,8 +1692,8 @@ void bf::ingame_view_frame::on_zoom_out( wxCommandEvent& WXUNUSED(event) )
       else
         m_ingame_view->set_zoom( m_ingame_view->get_zoom() - 10 );
 
-      m_ingame_view->Refresh();
       update_toolbar();
+      m_ingame_view->Refresh();
     }
 } // ingame_view_frame::on_zoom_out()
 
@@ -1670,6 +1705,7 @@ void bf::ingame_view_frame::on_zoom_out( wxCommandEvent& WXUNUSED(event) )
 void bf::ingame_view_frame::on_zoom_change( wxSpinEvent& event )
 {
   m_ingame_view->set_zoom( event.GetPosition() );
+  update_toolbar();
   m_ingame_view->Refresh();
 } // ingame_view_frame::on_zoom_change()
 
@@ -1705,6 +1741,47 @@ void bf::ingame_view_frame::on_next_layer( wxCommandEvent& WXUNUSED(event) )
         % m_ingame_view->get_level().layers_count() );
 } // ingame_view_frame::on_next_layer()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create a decorative layer from a big image and generate the sprites.
+ * \param event This event occured.
+ */
+void bf::ingame_view_frame::on_new_layer_from_image
+( wxCommandEvent& WXUNUSED(event) )
+{
+  new_layer_from_image_dialog dlg
+    ( *this, m_ingame_view->get_level().layers_count(),
+      m_layout.get_item_class_pool() );
+
+  if ( dlg.ShowModal() == wxID_OK )
+    {
+      level_action* result =
+        new action_add_layer( dlg.drop_layer(), dlg.get_layer_index() );
+
+      if ( dlg.layer_replaces_previous()
+           && ( dlg.get_layer_index()
+                < m_ingame_view->get_level().layers_count() ) )
+        {
+          action_group* g = new action_group( result->get_description() );
+          g->add_action( new action_remove_layer( dlg.get_layer_index() ) );
+          g->add_action( result );
+          result = g;
+        }
+
+      m_ingame_view->do_action( result );
+    }
+} // ingame_view_frame::on_new_layer_from_image()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief An item has been selected in the error frame.
+ * \param event The event carrying the item.
+ */
+void bf::ingame_view_frame::on_error_selected( item_event& event )
+{
+  m_ingame_view->select_item_and_layer( event.get_item() );
+} // ingame_view_frame::on_error_selected()
+
 /*----------------------------------------------------------------------------*/
 BEGIN_EVENT_TABLE(bf::ingame_view_frame, wxFrame)
   EVT_SIZE( bf::ingame_view_frame::on_size )
@@ -1725,6 +1802,7 @@ BEGIN_EVENT_TABLE(bf::ingame_view_frame, wxFrame)
   EVT_MENU( ID_SELECT_NONE, bf::ingame_view_frame::on_select_none )
   EVT_MENU(  bf::ingame_view_frame::ID_CHECK_LEVEL,
        bf::ingame_view_frame::on_check_level )
+  EVT_MENU(  wxID_SAVE, bf::ingame_view_frame::on_save )
   EVT_MENU(  bf::ingame_view_frame::ID_COMPILE_LEVEL,
        bf::ingame_view_frame::on_compile_level )
   EVT_MENU( wxID_CLOSE, bf::ingame_view_frame::on_menu_close )
@@ -1798,4 +1876,9 @@ BEGIN_EVENT_TABLE(bf::ingame_view_frame, wxFrame)
   EVT_TOOL( bf::ingame_view_frame::ID_NEXT_LAYER,
             bf::ingame_view_frame::on_next_layer )
 
+  EVT_MENU( bf::ingame_view_frame::ID_NEW_LAYER_FROM_IMAGE,
+            bf::ingame_view_frame::on_new_layer_from_image )
+
+  EVT_ITEM_SELECTION( bf::ingame_view_frame::ID_ERROR_FRAME,
+                      bf::ingame_view_frame::on_error_selected)
 END_EVENT_TABLE()
