@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -31,19 +31,23 @@
 #include "level_code_value.hpp"
 
 #include "bf/item_class_pool.hpp"
+#include "bf/layer_check_result.hpp"
 
 #include <claw/assert.hpp>
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
+ * \param layer_type The type of the layer.
+ * \param fit_level Tell if the size of the layer is the size of the level.
  * \param width The width of the layer.
  * \param height The height of the layer.
- * \param layer_type The type of the layer.
  */
 bf::layer::layer
-( unsigned int width, unsigned int height, const std::string& layer_type )
-  : m_width(width), m_height(height), m_layer_type(layer_type)
+( const std::string& layer_type, bool fit_level, unsigned int width,
+  unsigned int height )
+  : m_fit_level(fit_level), m_width(width), m_height(height),
+    m_layer_type(layer_type)
 {
   CLAW_PRECOND( width > 0 );
   CLAW_PRECOND( height > 0 );
@@ -68,6 +72,25 @@ bf::layer::~layer()
   clear();
 } // layer::~layer()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the layer has to fit the level.
+ * \param f Fit or not.
+ */
+void bf::layer::set_fit_level( bool f )
+{
+  m_fit_level = f;
+} // layer::set_fit_level()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the layer has to fit the level.
+ */
+bool bf::layer::fits_level() const
+{
+  return m_fit_level;
+} // layer::fits_level()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Change the size of the layer.
@@ -117,6 +140,7 @@ void bf::layer::add_item( item_instance* item )
 void bf::layer::remove_item( item_instance* item )
 {
   CLAW_PRECOND( m_item.find(item) != m_item.end() );
+  CLAW_PRECOND( !is_prioritized(item) );
 
   if ( evaluate_filters_on_item(*item) )
     m_filtered_item.erase(item);
@@ -124,6 +148,118 @@ void bf::layer::remove_item( item_instance* item )
   m_item.erase(item);
 } // layer::remove_item()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Find an item with a given id.
+ * \param id The id of the searched item.
+ */
+bf::layer::item_iterator
+bf::layer::find_item_by_id( const std::string& id ) const
+{
+  bool found = false;
+  item_iterator it = item_begin_no_filter();
+  item_iterator eit( item_end_no_filter() );
+
+  while ( !found && (it!=eit) )
+    if ( it->get_id() == id )
+      found = true;
+    else
+      ++it;
+
+  return it;
+} // layer::find_item_by_id()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get all the items whose identifier is set.
+ */
+std::list<bf::item_instance*> bf::layer::get_identified_items() const
+{
+  std::list<item_instance*> result;
+
+  for ( item_set_type::iterator it=m_item.begin(); it!=m_item.end(); ++it )
+    if ( !(*it)->get_id().empty() )
+      result.push_back(*it);
+
+  return result;
+} // layer::get_identified_items()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add an item at the end of the list of the prioritized items for the
+ *        compilation.
+ * \param item The item to add.
+ */
+void bf::layer::prioritize( item_instance* item )
+{
+  prioritize( item, m_priority.size() );
+} // layer::prioritize()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add an item at the end of the list of the prioritized items for the
+ *        compilation.
+ * \param item The item to add.
+ * \param p The position of the item in the list.
+ */
+void bf::layer::prioritize( item_instance* item, std::size_t p )
+{
+  if ( is_prioritized(item) )
+    deprioritize(item);
+
+  item_list_type::iterator it=m_priority.begin();
+  std::advance(it, std::min(p, m_priority.size()));
+  m_priority.insert( it, item );
+} // layer::prioritize()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove an item from the list of the prioritized items.
+ * \param item The item to remove.
+ * \pre is_prioritized(item)
+ */
+void bf::layer::deprioritize( item_instance* item )
+{
+  CLAW_PRECOND( is_prioritized(item) );
+
+  m_priority.erase( std::find( m_priority.begin(), m_priority.end(), item ) );
+} // layer::()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if an item is prioritized for the compilation.
+ * \param item The item to search.
+ */
+bool bf::layer::is_prioritized( item_instance* item ) const
+{
+  return std::find( m_priority.begin(), m_priority.end(), item )
+    != m_priority.end();
+} // layer::is_prioritized()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the priority of an item in the compilation.
+ * \param item The item for which we want the priority.
+ * \pre is_prioritized(item)
+ */
+std::size_t bf::layer::get_priority( item_instance* item ) const
+{
+  CLAW_PRECOND( is_prioritized(item) );
+
+  item_list_type::const_iterator it =
+    std::find( m_priority.begin(), m_priority.end(), item );
+  return std::distance( m_priority.begin(), it );
+} // layer::get_priority()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the prioritized items.
+ */
+std::vector<bf::item_instance*> bf::layer::get_prioritized_items() const
+{
+  return std::vector<item_instance*>(m_priority.begin(), m_priority.end());
+} // layer::get_prioritized_items()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the type of the layer.
@@ -182,19 +318,19 @@ bool bf::layer::contains( const item_instance& item ) const
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Test if the layer is valid.
- * Return the bad items.
+ * \param result The result of the check.
  */
-std::list<bf::item_instance*> bf::layer::check
-( const std::map<std::string,item_instance*>& map_id )
+void bf::layer::check( layer_check_result& result ) const
 {
-  std::list<item_instance*> items;
+  check_priorities(result);
+
+  std::set<std::string> map_id;
+  check_unique_identifiers( result, map_id );
+
   item_set_type::const_iterator it;
 
   for (it=m_item.begin(); it!=m_item.end(); ++it)
-    if ( !(*it)->check(map_id) )
-      items.push_back(*it);
-
-  return items;
+    result.check( *it, map_id );
 } // layer::check()
 
 /*----------------------------------------------------------------------------*/
@@ -219,11 +355,11 @@ void bf::layer::compile( compiled_file& f ) const
 
   sort_and_identify(referenced, id_to_int);
 
-  // declaration of referenced items
   if ( !referenced.empty() )
     {
       f << bear::level_code_value::item_declaration << referenced.size();
 
+      // declaration of referenced items
       for (iti=referenced.begin(); iti!=referenced.end(); ++iti)
         f << (*iti)->get_class().get_class_name();
 
@@ -269,7 +405,7 @@ bf::layer::const_filter_iterator bf::layer::filter_end() const
  *         filter before and when removing a filter if the pointed item does not
  *         verify any of the remaining filters or if there is no more filters.
  */
-bf::layer::item_iterator bf::layer::item_begin()
+bf::layer::item_iterator bf::layer::item_begin() const
 {
   if ( m_filters.empty() )
     return m_item.begin();
@@ -281,34 +417,7 @@ bf::layer::item_iterator bf::layer::item_begin()
 /**
  * \brief Get an iterator past the end of the set of items.
  */
-bf::layer::item_iterator bf::layer::item_end()
-{
-  if ( m_filters.empty() )
-    return m_item.end();
-  else
-    return m_filtered_item.end();
-} // layer::item_end()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get an iterator on the set of items.
- * \remark Iterators are invalidated when inserting a filter if there was no
- *         filter before and when removing a filter if the pointed item does not
- *         verify any of the remaining filters or if there is no more filters.
- */
-bf::layer::const_item_iterator bf::layer::item_begin() const
-{
-  if ( m_filters.empty() )
-    return m_item.begin();
-  else
-    return m_filtered_item.begin();
-} // layer::item_begin()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get an iterator past the end of the set of items.
- */
-bf::layer::const_item_iterator bf::layer::item_end() const
+bf::layer::item_iterator bf::layer::item_end() const
 {
   if ( m_filters.empty() )
     return m_item.end();
@@ -321,7 +430,7 @@ bf::layer::const_item_iterator bf::layer::item_end() const
  * \brief Get an iterator on the set of items.
  * \remark These iterators iterates over all items, whatever the filters are.
  */
-bf::layer::item_iterator bf::layer::item_begin_no_filter()
+bf::layer::item_iterator bf::layer::item_begin_no_filter() const
 {
   return m_item.begin();
 } // layer::item_begin_no_filter()
@@ -330,26 +439,7 @@ bf::layer::item_iterator bf::layer::item_begin_no_filter()
 /**
  * \brief Get an iterator past the end of the set of items.
  */
-bf::layer::item_iterator bf::layer::item_end_no_filter()
-{
-  return m_item.end();
-} // layer::item_end_no_filter()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get an iterator on the set of items.
- * \remark These iterators iterates over all items, whatever the filters are.
- */
-bf::layer::const_item_iterator bf::layer::item_begin_no_filter() const
-{
-  return m_item.begin();
-} // layer::item_begin_no_filter()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get an iterator past the end of the set of items.
- */
-bf::layer::const_item_iterator bf::layer::item_end_no_filter() const
+bf::layer::item_iterator bf::layer::item_end_no_filter() const
 {
   return m_item.end();
 } // layer::item_end_no_filter()
@@ -437,6 +527,7 @@ void bf::layer::assign( const layer& that )
   CLAW_PRECOND( m_filters.empty() );
   CLAW_PRECOND( &that != this );
 
+  m_fit_level = that.m_fit_level;
   m_width = that.m_width;
   m_height = that.m_height;
   m_layer_type = that. m_layer_type;
@@ -466,9 +557,10 @@ void bf::layer::sort_and_identify
   std::list<item_instance*>::const_iterator it;
 
   for (it=referenced.begin(); it!=referenced.end(); ++it)
-    items[(*it)->get_id()] = *it;
+    if ( !is_prioritized(*it) )
+      items[(*it)->get_id()] = *it;
 
-  referenced.clear();
+  referenced = m_priority;
 
   while ( !items.empty() )
     sort_by_dependency( items.begin()->second, items, referenced );
@@ -544,3 +636,65 @@ bool bf::layer::evaluate_filters_on_item( const item_instance& item ) const
 
   return result;
 } // layer::evaluate_filters_on_item()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Check that the prioritized items are in a feasible order.
+ * \param result The check result in which the errors are added.
+ */
+void bf::layer::check_priorities( layer_check_result& result ) const
+{
+  item_list_type::const_iterator it;
+
+  for ( it=m_priority.begin(); it!=m_priority.end(); ++it )
+    if ( (*it)->get_id().empty() )
+      result.add( *it, check_error("Prioritized items must have an id.") );
+    else
+      {
+        item_list_type::const_iterator next=it;
+
+        for ( ++next; next!=m_priority.end(); ++next )
+          if ( (*it)->has_a_reference_to((*next)->get_id()) )
+            {
+              const check_error error
+                ( (*it)->get_id() + "/" + (*next)->get_id(),
+                    "The build order is in conflict with the dependency based "
+                    "on the fields.");
+
+              result.add(*next, error);
+              result.add(*it, error);
+            }
+      }
+} // layer::check_priorities()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Check that the identifiers of the item are unique.
+ * \param result The check result in which the errors are added.
+ * \param identifiers (out) The identifiers of the items.
+ */
+void bf::layer::check_unique_identifiers
+( layer_check_result& result, std::set<std::string>& identifiers ) const
+{
+  std::map<std::string, item_instance*> map_id;
+
+  item_set_type::const_iterator it;
+  for ( it=m_item.begin(); it!=m_item.end(); ++it )
+    if ( !(*it)->get_id().empty() )
+      {
+        if ( map_id.find((*it)->get_id()) != map_id.end() )
+          {
+            item_instance* other = map_id[(*it)->get_id()];
+            const check_error error
+              ( (*it)->get_id(), "This identifier is already in use." );
+
+            result.add( other, error );
+            result.add( *it, error );
+          }
+        else
+          {
+            map_id[(*it)->get_id()] = *it;
+            identifiers.insert( (*it)->get_id() );
+          }
+      }
+} // layer::check_unique_identifiers()
