@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -30,14 +30,19 @@
 
 #include "bf/gui_level.hpp"
 #include "bf/ingame_view.hpp"
+#include "bf/item_reference_edit.hpp"
 #include "bf/layer_properties_frame.hpp"
+#include "bf/value_editor_dialog.hpp"
 #include "bf/wx_facilities.hpp"
 
 #include "bf/history/action_add_layer.hpp"
+#include "bf/history/action_deprioritize.hpp"
 #include "bf/history/action_move_layer_backward.hpp"
 #include "bf/history/action_move_layer_forward.hpp"
+#include "bf/history/action_prioritize.hpp"
 #include "bf/history/action_remove_layer.hpp"
 #include "bf/history/action_resize_layer.hpp"
+#include "bf/history/action_set_priority.hpp"
 
 #include "bf/icon/delete_filter.xpm"
 #include "bf/icon/delete_filter_everywhere.xpm"
@@ -48,6 +53,7 @@
 #include "bf/item_filter/item_filter_by_class_name.hpp"
 #include "bf/item_filter/item_filter_by_class_name_glob.hpp"
 
+#include <wx/notebook.h>
 #include <wx/artprov.h>
 
 /*----------------------------------------------------------------------------*/
@@ -70,7 +76,18 @@ void bf::layer_list_frame::set_level_view( ingame_view* view )
 {
   m_level_view = view;
   fill();
-} // layer_list_frame::set_level()
+} // layer_list_frame::set_level_view()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Refresh the content of the controls.
+ */
+void bf::layer_list_frame::refresh()
+{
+  // The priority list is the only part whose content that can change from
+  // outside
+  fill_priority_list();
+} // layer_list_frame::refresh()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -78,36 +95,30 @@ void bf::layer_list_frame::set_level_view( ingame_view* view )
  */
 void bf::layer_list_frame::create_controls()
 {
-  create_member_controls();
-  create_sizer_controls();
+  wxNotebook* tabs =
+    new wxNotebook(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxNB_TOP );
+
+  SetSizer( new wxBoxSizer(wxVERTICAL) );
+
+  GetSizer()->Add( create_layer_list( this ), 1, wxEXPAND );
+
+  tabs->AddPage( create_filters_page( tabs ), _("Filters") );
+  tabs->AddPage( create_priority_page( tabs ), _("Priority") );
+
+  GetSizer()->Add( tabs, 1, wxEXPAND );
 } // layer_list_frame::create_controls()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Create the controls for which we keep a reference.
+ * \brief Create the controls for the layer list.
+ * \param parent The parent window of the resulting window.
  */
-void bf::layer_list_frame::create_member_controls()
+wxWindow* bf::layer_list_frame::create_layer_list( wxWindow* parent )
 {
-  m_layer_list = new wxCheckListBox( this, IDC_LAYER_LIST );
-  m_filter_list =
-    new wxListBox
-    ( this, IDC_FILTER_LIST, wxDefaultPosition, wxDefaultSize, 0, NULL,
-      wxLB_MULTIPLE | wxLB_NEEDED_SB );
-  m_filter_entry =
-    new wxTextCtrl
-    ( this, IDC_FILTER_ENTRY, wxEmptyString, wxDefaultPosition, wxDefaultSize,
-      wxTE_PROCESS_ENTER );
+  wxWindow* result = new wxPanel( parent, wxID_ANY );
 
-  m_filter_entry->SetToolTip
-    ( _("Type the name of the only classes you want to see in the editor") );
-} // layer_list_frame::create_member_controls()
+  m_layer_list = new wxCheckListBox( result, IDC_LAYER_LIST );
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Create the controls and add them in sizers.
- */
-void bf::layer_list_frame::create_sizer_controls()
-{
   wxBoxSizer* sizer = new wxBoxSizer( wxVERTICAL );
 
   // the sizer for the buttons
@@ -115,55 +126,82 @@ void bf::layer_list_frame::create_sizer_controls()
 
   s_sizer->Add
     ( wx_new_bitmap_button
-      ( this, wxID_NEW, wxArtProvider::GetBitmap(wxART_NEW), _("New layer")),
+      ( result, wxID_NEW, wxArtProvider::GetBitmap(wxART_NEW), _("New layer")),
       0, wxEXPAND | wxALL, 0 );
   s_sizer->Add
     ( wx_new_bitmap_button
-      ( this, wxID_DELETE, wxArtProvider::GetBitmap(wxART_DELETE),
+      ( result, wxID_DELETE, wxArtProvider::GetBitmap(wxART_DELETE),
         _("Delete selected layer") ),
       0, wxEXPAND | wxALL, 0 );
   s_sizer->Add
     ( wx_new_bitmap_button
-      ( this, wxID_UP, wxArtProvider::GetBitmap(wxART_GO_UP),
+      ( result, wxID_UP, wxArtProvider::GetBitmap(wxART_GO_UP),
         _("Move selected layer backward") ),
       0, wxEXPAND | wxALL, 0 );
   s_sizer->Add
     ( wx_new_bitmap_button
-      ( this, wxID_DOWN, wxArtProvider::GetBitmap(wxART_GO_DOWN),
+      ( result, wxID_DOWN, wxArtProvider::GetBitmap(wxART_GO_DOWN),
         _("Move selected layer forward") ),
       0, wxEXPAND | wxALL, 0 );
   s_sizer->Add
     ( wx_new_bitmap_button
-      (this, wxID_PROPERTIES, wxBitmap(edit_xpm),
+      (result, wxID_PROPERTIES, wxBitmap(edit_xpm),
        _("Edit the properties of the selected layer") ),
       0, wxEXPAND | wxALL, 0 );
 
   sizer->Add( s_sizer, 0, wxEXPAND );
   sizer->Add( m_layer_list, 1, wxEXPAND );
 
-  s_sizer = new wxBoxSizer( wxHORIZONTAL );
+  result->SetSizer( sizer );
+  return result;
+} // create_layer_list()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the controls for the filter list.
+ * \param parent The parent window of the resulting window.
+ */
+wxWindow* bf::layer_list_frame::create_filters_page( wxWindow* parent )
+{
+  wxWindow* result = new wxPanel( parent, wxID_ANY );
+
+  m_filter_list =
+    new wxListBox
+    ( result, IDC_FILTER_LIST, wxDefaultPosition, wxDefaultSize, 0, NULL,
+      wxLB_MULTIPLE | wxLB_NEEDED_SB );
+  m_filter_entry =
+    new wxTextCtrl
+    ( result, IDC_FILTER_ENTRY, wxEmptyString, wxDefaultPosition, wxDefaultSize,
+      wxTE_PROCESS_ENTER );
+
+  m_filter_entry->SetToolTip
+    ( _("Type the name of the only classes you want to see in the editor") );
+
+  wxSizer* sizer = new wxBoxSizer( wxVERTICAL );
+  wxSizer* s_sizer = new wxBoxSizer( wxHORIZONTAL );
 
   s_sizer->Add
-    ( new wxStaticText(this, wxID_ANY, _("Filter:")), 0, wxEXPAND | wxALL, 0 );
+    ( new wxStaticText
+      (result, wxID_ANY, _("Filter:")), 0, wxEXPAND | wxALL, 0 );
   s_sizer->Add( m_filter_entry, 1, wxEXPAND | wxALL, 0 );
   s_sizer->Add
     ( wx_new_bitmap_button
-      ( this, IDC_APPLY_TO_CURRENT_LAYER, wxBitmap(filter_current_layer_xpm),
+      ( result, IDC_APPLY_TO_CURRENT_LAYER, wxBitmap(filter_current_layer_xpm),
         _("Apply filter to the selected layer") ),
       0, wxEXPAND | wxALL, 0 );
   s_sizer->Add
     ( wx_new_bitmap_button
-      ( this, IDC_APPLY_TO_ALL_LAYERS, wxBitmap(filter_all_layers_xpm),
+      ( result, IDC_APPLY_TO_ALL_LAYERS, wxBitmap(filter_all_layers_xpm),
         _("Apply filter to all layers") ),
       0, wxEXPAND | wxALL, 0 );
   s_sizer->Add
     ( wx_new_bitmap_button
-      (this, IDC_DELETE_FILTER, wxBitmap(delete_filter_xpm),
+      (result, IDC_DELETE_FILTER, wxBitmap(delete_filter_xpm),
        _("Remove the selected filter from the current layer") ),
       0, wxEXPAND | wxALL, 0 );
   s_sizer->Add
     ( wx_new_bitmap_button
-      (this, IDC_DELETE_FILTER_EVERYWHERE,
+      (result, IDC_DELETE_FILTER_EVERYWHERE,
        wxBitmap(delete_filter_everywhere_xpm),
        _("Remove the selected filter from all layers") ),
       0, wxEXPAND | wxALL, 0 );
@@ -171,8 +209,55 @@ void bf::layer_list_frame::create_sizer_controls()
   sizer->Add( s_sizer, 0, wxEXPAND );
   sizer->Add( m_filter_list, 1, wxEXPAND );
 
-  SetSizer(sizer);
-} // layer_list_frame::create_sizer_controls()
+  result->SetSizer( sizer );
+
+  return result;
+} // layer_list_frame::create_filters_page()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the controls for the items to compile in priority.
+ * \param parent The parent window of the resulting window.
+ */
+wxWindow* bf::layer_list_frame::create_priority_page( wxWindow* parent )
+{
+  wxWindow* result = new wxPanel( parent, wxID_ANY );
+
+  m_priority_list =
+    new wxListBox
+    ( result, IDC_FILTER_LIST, wxDefaultPosition, wxDefaultSize, 0, NULL,
+      wxLB_SINGLE | wxLB_NEEDED_SB );
+
+  wxSizer* sizer = new wxBoxSizer( wxVERTICAL );
+  wxSizer* s_sizer = new wxBoxSizer( wxHORIZONTAL );
+
+  s_sizer->Add
+    ( wx_new_bitmap_button
+      ( result, IDC_NEW_PRIORITY, wxArtProvider::GetBitmap(wxART_NEW),
+        _("Insert item")), 0, wxEXPAND | wxALL, 0 );
+  s_sizer->Add
+    ( wx_new_bitmap_button
+      ( result, IDC_DELETE_PRIORITY, wxArtProvider::GetBitmap(wxART_DELETE),
+        _("Remove the selected item") ),
+      0, wxEXPAND | wxALL, 0 );
+  s_sizer->Add
+    ( wx_new_bitmap_button
+      ( result, IDC_INCREASE_PRIORITY, wxArtProvider::GetBitmap(wxART_GO_UP),
+        _("Increase the priority") ),
+      0, wxEXPAND | wxALL, 0 );
+  s_sizer->Add
+    ( wx_new_bitmap_button
+      ( result, IDC_DECREASE_PRIORITY, wxArtProvider::GetBitmap(wxART_GO_DOWN),
+        _("Decrease the priority") ),
+      0, wxEXPAND | wxALL, 0 );
+
+  sizer->Add( s_sizer, 0, wxEXPAND );
+  sizer->Add( m_priority_list, 1, wxEXPAND );
+
+  result->SetSizer(sizer);
+
+  return result;
+} // layer_list_frame::create_priority_page()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -183,6 +268,7 @@ void bf::layer_list_frame::clear()
   m_layer_list->Clear();
   m_filter_list->Clear();
   m_filter_entry->Clear();
+  m_priority_list->Clear();
 } // layer_list_frame::clear()
 
 /*----------------------------------------------------------------------------*/
@@ -196,26 +282,75 @@ void bf::layer_list_frame::fill()
   if ( m_level_view != NULL )
     if ( !m_level_view->empty() )
       {
-        const gui_level& lvl = m_level_view->get_level();
-
-        for (unsigned int i=0; i!=lvl.layers_count(); ++i)
-          {
-            m_layer_list->Append
-              ( std_to_wx_string( lvl.get_layer(i).get_class_name() ) );
-            m_layer_list->Check( i, lvl.layer_is_visible(i) );
-          }
-
-        const std::size_t i = lvl.get_active_layer_index();
-
-        m_layer_list->SetSelection(i);
-
-        for ( layer::const_filter_iterator it=lvl.get_layer(i).filter_begin();
-              it!=lvl.get_layer(i).filter_end(); ++it )
-          m_filter_list->Append
-            ( std_to_wx_string( it->get_description() ) );
+        fill_layer_list();
+        fill_filter_list();
+        fill_priority_list();
     }
 } // layer_list_frame::fill()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Fill the layer list with the layers of the level.
+ */
+void bf::layer_list_frame::fill_layer_list()
+{
+  CLAW_PRECOND( m_level_view != NULL );
+  CLAW_PRECOND( !m_level_view->empty() );
+
+  const gui_level& lvl = m_level_view->get_level();
+  const std::size_t i = lvl.get_active_layer_index();
+
+  for (unsigned int i=0; i!=lvl.layers_count(); ++i)
+    {
+      m_layer_list->Append
+        ( std_to_wx_string( lvl.get_layer(i).get_class_name() ) );
+      m_layer_list->Check( i, lvl.layer_is_visible(i) );
+    }
+
+  m_layer_list->SetSelection(i);
+} // layer_list_frame::fill_layer_list()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Fill the filter list with the filters of the level.
+ */
+void bf::layer_list_frame::fill_filter_list()
+{
+  CLAW_PRECOND( m_level_view != NULL );
+  CLAW_PRECOND( !m_level_view->empty() );
+
+  const gui_level& lvl = m_level_view->get_level();
+  const std::size_t i = lvl.get_active_layer_index();
+
+  for ( layer::const_filter_iterator it=lvl.get_layer(i).filter_begin();
+        it!=lvl.get_layer(i).filter_end(); ++it )
+    m_filter_list->Append( std_to_wx_string( it->get_description() ) );
+} // layer_list_frame::fill_filter_list()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Fill the layer list of the items to compile in priority.
+ */
+void bf::layer_list_frame::fill_priority_list()
+{
+  CLAW_PRECOND( m_level_view != NULL );
+  CLAW_PRECOND( !m_level_view->empty() );
+
+  const gui_level& lvl = m_level_view->get_level();
+  std::size_t i = lvl.get_active_layer_index();
+  std::vector<item_instance*> items(lvl.get_layer(i).get_prioritized_items());
+
+  for ( i=0; (i!=items.size()) && (i<m_priority_list->GetCount()); ++i )
+    m_priority_list->SetString( i, std_to_wx_string( items[i]->get_id() ) );
+
+  if ( i != m_priority_list->GetCount() )
+    while ( i!=m_priority_list->GetCount() )
+      m_priority_list->Delete(i);
+  else
+    for ( ; i!=items.size(); ++i )
+      m_priority_list->Append( std_to_wx_string( items[i]->get_id() ) );
+} // layer_list_frame::fill_priority_list()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Create a filter corresponding to the text in the filter entry and
@@ -275,9 +410,6 @@ void bf::layer_list_frame::on_new_layer( wxCommandEvent& WXUNUSED(event) )
   if (m_level_view == NULL)
     return;
 
-  if ( m_level_view->empty() )
-    return;
-
   layer_properties_frame dlg(this);
 
   if ( dlg.ShowModal() == wxID_OK )
@@ -285,8 +417,8 @@ void bf::layer_list_frame::on_new_layer( wxCommandEvent& WXUNUSED(event) )
       m_level_view->do_action
         ( new action_add_layer
           ( new layer
-            ( dlg.get_layer_width(), dlg.get_layer_height(),
-              dlg.get_layer_class_name() ),
+            ( dlg.get_layer_class_name(), dlg.get_layer_fits_level(),
+              dlg.get_layer_width(), dlg.get_layer_height() ),
             m_level_view->get_level().layers_count() ) );
 
       fill();
@@ -329,8 +461,8 @@ void bf::layer_list_frame::on_show_properties( wxCommandEvent& WXUNUSED(event) )
       if ( dlg.ShowModal() == wxID_OK )
           m_level_view->do_action
             ( new action_resize_layer
-              ( dlg.get_layer_width(), dlg.get_layer_height(),
-                dlg.get_layer_class_name(),
+              ( dlg.get_layer_fits_level(), dlg.get_layer_width(),
+                dlg.get_layer_height(), dlg.get_layer_class_name(),
                 m_level_view->get_level().get_active_layer_index() ) );
     }
 } // layer_list_frame::on_show_properties()
@@ -539,6 +671,132 @@ void bf::layer_list_frame::on_delete_filter_everywhere
   m_level_view->Refresh();
 } // layer_list_frame::on_delete_filter_everywhere()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add a new item in the priority list.
+ * \param event This event occured.
+ */
+void bf::layer_list_frame::on_new_priority( wxCommandEvent& WXUNUSED(event) )
+{
+  if (m_level_view == NULL)
+    return;
+
+  if ( m_level_view->empty() )
+    return;
+
+  const layer& lay( m_level_view->get_level().get_active_layer() );
+  std::list<item_instance*> items = lay.get_identified_items();
+  std::list<item_instance*>::const_iterator it;
+  wxArrayString id;
+
+  for ( it=items.begin(); it!=items.end(); ++it )
+    if ( !(*it)->get_id().empty() && !lay.is_prioritized(*it) )
+      id.Add( std_to_wx_string((*it)->get_id()) );
+
+  value_editor_dialog<item_reference_edit> dlg
+    (*this, _("Item reference"), id, item_reference_type() );
+
+  if ( dlg.ShowModal() == wxID_OK )
+    {
+      const layer::item_iterator it =
+        lay.find_item_by_id( dlg.get_value().get_value() );
+
+      if ( it != lay.item_end_no_filter() )
+        {
+          m_level_view->do_action
+            ( new action_prioritize
+              ( &(*it), m_level_view->get_level().get_active_layer_index() ) );
+          fill_priority_list();
+        }
+    }
+} // layer_list_frame::on_new_priority()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Reove an item from the priority list.
+ * \param event This event occured.
+ */
+void bf::layer_list_frame::on_delete_priority( wxCommandEvent& WXUNUSED(event) )
+{
+  if (m_level_view == NULL)
+    return;
+
+  if ( m_level_view->empty() )
+    return;
+
+  const int index=m_priority_list->GetSelection();
+
+  if ( index == wxNOT_FOUND )
+    return;
+
+  const layer& lay( m_level_view->get_level().get_active_layer() );
+
+  m_level_view->do_action
+    ( new action_deprioritize
+      ( lay.get_prioritized_items()[index],
+        m_level_view->get_level().get_active_layer_index() ) );
+  fill_priority_list();
+} // layer_list_frame::on_delete_priority()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add a new item in the priority list.
+ * \param event This event occured.
+ */
+void bf::layer_list_frame::on_decrease_priority
+( wxCommandEvent& WXUNUSED(event) )
+{
+  if (m_level_view == NULL)
+    return;
+
+  if ( m_level_view->empty() )
+    return;
+
+  const int index=m_priority_list->GetSelection();
+
+  if ( (index == wxNOT_FOUND)
+       || (index == (int)m_priority_list->GetCount() - 1) )
+    return;
+
+  const layer& lay( m_level_view->get_level().get_active_layer() );
+
+  m_level_view->do_action
+    ( new action_set_priority
+      ( lay.get_prioritized_items()[index],
+        m_level_view->get_level().get_active_layer_index(), index+1 ) );
+  fill_priority_list();
+  m_priority_list->SetSelection(index+1);
+} // layer_list_frame::on_decrease_priority()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Add a new item in the priority list.
+ * \param event This event occured.
+ */
+void bf::layer_list_frame::on_increase_priority
+( wxCommandEvent& WXUNUSED(event) )
+{
+  if (m_level_view == NULL)
+    return;
+
+  if ( m_level_view->empty() )
+    return;
+
+  const int index=m_priority_list->GetSelection();
+
+  if ( (index == wxNOT_FOUND) || (index == 0) )
+    return;
+
+  const layer& lay( m_level_view->get_level().get_active_layer() );
+
+  m_level_view->do_action
+    ( new action_set_priority
+      ( lay.get_prioritized_items()[index],
+        m_level_view->get_level().get_active_layer_index(), index-1 ) );
+  fill_priority_list();
+  m_priority_list->SetSelection(index-1);
+} // layer_list_frame::on_increase_priority()
+
 /*----------------------------------------------------------------------------*/
 BEGIN_EVENT_TABLE(bf::layer_list_frame, wxPanel)
   EVT_BUTTON( wxID_NEW, bf::layer_list_frame::on_new_layer )
@@ -567,4 +825,12 @@ BEGIN_EVENT_TABLE(bf::layer_list_frame, wxPanel)
   EVT_BUTTON( bf::layer_list_frame::IDC_DELETE_FILTER_EVERYWHERE,
               bf::layer_list_frame::on_delete_filter_everywhere )
 
+  EVT_BUTTON( bf::layer_list_frame::IDC_NEW_PRIORITY,
+              bf::layer_list_frame::on_new_priority )
+  EVT_BUTTON( bf::layer_list_frame::IDC_DELETE_PRIORITY,
+              bf::layer_list_frame::on_delete_priority )
+  EVT_BUTTON( bf::layer_list_frame::IDC_DECREASE_PRIORITY,
+              bf::layer_list_frame::on_decrease_priority )
+  EVT_BUTTON( bf::layer_list_frame::IDC_INCREASE_PRIORITY,
+              bf::layer_list_frame::on_increase_priority )
 END_EVENT_TABLE()
