@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -43,20 +43,28 @@ const unsigned int bf::layer_properties_frame::s_min_height(600);
  * \param parent The window owning this window.
  */
 bf::layer_properties_frame::layer_properties_frame( wxWindow* parent )
-  : wxDialog(parent, wxID_ANY, wxString(_("Layer size"))), m_width(s_min_width),
-    m_height(s_min_height)
+  : wxDialog(parent, wxID_ANY, wxString(_("Layer properties")))
 {
   create_controls();
   Fit();
 } // layer_properties_frame::layer_properties_frame()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the layer fits the level.
+ */
+bool bf::layer_properties_frame::get_layer_fits_level() const
+{
+  return m_fit_level->IsChecked();
+} // layer_properties_frame::get_layer_fits_level()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the width of the layer.
  */
 unsigned int bf::layer_properties_frame::get_layer_width() const
 {
-  return m_width;
+  return m_width->GetValue();
 } // layer_properties_frame::get_layer_width()
 
 /*----------------------------------------------------------------------------*/
@@ -65,16 +73,16 @@ unsigned int bf::layer_properties_frame::get_layer_width() const
  */
 unsigned int bf::layer_properties_frame::get_layer_height() const
 {
-  return m_height;
+  return m_height->GetValue();
 } // layer_properties_frame::get_layer_height()
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the name of the class of the layer.
  */
-const std::string& bf::layer_properties_frame::get_layer_class_name() const
+std::string bf::layer_properties_frame::get_layer_class_name() const
 {
-  return m_class_name;
+  return wx_to_std_string( m_class_name->GetStringSelection() );
 } // layer_properties_frame::get_layer_class_name()
 
 /*----------------------------------------------------------------------------*/
@@ -87,41 +95,30 @@ const std::string& bf::layer_properties_frame::get_layer_class_name() const
  */
 void bf::layer_properties_frame::fill_from( const layer& lay )
 {
-  m_width = std::max(lay.get_width(), s_min_width);
-  m_height = std::max(lay.get_height(), s_min_height);
-  m_class_name = lay.get_class_name();
+  m_fit_level->SetValue( lay.fits_level() );
+  m_width->SetValue
+    ( wxString::Format(wxT("%d"), std::max(lay.get_width(), s_min_width)) );
+  m_height->SetValue
+    ( wxString::Format(wxT("%d"), std::max(lay.get_height(), s_min_height)) );
 
-  fill_controls();
-} // layer_properties_frame::set_layer_size()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Fill the controls with the values of the layer.
- */
-void bf::layer_properties_frame::fill_controls()
-{
-  m_width_text->SetValue( wxString::Format(wxT("%d"), m_width) );
-  m_height_text->SetValue( wxString::Format(wxT("%d"), m_height) );
+  m_height->Enable( !lay.fits_level() );
+  m_width->Enable( !lay.fits_level() );
 
   unsigned int i=0;
   bool found = false;
-  const wxString ref( std_to_wx_string(m_class_name) );
+  const wxString ref( std_to_wx_string(lay.get_class_name()) );
 
-  while ( !found && (i!=m_class_name_choice->GetCount()) )
-    if ( m_class_name_choice->GetString(i) == ref )
+  while ( !found && (i!=m_class_name->GetCount()) )
+    if ( m_class_name->GetString(i) == ref )
       found = true;
     else
       ++i;
 
   if ( found )
-    m_class_name_choice->SetSelection(i);
+    m_class_name->SetSelection(i);
   else
-    {
-      m_class_name_choice->SetSelection(0);
-      m_class_name =
-        wx_to_std_string( m_class_name_choice->GetStringSelection() );
-    }
-} // layer_properties_frame::fill_controls()
+    m_class_name->SetSelection(0);
+} // layer_properties_frame::set_layer_size()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -131,7 +128,6 @@ void bf::layer_properties_frame::create_controls()
 {
   create_member_controls();
   create_sizer_controls();
-  fill_controls();
 } // layer_properties_frame::create_controls()
 
 /*----------------------------------------------------------------------------*/
@@ -146,13 +142,15 @@ void bf::layer_properties_frame::create_member_controls()
   layer_names.Add( wxT("decoration_layer") );
   layer_names.Add( wxT("pattern_layer") );
 
-  m_width_text = new wxSpinCtrl( this, wxID_ANY );
-  m_height_text = new wxSpinCtrl( this, wxID_ANY );
-  m_class_name_choice = new wxChoice
+  m_fit_level =
+    new wxCheckBox( this, IDC_FIT_LEVEL_SIZE, _("Match level size.") );
+  m_width = new wxSpinCtrl( this, wxID_ANY );
+  m_height = new wxSpinCtrl( this, wxID_ANY );
+  m_class_name = new wxChoice
     ( this, wxID_ANY, wxDefaultPosition, wxDefaultSize, layer_names );
 
-  m_width_text->SetRange( s_min_width, std::numeric_limits<int>::max() );
-  m_height_text->SetRange( s_min_height, std::numeric_limits<int>::max() );
+  m_width->SetRange( s_min_width, std::numeric_limits<int>::max() );
+  m_height->SetRange( s_min_height, std::numeric_limits<int>::max() );
 } // layer_properties_frame::create_member_controls()
 
 /*----------------------------------------------------------------------------*/
@@ -161,31 +159,29 @@ void bf::layer_properties_frame::create_member_controls()
  */
 void bf::layer_properties_frame::create_sizer_controls()
 {
-  wxBoxSizer* sizer = new wxBoxSizer( wxVERTICAL );
+  wxSizer* sizer = new wxBoxSizer( wxHORIZONTAL );
 
-  // width
-  wxBoxSizer* s_sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add
+    ( new wxStaticText(this, wxID_ANY, _("Width")), 1, wxEXPAND | wxALL, 5 );
+  sizer->Add( m_width, 0  );
+  sizer->Add
+    ( new wxStaticText(this, wxID_ANY, _("Height")), 1, wxEXPAND | wxALL, 5 );
+  sizer->Add( m_height, 0 );
 
-  s_sizer->Add( new wxStaticText(this, wxID_ANY, _("Width")),
-                1, wxEXPAND | wxALL, 5 );
-  s_sizer->Add( m_width_text, 0, wxALL, 5 );
+  wxSizer* s_sizer = new wxStaticBoxSizer( wxVERTICAL, this, _("Size") );
+  s_sizer->Add( m_fit_level, 0 );
+  s_sizer->Add( sizer, 0 );
 
-  sizer->Add( s_sizer, 0, wxEXPAND );
-
-  // height
-  s_sizer = new wxBoxSizer( wxHORIZONTAL );
-
-  s_sizer->Add( new wxStaticText(this, wxID_ANY, _("Height")),
-                1, wxEXPAND | wxALL, 5 );
-  s_sizer->Add( m_height_text, 0, wxALL, 5 );
-  sizer->Add( s_sizer, 0, wxEXPAND );
+  sizer = new wxBoxSizer( wxVERTICAL );
+  sizer->Add(s_sizer, 0 );
 
   s_sizer = new wxBoxSizer( wxHORIZONTAL );
 
-  s_sizer->Add( new wxStaticText(this, wxID_ANY, _("Class name")),
-                1, wxEXPAND | wxALL, 5 );
-  s_sizer->Add( m_class_name_choice, 0, wxEXPAND );
-  sizer->Add( s_sizer, 0, wxEXPAND );
+  s_sizer->Add
+    ( new wxStaticText(this, wxID_ANY, _("Class name")), 1, wxEXPAND );
+  s_sizer->Add( m_class_name, 0, wxEXPAND );
+
+  sizer->Add( s_sizer, 0, wxEXPAND | wxALL, 5 );
 
   sizer->Add( CreateStdDialogButtonSizer(wxOK | wxCANCEL), 0,
               wxALL | wxCENTER, 5 );
@@ -200,14 +196,23 @@ void bf::layer_properties_frame::create_sizer_controls()
  */
 void bf::layer_properties_frame::on_ok( wxCommandEvent& WXUNUSED(event) )
 {
-  m_width = m_width_text->GetValue();
-  m_height = m_height_text->GetValue();
-  m_class_name = wx_to_std_string( m_class_name_choice->GetStringSelection() );
-
   EndModal(wxID_OK);
 } // layer_properties_frame::on_ok()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Answer to a click on the "Fit level" checkbox.
+ * \param event This event occured.
+ */
+void bf::layer_properties_frame::on_fit_level_size( wxCommandEvent& event )
+{
+  m_height->Enable( !event.IsChecked() );
+  m_width->Enable( !event.IsChecked() );
+} // layer_properties_frame::on_ok()
+
 /*----------------------------------------------------------------------------*/
 BEGIN_EVENT_TABLE(bf::layer_properties_frame, wxDialog)
   EVT_BUTTON( wxID_OK, bf::layer_properties_frame::on_ok )
+  EVT_CHECKBOX( bf::layer_properties_frame::IDC_FIT_LEVEL_SIZE,
+                bf::layer_properties_frame::on_fit_level_size )
 END_EVENT_TABLE()
