@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -28,6 +28,7 @@
  */
 #include "bf/level.hpp"
 
+#include "bf/level_check_result.hpp"
 #include "bf/version.hpp"
 #include "level_code_value.hpp"
 
@@ -73,18 +74,7 @@ bf::level::~level()
  * \brief Get a layer given its position in the stack.
  * \param index The position of the layer.
  */
-bf::layer& bf::level::get_layer( unsigned int index )
-{
-  CLAW_PRECOND( index < m_layer.size() );
-  return *m_layer[index];
-} // level::get_layer()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get a layer given its position in the stack.
- * \param index The position of the layer.
- */
-const bf::layer& bf::level::get_layer( unsigned int index ) const
+bf::layer& bf::level::get_layer( unsigned int index ) const
 {
   CLAW_PRECOND( index < m_layer.size() );
   return *m_layer[index];
@@ -108,15 +98,18 @@ bf::layer* bf::level::remove_layer( unsigned int index )
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add a layer.
+ * \param class_name The name of the class of the layer.
+ * \param fit_level Tell if the layer size is the same than the level.
  * \param width The width of the layer.
  * \param height The height of the layer.
- * \param class_name The name of the class of the layer.
  * \remark The layer is added at the end (index layers_count()).
  */
 bf::layer& bf::level::add_layer
-( unsigned int width, unsigned int height, const std::string& class_name )
+( const std::string& class_name, bool fit_level, unsigned int width,
+  unsigned int height )
 {
-  m_layer.push_back( new layer( width, height, class_name ) );
+  add_layer
+    ( new layer( class_name, fit_level, width, height ), m_layer.size() );
   return *m_layer.back();
 } // level::add_layer()
 
@@ -129,6 +122,10 @@ bf::layer& bf::level::add_layer
 void bf::level::add_layer( layer* lay, unsigned int index )
 {
   CLAW_PRECOND( index <= m_layer.size() );
+
+  if ( lay->fits_level() )
+    lay->resize( get_width(), get_height() );
+
   m_layer.insert( m_layer.begin() + index, lay );
 } // level::add_layer()
 
@@ -200,6 +197,10 @@ void bf::level::set_size( unsigned int width, unsigned int height )
 {
   m_width = width;
   m_height = height;
+
+  for ( std::size_t i=0; i!=m_layer.size(); ++i )
+    if ( m_layer[i]->fits_level() )
+      m_layer[i]->resize( m_width, m_height );
 } // level::set_size()
 
 /*----------------------------------------------------------------------------*/
@@ -245,25 +246,19 @@ void bf::level::set_name( const std::string& name )
  * \brief Find an item with a given id.
  * \param id The id of the searched item.
  */
-std::pair<bool, bf::layer::const_item_iterator>
+std::pair<bool, bf::layer::item_iterator>
 bf::level::find_item_by_id( const std::string& id ) const
 {
   bool found = false;
-  layer::const_item_iterator it;
+  layer::item_iterator it;
 
   for (unsigned int i=0; !found && (i!=m_layer.size()); ++i)
     {
-      layer::const_item_iterator eit( ((const layer*)m_layer[i])->item_end() );
-      it=((const layer*)m_layer[i])->item_begin();
-
-      while ( !found && (it!=eit) )
-        if ( it->get_id() == id )
-          found = true;
-        else
-          ++it;
+      it = m_layer[i]->find_item_by_id(id);
+      found = (it != m_layer[i]->item_end_no_filter());
     }
 
-  return std::pair<bool, layer::const_item_iterator>(found, it);
+  return std::pair<bool, layer::item_iterator>(found, it);
 } // level::find_item_by_id()
 
 /*----------------------------------------------------------------------------*/
@@ -347,49 +342,12 @@ bf::level& bf::level::operator=( const level& that )
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Test if the level is valid.
- * \param result The list of items on which we find errors.
+ * \param result The result of the check.
  */
-void bf::level::check( invalid_items_list& result )
+void bf::level::check( level_check_result& result )
 {
   for (unsigned int i=0; i!=m_layer.size(); ++i)
-    {
-      std::map<std::string,item_instance*> map_id;
-
-      // check the unicity of the identifier
-      layer::item_iterator it;
-      for ( it=get_layer(i).item_begin_no_filter();
-            it!=get_layer(i).item_end_no_filter(); ++it )
-        if ( !it->get_id().empty() )
-          {
-            if ( map_id.find(it->get_id()) != map_id.end() )
-              {
-                item_instance* other = map_id[it->get_id()];
-
-                const std::string error_msg
-                  ( "The identifier '" + it->get_id()
-                    +"' has been already given." );
-
-                result.push_back
-                  ( std::pair<item_instance*, unsigned int>(&(*it), i) );
-                result.push_back
-                  ( std::pair<item_instance*, unsigned int>(other, i) );
-
-                it->get_rendering_parameters().set_is_valid(false);
-                other->get_rendering_parameters().set_is_valid(false);
-                it->get_rendering_parameters().set_error(error_msg);
-                other->get_rendering_parameters().set_error(error_msg);
-              }
-            else
-              map_id[it->get_id()] = &(*it);
-          }
-
-      // check each item
-      std::list<item_instance*> items;
-      std::list<item_instance*>::iterator it1;
-      items = get_layer(i).check(map_id);
-      for ( it1 = items.begin(); it1!=items.end(); ++it1 )
-        result.push_back(std::pair<item_instance*, unsigned int>(*it1, i));
-    }
+    result.check( m_layer[i] );
 } // level::check()
 
 /*----------------------------------------------------------------------------*/
