@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -31,6 +31,8 @@
 #include "bf/config_frame.hpp"
 #include "bf/gui_level.hpp"
 #include "bf/image_pool.hpp"
+#include "bf/layer_check_result.hpp"
+#include "bf/level_check_result.hpp"
 #include "bf/level_file_xml_reader.hpp"
 #include "bf/level_file_xml_writer.hpp"
 #include "bf/main_frame.hpp"
@@ -128,7 +130,7 @@ void bf::level_editor::compile( const wxString& path ) const
       else
         {
           delete lvl;
-          CLAW_EXCEPTION("Invalid level.");
+          claw::exception("Invalid level.");
         }
     }
   catch(...)
@@ -190,7 +192,7 @@ void bf::level_editor::compile_level
       lvl.compile(cf);
     }
   else
-    throw CLAW_EXCEPTION("Can't open the level file.");
+    throw claw::exception("Can't open the level file.");
 } // level_editor::compile_level()
 
 /*----------------------------------------------------------------------------*/
@@ -270,23 +272,64 @@ void bf::level_editor::init_config()
  */
 bool bf::level_editor::check_level( level& lvl ) const
 {
-  level::invalid_items_list items;
-  level::invalid_items_list::const_iterator it;
+  level_check_result result;
 
-  lvl.check(items);
+  lvl.check(result);
 
-  for (it=items.begin(); it!=items.end(); ++it)
-    claw::logger << claw::log_error << "layer " << it->second << ", item "
-                 << it->first->get_class().get_class_name() << " bottom="
-                 << it->first->get_rendering_parameters().get_bottom()
-                 << " left="
-                 << it->first->get_rendering_parameters().get_left() << ": "
-                 << it->first->get_rendering_parameters().get_error()
-                 << std::endl;
+  for ( level_check_result::layer_iterator it=result.layer_begin();
+        it!=result.layer_end(); ++it )
+    print_layer_check_result( it->first, it->second );
 
-  return items.empty();
+  return result.is_ok();
 } // level_editor::check_level()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Display the check errors of a layer.
+ * \param lay The checked layer.
+ * \param result The result of the check.
+ */
+void bf::level_editor::print_layer_check_result
+( const layer* lay, const layer_check_result& result ) const
+{
+  wxPuts
+    ( wxString::Format
+      ( _("In layer '%s':\n"),
+        wxGetTranslation(std_to_wx_string(lay->get_class_name())) ) );
+
+  for ( layer_check_result::item_iterator it=result.item_begin();
+      it!=result.item_end(); ++it )
+    print_item_check_result( it->first, it->second );
+} // level_editor::print_layer_check_result()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Display the check errors of an item.
+ * \param item The checked item.
+ * \param result The result of the check.
+ */
+void bf::level_editor::print_item_check_result
+( const item_instance* item, const item_check_result& result ) const
+{
+  wxPuts
+  ( wxString::Format
+      ( _("In item '%s' at (%f, %f):\n"),
+          item->get_class().get_class_name().c_str(),
+          item->get_rendering_parameters().get_left(),
+          item->get_rendering_parameters().get_bottom() ) );
+
+  for ( item_check_result::const_iterator it=result.begin();
+      it!=result.end(); ++it )
+    if ( it->get_cause().empty() )
+      wxPuts( wxGetTranslation(std_to_wx_string( it->get_message() )) );
+    else
+      wxPuts
+      ( wxString::Format
+        ( _("%s: %s\n"),
+          wxGetTranslation(std_to_wx_string(it->get_cause())),
+          wxGetTranslation(std_to_wx_string(it->get_message())) ) );
+} // level_editor::print_item_check_result()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Load the levels passed on the command line.
