@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -33,7 +33,7 @@
 #include "bf/layer.hpp"
 #include "bf/wx_facilities.hpp"
 #include "bf/xml/exception.hpp"
-#include "bf/xml/item_instance_fields_node.hpp"
+#include "bf/xml/item_instance_node.hpp"
 #include "bf/xml/reader_tool.hpp"
 
 #include <claw/logger.hpp>
@@ -68,7 +68,7 @@ bf::gui_level* bf::level_file_xml_reader::load
  * \param node The node to parse.
  */
 bf::gui_level* bf::level_file_xml_reader::load_level
-( const item_class_pool& pool, wxXmlNode* node ) const
+( const item_class_pool& pool, const wxXmlNode* node ) const
 {
   if ( node->GetName() != wxT("level") )
     throw xml::bad_node( wx_to_std_string(node->GetName()) );
@@ -107,12 +107,13 @@ bf::gui_level* bf::level_file_xml_reader::load_level
  * \param node The node to parse.
  */
 void bf::level_file_xml_reader::load_layers
-( const item_class_pool& pool, gui_level& lvl, wxXmlNode* node ) const
+( const item_class_pool& pool, gui_level& lvl, const wxXmlNode* node ) const
 {
-  for ( ; node!=NULL; node=node->GetNext() )
+  for ( node=xml::reader_tool::skip_comments(node); node!=NULL;
+        node=xml::reader_tool::skip_comments(node->GetNext()) )
     if ( node->GetName() == wxT("layer") )
       load_layer(pool, lvl, node);
-    else if ( node->GetName() != wxT("comment") )
+    else
       claw::logger << claw::log_warning << "Ignored node '"
                    << wx_to_std_string(node->GetName()) << "'" << std::endl;
 } // level_file_xml_reader::load_layers()
@@ -125,20 +126,23 @@ void bf::level_file_xml_reader::load_layers
  * \param node The node to parse.
  */
 void bf::level_file_xml_reader::load_layer
-( const item_class_pool& pool, gui_level& lvl, wxXmlNode* node ) const
+( const item_class_pool& pool, gui_level& lvl, const wxXmlNode* node ) const
 {
   CLAW_PRECOND( node->GetName() == wxT("layer") );
 
+  bool fit_level;
   unsigned int width, height;
   wxString val;
 
   width = xml::reader_tool::read_uint(node, wxT("width"));
   height = xml::reader_tool::read_uint(node, wxT("height"));
+  fit_level = ((width == lvl.get_width()) && (height == lvl.get_height()))
+    || xml::reader_tool::read_bool_opt( node, wxT("fit_level"), false );
 
   if ( !node->GetPropVal( wxT("class_name"), &val ) )
     throw xml::missing_property( "class_name" );
 
-  layer& lay = lvl.add_layer( width, height, wx_to_std_string(val) );
+  layer& lay = lvl.add_layer( wx_to_std_string(val), fit_level, width, height );
 
   load_layer_content( pool, lay, node->GetChildren() );
 } // level_file_xml_reader::load_layer()
@@ -151,15 +155,68 @@ void bf::level_file_xml_reader::load_layer
  * \param node The node to parse.
  */
 void bf::level_file_xml_reader::load_layer_content
-( const item_class_pool& pool, layer& lay, wxXmlNode* node ) const
+( const item_class_pool& pool, layer& lay, const wxXmlNode* node ) const
 {
-  for ( ; node!=NULL; node=node->GetNext() )
+  node=xml::reader_tool::skip_comments(node);
+
+  if ( node != NULL )
+    {
+      if ( node->GetName() == wxT("items") )
+        load_items( pool, lay, node->GetChildren() );
+
+      node=xml::reader_tool::skip_comments(node->GetNext());
+
+      if ( node != NULL )
+        if ( node->GetName() == wxT("priority") )
+          load_priorities( lay, node->GetChildren() );
+    }
+} // level_file_xml_reader::load_layer_content()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Load the items of a layer.
+ * \param pool The pool of item classes in which we take the item classes.
+ * \param lay The layer in which we store the instances.
+ * \param node The node to parse.
+ */
+void bf::level_file_xml_reader::load_items
+( const item_class_pool& pool, layer& lay, const wxXmlNode* node ) const
+{
+  for ( node=xml::reader_tool::skip_comments(node); node!=NULL;
+        node=xml::reader_tool::skip_comments(node->GetNext()) )
     if ( node->GetName() == wxT("item") )
       load_item(pool, lay, node);
-    else if ( node->GetName() != wxT("comment") )
+    else
       claw::logger << claw::log_warning << "Ignored node '"
                    << wx_to_std_string(node->GetName()) << "'" << std::endl;
-} // level_file_xml_reader::load_layer_content()
+} // level_file_xml_reader::load_items()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Load the priority of the items.
+ * \param lay The layer in which we take the items.
+ * \param node The node to parse.
+ */
+void bf::level_file_xml_reader::load_priorities
+( layer& lay, const wxXmlNode* node ) const
+{
+  for ( node=xml::reader_tool::skip_comments(node); node!=NULL;
+        node=xml::reader_tool::skip_comments(node->GetNext()) )
+    if ( node->GetName() == wxT("ref") )
+      {
+        const std::string id = xml::reader_tool::read_string(node, wxT("id"));
+        layer::item_iterator item = lay.find_item_by_id( id );
+
+        if ( item != lay.item_end() )
+          lay.prioritize( &(*item) );
+        else
+          claw::logger << claw::log_warning << "Can't prioritize unknown item '"
+                       << id << "'" << std::endl;
+      }
+    else
+      claw::logger << claw::log_warning << "Ignored node '"
+                   << wx_to_std_string(node->GetName()) << "'" << std::endl;
+} // level_file_xml_reader::load_priorities()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -169,52 +226,13 @@ void bf::level_file_xml_reader::load_layer_content
  * \param node The node to parse.
  */
 void bf::level_file_xml_reader::load_item
-( const item_class_pool& pool, layer& lay, wxXmlNode* node ) const
+( const item_class_pool& pool, layer& lay, const wxXmlNode* node ) const
 {
   CLAW_PRECOND( node->GetName() == wxT("item") );
 
-  wxString val;
+  xml::item_instance_node item_node;
+  item_instance* item = item_node.read( pool, node );
 
-  if ( !node->GetPropVal( wxT("class_name"), &val ) )
-    throw xml::missing_property( "class_name" );
-
-  std::string class_name( wx_to_std_string(val) );
-  item_instance* item(NULL);
-
-  try
-    {
-      item = new item_instance( pool.get_item_class_ptr(class_name) );
-      item->set_fixed
-        ( xml::reader_tool::read_bool_opt(node, wxT("fixed"), false) );
-      item->set_id
-        ( wx_to_std_string(node->GetPropVal( wxT("id"), wxEmptyString )) );
-
-      load_fields( *item, node->GetChildren() );
-
-      lay.add_item(item);
-    }
-  catch( std::exception& e )
-    {
-      claw::logger << claw::log_error << e.what() << std::endl;
-      delete item;
-    }
+  if ( item != NULL )
+    lay.add_item(item);
 } // level_file_xml_reader::load_item()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Load the fields of an item.
- * \param item The item in which we set the fields.
- * \param node The node to parse.
- */
-void bf::level_file_xml_reader::load_fields
-( item_instance& item, const wxXmlNode* node ) const
-{
-  xml::item_instance_fields_node reader;
-  node = xml::reader_tool::skip_comments(node);
-
-  if ( node->GetName() == wxT("fields") )
-    reader.read(item, node);
-  else
-    claw::logger << claw::log_warning << "Ignored node '"
-                 << wx_to_std_string(node->GetName()) << "'" << std::endl;
-} // level_file_xml_reader::load_fields()
