@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -31,7 +31,7 @@
 #include "bf/item_class_pool.hpp"
 #include "bf/item_comparator.hpp"
 #include "bf/level.hpp"
-#include "bf/xml/item_instance_fields_node.hpp"
+#include "bf/xml/item_instance_node.hpp"
 
 #include <claw/logger.hpp>
 
@@ -65,9 +65,25 @@ void bf::level_file_xml_writer::save_layer
 {
   os << "  <layer class_name='" << the_layer.get_class_name() << "' width='"
      << the_layer.get_width() << "' height='" << the_layer.get_height()
-     << "'>\n\n";
+     << "' fit_level='" << the_layer.fits_level() << "'>\n\n";
+
+  save_items(os, the_layer);
+  save_priority(os, the_layer);
+
+  os << "  </layer><!-- " << the_layer.get_class_name() << " -->\n\n";
+} // level_file_xml_writer::save_layer()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Save the items of a layer.
+ * \param os The stream in which we write.
+ * \param the_layer The layer to save.
+ */
+void bf::level_file_xml_writer::save_items
+( std::ostream& os, const layer& the_layer ) const
+{
+  os << "<items>\n";
 
-  layer::const_item_iterator it;
   std::list<item_instance> items
     ( the_layer.item_begin_no_filter(), the_layer.item_end_no_filter() );
 
@@ -93,8 +109,34 @@ void bf::level_file_xml_writer::save_layer
         save_item( os, items.front() );
     }
 
-  os << "  </layer><!-- " << the_layer.get_class_name() << " -->\n\n";
-} // level_file_xml_writer::save_layer()
+  os << "</items>\n\n";
+} // level_file_xml_writer::save_items()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Save the priority of the items.
+ * \param os The stream in which we write.
+ * \param the_layer The layer to save.
+ */
+void bf::level_file_xml_writer::save_priority
+( std::ostream& os, const layer& the_layer ) const
+{
+  os << "<priority>\n";
+
+  std::vector<item_instance*> items = the_layer.get_prioritized_items();
+
+  for ( std::size_t i=0; i!=items.size(); ++i )
+    {
+      if ( !items[i]->get_id().empty() )
+        os << "<ref id=\"" << items[i]->get_id() << "\"/>\n";
+      else
+        claw::logger << claw::log_warning << "Item '"
+                     << items[i]->get_class().get_class_name()
+                     << "' has no id. His priority is not saved." << std::endl;
+    }
+
+  os << "</priority>\n\n";
+} // level_file_xml_writer::save_priority()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -105,21 +147,6 @@ void bf::level_file_xml_writer::save_layer
 void bf::level_file_xml_writer::save_item
 ( std::ostream& os, const item_instance& item ) const
 {
-  os << "    <item class_name='" << item.get_class().get_class_name()
-     << "' fixed='";
-
-  if ( item.get_fixed() )
-    os << "true'";
-  else
-    os << "false'";
-
-  if ( !item.get_id().empty() )
-    os << " id='" << item.get_id() << "'";
-
-  os << ">\n";
-
-  xml::item_instance_fields_node field_node;
-  field_node.write(item, os);
-
-  os << "    </item><!-- " << item.get_class().get_class_name() << " -->\n\n";
+  xml::item_instance_node item_node;
+  item_node.write(item, os);
 } // level_file_xml_writer::save_item()
