@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -77,42 +77,57 @@ void bf::level_thumbnail_ctrl::set_view( ingame_view_frame* view )
  */
 void bf::level_thumbnail_ctrl::update()
 {
-  std::list<sprite_with_position> sprites;
-  m_level->get_ingame_view()->get_structure_sprites( sprites );
-
-  double r_x =
-    (double)GetSize().x / m_level->get_ingame_view()->get_level().get_width();
-  double r_y =
-    (double)GetSize().y / m_level->get_ingame_view()->get_level().get_height();
-
-  m_thumbnail = wxBitmap( GetSize().x, GetSize().y );
-  wxMemoryDC dc(m_thumbnail);
-
-  dc.SetBackground(wxColour(127, 127, 127));
-  dc.Clear();
-
-  std::list<sprite_with_position>::const_iterator it;
-
-  for (it=sprites.begin(); it!=sprites.end(); ++it)
+  if (m_level != NULL)
     {
-      wxString name( std_to_wx_string(it->spr.get_image_name()) );
+      std::list<sprite_with_position> sprites;
+      m_level->get_ingame_view()->get_structure_sprites( sprites );
 
-      std::pair<wxBitmap, wxPoint> spr =
-        m_image_cache->get_image
-        ( it->spr, (unsigned int)(it->spr.width() * r_x),
-          (unsigned int)(it->spr.height() * r_y) );
+      double r_x =
+        (double)GetSize().x /
+        m_level->get_ingame_view()->get_level().get_width();
+      double r_y =
+        (double)GetSize().y /
+        m_level->get_ingame_view()->get_level().get_height();
 
-      if ( spr.first.IsOk() )
-        dc.DrawBitmap
-          ( spr.first,
-            (unsigned int)((it->pos.x + spr.second.x) * r_x),
-            (unsigned int)((it->pos.y + spr.second.y) * r_y), true );
+      m_thumbnail = wxBitmap( GetSize().x, GetSize().y );
+      wxMemoryDC dc(m_thumbnail);
+
+      dc.SetBackground(wxColour(127, 127, 127));
+      dc.Clear();
+
+      std::list<sprite_with_position>::const_iterator it;
+
+      for (it=sprites.begin(); it!=sprites.end(); ++it)
+        {
+          wxString name( std_to_wx_string(it->spr.get_image_name()) );
+
+          std::pair<wxBitmap, wxPoint> spr =
+            m_image_cache->get_image
+            ( it->spr, (unsigned int)(it->spr.width() * r_x),
+              (unsigned int)(it->spr.height() * r_y) );
+
+          if ( spr.first.IsOk() )
+            dc.DrawBitmap
+              ( spr.first,
+                (unsigned int)((it->pos.x + spr.second.x) * r_x),
+                (unsigned int)((it->pos.y + spr.second.y) * r_y), true );
+        }
+
+      compute_view_box();
     }
 
-  compute_view_box();
   Refresh();
 } // level_thumbnail_ctrl::on_size()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Return the level.
+ */
+const bf::ingame_view_frame* bf::level_thumbnail_ctrl::get_level() const
+{
+  return m_level;
+} // level_thumbnail_ctrl::get_level()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Compute the box of the view, scaled in this control.
