@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -68,7 +68,7 @@ bf::main_frame::main_frame()
   SetSizer( new wxBoxSizer(wxVERTICAL) );
 
   wxNotebook* tabs =
-    new wxNotebook(this, -1, wxDefaultPosition, wxDefaultSize, wxNB_TOP );
+    new wxNotebook(this, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxNB_TOP );
 
   layer_list_frame* lay = new layer_list_frame( tabs );
   lay->Show( wxGetApp().get_config().layer_list_visible );
