@@ -1,7 +1,7 @@
 /*
   Bear Engine - Level editor
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -290,6 +290,78 @@ void bf::properties_frame::create_controls()
   SetSizer(sizer);
 } // properties_frame::create_controls()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Clear the identifier of the selected items.
+ */
+void bf::properties_frame::clear_items_id()
+{
+  ingame_view* view =
+    m_windows_layout->get_current_level_view()->get_ingame_view();
+  bool ok=true;
+
+  item_field_edit::item_iterator it;
+  for ( it=m_prop->begin(); ok && (it!=m_prop->end()); ++it )
+    ok = !view->get_level().get_active_layer().is_prioritized(&(*it));
+
+  if ( !ok )
+    {
+      wxMessageDialog dlg
+        ( this, _("Cannot remove the identifier of a prioritized item."),
+          _("Action not allowed"), wxID_OK );
+
+      dlg.ShowModal();
+    }
+  else
+    {
+      action_group* action =
+        new action_group( action_set_item_id::get_action_description() );
+
+      for ( it=m_prop->begin(); it!=m_prop->end(); ++it )
+        action->add_action( new action_set_item_id(&(*it), std::string()) );
+
+      view->do_action(action);
+    }
+} // properties_frame::clear_items_id()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Clear the identifier of the selected items.
+ */
+void bf::properties_frame::set_item_id()
+{
+  CLAW_PRECOND( !m_id_text->IsEmpty() );
+  const std::string id = wx_to_std_string( m_id_text->GetValue() );
+  ingame_view* view =
+    m_windows_layout->get_current_level_view()->get_ingame_view();
+
+  if ( !m_prop->has_single_item() )
+    {
+      wxMessageDialog dlg
+        ( this, _("Can't set the same identifier to several items."),
+          _("Action is not allowed"), wxID_OK );
+
+      dlg.ShowModal();
+    }
+  else if ( id != m_prop->get_single_item().get_id() )
+    {
+      std::pair<bool, layer::item_iterator> it =
+        view->get_level().find_item_by_id(id);
+
+      if (it.first)
+        {
+          wxMessageDialog dlg
+            ( this, _("This identifier is already in use."),
+              _("Bad identifier"), wxID_OK );
+
+          dlg.ShowModal();
+        }
+      else
+        view->do_action
+          ( new action_set_item_id(&m_prop->get_single_item(), id) );
+    }
+} // properties_frame::set_item_id()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set the value of a field.
@@ -380,46 +452,10 @@ void bf::properties_frame::on_change_fixed( wxCommandEvent& WXUNUSED(event) )
  */
 void bf::properties_frame::on_validate_id( wxCommandEvent& WXUNUSED(event) )
 {
-  const std::string id = wx_to_std_string( m_id_text->GetValue() );
-  ingame_view* view =
-    m_windows_layout->get_current_level_view()->get_ingame_view();
-
-  if ( id.empty() )
-    {
-      action_group* action =
-        new action_group( action_set_item_id::get_action_description() );
-
-      item_field_edit::item_iterator it;
-      for ( it=m_prop->begin(); it!=m_prop->end(); ++it )
-        action->add_action( new action_set_item_id(&(*it), id) );
-
-      view->do_action(action);
-    }
-  else if ( !m_prop->has_single_item() )
-    {
-      wxMessageDialog dlg
-        ( this, _("Can't set the same identifier to several items."),
-          _("Action is not allowed"), wxID_OK );
-
-      dlg.ShowModal();
-    }
-  else if ( id != m_prop->get_single_item().get_id() )
-    {
-      std::pair<bool, layer::const_item_iterator> it =
-        view->get_level().find_item_by_id(id);
-
-      if (it.first)
-        {
-          wxMessageDialog dlg
-            ( this, _("This identifier is already in use."),
-              _("Bad identifier"), wxID_OK );
-
-          dlg.ShowModal();
-        }
-      else
-        view->do_action
-          ( new action_set_item_id(&m_prop->get_single_item(), id) );
-    }
+  if ( m_id_text->IsEmpty() )
+    clear_items_id();
+  else
+    set_item_id();
 } // properties_frame::on_validate_id()
 
 /*----------------------------------------------------------------------------*/
@@ -511,8 +547,8 @@ void bf::properties_frame::on_request_item_id( request_item_id_event& e )
 {
   const ingame_view* view =
     m_windows_layout->get_current_level_view()->get_ingame_view();
-  layer::const_item_iterator it;
-  const layer::const_item_iterator eit(view->get_active_layer().item_end());
+  layer::item_iterator it;
+  const layer::item_iterator eit(view->get_active_layer().item_end());
   std::list<std::string> valid_classes;
   e.get_type_field().get_set(valid_classes);
 
