@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -23,50 +23,72 @@
 */
 /**
  * \file bf/error_check_level_dialog.hpp
- * \brief A dialog to check error in level.
+ * \brief \brief This window displays the errors of a level.
  * \author Julien Jorge
  */
 #ifndef __BF_ERROR_CHECK_LEVEL_DIALOG_HPP__
 #define __BF_ERROR_CHECK_LEVEL_DIALOG_HPP__
 
-#include "bf/spin_ctrl.hpp"
-#include "bf/item_instance.hpp"
-
-#include <wx/dialog.h>
-#include <wx/wx.h>
+#include <wx/frame.h>
 #include <wx/listctrl.h>
-#include <list>
+#include <wx/textctrl.h>
+
+#include <vector>
 
 namespace bf
 {
+  class item_instance;
+  class item_check_result;
+  class layer;
+  class layer_check_result;
+  class level_check_result;
+
   /**
-   * \brief A dialog when the level is not valid.
+   * \brief This window displays the errors of a level.
    * \author Sebastien Angibaud
    */
   class error_check_level_dialog:
-    public wxDialog
+    public wxFrame
   {
-  public:
-    error_check_level_dialog
-    ( wxWindow& parent,
-      const std::list< std::pair<item_instance*, unsigned int> >& items );
+  private:
+      /** \brief The identifiers of the controls. */
+      enum control_id
+        {
+          ID_ERROR_LIST
+        }; // enum control_id
 
-    unsigned int get_index_selected() const;
+  public:
+    error_check_level_dialog( wxWindow* parent, wxWindowID id = wxID_ANY );
+
+    void set_errors( const level_check_result& errors );
 
   private:
+    void fill_layer_check_result
+    ( layer* lay, const layer_check_result& result );
+    void fill_item_check_result
+    ( item_instance* item, const item_check_result& result,
+        const wxString& lay_name );
+
     void create_controls();
     void create_sizers();
-    void adjust_last_column_size();
+    void adjust_last_column_size() const;
+
+    void on_close(wxCloseEvent& event);
     void on_size(wxSizeEvent& event);
+    void on_error_selected(wxListEvent& event);
 
   private:
-    /** \brief The list of bad items with them layer. */
-    const std::list< std::pair<item_instance*, unsigned int> >& m_items;
-
     /** \brief The control that displays the list of bad items. */
     wxListView* m_items_list;
 
+    /** \brief The area where the complete message is displayed. */
+    wxTextCtrl* m_details;
+
+    /** \brief The items associated with each line of the list. */
+    std::vector<item_instance*> m_items;
+
     DECLARE_EVENT_TABLE()
+
   }; // class error_check_level_dialog
 } // namespace bf
 
