@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -92,13 +92,13 @@ namespace bf
     void set_layer_visibility( unsigned int layer_index, bool b );
 
     void set_active_layer( unsigned int layer_index );
-    layer& get_active_layer();
-    const layer& get_active_layer() const;
+    layer& get_active_layer() const;
 
     unsigned int get_active_layer_index() const;
 
     layer& add_layer
-    ( unsigned int width, unsigned int height, const std::string& class_name );
+    ( const std::string& class_name, bool fit_level = true,
+      unsigned int width = 1, unsigned int height = 1 );
     void add_layer( layer* lay, unsigned int layer_index );
     layer* remove_layer( unsigned int layer_index );
 
