@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -83,8 +83,11 @@ namespace bf
     /** \brief Tell if the action has been done or not. */
     bool m_done;
 
+    /** \brief All actions happening before the removal of the item. */
+    action_group* m_pre_actions;
+
     /** \brief All actions happening consequently to the removal of the item. */
-    action_group* m_related_actions;
+    action_group* m_post_actions;
 
   }; // class action_remove_item
 } // namespace bf
