@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -45,14 +45,15 @@ namespace bf
   public:
     /**
      * \brief Constructor.
+     * \param fit_level Tell if the layer has the same size than the level.
      * \param width The new width of the layer.
      * \param height The new height of the layer.
      * \param class_name The name of the class of the layer.
      * \param lay The layer to resize.
      */
     action_resize_layer
-    ( unsigned int width, unsigned int height, const std::string& class_name,
-      unsigned int lay );
+    ( bool fit_level, unsigned int width, unsigned int height,
+      const std::string& class_name, unsigned int lay );
 
     /**
      * \remark Calling execute() two times will restore the initial size.
@@ -64,6 +65,9 @@ namespace bf
     wxString get_description() const;
 
   private:
+    /** \brief Tell if the layer has the same size than the level. */
+    bool m_fit_level;
+
     /** \brief The new width of the layer. */
     unsigned int m_width;
 
