@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -28,6 +28,7 @@
  */
 #include "bf/history/action_remove_item.hpp"
 
+#include "bf/history/action_deprioritize.hpp"
 #include "bf/history/action_set_item_field.hpp"
 #include "bf/item_class.hpp"
 #include "bf/gui_level.hpp"
@@ -44,7 +45,8 @@
  */
 bf::action_remove_item::action_remove_item
 ( item_instance* item, unsigned int lay )
-  : m_item(item), m_layer(lay), m_done(false), m_related_actions(NULL)
+  : m_item(item), m_layer(lay), m_done(false), m_pre_actions(NULL),
+    m_post_actions(NULL)
 {
 
 } // action_remove_item::action_remove_item()
@@ -57,7 +59,8 @@ bf::action_remove_item::~action_remove_item()
   if ( m_done )
     delete m_item;
 
-  delete m_related_actions;
+  delete m_pre_actions;
+  delete m_post_actions;
 } // action_remove_item::~action_remove_item()
 
 /*----------------------------------------------------------------------------*/
@@ -71,9 +74,10 @@ void bf::action_remove_item::execute( gui_level& lvl )
   m_selected = lvl.item_is_selected( m_layer, m_item );
   m_main_selection = lvl.item_is_main_selection( m_layer, m_item );
 
+  m_pre_actions->execute(lvl);
   lvl.remove_item( m_layer, m_item );
+  m_post_actions->execute(lvl);
 
-  m_related_actions->execute(lvl);
   m_done = true;
 } // action_remove_item::execute()
 
@@ -83,8 +87,9 @@ void bf::action_remove_item::undo( gui_level& lvl )
   CLAW_PRECOND( m_done );
   CLAW_PRECOND( lvl.layers_count() > m_layer );
 
-  m_related_actions->undo(lvl);
+  m_post_actions->undo(lvl);
   lvl.get_layer( m_layer ).add_item( m_item );
+  m_pre_actions->undo(lvl);
 
   if ( m_selected )
     lvl.add_to_selection( m_layer, m_item, m_main_selection );
@@ -101,36 +106,45 @@ bool bf::action_remove_item::is_identity( const gui_level& lvl ) const
 /*----------------------------------------------------------------------------*/
 wxString bf::action_remove_item::get_description() const
 {
-  return _("Remove %s")
-    + std_to_wx_string(m_item->get_class().get_class_name());
+  return wxString::Format
+    ( _("Remove %s"),
+      std_to_wx_string(m_item->get_class().get_class_name()).c_str() );
 } // action_remove_item::get_description()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Fill m_related_actions with actions consecutive to the removal of
+ * \brief Fill m_post_actions with actions consecutive to the removal of
  *        m_item.
  * \param lvl The level in which the action is done.
  */
 void bf::action_remove_item::create_related_actions( gui_level& lvl )
 {
-  if ( m_related_actions == NULL )
+  if ( (m_pre_actions != NULL) && (m_post_actions != NULL) )
+    return;
+
+  CLAW_PRECOND( m_pre_actions == NULL );
+  CLAW_PRECOND( m_post_actions == NULL );
+
+  m_pre_actions = new action_group;
+  m_post_actions = new action_group;
+
+  if ( !m_item->get_id().empty() )
     {
-      m_related_actions = new action_group;
+      layer::item_iterator it;
+      const layer::item_iterator eit(lvl.get_layer(m_layer).item_end());
 
-      if ( !m_item->get_id().empty() )
-        {
-          layer::item_iterator it;
-          const layer::item_iterator eit(lvl.get_layer(m_layer).item_end());
-
-          for ( it=lvl.get_layer(m_layer).item_begin(); it!=eit; ++it )
-            create_related_actions_with(&*it);
-        }
+      for ( it=lvl.get_layer(m_layer).item_begin(); it!=eit; ++it )
+        create_related_actions_with(&*it);
     }
+
+  if ( lvl.get_layer(m_layer).is_prioritized(m_item) )
+    m_pre_actions->add_action
+      ( new action_deprioritize(m_item, m_layer) );
 } // action_remove_item::create_related_actions()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Fill m_related_actions with actions consecutive to the removal of
+ * \brief Fill m_post_actions with actions consecutive to the removal of
  *        m_item.
  * \param item The item in which the actions are done (not m_item).
  */
@@ -182,7 +196,7 @@ void bf::action_remove_item::create_action_set_item_field_for
       item->get_value(f, val);
 
       if ( val.get_value() == m_item->get_id() )
-        m_related_actions->add_action
+        m_post_actions->add_action
           ( new action_set_item_field<item_reference_type>
             (item, f.get_name()) );
     }
@@ -221,11 +235,11 @@ void bf::action_remove_item::create_action_set_item_field_list_for
               ++it;
 
           if ( val.empty() )
-            m_related_actions->add_action
+            m_post_actions->add_action
               ( new action_set_item_field< std::list<item_reference_type> >
                 (item, f.get_name()) );
           else
-            m_related_actions->add_action
+            m_post_actions->add_action
               ( new action_set_item_field< std::list<item_reference_type> >
                 (item, f.get_name(), val) );
         }
