@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -35,9 +35,10 @@
 
 /*----------------------------------------------------------------------------*/
 bf::action_resize_layer::action_resize_layer
-( unsigned int width, unsigned int height, const std::string& class_name,
-  unsigned int lay )
-  : m_width(width), m_height(height), m_class(class_name), m_layer(lay)
+( bool fit_level, unsigned int width, unsigned int height,
+  const std::string& class_name, unsigned int lay )
+  : m_fit_level(fit_level), m_width(width), m_height(height),
+    m_class(class_name), m_layer(lay)
 {
 
 } // action_resize_layer::action_resize_layer()
@@ -46,14 +47,20 @@ bf::action_resize_layer::action_resize_layer
 void bf::action_resize_layer::execute( gui_level& lvl )
 {
   CLAW_PRECOND( lvl.layers_count() > m_layer );
+  CLAW_PRECOND( !m_fit_level
+                || ( (m_width == lvl.get_width())
+                     && (m_height == lvl.get_height()) ) );
 
+  const unsigned int f( lvl.get_layer( m_layer ).fits_level() );
   const unsigned int w( lvl.get_layer( m_layer ).get_width() );
   const unsigned int h( lvl.get_layer( m_layer ).get_height() );
   const std::string c( lvl.get_layer( m_layer ).get_class_name() );
 
+  lvl.get_layer( m_layer ).set_fit_level( m_fit_level );
   lvl.get_layer( m_layer ).resize( m_width, m_height );
   lvl.get_layer( m_layer ).set_class_name( m_class );
 
+  m_fit_level = f;
   m_width = w;
   m_height = h;
   m_class = c;
@@ -71,7 +78,8 @@ void bf::action_resize_layer::undo( gui_level& lvl )
 /*----------------------------------------------------------------------------*/
 bool bf::action_resize_layer::is_identity( const gui_level& lvl ) const
 {
-  return (m_width == lvl.get_layer( m_layer ).get_width())
+  return (m_fit_level == lvl.get_layer( m_layer ).fits_level())
+    && (m_width == lvl.get_layer( m_layer ).get_width())
     && (m_height == lvl.get_layer( m_layer ).get_height())
     && (m_class == lvl.get_layer( m_layer ).get_class_name());
 } // action_resize_layer::is_identity( const gui_level& gui )
