@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -31,6 +31,7 @@
 
 #include "bf/grid.hpp"
 #include "bf/level_clipboard.hpp"
+#include "bf/level_check_result.hpp"
 #include "bf/sprite_image_cache.hpp"
 #include "bf/sprite_with_position.hpp"
 #include "bf/history/level_history.hpp"
@@ -130,7 +131,7 @@ namespace bf
     unsigned int get_active_index() const;
     void set_active_index( unsigned int index );
 
-    const layer& get_active_layer() const;
+    layer& get_active_layer() const;
     const gui_level& get_level() const;
     gui_level& get_level();
 
@@ -163,6 +164,8 @@ namespace bf
     bool add_item( const std::string& class_name, wxCoord x, wxCoord y );
     bool add_item( const std::string& class_name );
 
+    bool check_level();
+    const level_check_result& get_check_result() const;
     void save( std::ostream& os );
 
     void undo();
@@ -175,8 +178,7 @@ namespace bf
     bool has_selection() const;
     void clear_selection();
     void select_all();
-    void select_item_and_layer
-    ( item_instance* item, const unsigned int index );
+    void select_item_and_layer( item_instance* item );
 
     const level_clipboard& get_clipboard() const;
 
@@ -192,12 +194,12 @@ namespace bf
     void render_layer( wxDC& dc, unsigned int i ) const;
 
     void render_items
-    ( wxDC& dc, const std::multimap<int, const item_instance*>& z_order,
+    ( wxDC& dc, const std::multimap<int, item_instance*>& z_order,
       unsigned int i ) const;
 
     void render_relationship
     ( wxDC& dc, const item_instance& item,
-      const std::multimap<int, const item_instance*>& z_order ) const;
+      const std::multimap<int, item_instance*>& z_order ) const;
     void render_relationship
     ( wxDC& dc, const item_instance& ref, const item_instance& rel ) const;
 
@@ -279,6 +281,8 @@ namespace bf
 
     void write_mouse_position(const wxPoint& point);
 
+    void set_tooltip( item_instance* item );
+
     bool set_drag_mode_size( const wxPoint& pos );
     wxRect get_drag_mode_size_box() const;
 
@@ -349,6 +353,9 @@ namespace bf
     /** \brief The current level of zoom. */
     unsigned int m_zoom;
 
+    /** \brief The result of the last check on the level. */
+    level_check_result m_check_result;
+
     /** \brief The size of the shape diplayed for sizeless items. */
     static const wxCoord s_point_size;
 
