@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -32,9 +32,13 @@
 
 #include <wx/wx.h>
 #include <wx/spinctrl.h>
+#include <string>
+
+#include "bf/item_event.hpp"
 
 namespace bf
 {
+  class error_check_level_dialog;
   class gui_level;
   class ingame_view;
   class level_overview_frame;
@@ -84,7 +88,9 @@ namespace bf
         ID_BRIGHT_BACKGROUND,
         ID_ZOOM,
         ID_PREVIOUS_LAYER,
-        ID_NEXT_LAYER
+        ID_NEXT_LAYER,
+        ID_NEW_LAYER_FROM_IMAGE,
+        ID_ERROR_FRAME
       }; // enum control_id
 
   public:
@@ -112,7 +118,8 @@ namespace bf
     const wxScrollBar& get_h_scrollbar();
     const wxScrollBar& get_v_scrollbar();
 
-    void update_zoom();
+    void update_zoom() const;
+    void update_toolbar() const;
 
   private:
     void make_title();
@@ -128,7 +135,6 @@ namespace bf
     wxMenu* create_view_menu() const;
 
     void create_toolbar();
-    void update_toolbar();
 
     void create_accelerators();
 
@@ -168,6 +174,7 @@ namespace bf
     void on_select_all(wxCommandEvent& event);
     void on_select_none(wxCommandEvent& event);
     void on_check_level(wxCommandEvent& event);
+    void on_save(wxCommandEvent& event);
     void on_compile_level(wxCommandEvent& event);
     void on_menu_close(wxCommandEvent& event);
     void on_show_grid_properties(wxCommandEvent& event);
@@ -209,6 +216,10 @@ namespace bf
     void on_previous_layer(wxCommandEvent& event);
     void on_next_layer(wxCommandEvent& event);
 
+    void on_new_layer_from_image(wxCommandEvent& event);
+
+    void on_error_selected( item_event& event );
+
   private:
     /** \brief The windows of the program. */
     windows_layout& m_layout;
@@ -241,6 +252,9 @@ namespace bf
     /** \brief Overview of the level. */
     level_overview_frame* m_overview;
 
+    /** \brief The list of the errors in the level. */
+    error_check_level_dialog* m_errors;
+
     /** \brief The control displaying the zoom. */
     wxSpinCtrl* m_zoom_spin;
 
