@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -42,6 +42,8 @@
 
 namespace bf
 {
+  class layer_check_result;
+
   /**
    * \brief A layer from our level.
    * \author Julien Jorge
@@ -50,12 +52,7 @@ namespace bf
   {
   public:
     typedef std::set<item_instance*> item_set_type;
-
-    typedef claw::wrapped_iterator
-    < const item_instance,
-      item_set_type::const_iterator,
-      claw::const_dereference<item_instance>
-    >::iterator_type const_item_iterator;
+    typedef std::list<item_instance*> item_list_type;
 
     typedef claw::wrapped_iterator
     < item_instance,
@@ -67,17 +64,30 @@ namespace bf
     typedef filter_list::const_iterator const_filter_iterator;
 
   public:
-    layer
-    ( unsigned int width, unsigned int height, const std::string& layer_type );
+    explicit layer( const std::string& layer_type, bool fit_level = true,
+                    unsigned int width = 1, unsigned int height = 1 );
     layer( const layer& that );
     ~layer();
 
+    void set_fit_level( bool f );
+    bool fits_level() const;
+
     void resize( unsigned int width, unsigned int height );
     void set_class_name( const std::string& class_name );
 
     void add_item( item_instance* item );
     void remove_item( item_instance* item );
 
+    item_iterator find_item_by_id( const std::string& id ) const;
+    std::list<item_instance*> get_identified_items() const;
+
+    void prioritize( item_instance* item );
+    void prioritize( item_instance* item, std::size_t p );
+    void deprioritize( item_instance* item );
+    bool is_prioritized( item_instance* item ) const;
+    std::size_t get_priority( item_instance* item ) const;
+    std::vector<item_instance*> get_prioritized_items() const;
+
     const std::string& get_class_name() const;
     unsigned int get_width() const;
     unsigned int get_height() const;
@@ -86,24 +96,18 @@ namespace bf
     bool empty() const;
     bool contains( const item_instance& item ) const;
 
-    std::list<item_instance*>
-    check( const std::map<std::string,item_instance*>& map_id);
+    void check( layer_check_result& result ) const;
+
     void compile( compiled_file& f ) const;
 
     const_filter_iterator filter_begin() const;
     const_filter_iterator filter_end() const;
 
-    item_iterator item_begin();
-    item_iterator item_end();
+    item_iterator item_begin() const;
+    item_iterator item_end() const;
 
-    const_item_iterator item_begin() const;
-    const_item_iterator item_end() const;
-
-    item_iterator item_begin_no_filter();
-    item_iterator item_end_no_filter();
-
-    const_item_iterator item_begin_no_filter() const;
-    const_item_iterator item_end_no_filter() const;
+    item_iterator item_begin_no_filter() const;
+    item_iterator item_end_no_filter() const;
 
     layer& operator=( const layer& that );
 
@@ -122,7 +126,15 @@ namespace bf
 
     bool evaluate_filters_on_item( const item_instance& item ) const;
 
+    void check_priorities( layer_check_result& result ) const;
+    void check_unique_identifiers
+    ( layer_check_result& result, std::set<std::string>& identifiers ) const;
+
   private:
+    /** \brief Tell if the width and the height are automatically set to the
+        size of the level. */
+    bool m_fit_level;
+
     /** \brief The width of the layer. */
     unsigned int m_width;
 
@@ -141,6 +153,9 @@ namespace bf
     /** \brief The filters on the items returned by item_begin()/item_end(). */
     filter_list m_filters;
 
+    /** \brief The prioritized items. */
+    item_list_type m_priority;
+
   }; // class layer
 } // namespace bf
 
