@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -50,11 +50,17 @@ namespace bf
       {
         IDC_LAYER_LIST,
         IDC_FILTER_LIST,
+        IDC_PRIORITY_LIST,
         IDC_FILTER_ENTRY,
         IDC_APPLY_TO_CURRENT_LAYER,
         IDC_APPLY_TO_ALL_LAYERS,
         IDC_DELETE_FILTER,
-        IDC_DELETE_FILTER_EVERYWHERE
+        IDC_DELETE_FILTER_EVERYWHERE,
+
+        IDC_NEW_PRIORITY,
+        IDC_DELETE_PRIORITY,
+        IDC_DECREASE_PRIORITY,
+        IDC_INCREASE_PRIORITY
       }; // enum control_id
 
   public:
@@ -62,14 +68,22 @@ namespace bf
 
     void set_level_view( ingame_view* view );
 
+    void refresh();
+
   private:
     void create_controls();
-    void create_member_controls();
-    void create_sizer_controls();
+
+    wxWindow* create_layer_list( wxWindow* parent );
+    wxWindow* create_filters_page( wxWindow* parent );
+    wxWindow* create_priority_page( wxWindow* parent );
 
     void clear();
     void fill();
 
+    void fill_layer_list();
+    void fill_filter_list();
+    void fill_priority_list();
+
     item_filter create_filter_from_entry() const;
 
     void remove_selected_filters();
@@ -92,6 +106,11 @@ namespace bf
     void on_delete_filter(wxCommandEvent& event);
     void on_delete_filter_everywhere(wxCommandEvent& event);
 
+    void on_new_priority(wxCommandEvent& event);
+    void on_delete_priority(wxCommandEvent& event);
+    void on_decrease_priority(wxCommandEvent& event);
+    void on_increase_priority(wxCommandEvent& event);
+
   private:
     /** \brief The level we are working on. */
     ingame_view* m_level_view;
@@ -99,6 +118,9 @@ namespace bf
     /** \brief The list of layers, presented to the user. */
     wxCheckListBox* m_layer_list;
 
+    /** \brief The list of the items to compile first on the current layer. */
+    wxListBox* m_priority_list;
+
     /** \brief The list of filters on the current layer. */
     wxListBox* m_filter_list;
 
