@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -31,6 +31,7 @@
 
 #include <wx/wx.h>
 #include <wx/spinctrl.h>
+#include <string>
 
 namespace bf
 {
@@ -43,44 +44,45 @@ namespace bf
   class layer_properties_frame:
     public wxDialog
   {
+  public:
+    /** \brief The identifiers of the controls. */
+    enum control_id
+      {
+        IDC_FIT_LEVEL_SIZE
+      }; // enum control_id
+
   public:
     layer_properties_frame( wxWindow* parent );
 
+    bool get_layer_fits_level() const;
     unsigned int get_layer_width() const;
     unsigned int get_layer_height() const;
-    const std::string& get_layer_class_name() const;
+    std::string get_layer_class_name() const;
 
     void fill_from( const layer& lay );
 
   private:
-    void fill_controls();
-
     void create_controls();
     void create_member_controls();
     void create_sizer_controls();
 
-    void on_ok(wxCommandEvent& event);
+    void on_ok( wxCommandEvent& event );
+    void on_fit_level_size( wxCommandEvent& event );
 
   private:
-    /** \brief The width of the layer. */
-    unsigned int m_width;
-
-    /** \brief The height of the layer. */
-    unsigned int m_height;
-
-    /** \brief The name of the class of the layer. */
-    std::string m_class_name;
+    /** \brief Tell if the layer size is the same than the level size. */
+    wxCheckBox* m_fit_level;
 
     /** \brief The text control in which we configure the width of the layer. */
-    wxSpinCtrl* m_width_text;
+    wxSpinCtrl* m_width;
 
     /** \brief The text control in which we configure the height of the
         layer. */
-    wxSpinCtrl* m_height_text;
+    wxSpinCtrl* m_height;
 
     /** \brief The text control in which we configure the name of the class of
         the layer. */
-    wxChoice* m_class_name_choice;
+    wxChoice* m_class_name;
 
     /** \brief Minimum width of the layer. */
     static const unsigned int s_min_width;
