@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -35,30 +35,27 @@
 
 namespace bf
 {
+  class level_check_result;
+
   /**
    * \brief A level, with its layers.
    * \author Julien Jorge
    */
   class level
   {
-  public:
-    /** \brief A list of invalid items. */
-    typedef
-    std::list< std::pair<item_instance*, unsigned int> > invalid_items_list;
-
   public:
     level( const std::string& name, unsigned int width, unsigned int height,
            const std::string& mus );
     level( const level& that );
     ~level();
 
-    layer& get_layer( unsigned int index );
-    const layer& get_layer( unsigned int index ) const;
+    layer& get_layer( unsigned int index ) const;
 
     layer* remove_layer( unsigned int index );
 
     layer& add_layer
-    ( unsigned int width, unsigned int height, const std::string& class_name );
+    ( const std::string& class_name, bool fit_level = true,
+      unsigned int width = 1, unsigned int height = 1 );
     void add_layer( layer* lay, unsigned int index );
 
     void move_backward( unsigned int layer_index );
@@ -77,7 +74,7 @@ namespace bf
     const std::string& get_name() const;
     void set_name( const std::string& name );
 
-    std::pair<bool, layer::const_item_iterator>
+    std::pair<bool, layer::item_iterator>
     find_item_by_id( const std::string& id ) const;
     unsigned int get_layer_by_item( const item_instance& item ) const;
 
@@ -86,7 +83,7 @@ namespace bf
 
     level& operator=( const level& that );
 
-    void check( invalid_items_list& result );
+    void check( level_check_result& result );
 
     void compile( compiled_file& f ) const;
 
@@ -97,6 +94,9 @@ namespace bf
     void clear();
     void assign( const level& that );
 
+    void check_unique_identifiers
+    ( unsigned int i, std::set<std::string>& identifiers ) const;
+
   private:
     /** \brief The name of the level. */
     std::string m_name;
