@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -35,7 +35,12 @@
 
 namespace bf
 {
+  class item_instance;
+  class item_check_result;
+  class layer;
+  class layer_check_result;
   class level;
+  class level_check_result;
   class main_frame;
 
   /**
@@ -66,6 +71,11 @@ namespace bf
 
     bool check_level( level& lvl ) const;
 
+    void print_layer_check_result
+    ( const layer* lay, const layer_check_result& result ) const;
+    void print_item_check_result
+    ( const item_instance* item, const item_check_result& result ) const;
+
     void load_levels();
 
   private:
