@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -51,15 +51,24 @@ namespace bf
     ( const item_class_pool& pool, const wxString& file_path ) const;
 
   private:
-    gui_level* load_level( const item_class_pool& pool, wxXmlNode* node ) const;
+    gui_level*
+    load_level( const item_class_pool& pool, const wxXmlNode* node ) const;
     void load_layers
-    ( const item_class_pool& pool, gui_level& lvl, wxXmlNode* node ) const;
+    ( const item_class_pool& pool, gui_level& lvl,
+      const wxXmlNode* node ) const;
     void load_layer
-    ( const item_class_pool& pool, gui_level& lvl, wxXmlNode* node ) const;
+    ( const item_class_pool& pool, gui_level& lvl,
+      const wxXmlNode* node ) const;
+
     void load_layer_content
-    ( const item_class_pool& pool, layer& lay, wxXmlNode* node ) const;
+    ( const item_class_pool& pool, layer& lay, const wxXmlNode* node ) const;
+
+    void load_items
+    ( const item_class_pool& pool, layer& lay, const wxXmlNode* node ) const;
+    void load_priorities( layer& lay, const wxXmlNode* node ) const;
+
     void load_item
-    ( const item_class_pool& pool, layer& lay, wxXmlNode* node ) const;
+    ( const item_class_pool& pool, layer& lay, const wxXmlNode* node ) const;
     void load_fields( item_instance& item, const wxXmlNode* node ) const;
 
   }; // class level_file_xml_reader
