@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -50,6 +50,8 @@ namespace bf
 
   private:
     void save_layer( std::ostream& os, const layer& the_layer ) const;
+    void save_items( std::ostream& os, const layer& item ) const;
+    void save_priority( std::ostream& os, const layer& item ) const;
     void save_item( std::ostream& os, const item_instance& item ) const;
 
   }; // class level_file_xml_writer
