@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -45,12 +45,23 @@ namespace bf
   class level_overview_frame
     : public wxFrame
   {
+  public:
+     /** \brief The identifiers of the controls. */
+    enum control_id
+      {
+        ID_UPDATE_WIDTH,
+        ID_UPDATE_HEIGHT
+      }; // enum control_id
+
   public:
     level_overview_frame( ingame_view_frame& parent );
+    ~level_overview_frame();
 
   private:
     void on_close(wxCloseEvent& event);
     void on_refresh(wxCommandEvent& event);
+    void on_update_width(wxCommandEvent& event);
+    void on_update_height(wxCommandEvent& event);
 
   private:
     level_thumbnail_ctrl* m_thumbnail;
