@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -34,6 +34,7 @@
 #include <wx/listctrl.h>
 #include <wx/panel.h>
 #include <wx/stattext.h>
+#include <string>
 
 namespace bf
 {
@@ -91,6 +92,9 @@ namespace bf
 
     void get_item_identifiers( wxArrayString& id, const type_field& f );
 
+    void clear_items_id();
+    void set_item_id();
+
     template<typename Type>
     void on_set_field_value( set_field_value_event<Type>& e );
 
