@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -79,6 +79,8 @@ namespace bf
            const sound_description& sound,
            const std::string& auto_next);
     action(const std::string& action_name, double duration);
+    action( const action& that );
+
     ~action();
 
     void add_snapshot( snapshot* s );
@@ -105,6 +107,7 @@ namespace bf
 
     void add_mark(mark* m);
     void remove_mark( mark* m );
+    bool has_marks() const;
     bool has_mark( const mark* m ) const;
     bool has_mark_label(const std::string& mark_label) const;
     mark* get_mark(const std::string& label);
