@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -30,6 +30,7 @@
 #define __BF_ACTION_LIST_FRAME_HPP__
 
 #include <wx/wx.h>
+#include <string>
 
 namespace bf
 {
@@ -60,12 +61,14 @@ namespace bf
     void create_controls();
     void create_member_controls();
     void create_sizer_controls();
+    void update_controls();
 
     void clear();
     void fill();
 
     void on_new_action(wxCommandEvent& event);
     void on_delete(wxCommandEvent& event);
+    void on_copy(wxCommandEvent& event);
 
     void on_show_properties(wxCommandEvent& event);
     void on_select_action(wxCommandEvent& event);
@@ -82,6 +85,15 @@ namespace bf
     /** \brief The button to create a new action. */
     wxButton* m_new_action_button;
 
+    /** \brief The button to delete an action. */
+    wxButton* m_delete_action_button;
+
+    /** \brief The button to copy an action. */
+    wxButton* m_copy_action_button;
+
+    /** \brief The button to edit properties of an action. */
+    wxButton* m_properties_action_button;
+
     DECLARE_EVENT_TABLE()
 
   }; // class action_list_frame
