@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -42,11 +42,9 @@
  * \param auto_next The new next action.
  */
 bf::action::action
-(const std::string& action_name, double duration,
- const sound_description& sound,
- const std::string& auto_next)
-  : m_name(action_name), m_duration(duration),
-    m_sound(sound),
+( const std::string& action_name, double duration,
+  const sound_description& sound, const std::string& auto_next )
+  : m_name(action_name), m_duration(duration), m_sound(sound),
     m_auto_next(auto_next)
 {
   create_initial_snapshot();
@@ -62,6 +60,30 @@ bf::action::action
 (const std::string& action_name, double duration)
   : m_name(action_name), m_duration(duration)
 {
+
+} // action::action()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Copy constructor.
+ * \param that The instance to copy from.
+ */
+bf::action::action( const action& that )
+  : m_name(that.m_name), m_duration(that.m_duration), m_sound(that.m_sound),
+    m_auto_next(that.m_auto_next)
+{
+  mark_list::const_iterator it;
+  std::map<const mark*, const mark*> marks;
+
+  for ( it=that.m_marks.begin(); it!=that.m_marks.end(); ++it)
+    {
+      m_marks.push_back( new mark(**it) );
+      marks[*it] = m_marks.back();
+    }
+
+  snapshot_list::const_iterator it_2;
+  for ( it_2=that.m_snapshots.begin(); it_2!=that.m_snapshots.end(); ++it_2)
+    m_snapshots.push_back( new snapshot(**it_2, marks) );
 } // action::action()
 
 /*----------------------------------------------------------------------------*/
@@ -130,7 +152,7 @@ void bf::action::remove_snapshot( snapshot* s )
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Tell if the action contain a snapshot.
+ * \brief Tell if the action contains a snapshot.
  * \param s The snapshot to test.
  */
 bool bf::action::has_snapshot( const snapshot* s ) const
@@ -147,7 +169,7 @@ bool bf::action::has_snapshot( const snapshot* s ) const
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Tell if the action contain a snapshot at a given date.
+ * \brief Tell if the action contains a snapshot at a given date.
  * \param date The snapshot date to test.
  */
 bool bf::action::has_snapshot_date( double date ) const
@@ -353,7 +375,16 @@ void bf::action::remove_mark( mark* m )
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Tell if the action contain a mark.
+ * \brief Tell if the action contains mark.
+ */
+bool bf::action::has_marks( ) const
+{
+  return !m_marks.empty();
+} // action::has_marks()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the action contains a mark.
  * \param m The mark to test.
  */
 bool bf::action::has_mark( const mark* m ) const
@@ -456,7 +487,9 @@ double bf::action::accumulated_mark_visibility
   snapshot_list::const_iterator it( get_const_iterator_less_equal(from) );
   const snapshot_list::const_iterator to_s( get_const_iterator_less_equal(to) );
 
-  CLAW_PRECOND( it != m_snapshots.end() );
+  if ( it == m_snapshots.end() )
+    return 0;
+
   CLAW_PRECOND( to_s != m_snapshots.end() );
 
   double result;
