@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -44,9 +44,11 @@
  */
 bf::action_list_frame::action_list_frame( wxWindow* parent )
   : wxPanel( parent ), m_model_frame(NULL), m_action_list(NULL),
-    m_new_action_button(NULL)
+    m_new_action_button(NULL), m_delete_action_button(NULL),
+    m_copy_action_button(NULL), m_properties_action_button(NULL)
 {
   create_controls();
+  update_controls();
 } // action_list_frame::action_list_frame()
 
 /*----------------------------------------------------------------------------*/
@@ -60,6 +62,7 @@ void bf::action_list_frame::set_model_frame( model_frame* f )
     {
       m_model_frame = f;
       fill();
+      update_controls();
     }
 } // action_list_frame::set_model_frame()
 
@@ -80,8 +83,30 @@ void bf::action_list_frame::create_controls()
 {
   create_member_controls();
   create_sizer_controls();
+  update_controls();
 } // action_list_frame::create_controls()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Update enable/disable of the controls of the window.
+ */
+void bf::action_list_frame::update_controls()
+{
+  bool enable = false;
+
+  if ( m_model_frame != NULL )
+    {
+      enable = !m_model_frame->empty();
+      m_new_action_button->Enable(true);
+    }
+  else
+    m_new_action_button->Enable(false);
+
+  m_delete_action_button->Enable(enable);
+  m_copy_action_button->Enable(enable);
+  m_properties_action_button->Enable(enable);
+} // action_list_frame::update_controls()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Create the controls for which we keep a reference.
@@ -89,8 +114,11 @@ void bf::action_list_frame::create_controls()
 void bf::action_list_frame::create_member_controls()
 {
   m_action_list = new wxListBox(this, IDC_ACTION_LIST);
+
   m_new_action_button = new wxButton(this, wxID_NEW);
-  m_new_action_button->SetLabel(wxEmptyString);
+  m_delete_action_button = new wxButton(this, wxID_DELETE);
+  m_copy_action_button = new wxButton(this, wxID_COPY);
+  m_properties_action_button = new wxButton(this, wxID_PROPERTIES);
 } // action_list_frame::create_member_controls()
 
 /*----------------------------------------------------------------------------*/
@@ -105,8 +133,9 @@ void bf::action_list_frame::create_sizer_controls()
   wxBoxSizer* s_sizer = new wxBoxSizer( wxVERTICAL );
 
   s_sizer->Add( m_new_action_button, 0, wxEXPAND | wxALL, 0 );
-  s_sizer->Add( new wxButton(this, wxID_DELETE), 0, wxEXPAND | wxALL, 0 );
-  s_sizer->Add( new wxButton(this, wxID_PROPERTIES), 0, wxEXPAND | wxALL, 0 );
+  s_sizer->Add( m_delete_action_button, 0, wxEXPAND | wxALL, 0 );
+  s_sizer->Add( m_copy_action_button, 0, wxEXPAND | wxALL, 0 );
+  s_sizer->Add( m_properties_action_button, 0, wxEXPAND | wxALL, 0 );
 
   sizer->Add( m_action_list, 1, wxEXPAND );
   sizer->Add( s_sizer, 0, wxEXPAND );
@@ -158,11 +187,11 @@ void bf::action_list_frame::on_new_action( wxCommandEvent& WXUNUSED(event) )
 {
   if (m_model_frame != NULL)
     {
-      action_properties_frame dlg(this,& m_model_frame->get_model());
+      action_properties_frame dlg(this, & m_model_frame->get_model());
 
       if ( dlg.ShowModal() == wxID_OK )
         {
-          m_model_frame->clear_mark_selection();
+          m_model_frame->clear_selection();
 
           m_model_frame->do_action
             ( new action_add_action
@@ -173,6 +202,7 @@ void bf::action_list_frame::on_new_action( wxCommandEvent& WXUNUSED(event) )
 
           m_model_frame->set_active_action(dlg.get_action_name());
           fill();
+          update_controls();
         }
     }
 } // action_list_frame::on_new_action()
@@ -187,7 +217,7 @@ void bf::action_list_frame::on_delete( wxCommandEvent& WXUNUSED(event) )
   if (m_model_frame != NULL)
     if ( !m_model_frame->empty() )
       {
-        m_model_frame->clear_mark_selection();
+        m_model_frame->clear_selection();
 
         int index = m_action_list->GetSelection();
         std::string name;
@@ -210,12 +240,41 @@ void bf::action_list_frame::on_delete( wxCommandEvent& WXUNUSED(event) )
                 (wx_to_std_string(m_action_list->GetString(index-1)));
           }
 
-         if ( m_model_frame->get_model().has_active_action() )
-           select_action
-             (m_model_frame->get_model().get_active_action().get_name());
+        if ( m_model_frame->get_model().has_active_action() )
+          select_action
+            (m_model_frame->get_model().get_active_action().get_name());
+
+        update_controls();
       }
 } // action_list_frame::on_delete()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Answer to a click on the button "copy".
+ * \param event This event occured.
+ */
+void bf::action_list_frame::on_copy( wxCommandEvent& WXUNUSED(event) )
+{
+  if (m_model_frame != NULL)
+    if ( !m_model_frame->empty() )
+      {
+        std::string name;
+        if ( !m_model_frame->get_model().has_active_action() )
+          return;
+
+        action* new_action =
+          new action(m_model_frame->get_model().get_active_action());
+        new_action->set_name
+          ( m_model_frame->get_model().create_unique_action_name
+            (new_action->get_name()) );
+
+        m_model_frame->do_action( new action_add_action( new_action ) );
+
+        fill();
+        update_controls();
+      }
+} // action_list_frame::on_copy()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Answer to a click on the button "Properties".
@@ -280,6 +339,7 @@ void bf::action_list_frame::on_close( wxCloseEvent& event )
 BEGIN_EVENT_TABLE(bf::action_list_frame, wxPanel)
   EVT_BUTTON( wxID_NEW, bf::action_list_frame::on_new_action )
   EVT_BUTTON( wxID_DELETE, bf::action_list_frame::on_delete )
+  EVT_BUTTON( wxID_COPY, bf::action_list_frame::on_copy )
   EVT_LISTBOX( bf::action_list_frame::IDC_ACTION_LIST,
                bf::action_list_frame::on_select_action )
   EVT_BUTTON( wxID_PROPERTIES, bf::action_list_frame::on_show_properties )
