@@ -1,7 +1,7 @@
 /*
   Bear Engine - Model editor
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -103,7 +103,7 @@ void bf::gui_model::reset_active_action()
 bool bf::gui_model::has_mark_selection() const
 {
   if ( has_active_action() )
-    return !m_selection.find(m_active_action)->second.empty();
+    return !m_selection.find(m_active_action)->second.mark_empty();
   else
     return false;
 } // gui_model::has_mark_selection()
@@ -116,7 +116,7 @@ const bf::mark* bf::gui_model::get_main_mark_selection() const
 {
   CLAW_PRECOND( has_active_action() );
 
-  return m_selection.find(m_active_action)->second.get_main_selection();
+  return m_selection.find(m_active_action)->second.get_main_mark_selection();
 } // gui_model::get_main_mark_selection()
 
 /*----------------------------------------------------------------------------*/
@@ -127,7 +127,7 @@ bf::mark* bf::gui_model::get_main_mark_selection()
 {
   CLAW_PRECOND( has_active_action() );
 
-  return m_selection[m_active_action].get_main_selection();
+  return m_selection[m_active_action].get_main_mark_selection();
 } // gui_model::get_main_mark_selection()
 
 /*----------------------------------------------------------------------------*/
@@ -135,7 +135,7 @@ bf::mark* bf::gui_model::get_main_mark_selection()
  * \brief Set the selected mark.
  * \param label The label of the new selected mark.
  */
-void bf::gui_model::set_mark_selection( const std::string& label)
+void bf::gui_model::set_mark_selection( const std::string& label )
 {
   CLAW_PRECOND( has_active_action() );
   CLAW_PRECOND( get_active_action().has_mark_label(label) );
@@ -162,9 +162,46 @@ void bf::gui_model::add_to_mark_selection
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Reset the selected mark.
+ * \brief Tell if the bounding box is selected.
  */
-void bf::gui_model::clear_mark_selection()
+bool bf::gui_model::bounding_box_is_selected() const
+{
+  if ( has_active_action() )
+    return m_selection.find(m_active_action)->second.bounding_box_is_selected();
+  else
+    return false;
+} // gui_model::bounding_box_is_selected()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the bounding box is the main selection.
+ */
+bool bf::gui_model::bounding_box_is_main_selection() const
+{
+  if ( has_active_action() )
+    return
+      m_selection.find
+      (m_active_action)->second.bounding_box_is_main_selection();
+  else
+    return false;
+} // gui_model::bounding_box_is_main_selection()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Select or deselect the bounding box.
+ * \param s Tell if the bounding box has to be selected.
+ */
+void bf::gui_model::set_bounding_box_selection( bool s )
+{
+  if ( has_active_action() )
+    m_selection[m_active_action].set_bounding_box_selection(s);
+} // gui_model::set_bounding_box_selection()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Remove all selections on the active action.
+ */
+void bf::gui_model::clear_selection()
 {
   if ( has_active_action() )
     m_selection[m_active_action].clear();
