@@ -1,7 +1,7 @@
 /*
     Bear Engine - Level editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -32,8 +32,9 @@
 #include "bf/config_frame.hpp"
 #include "bf/gui_model.hpp"
 #include "bf/image_pool.hpp"
-#include "bf/model_properties_ctrl.hpp"
+#include "bf/model_editor.hpp"
 #include "bf/model_frame.hpp"
+#include "bf/model_properties_ctrl.hpp"
 #include "bf/path_configuration.hpp"
 #include "bf/windows_layout.hpp"
 #include "bf/wx_facilities.hpp"
@@ -43,6 +44,8 @@
 #include <wx/filename.h>
 #include <wx/msgdlg.h>
 
+DECLARE_APP(bf::model_editor)
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Default constructor.
@@ -51,19 +54,7 @@ bf::main_frame::main_frame()
   : wxFrame(NULL, wxID_ANY, wxT("Bear Factory - Model editor")),
     m_model_properties(NULL), m_windows_layout(NULL)
 {
-  m_config.load();
-
-  if ( path_configuration::get_instance().item_class_path.empty()
-       || path_configuration::get_instance().data_path.empty() )
-    configure_paths();
-
-  std::list<std::string>::const_iterator it;
-
-  for ( it=path_configuration::get_instance().data_path.begin();
-        it!=path_configuration::get_instance().data_path.end(); ++it )
-    image_pool::get_instance().scan_directory(*it);
-
-  SetSize( m_config.main_rect );
+  SetSize( wxGetApp().get_config().main_rect );
 
   create_menu();
   create_controls();
@@ -240,13 +231,13 @@ wxMenu* bf::main_frame::create_help_menu() const
  */
 void bf::main_frame::save_config()
 {
-  m_config.main_rect = GetScreenRect();
+  wxGetApp().get_config().main_rect = GetScreenRect();
 
   if ( m_windows_layout->get_current_model_frame() != NULL )
-    m_config.default_model_window_size =
+    wxGetApp().get_config().default_model_window_size =
       m_windows_layout->get_current_model_frame()->GetSize();
 
-  m_config.save();
+  wxGetApp().get_config().save();
 } // main_frame::save_config()
 
 /*----------------------------------------------------------------------------*/
@@ -261,7 +252,7 @@ void bf::main_frame::add_model_view( model_frame* m )
   if ( m_windows_layout->get_current_model_frame() != NULL )
     s = m_windows_layout->get_current_model_frame()->GetSize();
   else
-    s = m_config.default_model_window_size;
+    s = wxGetApp().get_config().default_model_window_size;
 
   set_active_model(m);
   m->SetSize(s);
@@ -269,33 +260,6 @@ void bf::main_frame::add_model_view( model_frame* m )
   turn_model_entries(true);
 } // main_frame::add_model_view()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Show the path configuration dialog.
- */
-void bf::main_frame::configure_paths()
-{
-  config_frame dlg(this);
-
-  if ( dlg.ShowModal() == wxID_OK )
-    update_image_pool();
-} // main_frame::configure_paths()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Add the paths of the configuration in the image pool.
- */
-void bf::main_frame::update_image_pool()
-{
-  image_pool::get_instance().clear();
-
-  std::list<std::string>::const_iterator it;
-
-  for ( it=path_configuration::get_instance().data_path.begin();
-        it!=path_configuration::get_instance().data_path.end(); ++it )
-    image_pool::get_instance().scan_directory(*it);
-} // main_frame::update_image_pool()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Answer to a click on "Configuration" menu.
@@ -303,7 +267,7 @@ void bf::main_frame::update_image_pool()
  */
 void bf::main_frame::on_configuration_menu(wxCommandEvent& WXUNUSED(event))
 {
-  configure_paths();
+  wxGetApp().configure();
 } // main_frame::on_configuration_menu()
 
 /*----------------------------------------------------------------------------*/
@@ -313,7 +277,7 @@ void bf::main_frame::on_configuration_menu(wxCommandEvent& WXUNUSED(event))
  */
 void bf::main_frame::on_update_image_pool_menu(wxCommandEvent& WXUNUSED(event))
 {
-  update_image_pool();
+  wxGetApp().update_image_pool();
 } // main_frame::on_update_image_pool_menu()
 
 /*----------------------------------------------------------------------------*/
