@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -29,8 +29,6 @@
 #include "bf/mark.hpp"
 
 #include "bf/compiled_file.hpp"
-#include "bf/path_configuration.hpp"
-#include "bf/wx_facilities.hpp"
 
 /*----------------------------------------------------------------------------*/
 /**
