@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -44,9 +44,11 @@
  */
 bf::mark_list_frame::mark_list_frame( wxWindow* parent )
   : wxPanel( parent ), m_model_frame(NULL), m_mark_list(NULL),
-    m_new_mark_button(NULL)
+    m_new_mark_button(NULL), m_delete_mark_button(NULL),
+    m_properties_mark_button(NULL)
 {
   create_controls();
+  update_controls();
 } // mark_list_frame::mark_list_frame()
 
 /*----------------------------------------------------------------------------*/
@@ -58,6 +60,7 @@ void bf::mark_list_frame::set_model_frame( model_frame* f )
 {
   m_model_frame = f;
   fill();
+  update_controls();
 } // mark_list_frame::set_model_frame()
 
 /*----------------------------------------------------------------------------*/
@@ -98,6 +101,27 @@ void bf::mark_list_frame::create_controls()
   create_sizer_controls();
 } // mark_list_frame::create_controls()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Update enable/disable of the controls of the window.
+ */
+void bf::mark_list_frame::update_controls()
+{
+  bool enable = false;
+  bool new_mark_enable = false;
+
+  if ( m_model_frame != NULL )
+    if ( m_model_frame->get_model().has_active_action() )
+      {
+        enable = m_model_frame->get_model().get_active_action().has_marks();
+        new_mark_enable = true;
+      }
+
+  m_new_mark_button->Enable(new_mark_enable);
+  m_delete_mark_button->Enable(enable);
+  m_properties_mark_button->Enable(enable);
+} // action_list_frame::update_controls()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Create the controls for which we keep a reference.
@@ -121,9 +145,12 @@ void bf::mark_list_frame::create_sizer_controls()
   // the sizer for the buttons
   wxBoxSizer* s_sizer = new wxBoxSizer( wxVERTICAL );
 
+  m_delete_mark_button = new wxButton(this, wxID_DELETE);
+  m_properties_mark_button = new wxButton(this, wxID_PROPERTIES);
+
   s_sizer->Add( m_new_mark_button, 0, wxEXPAND | wxALL, 0 );
-  s_sizer->Add( new wxButton(this, wxID_DELETE), 0, wxEXPAND | wxALL, 0 );
-  s_sizer->Add( new wxButton(this, wxID_PROPERTIES), 0, wxEXPAND | wxALL, 0 );
+  s_sizer->Add( m_delete_mark_button, 0, wxEXPAND | wxALL, 0 );
+  s_sizer->Add( m_properties_mark_button, 0, wxEXPAND | wxALL, 0 );
 
   sizer->Add( m_mark_list, 1, wxEXPAND );
   sizer->Add( s_sizer, 0, wxEXPAND );
@@ -179,7 +206,7 @@ void bf::mark_list_frame::on_new_mark(wxCommandEvent& WXUNUSED(event))
     if ( m_model_frame->get_model().has_active_action() )
       {
         const action& a = m_model_frame->get_model().get_active_action();
-        mark_properties_frame dlg(this,&a);
+        mark_properties_frame dlg(this, &a);
 
         if ( dlg.ShowModal() == wxID_OK )
           {
@@ -193,6 +220,7 @@ void bf::mark_list_frame::on_new_mark(wxCommandEvent& WXUNUSED(event))
             fill();
 
             select_mark(dlg.get_mark_name());
+            update_controls();
           }
       }
 } // mark_list_frame::on_new_mark()
@@ -213,12 +241,12 @@ void bf::mark_list_frame::on_delete(wxCommandEvent& WXUNUSED(event))
             action& a = m_model_frame->get_model().get_active_action();
             std::string selection =
               wx_to_std_string(m_mark_list->GetStringSelection());
-            m_model_frame->clear_mark_selection();
+            m_model_frame->clear_selection();
 
             m_model_frame->do_action
               ( new action_remove_mark
-          ( m_model_frame->get_model().get_active_action().get_name(),
-            a.get_mark(selection)));
+                ( m_model_frame->get_model().get_active_action().get_name(),
+                  a.get_mark(selection)));
 
             fill();
 
@@ -233,6 +261,7 @@ void bf::mark_list_frame::on_delete(wxCommandEvent& WXUNUSED(event))
             (wx_to_std_string(m_mark_list->GetStringSelection()));
               }
           }
+        update_controls();
       }
 } // mark_list_frame::on_delete()
 
@@ -260,7 +289,7 @@ void bf::mark_list_frame::on_show_properties(wxCommandEvent& WXUNUSED(event))
             if ( dlg.ShowModal() == wxID_OK )
               m_model_frame->do_action
                 ( new action_modify_mark
-                  (m,dlg.get_mark_name(),dlg.get_mark_animation(),
+                  (m, dlg.get_mark_name(), dlg.get_mark_animation(),
                    dlg.apply_angle_to_animation(),
                    dlg.pause_animation_when_hidden()) );
 
