@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -34,6 +34,7 @@
 
 #include <sstream>
 #include <claw/assert.hpp>
+#include <boost/lexical_cast.hpp>
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -81,6 +82,35 @@ bool bf::model::has_action( const std::string& name ) const
   return result;
 } // model::has_action()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Find an action name that is not already used.
+ * \param base The base from which the name is computed.
+ */
+std::string
+bf::model::create_unique_action_name( const std::string& base ) const
+{
+  if ( !has_action(base) )
+    return base;
+
+  const std::string::size_type p = base.find_last_not_of("0123456789-");
+  std::string prefix;
+
+  if ( p == std::string::npos )
+    prefix = base;
+  else
+    prefix = base.substr(0, p+1);
+
+  for ( std::size_t i=1; /* nothing */ ; ++i )
+    {
+      const std::string candidate
+        ( prefix + '-' + boost::lexical_cast<std::string>(i) );
+
+      if ( !has_action(candidate) )
+        return candidate;
+    }
+} // model::create_unique_action_name()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Add an action.
@@ -96,7 +126,7 @@ bf::action& bf::model::add_action
 {
   CLAW_PRECOND( !has_action(action_name) );
 
-  action* a = new action(action_name,duration,sound, next_action);
+  action* a = new action(action_name, duration, sound, next_action);
 
   m_actions.push_back(a);
 
