@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -38,18 +38,19 @@
 #include "bf/wx_facilities.hpp"
 #include "bf/history/action_add_snapshot.hpp"
 #include "bf/history/action_remove_snapshot.hpp"
-#include "bf/history/action_add_snapshot.hpp"
 #include "bf/history/action_move_snapshot.hpp"
-#include "bf/history/action_remove_snapshot.hpp"
 #include "bf/history/action_group.hpp"
 #include "bf/history/action_modify_placement.hpp"
 #include "bf/history/action_modify_snapshot_size.hpp"
+#include "bf/history/action_set_placement_size.hpp"
 #include "bf/xml/model_file.hpp"
 
 #include "bf/icon/compile.xpm"
+#include "bf/icon/graphism.xpm"
 #include "bf/icon/player_play.xpm"
 #include "bf/icon/player_start.xpm"
 #include "bf/icon/player_stop.xpm"
+#include "bf/icon/text.xpm"
 #include "bf/icon/wireframe.xpm"
 #include "bf/icon/zoom_fit.xpm"
 #include "bf/icon/zoom_in.xpm"
@@ -77,7 +78,7 @@ const unsigned int bf::model_frame::s_button_width = 25;
  * \brief Constructor.
  * \param layout The layout of the windows of the program.
  * \param mdl The model.
- * \param model_file The path of the file from which \a mdl was read.
+ * \param model_file The path of the file from which a model was read.
  * The model will be deleted in the destructor.
  */
 bf::model_frame::model_frame
@@ -160,7 +161,7 @@ void bf::model_frame::set_active_action( const std::string& action_name )
   CLAW_PRECOND( m_history.get_model().has_action(action_name) );
 
   m_history.get_model().set_active_action(action_name);
-  m_history.get_model().clear_mark_selection();
+  m_history.get_model().clear_selection();
   set_date(0);
 
   update_layout();
@@ -175,7 +176,7 @@ void bf::model_frame::set_active_action( const std::string& action_name )
 void bf::model_frame::reset_active_action()
 {
   m_history.get_model().reset_active_action();
-  m_history.get_model().clear_mark_selection();
+  m_history.get_model().clear_selection();
   set_date(0);
 
   update_layout();
@@ -191,21 +192,40 @@ void bf::model_frame::reset_active_action()
  */
 void bf::model_frame::set_mark_selection( const std::string& label)
 {
-  m_history.get_model().set_mark_selection(label);
+  m_history.get_model().set_bounding_box_selection(false);
+
+  if ( label.empty() )
+    m_history.get_model().clear_selection();
+  else
+    m_history.get_model().set_mark_selection(label);
+
   m_layout.update_mark();
   fill();
 } // model_frame::set_mark_selection()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Reset the selected mark.
+ * \brief Set the selection on the bounding box.
  */
-void bf::model_frame::clear_mark_selection()
+void bf::model_frame::set_bounding_box_selection()
 {
-  m_history.get_model().clear_mark_selection();
+  m_history.get_model().clear_selection();
+  m_history.get_model().set_bounding_box_selection(true);
+
   m_layout.update_mark();
   fill();
-} // model_frame::clear_mark_selection()
+} // model_frame::set_bounding_box_selection()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Reset the selected mark.
+ */
+void bf::model_frame::clear_selection()
+{
+  m_history.get_model().clear_selection();
+  m_layout.update_mark();
+  fill();
+} // model_frame::clear_selection()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -381,15 +401,15 @@ void bf::model_frame::create_controls()
  */
 void bf::model_frame::create_member_controls()
 {
-  m_slider = new slider_with_ticks(this, ID_SLIDER,0,0,100);
+  m_slider = new slider_with_ticks(this, ID_SLIDER, 0, 0, 100);
 
   m_new_button = new wxBitmapButton
     ( this, ID_NEW_SNAPSHOT,
-      wxArtProvider::GetBitmap(wxART_NEW, wxART_MENU, wxSize(16,16)) );
+      wxArtProvider::GetBitmap(wxART_NEW, wxART_MENU, wxSize(16, 16)) );
 
   m_delete_button = new wxBitmapButton
     ( this, ID_DELETE_SNAPSHOT,
-      wxArtProvider::GetBitmap(wxART_DELETE, wxART_MENU, wxSize(16,16)) );
+      wxArtProvider::GetBitmap(wxART_DELETE, wxART_MENU, wxSize(16, 16)) );
 
   m_play_button = new wxBitmapButton
     (this, ID_PLAY_STOP, wxBitmap(player_play_xpm));
@@ -480,7 +500,7 @@ wxMenu* bf::model_frame::create_edit_menu() const
   result->Append
     ( wxID_UNDO, _("&Undo\tCTRL+Z"), _("Undo the last operation.") );
   result->Append
-    ( wxID_REDO, _("&Redo\tCTRL+Y"),_("Redo the last undone operation.") );
+    ( wxID_REDO, _("&Redo\tCTRL+Y"), _("Redo the last undone operation.") );
   result->AppendSeparator();
 
   result->Append
@@ -513,6 +533,10 @@ wxMenu* bf::model_frame::create_view_menu() const
   result->AppendCheckItem
     ( ID_WIREFRAME, _("&Wireframe\tW"),
       _("Display the bounding box and the marks.") );
+  result->AppendCheckItem
+    ( ID_GRAPHISM, _("&Graphic\tg"), _("Display the sprites of the marks.") );
+  result->AppendCheckItem
+    ( ID_TEXT, _("&Text\tg"), _("Display the name of the marks.") );
 
   result->AppendSeparator();
 
@@ -527,6 +551,9 @@ wxMenu* bf::model_frame::create_view_menu() const
   wx_menu_append_item
     ( sub_menu,  wxID_ZOOM_100, _("No zoom"), _("Remove the zoom ratio."),
       wxBitmap(zoom_original_xpm) );
+  wx_menu_append_item
+    ( sub_menu,  wxID_ZOOM_FIT, _("Zoom fit"), _("Zoom fit"),
+      wxBitmap(zoom_fit_xpm) );
 
   result->Append(wxID_ANY, _("&Zoom"), sub_menu, _("Adjust the zoom ratio.") );
 
@@ -564,6 +591,12 @@ void bf::model_frame::create_toolbar()
   bar->AddCheckTool
     ( ID_WIREFRAME, _("&Wireframe"), wxBitmap(wireframe_xpm),
       wxBitmap(wireframe_xpm), _("Wireframe") );
+  bar->AddCheckTool
+    ( ID_GRAPHISM, _("&Graphism"), wxBitmap(graphism_xpm),
+      wxBitmap(graphism_xpm), _("Graphism") );
+  bar->AddCheckTool
+    ( ID_TEXT, _("&Text"), wxBitmap(text_xpm), wxBitmap(text_xpm),
+      _("Text") );
   bar->AddSeparator();
 
   m_zoom_spin = new wxSpinCtrl( bar, ID_ZOOM );
@@ -593,7 +626,7 @@ void bf::model_frame::create_accelerators()
     {
       wxAcceleratorEntry( wxACCEL_CTRL, (int)'C', wxID_COPY ),
       wxAcceleratorEntry( wxACCEL_CTRL, (int)'S', wxID_SAVE ),
-      wxAcceleratorEntry( wxACCEL_CTRL | wxACCEL_SHIFT, (int)'S',wxID_SAVEAS ),
+      wxAcceleratorEntry( wxACCEL_CTRL | wxACCEL_SHIFT, (int)'S', wxID_SAVEAS ),
       wxAcceleratorEntry( wxACCEL_CTRL, (int)'V', wxID_PASTE ),
       wxAcceleratorEntry( wxACCEL_CTRL, (int)'X', wxID_CUT ),
       wxAcceleratorEntry( wxACCEL_CTRL, (int)'Y', wxID_REDO ),
@@ -616,6 +649,24 @@ void bf::model_frame::toggle_wireframe_mode()
   m_model_view->toggle_wireframe_mode();
 } // model_frame::toggle_wireframe_mode()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Toggle the graphic mode.
+ */
+void bf::model_frame::toggle_graphic_mode()
+{
+  m_model_view->toggle_graphic_mode();
+} // model_frame::toggle_graphic_mode()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Toggle the text mode.
+ */
+void bf::model_frame::toggle_text_mode()
+{
+  m_model_view->toggle_text_mode();
+} // model_frame::toggle_text_mode()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Check the validity of current model.
@@ -637,7 +688,7 @@ bool bf::model_frame::check_model()
 
   if ( !actions.empty() )
     {
-      error_check_model_dialog dlg(*this,actions);
+      error_check_model_dialog dlg(*this, actions);
 
       dlg.ShowModal();
 
@@ -730,8 +781,8 @@ void bf::model_frame::update_layout()
 {
   m_layout.set_current_model_frame(*this);
   fill();
-
   Refresh();
+  SendSizeEvent();
 } // model_frame::update_layout()
 
 /*----------------------------------------------------------------------------*/
@@ -774,6 +825,8 @@ void bf::model_frame::update_toolbar()
   wxToolBar* bar = GetToolBar();
 
   bar->ToggleTool(ID_WIREFRAME, m_model_view->get_wireframe_drawing());
+  bar->ToggleTool(ID_GRAPHISM, m_model_view->get_graphic_drawing());
+  bar->ToggleTool(ID_TEXT, m_model_view->get_text_drawing());
 
   if( m_model_view->get_zoom() == 10 )
     bar->EnableTool(wxID_ZOOM_OUT, false);
@@ -809,7 +862,7 @@ bool bf::model_frame::can_delete_snapshot() const
 
       result =
         m_history.get_model().get_active_action().has_snapshot_date(date) &&
-        (m_slider->get_value() != 0) ;
+        (m_slider->get_value() != 0);
     }
 
   return result;
@@ -991,7 +1044,6 @@ void bf::model_frame::on_close(wxCloseEvent& event)
   if ( ok || !event.CanVeto() )
     {
       m_layout.remove_model_frame(*this);
-
       Destroy();
     }
   else
@@ -1157,6 +1209,28 @@ void bf::model_frame::on_wireframe(wxCommandEvent& WXUNUSED(event))
   GetToolBar()->ToggleTool(ID_WIREFRAME, m_model_view->get_wireframe_drawing());
 } // model_frame::on_wireframe()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Answer to a click on the menu "Graphic".
+ * \param event This event occured.
+ */
+void bf::model_frame::on_graphic(wxCommandEvent& WXUNUSED(event))
+{
+  toggle_graphic_mode();
+  GetToolBar()->ToggleTool(ID_GRAPHISM, m_model_view->get_graphic_drawing());
+} // model_frame::on_graphic()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Answer to a click on the menu "Text".
+ * \param event This event occured.
+ */
+void bf::model_frame::on_text(wxCommandEvent& WXUNUSED(event))
+{
+  toggle_text_mode();
+  GetToolBar()->ToggleTool(ID_TEXT, m_model_view->get_text_drawing());
+} // model_frame::on_text()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Answer to a click on the menu "zoom_100".
@@ -1166,6 +1240,7 @@ void bf::model_frame::on_zoom_100(wxCommandEvent& WXUNUSED(event))
 {
   m_model_view->set_zoom(100);
   m_model_view->Refresh();
+  SendSizeEvent();
   update_toolbar();
 } // model_frame::on_zoom_100()
 
@@ -1178,6 +1253,7 @@ void bf::model_frame::on_zoom_in(wxCommandEvent& WXUNUSED(event))
 {
   m_model_view->set_zoom( m_model_view->get_zoom() + 10);
   m_model_view->Refresh();
+  SendSizeEvent();
   update_toolbar();
 } // model_frame::on_zoom_in()
 
@@ -1196,6 +1272,7 @@ void bf::model_frame::on_zoom_out(wxCommandEvent& WXUNUSED(event))
         m_model_view->set_zoom( m_model_view->get_zoom() - 10);
 
       m_model_view->Refresh();
+      SendSizeEvent();
       update_toolbar();
     }
 } // model_frame::on_zoom_out()
@@ -1209,6 +1286,7 @@ void bf::model_frame::on_zoom_fit(wxCommandEvent& WXUNUSED(event))
 {
   m_model_view->auto_zoom();
   m_model_view->Refresh();
+  SendSizeEvent();
   update_toolbar();
 } // model_frame::on_zoom_fit()
 
@@ -1221,8 +1299,34 @@ void bf::model_frame::on_zoom_change( wxSpinEvent& event )
 {
   m_model_view->set_zoom( event.GetPosition() );
   m_model_view->Refresh();
+  SendSizeEvent();
 } // model_frame::on_zoom_change()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The middle button of mouse turn.
+ * \param event The mouse event that occured.
+ */
+void bf::model_frame::on_mouse_wheel_rotation(wxMouseEvent& event)
+{
+  int rotation = event.GetWheelRotation();
+
+  if ( event.ControlDown() )
+    {
+      unsigned int zoom = m_model_view->get_zoom();
+
+      if ( rotation >= 0 )
+        zoom += 15;
+      else if ( zoom > 15 )
+        zoom -= 15;
+
+      m_model_view->set_zoom(zoom);
+      m_model_view->Refresh();
+      SendSizeEvent();
+      update_toolbar();
+    }
+} // model_frame::on_mouse_wheel_rotation
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Answer to a click on a new snapshot.
@@ -1301,7 +1405,7 @@ void bf::model_frame::on_tick_move(tick_event& event)
               snapshot* s =
                 new snapshot(*act.get_snapshot_before_or_at_date(initial_date));
               s->set_date(new_date);
-              group->add_action( new action_add_snapshot(act.get_name(),s));
+              group->add_action( new action_add_snapshot(act.get_name(), s));
             }
           else
             group->add_action
@@ -1315,7 +1419,7 @@ void bf::model_frame::on_tick_move(tick_event& event)
                 new snapshot
                 ( *act.get_snapshot_before_or_at_date(initial_date) );
               s->set_date(0);
-              group->add_action( new action_add_snapshot(act.get_name(),s));
+              group->add_action( new action_add_snapshot(act.get_name(), s));
             }
 
           do_action(group);
@@ -1385,11 +1489,37 @@ void bf::model_frame::on_mark_move(placement_event& event)
 
   do_action
     ( new action_modify_placement
-      (get_model().get_selected_snapshot(), m, event.get_left(),
-       event.get_bottom(), p.get_depth_position(),
-       p.get_angle(), p.is_visible()) );
+      (get_model().get_selected_snapshot(), m, event.get_x(), event.get_y(),
+       p.get_depth_position(), p.get_angle(), p.is_visible()) );
 } // model_frame::on_mark_move()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The selected mark is resized.
+ * \param event This event occured.
+ */
+void bf::model_frame::on_mark_size(placement_event& event)
+{
+  set_mark_selection(event.get_label());
+
+  mark* m( get_model().get_main_mark_selection() );
+  const mark_placement& p =
+    get_model().get_selected_snapshot()->get_placement(m);
+
+  action_group* a = new action_group();
+  a->set_description( _("Resize mark") );
+  a->add_action
+    ( new action_modify_placement
+      (get_model().get_selected_snapshot(), m, event.get_x(), event.get_y(),
+       p.get_depth_position(), p.get_angle(), p.is_visible()) );
+  a->add_action
+    ( new action_set_placement_size
+      ( get_model().get_selected_snapshot(), m, event.get_width(),
+        event.get_height() ) );
+
+  do_action(a);
+} // model_frame::on_mark_size()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief The bounding_box change.
@@ -1415,14 +1545,11 @@ void bf::model_frame::on_bounding_box_change(bounding_box_event& event)
             mark_placement& p = s->get_placement(label);
             mark* m = get_model().get_active_action().get_mark(label);
 
-            double x = p.get_position_x();
-            double y = p.get_position_y();
+            double x = p.get_x_position();
+            double y = p.get_y_position();
 
-            if ( event.get_mark_move_x() )
-              x -= event.get_left();
-
-            if ( event.get_mark_move_y() )
-              y += event.get_height() - event.get_bottom();
+            x -= event.get_left();
+            y -= event.get_bottom();
 
             a->add_action
               ( new action_modify_placement
@@ -1437,6 +1564,17 @@ void bf::model_frame::on_bounding_box_change(bounding_box_event& event)
     }
 } // model_frame::on_bounding_box_change()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The bounding_box has been selected.
+ * \param event This event occured.
+ */
+void bf::model_frame::on_bounding_box_selected
+( bounding_box_event& WXUNUSED(event) )
+{
+  set_bounding_box_selection();
+} // model_frame::on_bounding_box_selected()
+
 /*----------------------------------------------------------------------------*/
 BEGIN_EVENT_TABLE(bf::model_frame, wxFrame)
   EVT_ACTIVATE( bf::model_frame::on_activate )
@@ -1460,8 +1598,9 @@ BEGIN_EVENT_TABLE(bf::model_frame, wxFrame)
   EVT_MENU_HIGHLIGHT_ALL( bf::model_frame::on_menu_highlight )
   EVT_MENU_OPEN( bf::model_frame::on_open_menu )
 
-  EVT_MENU( bf::model_frame::ID_WIREFRAME,
-            bf::model_frame::on_wireframe )
+  EVT_MENU( bf::model_frame::ID_WIREFRAME, bf::model_frame::on_wireframe )
+  EVT_MENU( bf::model_frame::ID_GRAPHISM, bf::model_frame::on_graphic )
+  EVT_MENU( bf::model_frame::ID_TEXT, bf::model_frame::on_text )
 
   EVT_MENU( wxID_ZOOM_100,
             bf::model_frame::on_zoom_100)
@@ -1494,6 +1633,12 @@ BEGIN_EVENT_TABLE(bf::model_frame, wxFrame)
                              bf::model_frame::on_mark_change )
   EVT_PLACEMENT_MOVE( bf::model_frame::ID_MODEL_VIEW,
                       bf::model_frame::on_mark_move )
+  EVT_PLACEMENT_SIZE( bf::model_frame::ID_MODEL_VIEW,
+                      bf::model_frame::on_mark_size )
   EVT_BOUNDING_BOX_CHANGE( bf::model_frame::ID_MODEL_VIEW,
                            bf::model_frame::on_bounding_box_change )
+  EVT_BOUNDING_BOX_SELECTED( bf::model_frame::ID_MODEL_VIEW,
+                             bf::model_frame::on_bounding_box_selected )
+  EVT_MOUSEWHEEL( bf::model_frame::on_mouse_wheel_rotation )
+
 END_EVENT_TABLE()
