@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -126,7 +126,7 @@ void bf::model_view_ctrl::auto_zoom()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Toggle the value of the wiriframe drawing.
+ * \brief Toggle the value of the wireframe drawing.
  */
 void bf::model_view_ctrl::toggle_wireframe_mode()
 {
@@ -142,6 +142,42 @@ bool bf::model_view_ctrl::get_wireframe_drawing() const
   return m_model_view->get_wireframe_drawing();
 } // model_view_ctrl::get_wireframe_drawing()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Toggle the value of the graphic drawing.
+ */
+void bf::model_view_ctrl::toggle_graphic_mode()
+{
+  m_model_view->toggle_graphic_mode();
+} // model_view_ctrl::toggle_graphic_mode()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the sprites of the marks are drawn.
+ */
+bool bf::model_view_ctrl::get_graphic_drawing() const
+{
+  return m_model_view->get_graphic_drawing();
+} // model_view_ctrl::get_graphic_drawing()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Toggle the value of the text drawing.
+ */
+void bf::model_view_ctrl::toggle_text_mode()
+{
+  m_model_view->toggle_text_mode();
+} // model_view_ctrl::toggle_text_mode()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the name and the function of the marks are drawn.
+ */
+bool bf::model_view_ctrl::get_text_drawing() const
+{
+  return m_model_view->get_text_drawing();
+} // model_view_ctrl::get_text_drawing()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Create the controls.
@@ -246,14 +282,30 @@ void bf::model_view_ctrl::on_mark_change(mark_event& event)
  * \brief The selected mark move.
  * \param event This event occured.
  */
-void bf::model_view_ctrl::on_placement_change(placement_event& event)
+void bf::model_view_ctrl::on_placement_move(placement_event& event)
 {
   placement_event e
-     ( event.get_label(), event.get_left(), event.get_bottom(),
-       placement_event::move_event_type, GetId() );
+    ( event.get_label(), event.get_x(), event.get_y(),
+      event.get_width(), event.get_height(),
+      placement_event::move_event_type, GetId() );
   e.SetEventObject(this);
   ProcessEvent(e);
-} // model_view_ctrl::on_placement_change()
+} // model_view_ctrl::on_placement_move()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The selected mark is resized.
+ * \param event This event occured.
+ */
+void bf::model_view_ctrl::on_placement_size(placement_event& event)
+{
+  placement_event e
+    ( event.get_label(), event.get_x(), event.get_y(),
+      event.get_width(), event.get_height(),
+      placement_event::size_event_type, GetId() );
+  e.SetEventObject(this);
+  ProcessEvent(e);
+} // model_view_ctrl::on_placement_size()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -265,12 +317,26 @@ void bf::model_view_ctrl::on_bounding_box_change(bounding_box_event& event)
   bounding_box_event e
      ( event.get_left(), event.get_bottom(),
        event.get_width(), event.get_height(),
-       event.get_mark_move_x(), event.get_mark_move_y(),
        bounding_box_event::change_event_type, GetId() );
   e.SetEventObject(this);
   ProcessEvent(e);
 } // model_view_ctrl::on_bounding_box_change()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The bounding box has been selected.
+ * \param event This event occured.
+ */
+void bf::model_view_ctrl::on_bounding_box_selection(bounding_box_event& event)
+{
+  bounding_box_event e
+     ( event.get_left(), event.get_bottom(),
+       event.get_width(), event.get_height(),
+       bounding_box_event::select_event_type, GetId() );
+  e.SetEventObject(this);
+  ProcessEvent(e);
+} // model_view_ctrl::on_bounding_box_selection()
+
 /*----------------------------------------------------------------------------*/
 BEGIN_EVENT_TABLE(bf::model_view_ctrl, wxPanel)
   EVT_SCROLL( bf::model_view_ctrl::on_scroll )
@@ -278,7 +344,11 @@ BEGIN_EVENT_TABLE(bf::model_view_ctrl, wxPanel)
   EVT_MARK_SELECTION_CHANGE( bf::model_view_ctrl::ID_MODEL_VIEW,
                              bf::model_view_ctrl::on_mark_change )
   EVT_PLACEMENT_MOVE( bf::model_view_ctrl::ID_MODEL_VIEW,
-                      bf::model_view_ctrl::on_placement_change )
+                      bf::model_view_ctrl::on_placement_move )
+  EVT_PLACEMENT_SIZE( bf::model_view_ctrl::ID_MODEL_VIEW,
+                      bf::model_view_ctrl::on_placement_size )
   EVT_BOUNDING_BOX_CHANGE( bf::model_view_ctrl::ID_MODEL_VIEW,
                            bf::model_view_ctrl::on_bounding_box_change )
+  EVT_BOUNDING_BOX_SELECTED( bf::model_view_ctrl::ID_MODEL_VIEW,
+                             bf::model_view_ctrl::on_bounding_box_selection )
 END_EVENT_TABLE()
