@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -44,8 +44,35 @@ bf::snapshot::snapshot()
     m_x_alignment_value(0), m_y_alignment("align_bottom"),
     m_y_alignment_value(0)
 {
+
 } // snapshot::get_date()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Copy constructor.
+ * \param that The instance to copy from.
+ * \param marks The copies of the marks of that to use in the copy of the
+ *        snapshot.
+ */
+bf::snapshot::snapshot
+( const snapshot& that, const std::map<const mark*, const mark*>& marks )
+  : m_date(that.m_date), m_function(that.m_function), m_sound(that.m_sound),
+    m_width(that.m_width), m_height(that.m_height),
+    m_x_alignment(that.m_x_alignment),
+    m_x_alignment_value(that.m_x_alignment_value),
+    m_y_alignment(that.m_y_alignment),
+    m_y_alignment_value(that.m_y_alignment_value)
+{
+  placement_list::const_iterator it;
+
+  for ( it=that.m_placement.begin(); it!=that.m_placement.end(); ++it )
+    {
+      m_placement.push_back
+        ( mark_placement(marks.find(it->get_mark())->second) );
+      m_placement.back().copy(*it);
+    }
+} // snapshot::snapshot()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the date.
@@ -91,7 +118,7 @@ bool bf::snapshot::has_mark( const std::string& mark_label ) const
  * \param m The mark for which we want the placement.
  * \pre There is such a mark \a m in the snapshot.
  */
-bf::mark_placement& bf::snapshot::get_placement( mark* m )
+bf::mark_placement& bf::snapshot::get_placement( const mark* m )
 {
   CLAW_PRECOND( has_mark(m) );
 
@@ -220,15 +247,15 @@ void bf::snapshot::get_bounds
   const_mark_placement_iterator it;
   const const_mark_placement_iterator eit( mark_placement_end() );
 
-  min_x = std::numeric_limits<double>::infinity();
-  min_y = std::numeric_limits<double>::infinity();
-  max_x = -std::numeric_limits<double>::infinity();
-  max_y = -std::numeric_limits<double>::infinity();
+  min_x = 0;
+  min_y = 0;
+  max_x = m_width;
+  max_y = m_height;
 
   for (it=mark_placement_begin(); it!=eit; ++it)
     {
-      const double x( it->get_position_x() );
-      const double y( it->get_position_y() );
+      const double x( it->get_x_position() );
+      const double y( it->get_y_position() );
       double w(0);
       double h(0);
 
@@ -396,18 +423,10 @@ void bf::snapshot::compile
  * \brief Get an iterator on the placement of a given mark.
  * \param m The mark for which we want the iterator.
  */
-bf::snapshot::placement_list::iterator bf::snapshot::get_iterator( mark* m )
+bf::snapshot::placement_list::iterator
+bf::snapshot::get_iterator( const mark* m )
 {
-  placement_list::iterator it( m_placement.begin() );
-  bool found(false);
-
-  while ( !found && (it!=m_placement.end()) )
-    if ( it->get_mark() == m )
-      found = true;
-    else
-      ++it;
-
-  return it;
+  return get_iterator(m->get_label());
 } // snapshot::get_iterator()
 
 /*----------------------------------------------------------------------------*/
@@ -418,16 +437,7 @@ bf::snapshot::placement_list::iterator bf::snapshot::get_iterator( mark* m )
 bf::snapshot::placement_list::const_iterator
 bf::snapshot::get_const_iterator( const mark* m ) const
 {
-  placement_list::const_iterator it( m_placement.begin() );
-  bool found(false);
-
-  while ( !found && (it!=m_placement.end()) )
-    if ( it->get_mark() == m )
-      found = true;
-    else
-      ++it;
-
-  return it;
+  return get_const_iterator(m->get_label());
 } // snapshot::get_const_iterator()
 
 /*----------------------------------------------------------------------------*/
