@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -24,10 +24,12 @@
 /**
  * \file bf/code/snapshot_frame.cpp
  * \brief Implementation of the bf::snapshot_frame class.
- * \author Sbastien Angibaud
+ * \author Sébastien Angibaud
  */
 #include "bf/snapshot_frame.hpp"
 
+#include "bf/accordion.hpp"
+#include "bf/easing_combo_popup.hpp"
 #include "bf/gui_model.hpp"
 #include "bf/mark.hpp"
 #include "bf/model_frame.hpp"
@@ -43,6 +45,13 @@
 #include "bf/history/action_modify_snapshot_alignment.hpp"
 #include "bf/history/action_modify_snapshot_size.hpp"
 #include "bf/history/action_modify_snapshot_sound.hpp"
+#include "bf/history/action_set_angle_easing.hpp"
+#include "bf/history/action_set_height_easing.hpp"
+#include "bf/history/action_set_placement_function.hpp"
+#include "bf/history/action_set_placement_size.hpp"
+#include "bf/history/action_set_width_easing.hpp"
+#include "bf/history/action_set_x_easing.hpp"
+#include "bf/history/action_set_y_easing.hpp"
 #include "bf/history/action_group.hpp"
 
 #include <limits>
@@ -102,59 +111,158 @@ void bf::snapshot_frame::update_mark( )
  */
 void bf::snapshot_frame::create_controls()
 {
-  create_member_controls();
-  create_sizer_controls();
+  accordion* a = new accordion( this, wxVERTICAL );
+
+  create_member_controls(a);
+  create_sizer_controls(a);
 } // snapshot_frame::create_controls()
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Create the controls for which we keep a reference.
+ * \param a The accordion in which the groups are added.
  */
-void bf::snapshot_frame::create_member_controls()
+void bf::snapshot_frame::create_member_controls( accordion* a )
 {
-  m_date_button = new wxButton( this, IDC_DATE_CTRL, wxT("0"));
+  create_snapshot_controls(a);
+  create_marks_controls(a);
+  create_sound_controls(a);
+  create_item_box_controls(a);
 
-  m_function_button = new wxButton( this, IDC_FUNCTION, wxEmptyString );
+  enable_controls(false);
+} // snapshot_frame::create_member_controls()
 
-  m_mark_choice = new wxChoice( this, IDC_MARK_CHOICE );
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the controls and add them in sizers.
+ * \param a The accordion in which the groups are added.
+ */
+void bf::snapshot_frame::create_sizer_controls( accordion* a )
+{
+  wxBoxSizer* sizer = new wxBoxSizer( wxVERTICAL );
 
-  m_mark_left_spin = new spin_ctrl<double>
-    ( this, IDC_MARK_PLACEMENT, wxDefaultPosition,
-      wxDefaultSize, 0, - std::numeric_limits<double>::infinity(),
+  a->add( create_snapshot_sizer(a), _("Snapshot") );
+  a->add( create_marks_sizer(a), _("Mark") );
+  a->add( create_sound_sizer(a), _("Sound") );
+  a->add( create_item_box_sizer(a), _("Bounding box") );
+
+  sizer->Add( a, 1, wxEXPAND );
+  SetSizer(sizer);
+} // snapshot_frame::create_sizer_controls()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the controls for the snapshot.
+ * \param parent The parent window of the created controls.
+ */
+void bf::snapshot_frame::create_snapshot_controls( wxWindow* parent )
+{
+  m_date_button = new wxButton( parent, IDC_DATE_CTRL, wxT("0"));
+  m_function_button = new wxButton( parent, IDC_FUNCTION, wxEmptyString );
+} // snapshot_frame::create_snapshot_controls()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the controls for the marks.
+ * \param parent The parent window of the created controls.
+ */
+void bf::snapshot_frame::create_marks_controls( wxWindow* parent )
+{
+  m_mark_choice = new wxChoice( parent, IDC_MARK_CHOICE );
+
+  m_mark_left_spin =
+    new spin_ctrl<double>
+    ( parent, IDC_MARK_PLACEMENT, wxDefaultPosition, wxDefaultSize, 0,
+      -std::numeric_limits<double>::infinity(),
       std::numeric_limits<double>::infinity(), 0, 1 );
-  m_mark_bottom_spin = new spin_ctrl<double>
-    ( this, IDC_MARK_PLACEMENT, wxDefaultPosition,
-      wxDefaultSize, 0, - std::numeric_limits<double>::infinity(),
+  m_mark_bottom_spin =
+    new spin_ctrl<double>
+    ( parent, IDC_MARK_PLACEMENT, wxDefaultPosition, wxDefaultSize, 0,
+      -std::numeric_limits<double>::infinity(),
       std::numeric_limits<double>::infinity(), 0, 1  );
-  m_mark_depth_spin = new wxSpinCtrl( this, IDC_MARK_PLACEMENT );
-  m_mark_angle_spin = new spin_ctrl<double>
-    ( this, IDC_MARK_PLACEMENT, wxDefaultPosition,
-      wxDefaultSize, 0, - std::numeric_limits<double>::infinity(),
+  m_mark_width_spin =
+    new spin_ctrl<double>
+    ( parent, IDC_MARK_SIZE, wxDefaultPosition, wxDefaultSize, 0,
+      -std::numeric_limits<double>::infinity(),
+      std::numeric_limits<double>::infinity(), 0, 1 );
+  m_mark_height_spin =
+    new spin_ctrl<double>
+    ( parent, IDC_MARK_SIZE, wxDefaultPosition, wxDefaultSize, 0,
+      -std::numeric_limits<double>::infinity(),
+      std::numeric_limits<double>::infinity(), 0, 1  );
+  m_mark_depth_spin = new wxSpinCtrl( parent, IDC_MARK_PLACEMENT );
+  m_mark_angle_spin =
+    new spin_ctrl<double>
+    ( parent, IDC_MARK_PLACEMENT, wxDefaultPosition, wxDefaultSize, 0,
+      -std::numeric_limits<double>::infinity(),
       std::numeric_limits<double>::infinity(), 0, 0.01 );
 
+  m_mark_visible_box = new wxCheckBox( parent, IDC_VISIBILITY, _("Visible") );
+  m_collision_function_button =
+    new wxButton( parent, IDC_MARK_FUNCTION, wxEmptyString );
   m_mark_depth_spin->SetRange
     ( std::numeric_limits<int>::min(), std::numeric_limits<int>::max() );
-  m_mark_visible_box = new wxCheckBox( this, IDC_VISIBILITY,_("Visible") );
 
-  m_sound_button = new wxButton(this, IDC_SOUND_FILE, wxT("..."));
-  m_sound_path = new wxTextCtrl(this, IDC_SOUND_TEXT);
+  m_mark_x_easing = create_easing_combo( parent );
+  m_mark_x_easing->GetPopupControl()->GetControl()->Connect
+    ( wxEVT_COMMAND_COMBOBOX_SELECTED,
+      wxCommandEventHandler(snapshot_frame::on_x_easing), NULL, this );
+
+  m_mark_y_easing = create_easing_combo( parent );
+  m_mark_y_easing->GetPopupControl()->GetControl()->Connect
+    ( wxEVT_COMMAND_COMBOBOX_SELECTED,
+      wxCommandEventHandler(snapshot_frame::on_y_easing), NULL, this );
+
+  m_mark_width_easing = create_easing_combo( parent );
+  m_mark_width_easing->GetPopupControl()->GetControl()->Connect
+    ( wxEVT_COMMAND_COMBOBOX_SELECTED,
+      wxCommandEventHandler(snapshot_frame::on_width_easing), NULL, this );
+
+  m_mark_height_easing = create_easing_combo( parent );
+  m_mark_height_easing->GetPopupControl()->GetControl()->Connect
+    ( wxEVT_COMMAND_COMBOBOX_SELECTED,
+      wxCommandEventHandler(snapshot_frame::on_height_easing), NULL, this );
+
+  m_mark_angle_easing = create_easing_combo( parent );
+  m_mark_angle_easing->GetPopupControl()->GetControl()->Connect
+    ( wxEVT_COMMAND_COMBOBOX_SELECTED,
+      wxCommandEventHandler(snapshot_frame::on_angle_easing), NULL, this );
+} // snapshot_frame::create_marks_controls()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the controls for the sound.
+ * \param parent The parent window of the created controls.
+ */
+void bf::snapshot_frame::create_sound_controls( wxWindow* parent )
+{
+  m_sound_button = new wxButton(parent, IDC_SOUND_FILE, wxT("…"));
+  m_sound_path = new wxTextCtrl(parent, IDC_SOUND_TEXT);
   m_globally_sound_box =
-    new wxCheckBox( this, IDC_GLOBALLY_SOUND,_("Play globally") );
+    new wxCheckBox( parent, IDC_GLOBALLY_SOUND, _("Play globally") );
+} // snapshot_frame::create_sound_controls()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the controls for the item box.
+ * \param parent The parent window of the created controls.
+ */
+void bf::snapshot_frame::create_item_box_controls( wxWindow* parent )
+{
   m_width_spin = new spin_ctrl<double>
-    ( this, IDC_SIZE, wxDefaultPosition,
+    ( parent, IDC_SIZE, wxDefaultPosition,
       wxDefaultSize, 0, 0, std::numeric_limits<double>::infinity(), 0, 1 );
   m_height_spin = new spin_ctrl<double>
-    ( this, IDC_SIZE, wxDefaultPosition,
+    ( parent, IDC_SIZE, wxDefaultPosition,
       wxDefaultSize, 0, 0, std::numeric_limits<double>::infinity(), 0, 1 );
 
    m_x_alignment_value_spin = new spin_ctrl<double>
-    ( this, IDC_ALIGNMENT, wxDefaultPosition,
+    ( parent, IDC_ALIGNMENT, wxDefaultPosition,
       wxDefaultSize, 0, -std::numeric_limits<double>::infinity(),
       std::numeric_limits<double>::infinity(), 0, 1 );
 
   m_y_alignment_value_spin = new spin_ctrl<double>
-    ( this, IDC_ALIGNMENT, wxDefaultPosition,
+    ( parent, IDC_ALIGNMENT, wxDefaultPosition,
       wxDefaultSize, 0, -std::numeric_limits<double>::infinity(),
       std::numeric_limits<double>::infinity(), 0, 1 );
 
@@ -163,133 +271,118 @@ void bf::snapshot_frame::create_member_controls()
   array.Add(wxT("align_center"));
   array.Add(wxT("align_top"));
   m_y_alignment_choice = new wxChoice
-    ( this, IDC_ALIGNMENT, wxDefaultPosition, wxDefaultSize, array );
+    ( parent, IDC_ALIGNMENT, wxDefaultPosition, wxDefaultSize, array );
 
   array.Clear();
   array.Add(wxT("align_left"));
   array.Add(wxT("align_center"));
   array.Add(wxT("align_right"));
+
   m_x_alignment_choice = new wxChoice
-    ( this, IDC_ALIGNMENT, wxDefaultPosition, wxDefaultSize, array );
-
-  enable_controls(false);
-} // snapshot_frame::create_member_controls()
+    ( parent, IDC_ALIGNMENT, wxDefaultPosition, wxDefaultSize, array );
+} // snapshot_frame::create_item_box_controls()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Create the controls and add them in sizers.
+ * \brief Create the sizer for the snapshot part part.
+ * \param parent The parent window of the created controls.
  */
-void bf::snapshot_frame::create_sizer_controls()
-{
-   wxBoxSizer* sizer = new wxBoxSizer( wxVERTICAL );
-
-  // width
-  wxBoxSizer* s_sizer = new wxBoxSizer( wxHORIZONTAL );
-  s_sizer->Add( new wxStaticText(this, wxID_ANY, _("Date:")),
-                0, wxEXPAND | wxALL, 5 );
-  s_sizer->Add( m_date_button, 0, wxEXPAND | wxALIGN_LEFT );
-  sizer->Add( s_sizer, 0, wxEXPAND );
-
-  s_sizer = new wxBoxSizer( wxHORIZONTAL );
-  s_sizer->Add( new wxStaticText(this, wxID_ANY, _("Function:")),
-                0, wxEXPAND | wxALL, 5 );
-  s_sizer->Add( m_function_button, 1, wxEXPAND | wxALIGN_LEFT );
-  sizer->Add( s_sizer, 0, wxEXPAND );
-
-  sizer->Add( create_marks_sizer(), 0, wxEXPAND );
-
-  sizer->Add( create_sound_sizer(), 0, wxEXPAND );
-
-  wxStaticBoxSizer* static_sizer;
-  static_sizer = new wxStaticBoxSizer( wxHORIZONTAL, this, _("Size") );
-  static_sizer->Add( new wxStaticText(this, wxID_ANY, _("Width:")), 0,
-                     wxALIGN_CENTER_VERTICAL );
-  static_sizer->Add( m_width_spin, 1 );
-  static_sizer->AddSpacer(5);
-  static_sizer->Add( new wxStaticText(this, wxID_ANY, _("Height:")), 0,
-                     wxALIGN_CENTER_VERTICAL );
-  static_sizer->Add( m_height_spin, 1 );
-  sizer->Add( static_sizer, 0, wxEXPAND );
-
-  static_sizer =
-    new wxStaticBoxSizer( wxVERTICAL, this, _("Alignments") );
-  s_sizer = new wxBoxSizer( wxHORIZONTAL );
-  s_sizer->Add( new wxStaticText(this, wxID_ANY, _("X:")), 0,
-                     wxALIGN_CENTER_VERTICAL );
-  s_sizer->Add( m_x_alignment_choice, 1, wxALL );
-  s_sizer->AddSpacer(5);
-  s_sizer->Add( new wxStaticText(this, wxID_ANY, _("Gap:")), 0,
-                     wxALIGN_CENTER_VERTICAL );
-  s_sizer->Add( m_x_alignment_value_spin, 1 );
-  static_sizer->Add( s_sizer, 0, wxEXPAND );
-  s_sizer = new wxBoxSizer( wxHORIZONTAL );
-  s_sizer->Add( new wxStaticText(this, wxID_ANY, _("Y:")), 0,
-                     wxALIGN_CENTER_VERTICAL );
-  s_sizer->Add( m_y_alignment_choice, 1, wxALL );
-  s_sizer->AddSpacer(5);
-  s_sizer->Add( new wxStaticText(this, wxID_ANY, _("Gap:")), 0,
-                     wxALIGN_CENTER_VERTICAL );
-  s_sizer->Add( m_y_alignment_value_spin, 1 );
-
-  static_sizer->Add( s_sizer, 0, wxEXPAND );
-  sizer->Add( static_sizer, 0, wxEXPAND );
-
-  SetSizer(sizer);
-} // snapshot_frame::create_sizer_controls()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Create the controls and the sizer for marks.
- */
-wxSizer* bf::snapshot_frame::create_marks_sizer()
+wxSizer* bf::snapshot_frame::create_snapshot_sizer( wxWindow* parent )
 {
   wxStaticBoxSizer* result =
-    new wxStaticBoxSizer( wxVERTICAL, this, _("Marks") );
+    new wxStaticBoxSizer( wxVERTICAL, parent, _("Snapshot") );
 
-  wxBoxSizer* s_sizer = new wxBoxSizer( wxHORIZONTAL );
-  s_sizer->Add
-    ( new wxStaticText(this, wxID_ANY, _("Mark:")),
-      0, wxALIGN_CENTRE_VERTICAL | wxALL, 5 );
-  s_sizer->Add( m_mark_choice, 1, wxALL, 5 );
-  result->Add( s_sizer, 0, wxEXPAND, 0 );
+  wxBoxSizer* sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Date:")), 0,
+      wxALIGN_CENTER_VERTICAL );
+  sizer->Add( m_date_button, 1, wxEXPAND );
+  result->Add( sizer, 0, wxEXPAND );
 
-  s_sizer = new wxBoxSizer( wxHORIZONTAL );
-  s_sizer->Add
-    ( new wxStaticText(this, wxID_ANY, _("X:")),
-      0, wxALIGN_CENTRE_VERTICAL | wxALL, 5 );
-  s_sizer->Add( m_mark_left_spin, 1, wxALL, 5 );
-  s_sizer->Add
-    ( new wxStaticText(this, wxID_ANY, _("Y:")),
-      0, wxALIGN_CENTRE_VERTICAL | wxALL, 5 );
-  s_sizer->Add( m_mark_bottom_spin, 1, wxALL, 5 );
-  result->Add( s_sizer, 0, wxEXPAND, 0 );
+  sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Function:")), 0,
+      wxALIGN_CENTER_VERTICAL );
+  sizer->Add( m_function_button, 1, wxEXPAND );
+  result->Add( sizer, 0, wxEXPAND );
 
-  s_sizer = new wxBoxSizer( wxHORIZONTAL );
-  s_sizer->Add
-    ( new wxStaticText(this, wxID_ANY, _("Depth:")),
-      0, wxALIGN_CENTRE_VERTICAL | wxALL, 5 );
-  s_sizer->Add( m_mark_depth_spin, 1, wxALL, 5 );
-  s_sizer->Add
-    ( new wxStaticText(this, wxID_ANY, _("Angle:")),
-      0, wxALIGN_CENTRE_VERTICAL | wxALL, 5 );
-  s_sizer->Add( m_mark_angle_spin, 1, wxALL, 5 );
-  result->Add( s_sizer, 0, wxEXPAND, 0 );
+  return result;
+} // snapshot_frame::create_snapshot_sizer()
 
-  s_sizer = new wxBoxSizer( wxHORIZONTAL );
-  s_sizer->Add( m_mark_visible_box, 0, wxALL, 5 );
-  result->Add( s_sizer, 0, wxEXPAND, 0 );
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the sizer for the marks part.
+ * \param parent The parent window of the created controls.
+ */
+wxSizer* bf::snapshot_frame::create_marks_sizer( wxWindow* parent )
+{
+  wxStaticBoxSizer* result =
+    new wxStaticBoxSizer( wxVERTICAL, parent, _("Marks") );
+
+  wxBoxSizer* sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Mark:")), 0,
+      wxALIGN_CENTRE_VERTICAL | wxALL );
+  sizer->Add( m_mark_choice, 1, wxALL );
+  sizer->Add( m_mark_visible_box, 0, wxALIGN_CENTRE_VERTICAL | wxALL );
+  result->Add( sizer, 0, wxEXPAND );
+
+  sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("X:")), 0, wxALIGN_CENTRE_VERTICAL );
+  sizer->Add( m_mark_left_spin, 1 );
+  sizer->Add( m_mark_x_easing, 1 );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Y:")), 0,
+      wxALIGN_CENTRE_VERTICAL | wxLEFT, 5 );
+  sizer->Add( m_mark_bottom_spin, 1 );
+  sizer->Add( m_mark_y_easing, 1 );
+  result->Add( sizer, 0, wxEXPAND | wxTOP, 3 );
+
+  sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add
+    ( new wxStaticText
+      (parent, wxID_ANY, _("Width:")), 0, wxALIGN_CENTRE_VERTICAL );
+  sizer->Add( m_mark_width_spin, 1 );
+  sizer->Add( m_mark_width_easing, 1 );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Height:")), 0,
+      wxALIGN_CENTRE_VERTICAL | wxLEFT, 5 );
+  sizer->Add( m_mark_height_spin, 1 );
+  sizer->Add( m_mark_height_easing, 1 );
+  result->Add( sizer, 0, wxEXPAND | wxTOP, 3 );
+
+  sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Depth:")), 0,
+      wxALIGN_CENTRE_VERTICAL );
+  sizer->Add( m_mark_depth_spin, 1 );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Angle:")), 0,
+      wxALIGN_CENTRE_VERTICAL | wxLEFT, 5 );
+  sizer->Add( m_mark_angle_spin, 1 );
+  sizer->Add( m_mark_angle_easing, 1 );
+  result->Add( sizer, 0, wxEXPAND | wxTOP, 3 );
+
+  sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Collision function:")), 0,
+      wxALIGN_CENTRE_VERTICAL );
+  sizer->Add( m_collision_function_button, 1 );
+  result->Add( sizer, 0, wxEXPAND | wxTOP, 3 );
 
   return result;
 } // snapshot_frame::create_marks_sizer()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Create the controls and the sizer for sound.
+ * \brief Create the sizer for sound part.
+ * \param parent The parent window of the created controls.
  */
-wxSizer* bf::snapshot_frame::create_sound_sizer()
+wxSizer* bf::snapshot_frame::create_sound_sizer( wxWindow* parent )
 {
   wxStaticBoxSizer* result =
-    new wxStaticBoxSizer( wxVERTICAL, this, _("Sound") );
+    new wxStaticBoxSizer( wxVERTICAL, parent, _("Sound") );
 
   wxBoxSizer* s_sizer = new wxBoxSizer( wxHORIZONTAL );
   s_sizer = new wxBoxSizer( wxHORIZONTAL );
@@ -302,6 +395,77 @@ wxSizer* bf::snapshot_frame::create_sound_sizer()
   return result;
 } // snapshot_frame::create_sound_sizer()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the sizer for sound part.
+ * \param parent The parent window of the created controls.
+ */
+wxSizer* bf::snapshot_frame::create_item_box_sizer( wxWindow* parent )
+{
+  wxStaticBoxSizer* result =
+    new wxStaticBoxSizer( wxVERTICAL, parent, _("Item box") );
+
+  wxBoxSizer* sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Width:")), 0,
+      wxALIGN_CENTER_VERTICAL );
+  sizer->Add( m_width_spin, 1 );
+  sizer->AddSpacer(5);
+  sizer->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Height:")), 0,
+      wxALIGN_CENTER_VERTICAL );
+  sizer->Add( m_height_spin, 1 );
+  result->Add( sizer, 0, wxEXPAND );
+
+  result->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Horizontal alignment policy:")), 0,
+      wxALIGN_CENTER_VERTICAL | wxTOP, 3 );
+
+  sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add( m_x_alignment_choice, 1 );
+  sizer->AddSpacer(5);
+  sizer->Add
+    ( new wxStaticText
+      (parent, wxID_ANY, _("Gap:")), 0, wxALIGN_CENTER_VERTICAL );
+  sizer->Add( m_x_alignment_value_spin, 1 );
+  result->Add( sizer, 0, wxEXPAND );
+
+  result->Add
+    ( new wxStaticText(parent, wxID_ANY, _("Vertical alignment policy:")), 0,
+      wxALIGN_CENTER_VERTICAL | wxTOP, 3 );
+
+  sizer = new wxBoxSizer( wxHORIZONTAL );
+  sizer->Add( m_y_alignment_choice, 1 );
+  sizer->AddSpacer(5);
+  sizer->Add
+    ( new wxStaticText
+      (parent, wxID_ANY, _("Gap:")), 0, wxALIGN_CENTER_VERTICAL );
+  sizer->Add( m_y_alignment_value_spin, 1 );
+
+  result->Add( sizer, 0, wxEXPAND );
+
+  return result;
+} // snapshot_frame::create_item_box_sizer()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create a combo for the easing functions.
+ * \param parent The parent control of the combo.
+ */
+wxComboCtrl*
+bf::snapshot_frame::create_easing_combo( wxWindow* parent )
+{
+  wxComboCtrl* result =
+    new wxComboCtrl
+    ( parent, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize,
+      wxCB_READONLY );
+  result->SetPopupControl( new easing_combo_popup() );
+
+  result->SetPopupMinWidth( 300 );
+
+  return result;
+} // snapshot_frame::create_easing_combo()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Fill the list with the marks of the model.
@@ -384,19 +548,48 @@ void bf::snapshot_frame::fill_mark()
 
               mark_placement p = m_snapshot->get_placement(m->get_label());
 
-              m_mark_left_spin->SetValue(p.get_position_x());
-              m_mark_bottom_spin->SetValue(p.get_position_y());
+              m_mark_left_spin->SetValue(p.get_x_position());
+              m_mark_x_easing->SetValue
+                ( std_to_wx_string(p.get_x_easing().to_string()) );
+
+              m_mark_bottom_spin->SetValue(p.get_y_position());
+              m_mark_y_easing->SetValue
+                ( std_to_wx_string(p.get_y_easing().to_string()) );
+
+              m_mark_width_spin->SetValue(p.get_width());
+              m_mark_width_easing->SetValue
+                ( std_to_wx_string(p.get_width_easing().to_string()) );
+
+              m_mark_height_spin->SetValue(p.get_height());
+              m_mark_height_easing->SetValue
+                ( std_to_wx_string(p.get_height_easing().to_string()) );
+
               m_mark_depth_spin->SetValue(p.get_depth_position());
+
               m_mark_angle_spin->SetValue(p.get_angle());
+              m_mark_angle_easing->SetValue
+                ( std_to_wx_string(p.get_angle_easing().to_string()) );
+
               m_mark_visible_box->SetValue(p.is_visible());
+              m_collision_function_button->SetLabel
+                ( std_to_wx_string(p.get_collision_function()) );
             }
         }
 
   m_mark_left_spin->Enable(enable);
   m_mark_bottom_spin->Enable(enable);
+  m_mark_width_spin->Enable(enable);
+  m_mark_height_spin->Enable(enable);
   m_mark_depth_spin->Enable(enable);
   m_mark_angle_spin->Enable(enable);
   m_mark_visible_box->Enable(enable);
+  m_collision_function_button->Enable(enable);
+
+  m_mark_x_easing->Enable(enable);
+  m_mark_y_easing->Enable(enable);
+  m_mark_width_easing->Enable(enable);
+  m_mark_height_easing->Enable(enable);
+  m_mark_angle_easing->Enable(enable);
 } // snapshot_frame::fill_mark()
 
 /*----------------------------------------------------------------------------*/
@@ -444,7 +637,7 @@ void bf::snapshot_frame::size_change()
 /**
  * \brief The sound has changed.
  */
-void  bf::snapshot_frame::sound_change()
+void bf::snapshot_frame::sound_change()
 {
   sound_description sound;
 
@@ -459,7 +652,7 @@ void  bf::snapshot_frame::sound_change()
  * \brief Enable or disable the controls.
  * \param enable Tell if the controls have to be enabled.
  */
-void  bf::snapshot_frame::enable_controls(bool enable)
+void bf::snapshot_frame::enable_controls(bool enable)
 {
   m_date_button->Enable(enable);
   m_mark_choice->Enable(enable);
@@ -474,6 +667,12 @@ void  bf::snapshot_frame::enable_controls(bool enable)
   m_y_alignment_choice->Enable(enable);
   m_x_alignment_value_spin->Enable(enable);
   m_y_alignment_value_spin->Enable(enable);
+
+  m_mark_x_easing->Enable(enable);
+  m_mark_y_easing->Enable(enable);
+  m_mark_width_easing->Enable(enable);
+  m_mark_height_easing->Enable(enable);
+  m_mark_angle_easing->Enable(enable);
 } // snapshot_frame::enable_controls()
 
 /*----------------------------------------------------------------------------*/
@@ -560,7 +759,6 @@ void bf::snapshot_frame::on_alignment_choice_change
   alignment_change();
 } // snapshot_frame::on_alignment_choice_change()
 
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief The placement has been changed.
@@ -572,6 +770,43 @@ void bf::snapshot_frame::on_placement_change
   placement_change();
 } // snapshot_frame::on_placement_change()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The size of the mark placement has been modified.
+ * \param event The event that occured.
+ */
+void bf::snapshot_frame::on_mark_size( spin_event<double>& WXUNUSED(event) )
+{
+  mark* m( m_model_frame->get_model().get_main_mark_selection() );
+
+  m_model_frame->do_action
+    ( new action_set_placement_size
+      ( m_snapshot, m, m_mark_width_spin->GetValue(),
+        m_mark_height_spin->GetValue() ) );
+} // snapshot_frame::on_mark_size()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The user asked to change the collision function of a mark.
+ * \param event The event that occured.
+ */
+void bf::snapshot_frame::on_mark_function( wxCommandEvent& WXUNUSED(event) )
+{
+  mark* m( m_model_frame->get_model().get_main_mark_selection() );
+  wxTextEntryDialog dlg
+    (this, _("Function:"), _("Set mark's collision function"),
+     std_to_wx_string(m_snapshot->get_placement(m).get_collision_function()) );
+
+  if ( dlg.ShowModal() == wxID_OK )
+    {
+      m_model_frame->do_action
+        ( new action_set_placement_function
+          (m_snapshot, m, wx_to_std_string(dlg.GetValue())) );
+
+      m_collision_function_button->SetLabel( dlg.GetValue() );
+    }
+} // snapshot_frame::on_mark_function()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief The alignment has been changed.
@@ -621,7 +856,7 @@ void bf::snapshot_frame::on_visibility_change( wxCommandEvent& WXUNUSED(event) )
 void bf::snapshot_frame::on_function_change( wxCommandEvent& WXUNUSED(event) )
 {
   wxTextEntryDialog dlg
-    (this, _("Function:"), _("Set function"),
+    (this, _("Function:"), _("Set snapshot function"),
      std_to_wx_string(m_snapshot->get_function()) );
 
   if ( dlg.ShowModal() == wxID_OK )
@@ -655,7 +890,7 @@ void bf::snapshot_frame::on_sound_file_edit( wxCommandEvent& WXUNUSED(event) )
   std::string p = wx_to_std_string(m_sound_path->GetValue());
   path_configuration::get_instance().get_full_path(p);
 
-  wxFileDialog dlg(this,_("Choose a sound"), wxEmptyString,
+  wxFileDialog dlg(this, _("Choose a sound"), wxEmptyString,
                    std_to_wx_string(p),
                    _("Sound files (*.ogg;*.wav)|*.wav;*.ogg"),
                    wxFD_DEFAULT_STYLE | wxFD_FILE_MUST_EXIST );
@@ -665,7 +900,7 @@ void bf::snapshot_frame::on_sound_file_edit( wxCommandEvent& WXUNUSED(event) )
       std::string new_p = wx_to_std_string( dlg.GetPath() );
       path_configuration::get_instance().get_relative_path(new_p);
 
-      m_sound_path->SetValue(std_to_wx_string(new_p) ) ;
+      m_sound_path->SetValue(std_to_wx_string(new_p) );
 
       sound_change();
     }
@@ -681,6 +916,89 @@ void bf::snapshot_frame::on_sound_text_edit( wxCommandEvent& WXUNUSED(event) )
   sound_change();
 } // snapshot_frame::on_sound_text_edit()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The easing for the x-coordinate has changed.
+ * \param event The event that occured.
+ */
+void bf::snapshot_frame::on_x_easing( wxCommandEvent& event )
+{
+  bear::easing e;
+  e.from_string
+    ( wx_to_std_string(m_mark_x_easing->GetPopupControl()->GetStringValue()) );
+
+  mark* m( m_model_frame->get_model().get_main_mark_selection() );
+
+  m_model_frame->do_action( new action_set_x_easing( m_snapshot, m, e ) );
+} // snapshot_frame::on_x_easing()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The easing for the y-coordinate has changed.
+ * \param event The event that occured.
+ */
+void bf::snapshot_frame::on_y_easing( wxCommandEvent& WXUNUSED(event) )
+{
+  bear::easing e;
+  e.from_string
+    ( wx_to_std_string(m_mark_y_easing->GetPopupControl()->GetStringValue()) );
+
+  mark* m( m_model_frame->get_model().get_main_mark_selection() );
+
+  m_model_frame->do_action( new action_set_y_easing( m_snapshot, m, e ) );
+} // snapshot_frame::on_y_easing()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The easing for the width has changed.
+ * \param event The event that occured.
+ */
+void bf::snapshot_frame::on_width_easing( wxCommandEvent& WXUNUSED(event) )
+{
+  bear::easing e;
+  e.from_string
+    ( wx_to_std_string
+      (m_mark_width_easing->GetPopupControl()->GetStringValue()) );
+
+  mark* m( m_model_frame->get_model().get_main_mark_selection() );
+
+  m_model_frame->do_action( new action_set_width_easing( m_snapshot, m, e ) );
+} // snapshot_frame::on_width_easing()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The easing for the height has changed.
+ * \param event The event that occured.
+ */
+void bf::snapshot_frame::on_height_easing( wxCommandEvent& WXUNUSED(event) )
+{
+  bear::easing e;
+  e.from_string
+    ( wx_to_std_string
+      (m_mark_height_easing->GetPopupControl()->GetStringValue()) );
+
+  mark* m( m_model_frame->get_model().get_main_mark_selection() );
+
+  m_model_frame->do_action( new action_set_height_easing( m_snapshot, m, e ) );
+} // snapshot_frame::on_height_easing()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief The easing for the angle has changed.
+ * \param event The event that occured.
+ */
+void bf::snapshot_frame::on_angle_easing( wxCommandEvent& WXUNUSED(event) )
+{
+  bear::easing e;
+  e.from_string
+    ( wx_to_std_string
+      (m_mark_angle_easing->GetPopupControl()->GetStringValue()) );
+
+  mark* m( m_model_frame->get_model().get_main_mark_selection() );
+
+  m_model_frame->do_action( new action_set_angle_easing( m_snapshot, m, e ) );
+} // snapshot_frame::on_angle_easing()
+
 /*----------------------------------------------------------------------------*/
 BEGIN_EVENT_TABLE(bf::snapshot_frame, wxPanel)
   EVT_CLOSE( bf::snapshot_frame::on_close )
@@ -693,6 +1011,10 @@ BEGIN_EVENT_TABLE(bf::snapshot_frame, wxPanel)
   EVT_SPIN_VALUE_CHANGE(bf::snapshot_frame::IDC_MARK_PLACEMENT,
                         bf::snapshot_frame::on_placement_change,
                         double)
+  EVT_SPIN_VALUE_CHANGE( bf::snapshot_frame::IDC_MARK_SIZE,
+                         bf::snapshot_frame::on_mark_size, double )
+  EVT_BUTTON( bf::snapshot_frame::IDC_MARK_FUNCTION,
+              bf::snapshot_frame::on_mark_function )
   EVT_SPIN_VALUE_CHANGE(bf::snapshot_frame::IDC_ALIGNMENT,
                         bf::snapshot_frame::on_alignment_change,
                         double)
