@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -31,7 +31,7 @@
 
 #include "bf/model.hpp"
 #include "bf/sprite.hpp"
-#include "bf/mark_selection.hpp"
+#include "bf/model_selection.hpp"
 
 #include <map>
 
@@ -62,7 +62,12 @@ namespace bf
     void set_mark_selection( const std::string& label );
     void add_to_mark_selection
     ( const std::string& label, bool is_main_selection=false );
-    void clear_mark_selection();
+
+    bool bounding_box_is_selected() const;
+    bool bounding_box_is_main_selection() const;
+    void set_bounding_box_selection( bool s );
+
+    void clear_selection();
 
     void set_date(double date);
     double get_date() const;
@@ -90,7 +95,7 @@ namespace bf
     action* m_active_action;
 
     /** \brief Name of the main mark selection. */
-    std::map<action*, mark_selection> m_selection;
+    std::map<action*, model_selection> m_selection;
 
     /** \brief Current date. */
     double m_date;
