@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -63,8 +63,8 @@ void bf::action_modify_placement::execute( gui_model& mdl )
 
   mark_placement& p = m_snapshot->get_placement(m_mark);
 
-  double left(p.get_position_x());
-  double bottom(p.get_position_y());
+  double left(p.get_x_position());
+  double bottom(p.get_y_position());
   int depth(p.get_depth_position());
   double angle(p.get_angle());
   bool visible(p.is_visible());
@@ -94,11 +94,11 @@ bool bf::action_modify_placement::is_identity
 {
   mark_placement& p = m_snapshot->get_placement(m_mark);
 
-  return ( (p.get_position_x() == m_left) &&
-           (p.get_position_y() == m_bottom) &&
+  return ( (p.get_x_position() == m_left) &&
+           (p.get_y_position() == m_bottom) &&
            (p.get_depth_position() == m_depth) &&
            (p.get_angle() == m_angle) &&
-           (p.is_visible() == m_visible) ) ;
+           (p.is_visible() == m_visible) );
 } // action_modify_placement::is_identity()
 
 /*----------------------------------------------------------------------------*/
