@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -63,7 +63,7 @@ void bf::action_remove_mark::execute( gui_model& mdl )
  for ( it = mdl.get_action(m_action_name).snapshot_begin();
        it != mdl.get_action(m_action_name).snapshot_end(); ++it )
    m_placements.push_back
-     ( std::pair<double,mark_placement>
+     ( std::pair<double, mark_placement>
        (it->get_date(), it->get_placement(m_mark)));
 
  mdl.remove_mark( m_action_name, m_mark );
@@ -80,7 +80,7 @@ void bf::action_remove_mark::undo( gui_model& mdl )
 
   mdl.add_mark( m_action_name, m_mark );
 
-  std::list< std::pair<double,mark_placement> >::const_iterator it;
+  std::list< std::pair<double, mark_placement> >::const_iterator it;
   for ( it = m_placements.begin(); it != m_placements.end(); ++it )
     {
       CLAW_PRECOND(mdl.get_action(m_action_name).has_snapshot_date(it->first));
@@ -89,7 +89,7 @@ void bf::action_remove_mark::undo( gui_model& mdl )
         (it->first)->get_placement( m_mark );
 
       p.set_position
-        ( it->second.get_position_x(), it->second.get_position_y() );
+        ( it->second.get_x_position(), it->second.get_y_position() );
       p.set_depth_position( it->second.get_depth_position() );
       p.set_angle( it->second.get_angle() );
     }
