@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -76,9 +76,6 @@ namespace bf
 
     void add_model_view( model_frame* m );
 
-    void configure_paths();
-    void update_image_pool();
-
     void on_configuration_menu(wxCommandEvent& event);
     void on_update_image_pool_menu(wxCommandEvent& event);
     void on_new_model(wxCommandEvent& event);
@@ -93,9 +90,6 @@ namespace bf
     /** \brief The configuration of the program. */
     void turn_model_entries( bool enable );
 
-    /** \brief The configuration of the program. */
-    configuration m_config;
-
     /** \brief The properties of the currently edited model. */
     model_properties_ctrl* m_model_properties;
 
