@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -30,6 +30,7 @@
 #define __BF_MARK_LIST_FRAME_HPP__
 
 #include <wx/wx.h>
+#include <string>
 
 namespace bf
 {
@@ -63,6 +64,7 @@ namespace bf
     void create_controls();
     void create_member_controls();
     void create_sizer_controls();
+    void update_controls();
 
     void clear();
     void fill();
@@ -84,6 +86,12 @@ namespace bf
     /** \brief The button to create a new mark. */
     wxButton* m_new_mark_button;
 
+    /** \brief The button to delete a mark. */
+    wxButton* m_delete_mark_button;
+
+    /** \brief The button to edit the properties of a mark. */
+    wxButton* m_properties_mark_button;
+
     DECLARE_EVENT_TABLE()
 
   }; // class mark_list_frame
