@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -30,6 +30,7 @@
 #define __BF_MODEL_EDITOR_HPP__
 
 #include "bf/base_editor_application.hpp"
+#include "bf/configuration.hpp"
 
 namespace bf
 {
@@ -46,18 +47,32 @@ namespace bf
   public:
     model_editor();
 
+    configuration& get_config();
+    const configuration& get_config() const;
+
+    void configure();
+    void update_image_pool() const;
+
+    void compile( const wxString& path ) const;
+    void update( const wxString& path ) const;
+    bool compile_model( const model& mdl, const wxString& path ) const;
+
   private:
     bool do_init_app();
-    void update( const wxString& path ) const;
-    void compile( const wxString& path ) const;
+    bool do_command_line_init();
+    void init_config();
 
     bool check_model( const model& mdl ) const;
-    bool compile_model( const model& mdl, const wxString& path ) const;
+
+    void load_models();
 
   private:
     /** \brief The main window of our program. */
     main_frame* m_main_frame;
 
+    /** \brief The configuration of the program. */
+    configuration m_config;
+
   }; // class model_editor
 } // namespace bf
 
