@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -68,7 +68,9 @@ namespace bf
         ID_TIMER,
         ID_ZOOM,
         ID_MODEL_VIEW,
-        ID_WIREFRAME
+        ID_WIREFRAME,
+        ID_GRAPHISM,
+        ID_TEXT
       }; // enum control_id
 
   public:
@@ -87,7 +89,8 @@ namespace bf
     void reset_active_action();
 
     void set_mark_selection( const std::string& label);
-    void clear_mark_selection();
+    void set_bounding_box_selection();
+    void clear_selection();
 
     void set_date(double date);
 
@@ -117,6 +120,8 @@ namespace bf
     void create_accelerators();
 
     void toggle_wireframe_mode();
+    void toggle_graphic_mode();
+    void toggle_text_mode();
 
     bool check_model();
     void check_model_verbose();
@@ -158,11 +163,14 @@ namespace bf
     void on_menu_highlight(wxMenuEvent& event);
     void on_open_menu(wxMenuEvent& event);
     void on_wireframe(wxCommandEvent& event);
+    void on_graphic(wxCommandEvent& event);
+    void on_text(wxCommandEvent& event);
     void on_zoom_100(wxCommandEvent& event);
     void on_zoom_in(wxCommandEvent& event);
     void on_zoom_out(wxCommandEvent& event);
     void on_zoom_fit(wxCommandEvent& event);
-    void on_zoom_change( wxSpinEvent& event );
+    void on_zoom_change(wxSpinEvent& event);
+    void on_mouse_wheel_rotation(wxMouseEvent& event);
     void on_new_snapshot(wxCommandEvent& event);
     void on_delete_snapshot(wxCommandEvent& event);
     void on_show_properties(wxCommandEvent& event);
@@ -173,7 +181,9 @@ namespace bf
     void on_timer(wxTimerEvent& event);
     void on_mark_change(mark_event& event);
     void on_mark_move(placement_event& event);
+    void on_mark_size(placement_event& event);
     void on_bounding_box_change(bounding_box_event& event);
+    void on_bounding_box_selected(bounding_box_event& event);
 
   private:
     /** \brief The layout of the windows of the program. */
