@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -41,7 +41,7 @@ namespace bf
   class bounding_box_event;
 
   /**
-   * \brief This control displays a action.
+   * \brief This control displays an action.
    * \author Julien Jorge
    */
   class model_view_ctrl:
@@ -54,7 +54,6 @@ namespace bf
         ID_MODEL_VIEW
       }; // enum control_id
 
-
   public:
     model_view_ctrl( wxWindow& parent, wxWindowID id, gui_model& m );
 
@@ -72,6 +71,12 @@ namespace bf
     void toggle_wireframe_mode();
     bool get_wireframe_drawing() const;
 
+    void toggle_graphic_mode();
+    bool get_graphic_drawing() const;
+
+    void toggle_text_mode();
+    bool get_text_drawing() const;
+
   private:
     void create_controls( gui_model& m );
     void create_sizers();
@@ -81,8 +86,10 @@ namespace bf
     void on_scroll(wxScrollEvent& event);
     void on_size(wxSizeEvent& event);
     void on_mark_change(mark_event& event);
-    void on_placement_change(placement_event& event);
+    void on_placement_move(placement_event& event);
+    void on_placement_size(placement_event& event);
     void on_bounding_box_change(bounding_box_event& event);
+    void on_bounding_box_selection(bounding_box_event& event);
 
   private:
     /** \brief The control that displays the model. */
