@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -43,7 +43,7 @@ namespace bf
   /**
    * \brief A snapshot is a set of one placement for each mark.
    *
-   * All snapshots in an action contains the same marks.
+   * All snapshots in an action contain the same marks.
    *
    * \author Julien Jorge
    */
@@ -63,13 +63,15 @@ namespace bf
 
   public:
     snapshot();
+    snapshot
+    ( const snapshot& that, const std::map<const mark*, const mark*>& marks );
 
     double get_date() const;
     void set_date(double date);
 
     bool has_mark( const std::string& mark_label ) const;
     bool has_mark( const mark* m ) const;
-    mark_placement& get_placement( mark* m );
+    mark_placement& get_placement( const mark* m );
     mark_placement& get_placement( const std::string& mark_label );
     const mark_placement& get_placement( const mark* m ) const;
 
@@ -108,7 +110,7 @@ namespace bf
       const std::map<std::string, unsigned int>& label_to_int ) const;
 
   private:
-    placement_list::iterator get_iterator( mark* m );
+    placement_list::iterator get_iterator( const mark* m );
     placement_list::const_iterator get_const_iterator( const mark* m ) const;
     placement_list::iterator get_iterator( const std::string& mark_label );
     placement_list::const_iterator
@@ -144,6 +146,7 @@ namespace bf
 
     /** \brief The alignment on y-coordinate. */
     double m_y_alignment_value;
+
   }; // class snapshot
 } // namespace bf
 
