@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -29,21 +29,22 @@
 #ifndef __BF_SNAPSHOT_FRAME_HPP__
 #define __BF_SNAPSHOT_FRAME_HPP__
 
+#include "bf/accordion.hpp"
 #include "bf/base_file_edit.hpp"
-#include <wx/combobox.h>
 #include "bf/spin_ctrl.hpp"
+
+#include <wx/combo.h>
 #include <wx/spinctrl.h>
 #include <wx/wx.h>
 #include <string>
 
 namespace bf
 {
-  class ingame_view;
   class model_frame;
   class snapshot;
 
   /**
-   * \brief The window displaying the list of marks of an action.
+   * \brief The window displaying various informations about a snapshot.
    * \author Sbastien Angibaud
    */
   class snapshot_frame:
@@ -55,6 +56,8 @@ namespace bf
         IDC_DATE_CTRL,
         IDC_MARK_CHOICE,
         IDC_MARK_PLACEMENT,
+        IDC_MARK_SIZE,
+        IDC_MARK_FUNCTION,
         IDC_VISIBILITY,
         IDC_FUNCTION,
         IDC_GLOBALLY_SOUND,
@@ -74,12 +77,21 @@ namespace bf
 
   private:
     void create_controls();
-    void create_member_controls();
-    void create_sizer_controls();
-    wxSizer* create_marks_sizer();
-    wxSizer* create_sound_sizer();
+    void create_member_controls( accordion* a );
+    void create_sizer_controls( accordion* a );
+
+    void create_snapshot_controls( wxWindow* parent );
+    void create_marks_controls( wxWindow* parent );
+    void create_sound_controls( wxWindow* parent );
+    void create_item_box_controls( wxWindow* parent );
+
+    wxSizer* create_snapshot_sizer( wxWindow* parent );
+    wxSizer* create_marks_sizer( wxWindow* parent );
+    wxSizer* create_sound_sizer( wxWindow* parent );
+    wxSizer* create_item_box_sizer( wxWindow* parent );
+
+    wxComboCtrl* create_easing_combo( wxWindow* parent );
 
-    void clear();
     void fill();
     void fill_mark();
 
@@ -95,6 +107,8 @@ namespace bf
     void on_mark_change( wxCommandEvent& event );
     void on_alignment_choice_change( wxCommandEvent& event );
     void on_placement_change( spin_event<double>& event );
+    void on_mark_size( spin_event<double>& event );
+    void on_mark_function( wxCommandEvent& event );
     void on_alignment_change( spin_event<double>& event );
     void on_size_change( spin_event<double>& event );
     void on_depth_change( wxSpinEvent& event );
@@ -104,6 +118,12 @@ namespace bf
     void on_sound_file_edit( wxCommandEvent& event );
     void on_sound_text_edit( wxCommandEvent& event );
 
+    void on_x_easing( wxCommandEvent& event );
+    void on_y_easing( wxCommandEvent& event );
+    void on_width_easing( wxCommandEvent& event );
+    void on_height_easing( wxCommandEvent& event );
+    void on_angle_easing( wxCommandEvent& event );
+
   private:
     /** \brief The current model_frame. */
     model_frame* m_model_frame;
@@ -124,6 +144,16 @@ namespace bf
     /** \brief The spin control in which we configure the bottom of the mark.*/
     spin_ctrl<double>* m_mark_bottom_spin;
 
+    /** \brief The spin control in which we configure the width of a mark.*/
+    spin_ctrl<double>* m_mark_width_spin;
+
+    /** \brief The spin control in which we configure the height of the mark.*/
+    spin_ctrl<double>* m_mark_height_spin;
+
+    /** \brief The text control in which we configure the function to call on
+        a collision on a mark. */
+    wxButton* m_collision_function_button;
+
     /** \brief The spin control in which we configure the z-coordinate of
         the box. */
     wxSpinCtrl* m_mark_depth_spin;
@@ -137,6 +167,21 @@ namespace bf
     /** \brief The button control to check the visibily of the mark. */
     wxCheckBox* m_mark_visible_box;
 
+    /** \brief The easing function for the x-position of the mark. */
+    wxComboCtrl* m_mark_x_easing;
+
+    /** \brief The easing function for the y-position of the mark. */
+    wxComboCtrl* m_mark_y_easing;
+
+    /** \brief The easing function for the width of the mark. */
+    wxComboCtrl* m_mark_width_easing;
+
+    /** \brief The easing function for the height of the mark. */
+    wxComboCtrl* m_mark_height_easing;
+
+    /** \brief The easing function for the angle of the mark. */
+    wxComboCtrl* m_mark_angle_easing;
+
     /** \brief The sound button to edit path. */
     wxButton* m_sound_button;
 
