@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -35,6 +35,7 @@
 #include "bf/xml/xml_to_value.hpp"
 
 #include <claw/assert.hpp>
+#include <claw/logger.hpp>
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -60,11 +61,18 @@ void bf::xml::model_mark_node::read( mark& m, const wxXmlNode* node ) const
 
   if ( child!=NULL )
     {
-      any_animation a;
-      xml_to_value<any_animation> reader;
+      if ( xml_to_value<any_animation>::supported_node(child->GetName()) )
+        {
+          any_animation a;
+          xml_to_value<any_animation> reader;
 
-      reader( a, child );
-      m.set_animation( a );
+          reader( a, child );
+          m.set_animation( a );
+          child = reader_tool::skip_comments(child);
+        }
+      else
+        claw::logger << claw::log_warning << "Ignored node '"
+                     << wx_to_std_string(node->GetName()) << "'" << std::endl;
     }
 } // model_mark_node::read()
 
@@ -82,7 +90,8 @@ bf::xml::model_mark_node::write( const mark& m, std::ostream& os ) const
      << "\" pause_animation_when_hidden=\"" << m.pause_animation_when_hidden()
      << "\">\n";
 
-  value_to_xml<any_animation>::write( os, m.get_animation() );
+  if ( m.has_animation() )
+    value_to_xml<any_animation>::write( os, m.get_animation() );
 
   os << "</mark>\n";
 
