@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -58,16 +58,42 @@ void bf::xml::model_mark_placement_node::read
     {
       mark_placement& m = s.get_placement(label);
 
-      m.set_position_x
-        ( reader_tool::read_real_opt(node, wxT("x"), m.get_position_x()) );
-      m.set_position_y
-        ( reader_tool::read_real_opt(node, wxT("y"), m.get_position_y()) );
+      m.set_x_position
+        ( reader_tool::read_real_opt(node, wxT("x"), m.get_x_position()) );
+      m.set_y_position
+        ( reader_tool::read_real_opt(node, wxT("y"), m.get_y_position()) );
+      m.set_width
+        ( reader_tool::read_real_opt(node, wxT("width"), m.get_width()) );
+      m.set_height
+        ( reader_tool::read_real_opt(node, wxT("height"), m.get_height()) );
       m.set_depth_position
         ( reader_tool::read_int_opt(node, wxT("z"), m.get_depth_position()) );
       m.set_angle
         ( reader_tool::read_real_opt(node, wxT("angle"), m.get_angle()) );
       m.set_visibility
         ( reader_tool::read_bool_opt(node, wxT("visible"), m.is_visible()) );
+      m.set_collision_function
+        ( reader_tool::read_string_opt(node, wxT("function"), "") );
+
+      bear::easing e;
+      const std::string def(e.to_string());
+      e.from_string( reader_tool::read_string_opt(node, wxT("x_easing"), def) );
+      m.set_x_easing(e);
+
+      e.from_string( reader_tool::read_string_opt(node, wxT("y_easing"), def) );
+      m.set_y_easing(e);
+
+      e.from_string
+        ( reader_tool::read_string_opt(node, wxT("width_easing"), def) );
+      m.set_width_easing(e);
+
+      e.from_string
+        ( reader_tool::read_string_opt(node, wxT("height_easing"), def) );
+      m.set_height_easing(e);
+
+      e.from_string
+        ( reader_tool::read_string_opt(node, wxT("angle_easing"), def) );
+      m.set_angle_easing(e);
     }
 } // model_mark_placement_node::read()
 
@@ -82,7 +108,16 @@ void bf::xml::model_mark_placement_node::write
 {
   os << "<mark_placement label=\""
      << xml::util::replace_special_characters(m.get_mark()->get_label())
-     << "\" x=\"" << m.get_position_x() << "\" y=\"" << m.get_position_y()
+     << "\" function=\""
+     << xml::util::replace_special_characters(m.get_collision_function())
+     << "\" x=\"" << m.get_x_position() << "\" y=\"" << m.get_y_position()
+     << "\" width=\"" << m.get_width() << "\" height=\"" << m.get_height()
      << "\" z=\"" << m.get_depth_position() << "\" angle=\"" << m.get_angle()
-     << "\" visible=\"" << m.is_visible() << "\"/>\n";
+     << "\" visible=\"" << m.is_visible()
+     << "\" x_easing=\"" << m.get_x_easing().to_string()
+     << "\" y_easing=\"" << m.get_y_easing().to_string()
+     << "\" width_easing=\"" << m.get_width_easing().to_string()
+     << "\" height_easing=\"" << m.get_height_easing().to_string()
+     << "\" angle_easing=\"" << m.get_angle_easing().to_string()
+     << "\"/>\n";
 } // model_mark_placement_node::write()
