@@ -1,7 +1,7 @@
 /*
     Bear Engine - Model editor
 
-    Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+    Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
     This program is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by the
@@ -45,7 +45,8 @@ namespace bf
     class model_mark_node
     {
     public:
-      void read( mark& m, const wxXmlNode* node ) const;
+      void
+      read( mark& m, const wxXmlNode* node ) const;
       void write( const mark& m, std::ostream& os ) const;
 
     }; // class model_mark_node
