@@ -29,44 +29,16 @@
 ;
 (load "../../../common.scm")
 
+(load "gorilla-sprites.scm")
+
 (define idle-gorilla
   (lambda (dest_image)
 
-    (let ( (idle_name "idle.xcf.bz2") )
-      (let ( (idle_image (car (gimp-file-load 1 idle_name idle_name)))
-             )
+    (gorilla-idle-sprite 0 0 0 113 103 dest_image ".")
+    (gorilla-idle-sprite 1 113 0 113 103 dest_image ".")
+    (gorilla-idle-sprite 2 226 0 113 103 dest_image ".")
+    (gorilla-idle-sprite 3 339 0 113 103 dest_image ".")
 
-        ; layer names
-        (let ( (mouth_3   0)
-               (mouth_2   1)
-               (mouth_1   2)
-               (right_arm 3)
-               (right_leg 4)
-               (left_foot 5)
-               (body      6)
-               (grass     7)
-               (face      8)
-               (left_leg  9) )
-
-          (create-layer idle_image
-                        (list grass
-                         right_arm right_leg left_foot body face left_leg)
-                        0 0 113 103 dest_image)
-          (create-layer idle_image
-                        (list mouth_1
-                         right_arm right_leg left_foot body face left_leg)
-                        113 0 113 103 dest_image)
-          (create-layer idle_image
-                        (list mouth_2
-                         right_arm right_leg left_foot body face left_leg)
-                        226 0 113 103 dest_image)
-          (create-layer idle_image
-                        (list mouth_3
-                         right_arm right_leg left_foot body face left_leg)
-                        339 0 113 103 dest_image)
-          ) ; let
-        ) ; let
-      ) ; let
     ) ; lambda
   ) ; define idle-gorilla
 
