@@ -55,6 +55,21 @@
     ) ; lambda
   ) ; define human-talking
 
+; coeff: x=0.497942387 y=0.49851632
+(define ball-creation
+  (lambda (dest_image)
+    (let ( (src_name "ball-creation.xcf.bz2") )
+      (let ( (src_image (car (gimp-file-load 1 src_name src_name)))
+             )
+
+        (create-layer src_image '(0 1) 256 340 127 156 dest_image)
+        (create-layer src_image '(0 2) 383 340 127 156 dest_image)
+
+        ) ; let
+      ) ; let
+    ) ; lambda
+  ) ; define ball-creation
+
 (let ( (dest_name "human-talking.png") )
   (let ( (dest_image (car (gimp-image-new 512 512 RGB))) )
     (let ( (bk (car (gimp-layer-new dest_image 512 512 1 "background" 100 0)))
@@ -62,7 +77,8 @@
       (gimp-image-add-layer dest_image bk 0)
       )
 
-    (human-talking dest_image);
+    (human-talking dest_image)
+    (ball-creation dest_image)
 
     (save-frames-and-exit dest_name dest_image)
     ) ; let
