@@ -28,26 +28,25 @@
 ;   gimp-console -b - < this_script.scm
 ;
 (load "../../common.scm")
+(load "./shiny-honey-jar-sprites.scm")
 
-(let ( (src_name "shiny-honey-jar.xcf.bz2")
-       (dest_name "shiny-honey-jar.png") )
-  (let ( (src_image (car (gimp-file-load 1 src_name src_name)))
-         (dest_image (car (gimp-image-new 256 128 RGB)))
+(let ( (dest_name "shiny-honey-jar.png") )
+  (let ( (dest_image (car (gimp-image-new 256 128 RGB)))
          )
     (let ( (bk (car (gimp-layer-new dest_image 256 128 1 "background" 100 0)))
            )
       (gimp-image-add-layer dest_image bk 0)
       )
 
-    ( create-layer src_image '(0 5 10 11 12 13)   0  0 64 64 dest_image )
-    ( create-layer src_image '(1 6 10 11 12 13)  64  0 64 64 dest_image )
-    ( create-layer src_image '(2 7 10 11 12 13) 128  0 64 64 dest_image )
-    ( create-layer src_image '(3 8 10 11 12 13) 192  0 64 64 dest_image )
-    ( create-layer src_image '(4 9 10 11 12 13)   0 64 64 64 dest_image )
+    (shiny-honey-jar-sprite 0 0 0 64 64 dest_image ".")
+    (shiny-honey-jar-sprite 1 64  0 64 64 dest_image ".")
+    (shiny-honey-jar-sprite 2 128  0 64 64 dest_image ".")
+    (shiny-honey-jar-sprite 3 192  0 64 64 dest_image ".")
+    (shiny-honey-jar-sprite 4 0 64 64 64 dest_image ".")
 
-    ( create-layer src_image '(3 5 10 11 12 13)  64 64 64 64 dest_image )
-    ( create-layer src_image '(2 7 10 11 12 13) 128 64 64 64 dest_image )
-    ( create-layer src_image '(1 9 10 11 12 13) 192 64 64 64 dest_image )
+    (shiny-honey-jar-sprite 5 64 64 64 64 dest_image ".")
+    (shiny-honey-jar-sprite 6 128 64 64 64 dest_image ".")
+    (shiny-honey-jar-sprite 7 192 64 64 64 dest_image ".")
     
     (save-frames-and-exit dest_name dest_image)
     ) ; let
