@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -35,12 +35,14 @@
 
 namespace ptb
 {
-  class player;
+  class player_proxy;
 
   /**
    * \brief A item that contains a bonus.
    *
    * The valid fields for this item are
+   *  - \a player_index : (unsigned int) Index of player that can take
+   * the bonus (0 if all players)
    *  - \a type: (string) \b [required] the type of the bonus
    *      - "air_power"
    *      - "fire_power"
@@ -96,6 +98,10 @@ namespace ptb
     void add_type(base_bonus_type t);
     unsigned int get_stock() const;
     void set_stock(unsigned int stock);
+    void set_player_index(unsigned int index);
+    unsigned int get_player_index() const;
+
+    const bear::visual::animation& get_animation() const;
     void set_animation(const bear::visual::animation& anim);
 
     static base_bonus_type type_from_string( const std::string& t );
@@ -103,12 +109,14 @@ namespace ptb
 
   protected:
     void to_string( std::string& str ) const;
-    void give_bonus(player* p);
+    void give_bonus(const player_proxy& p);
+    bool can_give_bonus(const player_proxy& p) const;
 
   private:
     void create_little_plee(bool plee_orientation);
 
     virtual void do_set_type(base_bonus_type t);
+    void give_max_energy(const player_proxy& p);
 
   private:
     /** \brief The type of the base_bonus. */
@@ -117,6 +125,9 @@ namespace ptb
     /** \brief The current type of the bonus. */
     std::size_t m_current_type;
 
+    /** \brief Index of player that can take the bonus (0 if all players). */
+    unsigned int m_player_index;
+
     /** \brief The delay before changing the bonus. */
     bear::universe::time_type m_change_interval;
 
