@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -44,7 +44,7 @@ namespace ptb
    * \author Sbastien Angibaud
    */
   template<class Base>
-  class base_enemy :
+  class base_enemy:
     public monster_item<Base>
   {
   public:
@@ -54,26 +54,25 @@ namespace ptb
   public:
     base_enemy();
 
+    void build();
     virtual bool set_u_integer_field
     ( const std::string& name, unsigned int value );
-    virtual void build();
     virtual void get_visual
     ( std::list<bear::engine::scene_visual>& visuals ) const;
 
-    /** \brief Create a headstone */
     void create_headstone
     ( const bear::universe::position_type& bottom_middle_pos,
       const bear::visual::animation& soul_anim,
       unsigned int soul_energy, unsigned int pos_z);
 
-    /** \brief Create floating score */
-    void create_floating_score( unsigned int index );
+    void create_floating_score( unsigned int index ) const;
 
     void die(const monster& attacker);
 
   private:
     /** \brief The score to give when this enemy dies. */
     unsigned int m_score;
+
   }; // class base_enemy
 } // namespace ptb
 
