@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,12 +28,15 @@
  */
 #include "ptb/base_bonus.hpp"
 
+#include "ptb/game_variables.hpp"
+#include "ptb/player_proxy.hpp"
+#include "ptb/item/little_plee.hpp"
+#include "ptb/defines.hpp"
+
 #include "universe/collision_info.hpp"
 #include "generic_items/decorative_item.hpp"
-#include "ptb/player.hpp"
-#include "ptb/item/little_plee.hpp"
-#include "engine/game.hpp"
 
+#include "engine/game.hpp"
 #include "engine/export.hpp"
 
 /*----------------------------------------------------------------------------*/
@@ -41,7 +44,7 @@
  * \brief Contructor.
  */
 ptb::base_bonus::base_bonus()
-  : m_current_type(0),
+  : m_current_type(0), m_player_index(0),
     m_change_interval
     (std::numeric_limits<bear::universe::time_type>::infinity()),
     m_elapsed_time(0), m_stock(0), m_bonus_given(false)
@@ -205,6 +208,34 @@ void ptb::base_bonus::set_stock(unsigned int stock)
   m_stock = stock;
 } // base_bonus::set_stock()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set index of player that can take the bonus (0 if all players).
+ * \param player_index The new player index.
+ */
+void ptb::base_bonus::set_player_index(unsigned int index)
+{
+  m_player_index = index;
+} // base_bonus::set_player_index()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the player index to consider.
+ */
+unsigned int  ptb::base_bonus::get_player_index() const
+{
+  return m_player_index;
+} // base_bonus::get_player_index()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get the animation.
+ */
+const bear::visual::animation& ptb::base_bonus::get_animation() const
+{
+  return m_animation;
+} // base_bonus::get_animation()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set the animation.
@@ -284,38 +315,34 @@ void ptb::base_bonus::to_string( std::string& str ) const
  * \brief Give the bonus.
  * \param p The player.
  */
-void ptb::base_bonus::give_bonus(player* p)
+void ptb::base_bonus::give_bonus( const player_proxy& p )
 {
   switch ( get_type() )
     {
     case air_power:
-      game_variables::set_air_power(p->get_index(), true);
+      game_variables::set_air_power(p.get_index(), true);
       break;
     case fire_power:
-      game_variables::set_fire_power(p->get_index(), true);
+      game_variables::set_fire_power(p.get_index(), true);
       break;
     case water_power:
-      game_variables::set_water_power(p->get_index(), true);
+      game_variables::set_water_power(p.get_index(), true);
       break;
     case invincibility_power:
-      p->set_invincible(true);
+      p.set_invincible(true);
       break;
     case stones_stock:
     case stones_big_stock:
       game_variables::set_stones_count
-        ( p->get_index(),
-          game_variables::get_stones_count(p->get_index()) + m_stock);
+        ( p.get_index(),
+          game_variables::get_stones_count(p.get_index()) + m_stock);
       break;
     case  one_more_life:
-      create_little_plee(p->get_rendering_attributes().is_mirrored());
+      create_little_plee( p.get_rendering_attributes().is_mirrored() );
       break;
     case increase_max_energy:
       {
-        game_variables::set_max_energy
-          ( p->get_index(),
-            game_variables::get_max_energy(p->get_index()) + m_stock);
-
-        p->receive_energy( game_variables::get_max_energy(p->get_index()) );
+        give_max_energy(p);
         break;
       }
     case switch_players:
@@ -330,6 +357,19 @@ void ptb::base_bonus::give_bonus(player* p)
   kill();
 } // base_bonus::give_bonus()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Indicates if the bonus can be given at a specific player.
+ * \param p The player.
+ */
+bool ptb::base_bonus::can_give_bonus( const player_proxy& p ) const
+{
+  if ( get_type() == increase_max_energy )
+    return ( p.get_index() == m_player_index ) || ( m_player_index == 0 ) ;
+  else
+    return true;
+} // base_bonus::can_give_bonus()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Give the bonus.
@@ -359,3 +399,21 @@ void ptb::base_bonus::do_set_type(base_bonus_type t)
 {
   // nothing to do
 } // base_bonus::do_set_type()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Give max energy bonus.
+ */
+void ptb::base_bonus::give_max_energy(const player_proxy& p)
+{
+  unsigned int energy =
+    game_variables::get_max_energy(p.get_index()) + m_stock;
+  if ( energy > PTB_MAXIMUM_ENERGY )
+    energy = PTB_MAXIMUM_ENERGY;
+
+  game_variables::set_max_energy( p.get_index(), energy );
+  p.receive_energy( energy );
+
+  game_variables::set_current_level_max_energy_state(true);
+  game_variables::set_current_level_max_energy_state(p.get_index(), true);
+} // base_bonus::give_max_energy()
