@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -41,6 +41,7 @@
 #include <claw/string_algorithm.hpp>
 #include <claw/configuration_file.hpp>
 #include <sstream>
+#include <boost/preprocessor/stringize.hpp>
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -97,6 +98,8 @@ void init_plee_the_bear()
 
 #ifdef _WIN32
   bindtextdomain( "plee-the-bear", "share/locale" );
+#elif defined PTB_TEXT_DOMAIN_PATH
+  bindtextdomain( "plee-the-bear", BOOST_PP_STRINGIZE(PTB_TEXT_DOMAIN_PATH) );
 #endif
 
   bind_textdomain_codeset( "plee-the-bear", "ISO-8859-15" );
