@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -79,63 +79,98 @@ void ptb::level_variables::set_players_on_exit
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Get the number of killed enemies.
+ * \brief Get the number of a given object in the level.
  * \param lvl The level in which we take the variable.
+ * \param object_type The type of the object.
  */
 unsigned int
-ptb::level_variables::get_killed_enemies( const bear::engine::level& lvl )
+ptb::level_variables::get_object_count
+( const bear::engine::level& lvl, const std::string& object_type )
 {
   return ptb_level_variables_get_value
-    ( lvl, "killed_ennemies", (unsigned int)0 );
-} // level_variables::get_killed_enemies()
+    ( lvl, "object_count/" + object_type, (unsigned int)0 );
+} // level_variables::get_object_count()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Set the number of killed enemies.
+ * \brief Set the number of a given object in the level.
  * \param lvl The level in which we take the variable.
+ * \param object_type The type of the object.
  * \param c The number of killed enemies.
  */
-void ptb::level_variables::set_killed_enemies
-( bear::engine::level& lvl, unsigned int nb )
+void ptb::level_variables::set_object_count
+( bear::engine::level& lvl, const std::string& object_type, unsigned int nb )
 {
   lvl.set_level_variable
-    ( bear::engine::variable<unsigned int>( "killed_enemies", nb ) );
-} // level_variables::set_killed_enemies()
+    ( bear::engine::variable<unsigned int>
+      ( "object_count/" + object_type, nb ) );
+} // level_variables::set_object_count()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Get the number of enemies in the level.
+ * \brief Get the number of killed items of a given type in the level.
  * \param lvl The level in which we take the variable.
+ * \param object_type The type of the object.
  */
 unsigned int
-ptb::level_variables::get_enemy_count( const bear::engine::level& lvl )
+ptb::level_variables::get_killed_object_count
+( const bear::engine::level& lvl, const std::string& object_type )
 {
   return ptb_level_variables_get_value
-    ( lvl, "enemy_count", (unsigned int)0 );
-} // level_variables::get_enemy_count()
+    ( lvl, "killed_object_count/" + object_type, (unsigned int)0 );
+} // level_variables::get_killed_object_count()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Set the number of enemies in the level.
+ * \brief Set the number of killed items a given type in the level.
  * \param lvl The level in which we take the variable.
+ * \param object_type The type of the object.
  * \param c The number of killed enemies.
  */
-void ptb::level_variables::set_enemy_count
-( bear::engine::level& lvl, unsigned int nb )
+void ptb::level_variables::set_killed_object_count
+( bear::engine::level& lvl, const std::string& object_type, unsigned int nb )
 {
   lvl.set_level_variable
-    ( bear::engine::variable<unsigned int>( "enemy_count", nb ) );
-} // level_variables::set_enemy_count()
+    ( bear::engine::variable<unsigned int>
+      ( "killed_object_count/" + object_type, nb ) );
+} // level_variables::set_killed_object_count()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the hazelnut is currently found.
+ * \param lvl The level in which we take the variable.
+ */
+bool ptb::level_variables::get_current_hazelnut
+( const bear::engine::level& lvl )
+{
+  return ptb_level_variables_get_value
+    ( lvl, "current_hazelnut", false );
+} // level_variables::get_current_hazelnut()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set if the hazelnut is currently found.
+ * \param lvl The level in which we take the variable.
+ * \param v Found or not.
+ */
+void ptb::level_variables::set_current_hazelnut
+( bear::engine::level& lvl, bool v )
+{
+  lvl.set_level_variable
+    ( bear::engine::variable<bool>( "current_hazelnut", v ) );
+} // level_variables::set_current_hazelnut()
 
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell if the hazelnut has been found.
  * \param lvl The level in which we take the variable.
  */
-bool ptb::level_variables::get_hazelnut( const bear::engine::level& lvl )
+bool ptb::level_variables::get_hazelnut_found
+( const bear::engine::level& lvl )
 {
-  return ptb_level_variables_get_value( lvl, "hazelnut", false );
-} // level_variables::get_hazelnut()
+  return ptb_level_variables_get_value
+    ( lvl, "hazelnut_found", false );
+} // level_variables::get_found_hazelnut()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -143,11 +178,37 @@ bool ptb::level_variables::get_hazelnut( const bear::engine::level& lvl )
  * \param lvl The level in which we take the variable.
  * \param v Found or not.
  */
-void ptb::level_variables::set_hazelnut( bear::engine::level& lvl, bool v )
+void ptb::level_variables::set_hazelnut_found
+( bear::engine::level& lvl, bool v )
 {
   lvl.set_level_variable
-    ( bear::engine::variable<bool>( "hazelnut", v ) );
-} // level_variables::set_hazelnut()
+    ( bear::engine::variable<bool>( "hazelnut_found", v ) );
+} // level_variables::set_hazelnut_found()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Tell if the secret_level has been found.
+ * \param lvl The level in which we take the variable.
+ */
+bool ptb::level_variables::get_secret_level_found
+( const bear::engine::level& lvl )
+{
+  return ptb_level_variables_get_value
+    ( lvl, "secret_level_found", false );
+} // level_variables::get_found_secret_level()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set if the secret level has been found.
+ * \param lvl The level in which we take the variable.
+ * \param v Found or not.
+ */
+void ptb::level_variables::set_secret_level_found
+( bear::engine::level& lvl, bool v )
+{
+  lvl.set_level_variable
+    ( bear::engine::variable<bool>( "secret_level_found", v ) );
+} // level_variables::set_secret_level_found()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -174,6 +235,40 @@ void ptb::level_variables::set_honeypots_found
     ( bear::engine::variable<unsigned int>( "honeypots_found", nb ) );
 } // level_variables::set_honeypots_found()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Get if a given honeypot has been found.
+ * \param lvl The level in which we take the variable.
+ * \param id The identifier of the honeypot.
+ */
+bool
+ptb::level_variables::get_honeypot_found
+( const bear::engine::level& lvl, unsigned int id )
+{
+  std::ostringstream s;
+  s << "honeypot " << id;
+  std::string var(s.str());
+
+  return ptb_level_variables_get_value( lvl, var, false );
+} // level_variables::get_honeypots_found()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set if a given honeypot has been found.
+ * \param lvl The level in which we take the variable.
+ * \param id The identifier of honeypot.
+ * \param b The new value.
+ */
+void ptb::level_variables::set_honeypot_found
+( bear::engine::level& lvl, unsigned int id, bool b )
+{
+  std::ostringstream s;
+  s << "honeypot " << id;
+  std::string var(s.str());
+
+  lvl.set_level_variable( bear::engine::variable<bool>( var, b ) );
+} // level_variables::set_honeypots_found()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Tell if we are leaving the level.
@@ -218,28 +313,15 @@ void ptb::level_variables::meet_the_owl( bear::engine::level& lvl )
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Get the time record for the level.
+ * \brief Set that all hideouts are found.
  * \param lvl The level in which we take the variable.
  */
-bear::universe::time_type
-ptb::level_variables::get_time_record( const bear::engine::level& lvl )
-{
-  return ptb_level_variables_get_value
-    ( lvl, "time_record", (bear::universe::time_type)0 );
-} // level_variables::get_time_record()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Set the time record for the level.
- * \param lvl The level in which we take the variable.
- * \param t The record.
- */
-void ptb::level_variables::set_time_record
-( bear::engine::level& lvl, bear::universe::time_type t )
+void ptb::level_variables::all_hideouts_found
+( bear::engine::level& lvl )
 {
   lvl.set_level_variable
-    ( bear::engine::variable<bear::universe::time_type>( "time_record", t ) );
-} // level_variables::set_time_record()
+    ( bear::engine::variable<bool>( "all_hideouts_found", true ) );
+} // level_variables::all_hideouts_found()
 
 /*----------------------------------------------------------------------------*/
 /**
