@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,6 +28,8 @@
  */
 #include "ptb/speaker_item.hpp"
 
+#include <libintl.h>
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Constructor.
@@ -118,7 +120,11 @@ void ptb::speaker_item::stop_to_speak()
  */
 void ptb::speaker_item::speak(const std::vector<std::string>& speech)
 {
-  m_speeches.push_back( std::list<std::string>(speech.begin(), speech.end()) );
+  std::list<std::string> s;
+  for ( std::size_t i=0; i!=speech.size(); ++i )
+    s.push_back( gettext(speech[i].c_str()) );
+
+  m_speeches.push_back(s);
 } // speaker_item::speak()
 
 /*----------------------------------------------------------------------------*/
@@ -131,7 +137,7 @@ void ptb::speaker_item::speak(const std::vector<std::string>& speech)
 void ptb::speaker_item::speak(const std::string& s)
 {
   std::list<std::string> t;
-  t.push_back(s);
+  t.push_back(gettext(s.c_str()));
   m_speeches.push_back(t);
 } // speaker_item::speak()
 
