@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -38,6 +38,9 @@
 /** \brief The number of points over which the player wins a new try. */
 #define PTB_ONE_UP_POINTS_COUNT 50000
 
+/** \brief The maximum energy that a player can have. */
+#define PTB_MAXIMUM_ENERGY 200
+
 /** \brief The name of the layer displaying the transition effects. */
 #define PTB_TRANSITION_EFFECT_DEFAULT_TARGET_NAME "transition_effect_layer"
 
@@ -47,6 +50,10 @@
 /** \brief The name of the layer displaying the frames during the game. */
 #define PTB_WINDOWS_LAYER_DEFAULT_TARGET_NAME "windows_layer"
 
+/** \brief The name of the layer displaying the informations about the
+    players. */
+#define PTB_STATUS_LAYER_DEFAULT_TARGET_NAME "status_layer"
+
 /** \brief The default orange color, used in gui layers. */
 #define PTB_ORANGE_PIXEL bear::visual::color_type(254, 160, 0, 255)
 
@@ -59,4 +66,25 @@
 /** \brief The number of record lines for mini-games. */
 #define PTB_NUMBER_OF_RECORDS 6
 
+/** \brief The number of profiles. */
+#define PTB_NUMBER_OF_PROFILES 3
+
+/** \brief The name of the folder in which profiles are saved. */
+#define PTB_PROFILES_FOLDER "profiles/"
+
+/** \brief The prefix for game variable to save. */
+#define PTB_PERSISTENT_PREFIX "persistent/"
+
+/** \brief The filename for one player save. */
+#define PTB_SAVE_ONE_PLAYER_FILENAME "1p-game-variables.sav"
+
+/** \brief The filename for one player save. */
+#define PTB_SAVE_TWO_PLAYERS_FILENAME "2p-game-variables.sav"
+
+/** \brief The color of the aura of god */
+#define PTB_GOD_AURA_COLOR bear::visual::color_type(255, 255, 133, 255)
+
+/** \brief The color of the border of the aura of god */
+#define PTB_GOD_AURA_BORDER_COLOR bear::visual::color_type(192, 192, 100, 255)
+
 #endif // __PTB_DEFINES_HPP__
