@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -40,7 +40,7 @@
  * \param owning_layer The layer onwing the window.
  */
 ptb::frame::frame( windows_layer* owning_layer )
-  : bear::gui::frame( NULL ), m_owning_layer(owning_layer)
+  : bear::gui::frame(), m_owning_layer(owning_layer)
 {
   CLAW_PRECOND(owning_layer != NULL);
 
@@ -54,7 +54,7 @@ ptb::frame::frame( windows_layer* owning_layer )
  * \param title The title of the frame.
  */
 ptb::frame::frame( windows_layer* owning_layer, const std::string& title )
-  : bear::gui::frame( NULL, title ), m_owning_layer(owning_layer)
+  : bear::gui::frame(title), m_owning_layer(owning_layer)
 {
   CLAW_PRECOND(owning_layer != NULL);
 
@@ -76,7 +76,7 @@ void ptb::frame::on_focus()
  */
 bear::visual::sprite ptb::frame::get_arrow() const
 {
-  return get_frame_sprite_at( 64, 0, 18, 20 );
+  return get_frame_sprite( "arrow" );
 } // frame::get_cursor()
 
 /*----------------------------------------------------------------------------*/
@@ -85,7 +85,7 @@ bear::visual::sprite ptb::frame::get_arrow() const
  */
 bear::visual::sprite ptb::frame::get_cursor() const
 {
-  return get_frame_sprite_at( 40, 0, 24, 25 );
+  return get_frame_sprite( "cursor" );
 } // frame::get_cursor()
 
 /*----------------------------------------------------------------------------*/
@@ -94,7 +94,7 @@ bear::visual::sprite ptb::frame::get_cursor() const
  */
 bear::visual::sprite ptb::frame::get_checkbox_off() const
 {
-  return get_frame_sprite_at( 82, 0, 23, 23 );
+  return get_frame_sprite( "checkbox off" );
 } // frame::get_checkbox_off()
 
 /*----------------------------------------------------------------------------*/
@@ -103,16 +103,34 @@ bear::visual::sprite ptb::frame::get_checkbox_off() const
  */
 bear::visual::sprite ptb::frame::get_checkbox_on() const
 {
-  return get_frame_sprite_at( 105, 0, 23, 23 );
+  return get_frame_sprite( "checkbox on" );
 } // frame::get_checkbox_on()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the sprite to use for a not checked radio.
+ */
+bear::visual::sprite ptb::frame::get_radio_off() const
+{
+  return get_frame_sprite( "radio off" );
+} // frame::get_radio_off()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create the sprite to use for a checked radio.
+ */
+bear::visual::sprite ptb::frame::get_radio_on() const
+{
+  return get_frame_sprite( "radio on" );
+} // frame::get_radio_on()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Create the sprite of the slider bar.
  */
 bear::visual::sprite ptb::frame::get_slider_bar() const
 {
-  return get_frame_sprite_at(40, 25, 1, 7);
+  return get_frame_sprite( "slider bar" );
 } // frame::get_slider_bar()
 
 /*----------------------------------------------------------------------------*/
@@ -121,7 +139,7 @@ bear::visual::sprite ptb::frame::get_slider_bar() const
  */
 bear::visual::sprite ptb::frame::get_slider() const
 {
-  return get_frame_sprite_at(64, 20, 9, 21);
+  return get_frame_sprite( "slider" );
 } // frame::get_slider()
 
 /*----------------------------------------------------------------------------*/
@@ -186,6 +204,17 @@ void ptb::frame::show_window( frame* wnd ) const
   m_owning_layer->show_centered_window(wnd);
 } // frame::show_window()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Replace the current window by a new window.
+ * \param wnd The class name of the window to show.
+ */
+void ptb::frame::replace_with( frame* wnd )
+{
+  CLAW_PRECOND(wnd != NULL);
+  m_owning_layer->replace_window(this, wnd);
+} // frame::replace_with()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Close the current window (come back to the previous one).
@@ -202,6 +231,8 @@ void ptb::frame::close_window() const
  */
 void ptb::frame::insert_control( bear::gui::visual_component& c )
 {
+  get_content().insert(&c);
+
   m_controls.push_back(&c);
 
   if ( m_controls.size() == 1 )
@@ -296,37 +327,15 @@ bool ptb::frame::on_mouse_move
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Get the sprite of the frame.
- * \param x X-position of the sprite in the resource image.
- * \param y Y-position of the sprite in the resource image.
- * \param w Width of the sprite in the resource image.
- * \param h Height of the sprite in the resource image.
+ * \param name The name of the sprite to get.
  */
-bear::visual::sprite ptb::frame::get_frame_sprite_at
-( unsigned int x, unsigned int y, unsigned int w, unsigned int h ) const
+bear::visual::sprite
+ptb::frame::get_frame_sprite( const std::string& name ) const
 {
-  return get_frame_sprite_at(m_owning_layer, x, y, w, h);
-} // frame::get_frame_sprite_at()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Get the sprite of the frame.
- * \param owner The layer from which we can get the resources.
- * \param x X-position of the sprite in the resource image.
- * \param y Y-position of the sprite in the resource image.
- * \param w Width of the sprite in the resource image.
- * \param h Height of the sprite in the resource image.
- */
-bear::visual::sprite ptb::frame::get_frame_sprite_at
-( const windows_layer* owner, unsigned int x, unsigned int y, unsigned int w,
-  unsigned int h ) const
-{
-  bear::engine::level_globals& glob = owner->get_level().get_globals();
-
-  const bear::visual::image& img = glob.get_image( "gfx/frame.tga" );
-  claw::math::rectangle<unsigned int> rect( x, y, w, h );
-
-  return bear::visual::sprite( img, rect );
-} // frame::get_frame_sprite_at()
+  return
+    m_owning_layer->get_level().get_globals().auto_sprite
+    ( "gfx/ui/frame.png", name );
+} // frame::get_frame_sprite()
 
 /*----------------------------------------------------------------------------*/
 /**
