@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -47,8 +47,11 @@ ptb::frame_audio::frame_audio( windows_layer* owning_layer )
   : frame(owning_layer, gettext("Audio")),
     m_saved_sound_muted(bear::engine::game::get_instance().get_sound_muted()),
     m_saved_music_muted(bear::engine::game::get_instance().get_music_muted()),
-    m_saved_sound_volume(bear::engine::game::get_instance().get_sound_volume()),
-    m_saved_music_volume(bear::engine::game::get_instance().get_music_volume())
+    m_saved_sound_volume
+  (bear::engine::game::get_instance().get_sound_volume()),
+    m_saved_music_volume
+  (bear::engine::game::get_instance().get_music_volume()),
+    m_ok_is_pressed(false)
 {
   create_controls();
 } // frame_audio::frame_audio()
@@ -104,15 +107,14 @@ bear::gui::visual_component*
 ptb::frame_audio::create_music_checkbox( bear::visual::font f )
 {
   bear::gui::checkbox* box =
-    new bear::gui::checkbox
-    ( &get_content(), get_checkbox_off(), get_checkbox_on(), f );
+    new bear::gui::checkbox( get_checkbox_off(), get_checkbox_on(), f );
 
-  box->set_checked_callback
+  box->add_checked_callback
     ( bear::gui::callback_function_maker
       ( boost::bind
         ( &bear::engine::game::set_music_muted,
           &bear::engine::game::get_instance(), false ) ) );
-  box->set_unchecked_callback
+  box->add_unchecked_callback
     ( bear::gui::callback_function_maker
       ( boost::bind
         ( &bear::engine::game::set_music_muted,
@@ -133,15 +135,15 @@ ptb::frame_audio::create_music_checkbox( bear::visual::font f )
 bear::gui::visual_component*
 ptb::frame_audio::create_sound_checkbox( bear::visual::font f )
 {
-  bear::gui::checkbox* box = new bear::gui::checkbox
-    ( &get_content(), get_checkbox_off(), get_checkbox_on(), f );
+  bear::gui::checkbox* box =
+    new bear::gui::checkbox( get_checkbox_off(), get_checkbox_on(), f );
 
-  box->set_checked_callback
+  box->add_checked_callback
     ( bear::gui::callback_function_maker
       ( boost::bind
         ( &bear::engine::game::set_sound_muted,
           &bear::engine::game::get_instance(), false ) ) );
-  box->set_unchecked_callback
+  box->add_unchecked_callback
     ( bear::gui::callback_function_maker
       ( boost::bind
         ( &bear::engine::game::set_sound_muted,
@@ -163,7 +165,7 @@ bear::gui::visual_component* ptb::frame_audio::create_music_slider()
 {
   m_music_volume =
     new bear::gui::slider<double>
-    ( &get_content(), get_slider_bar(), get_slider(), 0, 1,
+    ( get_slider_bar(), get_slider(), 0, 1,
       bear::engine::game::get_instance().get_music_volume(),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_audio::set_volume, this ) ) );
@@ -184,7 +186,7 @@ bear::gui::visual_component* ptb::frame_audio::create_sound_slider()
 {
   m_sound_volume =
     new bear::gui::slider<double>
-    ( &get_content(), get_slider_bar(), get_slider(), 0, 1,
+    ( get_slider_bar(), get_slider(), 0, 1,
       bear::engine::game::get_instance().get_sound_volume(),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_audio::set_volume, this ) ) );
@@ -208,7 +210,7 @@ ptb::frame_audio::create_ok_button( bear::visual::font f )
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), f, gettext("OK"),
+    ( f, gettext("OK"),
       bear::gui::callback_function_maker
       ( boost::bind(&frame_audio::on_ok, this) ) );
 
@@ -229,7 +231,7 @@ ptb::frame_audio::create_cancel_button( bear::visual::font f )
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), f, gettext("Cancel"),
+    ( f, gettext("Cancel"),
       bear::gui::callback_function_maker
       ( boost::bind(&frame_audio::on_cancel, this) ) );
 
@@ -242,7 +244,7 @@ ptb::frame_audio::create_cancel_button( bear::visual::font f )
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Save the screen configuration.
+ * \brief Save the audio configuration.
  */
 void ptb::frame_audio::save()
 {
@@ -256,12 +258,37 @@ void ptb::frame_audio::save()
   config.save();
 } // frame_audio::save()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Cancel audio configuration.
+ */
+void ptb::frame_audio::cancel() const
+{
+ if ( m_saved_sound_muted
+       != bear::engine::game::get_instance().get_sound_muted() )
+    bear::engine::game::get_instance().set_sound_muted( m_saved_sound_muted );
+
+  if ( m_saved_music_muted
+       != bear::engine::game::get_instance().get_music_muted() )
+    bear::engine::game::get_instance().set_music_muted( m_saved_music_muted );
+
+  if ( m_saved_sound_volume
+       != bear::engine::game::get_instance().get_sound_volume() )
+    bear::engine::game::get_instance().set_sound_volume(m_saved_sound_volume);
+
+  if ( m_saved_music_volume
+       != bear::engine::game::get_instance().get_music_volume() )
+    bear::engine::game::get_instance().set_music_volume(m_saved_music_volume);
+} // frame_audio::cancel()
+
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Save the configuration.
  */
 bool ptb::frame_audio::on_ok()
 {
+  m_ok_is_pressed = true;
   save();
   close_window();
 
@@ -274,22 +301,19 @@ bool ptb::frame_audio::on_ok()
  */
 bool ptb::frame_audio::on_cancel()
 {
-  if ( m_saved_sound_muted
-       != bear::engine::game::get_instance().get_sound_muted() )
-    bear::engine::game::get_instance().set_sound_muted( m_saved_sound_muted );
-
-  if ( m_saved_music_muted
-       != bear::engine::game::get_instance().get_music_muted() )
-    bear::engine::game::get_instance().set_music_muted( m_saved_music_muted );
-
-  if ( m_saved_sound_volume
-       != bear::engine::game::get_instance().get_sound_volume() )
-    bear::engine::game::get_instance().set_sound_volume( m_saved_sound_volume );
-
-  if ( m_saved_music_volume
-       != bear::engine::game::get_instance().get_music_volume() )
-    bear::engine::game::get_instance().set_music_volume( m_saved_music_volume );
-
   close_window();
   return true;
 } // frame_audio::on_cancel()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Method called before closing the frame.
+ * \return True if the frame can be closed.
+ */
+bool ptb::frame_audio::on_close()
+{
+  if ( !m_ok_is_pressed )
+    cancel();
+
+  return super::on_close();
+} // frame_audio::on_close()
