@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -77,16 +77,15 @@ bear::gui::visual_component*
 ptb::frame_game_options::create_checkbox( bear::visual::font f )
 {
   bear::gui::checkbox* result =
-    new bear::gui::checkbox
-    ( &get_content(), frame::get_checkbox_off(), frame::get_checkbox_on(), f );
+    new bear::gui::checkbox( get_checkbox_off(), get_checkbox_on(), f );
 
   result->set_text( gettext("Friendly fire") );
   result->check( game_variables::get_friendly_fire() );
 
-  result->set_checked_callback
+  result->add_checked_callback
     ( bear::gui::callback_function_maker
       ( boost::bind( &frame_game_options::on_friendly_fire_check, this ) ) );
-  result->set_unchecked_callback
+  result->add_unchecked_callback
     ( bear::gui::callback_function_maker
       ( boost::bind( &frame_game_options::on_friendly_fire_uncheck, this ) ) );
 
@@ -104,7 +103,7 @@ ptb::frame_game_options::create_ok_button( bear::visual::font f )
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), f, "OK",
+    ( f, gettext("OK"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_game_options::on_ok, this ) ) );
 
@@ -125,7 +124,7 @@ ptb::frame_game_options::create_cancel_button( bear::visual::font f )
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), f, "Cancel",
+    ( f, "Cancel",
       bear::gui::callback_function_maker
       ( boost::bind( &frame_game_options::on_cancel, this ) ) );
 
