@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,9 +30,11 @@
 
 #include "engine/game.hpp"
 #include "ptb/game_variables.hpp"
-#include "ptb/frame/frame_start_menu.hpp"
 #include "ptb/frame/frame_configure.hpp"
+#include "ptb/frame/frame_profiles.hpp"
+#include "ptb/frame/frame_start_menu.hpp"
 #include "ptb/frame/frame_play_mini_game.hpp"
+
 #include "ptb/defines.hpp"
 
 #include "gui/callback_function.hpp"
@@ -123,20 +125,23 @@ void ptb::frame_main_menu::create_controls()
     ( gettext("Quit"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_main_menu::on_quit, this ) ) );
+
   push
     ( gettext("Configuration"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_main_menu::on_configuration, this ) ) );
+
   push
-    ( gettext("Play mini-game"),
+    ( gettext("Mini-game"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_main_menu::on_mini_game, this ) ) );
   push
-    ( gettext("Start tutorial"),
+    ( gettext("Tutorial"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_main_menu::on_tutorial, this ) ) );
+
   push
-    ( gettext("Start game"),
+    ( gettext("History"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_main_menu::on_game, this ) ) );
 
@@ -163,16 +168,22 @@ void ptb::frame_main_menu::on_focus()
     on_mini_game();
 } // frame_main_menu::on_focus()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Action done when clicking on the "Configuration" entry.
+ */
+void ptb::frame_main_menu::on_configuration()
+{
+  show_window( new frame_configure(&get_layer()) );
+} // frame_main_menu::on_configuration()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Action done when clicking on the "Start game" entry.
  */
 void ptb::frame_main_menu::on_game()
 {
-  game_variables::set_next_level_name( "level/intro.cl" );
-  show_window
-    ( new frame_start_menu
-      (&get_layer(), false, playability_type::one_or_two_players) );
+  show_window( new frame_profiles(&get_layer()) );
 } // frame_main_menu::on_game()
 
 /*----------------------------------------------------------------------------*/
@@ -189,24 +200,15 @@ void ptb::frame_main_menu::on_tutorial()
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Action done when clicking on the "Play mini-game" entry.
+ * \brief Action done when clicking on the "Play_Menu mini-game" entry.
  */
 void ptb::frame_main_menu::on_mini_game()
 {
   game_variables::set_mini_game( true );
   show_window( new frame_play_mini_game
-               (&get_layer(),PTB_MINI_GAME_INFORMATIONS) );
+               (&get_layer(), PTB_MINI_GAME_INFORMATIONS) );
 } // frame_main_menu::on_mini_game()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Action done when clicking on the "Configuration" entry.
- */
-void ptb::frame_main_menu::on_configuration()
-{
-  show_window( new frame_configure(&get_layer()) );
-} // frame_main_menu::()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Action done when clicking on the "Quit" entry.
