@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -31,8 +31,7 @@
 #include "ptb/frame/frame_start_menu.hpp"
 #include "ptb/frame/theme_colors.hpp"
 #include "ptb/game_variables.hpp"
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 
 #include "engine/game.hpp"
 #include "engine/resource_pool.hpp"
@@ -95,10 +94,9 @@ void ptb::frame_password::create_controls()
 bear::gui::visual_component* ptb::frame_password::create_input()
 {
   m_password =
-    new bear::gui::text_input
-    ( &get_content(), get_font(), claw::graphic::red_pixel );
+    new bear::gui::text_input( get_font(), claw::graphic::red_pixel );
 
-  m_password->set_enter_callback
+  m_password->add_enter_callback
     ( bear::gui::callback_function_maker
       ( boost::bind( &frame_password::validate, this ) ) );
 
@@ -117,7 +115,7 @@ bear::gui::visual_component* ptb::frame_password::create_back()
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), get_font(), gettext("Back"),
+    ( get_font(), gettext("Back"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_password::close_window, this ) ) );
 
@@ -126,7 +124,7 @@ bear::gui::visual_component* ptb::frame_password::create_back()
   insert_control(*result);
 
   return result;
-} // frame_language::create_back()
+} // frame_password::create_back()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -217,10 +215,10 @@ void ptb::frame_password::command_give
 
   if ( command.size() == 2 )
     {
-      player* player =
+      player_proxy p =
         util::find_player( get_layer().get_level_globals(), index );
 
-      if ( player != NULL )
+      if ( p != NULL )
         {
           const bool all = (command[1] == "all");
 
@@ -238,10 +236,10 @@ void ptb::frame_password::command_give
             game_variables::set_water_power(index, true);
 
           if ( all || (command[1] == "energy") )
-            player->receive_energy( game_variables::get_max_energy(index) );
+            p.receive_energy( game_variables::get_max_energy(index) );
 
           if ( all || (command[1] == "oxygen") )
-            player->receive_oxygen( player::s_max_oxygen );
+            p.receive_oxygen( p.get_oxygen_gauge().get_max_value() );
 
           if ( all || (command[1] == "life") )
             game_variables::set_lives_count
