@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -86,6 +86,17 @@ void ptb::frame_pause::on_resume() const
   close_window();
 } // frame_pause::on_resume()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Restart the level.
+ */
+void ptb::frame_pause::on_restart_level()
+{
+  bear::engine::game::get_instance().set_waiting_level
+    ( get_layer().get_level().get_filename() );
+  close_window();
+} // frame_pause::on_restart_level()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Come back to the title screen.
@@ -95,7 +106,7 @@ void ptb::frame_pause::on_title_screen()
   m_msg_result = message_box::s_ok | message_box::s_cancel;
   message_box* msg =
     new message_box
-    ( &get_layer(), gettext("You are leaving this level. Are you sure?"),
+    ( &get_layer(), gettext("Are you sure you want to leave this level?"),
       &m_msg_result );
 
   show_window(msg);
@@ -116,6 +127,13 @@ void ptb::frame_pause::on_configuration()
  */
 void ptb::frame_pause::create_controls()
 {
+#ifdef PTB_CAN_RESTART_LEVEL
+  push
+    ( gettext("Restart level"),
+      bear::gui::callback_function_maker
+      ( boost::bind( &frame_pause::on_restart_level, this ) ) );
+#endif
+
   push
     ( gettext("Back to title screen"),
       bear::gui::callback_function_maker
