@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -156,7 +156,7 @@ bear::gui::visual_component* ptb::frame_player_controls::create_ok_button()
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), get_font(), gettext("OK"),
+    ( get_font(), gettext("OK"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_player_controls::on_ok, this ) ) );
 
@@ -175,7 +175,7 @@ bear::gui::visual_component* ptb::frame_player_controls::create_cancel_button()
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), get_font(), gettext("Cancel"),
+    ( get_font(), gettext("Cancel"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_player_controls::close_window, this ) ) );
 
@@ -305,9 +305,8 @@ ptb::frame_player_controls::make_static_text
   if (!s.empty())
     s[0] = std::toupper(s[0], loc);
 
-  bear::gui::static_text* result =
-    new bear::gui::static_text(&get_content(), get_font());
-
+  bear::gui::static_text* result = new bear::gui::static_text(get_font());
+  get_content().insert(result);
   result->set_auto_size(true);
   result->set_bottom(b);
   result->set_text( gettext(s.c_str()) );
@@ -324,8 +323,7 @@ ptb::key_edit*
 ptb::frame_player_controls::make_key_edit_command( gui_command::value_type c )
 {
   key_edit* result =
-    new key_edit
-    ( &get_content(), get_font(), m_controller_layout.get_from_command(c) );
+    new key_edit( get_font(), m_controller_layout.get_from_command(c) );
 
   result->set_change_callback
     ( bear::gui::callback_function_maker
@@ -348,8 +346,7 @@ ptb::key_edit*
 ptb::frame_player_controls::make_key_edit_action( player_action::value_type a )
 {
   key_edit* result =
-    new key_edit
-    ( &get_content(), get_font(), m_controller_layout.get_from_action(a) );
+    new key_edit( get_font(), m_controller_layout.get_from_action(a) );
 
   result->set_change_callback
     ( bear::gui::callback_function_maker
