@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -45,7 +45,8 @@
  */
 ptb::frame_screen::frame_screen( windows_layer* owning_layer )
   : frame(owning_layer, gettext("Screen")),
-    m_saved_mode(bear::engine::game::get_instance().get_fullscreen())
+    m_saved_mode(bear::engine::game::get_instance().get_fullscreen()),
+    m_ok_is_pressed(false)
 {
   create_controls();
 } // frame_screen::frame_screen()
@@ -75,18 +76,17 @@ bear::gui::visual_component* ptb::frame_screen::create_checkbox()
 {
   bear::gui::checkbox* result =
     new bear::gui::checkbox
-    ( &get_content(), frame::get_checkbox_off(), frame::get_checkbox_on(),
-      get_font() );
+    ( get_checkbox_off(), get_checkbox_on(), get_font() );
 
   result->set_text( gettext("Fullscreen") );
   result->check( bear::engine::game::get_instance().get_fullscreen() );
 
-  result->set_checked_callback
+  result->add_checked_callback
     ( bear::gui::callback_function_maker
       ( boost::bind
         ( &bear::engine::game::set_fullscreen,
           &bear::engine::game::get_instance(), true ) ) );
-  result->set_unchecked_callback
+  result->add_unchecked_callback
     ( bear::gui::callback_function_maker
       ( boost::bind
         ( &bear::engine::game::set_fullscreen,
@@ -105,15 +105,16 @@ bear::gui::visual_component* ptb::frame_screen::create_ok_button()
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), get_font(), gettext("OK"),
+    ( get_font(), gettext("OK"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_screen::on_ok, this ) ) );
 
+  result->set_margin( get_margin() / 2 );
   set_borders_up(*result);
   insert_control(*result);
 
   return result;
-} // frame_language::create_ok_button()
+} // frame_screen::create_ok_button()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -123,15 +124,16 @@ bear::gui::visual_component* ptb::frame_screen::create_cancel_button()
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), get_font(), gettext("Cancel"),
+    ( get_font(), gettext("Cancel"),
       bear::gui::callback_function_maker
       ( boost::bind( &frame_screen::on_cancel, this ) ) );
 
+  result->set_margin( get_margin() / 2 );
   set_borders_up(*result);
   insert_control(*result);
 
   return result;
-} // frame_language::create_cancel_button()
+} // frame_screen::create_cancel_button()
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -139,6 +141,8 @@ bear::gui::visual_component* ptb::frame_screen::create_cancel_button()
  */
 bool ptb::frame_screen::on_ok()
 {
+  m_ok_is_pressed = true;
+
   config_file config;
   config.set_fullscreen( bear::engine::game::get_instance().get_fullscreen() );
   config.save();
@@ -154,9 +158,20 @@ bool ptb::frame_screen::on_ok()
  */
 bool ptb::frame_screen::on_cancel()
 {
-  if ( m_saved_mode != bear::engine::game::get_instance().get_fullscreen() )
-    bear::engine::game::get_instance().set_fullscreen( m_saved_mode );
-
   close_window();
   return true;
 } // frame_screen::on_cancel()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Method called before closing the frame.
+ * \return True if the frame can be closed.
+ */
+bool ptb::frame_screen::on_close()
+{
+  if ( !m_ok_is_pressed )
+    if ( m_saved_mode != bear::engine::game::get_instance().get_fullscreen() )
+      bear::engine::game::get_instance().set_fullscreen( m_saved_mode );
+
+  return super::on_close();
+} // frame_screen::on_close()
