@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -54,8 +54,7 @@ ptb::menu_frame::menu_frame
 void
 ptb::menu_frame::push( const std::string& text, const bear::gui::callback& c )
 {
-  bear::gui::button* b =
-    new bear::gui::button( &get_content(), get_font(), text, c );
+  bear::gui::button* b = new bear::gui::button( get_font(), text, c );
   b->set_margin(3);
 
   if ( m_top != NULL )
