@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -144,8 +144,9 @@ void ptb::message_box::create_controls( const std::string& msg )
 bear::gui::visual_component*
 ptb::message_box::create_text( const std::string& msg )
 {
-  bear::gui::static_text* result =
-    new bear::gui::static_text( &get_content(), get_font() );
+  bear::gui::static_text* result = new bear::gui::static_text( get_font() );
+
+  get_content().insert(result);
 
   result->set_size( get_size() / 2 );
   result->set_text( msg );
@@ -162,7 +163,7 @@ bear::gui::visual_component* ptb::message_box::create_ok_button()
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), get_font(), gettext("OK"),
+    ( get_font(), gettext("OK"),
       bear::gui::callback_function_maker
       ( boost::bind(&message_box::on_ok, this) ) );
 
@@ -181,7 +182,7 @@ bear::gui::visual_component* ptb::message_box::create_cancel_button()
 {
   bear::gui::button* result =
     new bear::gui::button
-    ( &get_content(), get_font(), gettext("Cancel"),
+    ( get_font(), gettext("Cancel"),
       bear::gui::callback_function_maker
       ( boost::bind(&message_box::on_cancel, this) ) );
 
