@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -54,6 +54,8 @@ namespace ptb
     bear::visual::sprite get_cursor() const;
     bear::visual::sprite get_checkbox_off() const;
     bear::visual::sprite get_checkbox_on() const;
+    bear::visual::sprite get_radio_off() const;
+    bear::visual::sprite get_radio_on() const;
     bear::visual::sprite get_slider_bar() const;
     bear::visual::sprite get_slider() const;
     bear::visual::font get_font() const;
@@ -68,6 +70,7 @@ namespace ptb
 
   protected:
     void show_window( frame* wnd ) const;
+    void replace_with( frame* wnd );
     void close_window() const;
 
     void insert_control( bear::gui::visual_component& c );
@@ -84,12 +87,7 @@ namespace ptb
     bool on_mouse_move( const claw::math::coordinate_2d<unsigned int>& pos );
 
   private:
-    bear::visual::sprite get_frame_sprite_at
-    ( unsigned int x, unsigned int y, unsigned int w, unsigned int h ) const;
-
-    bear::visual::sprite get_frame_sprite_at
-    ( const windows_layer* owner, unsigned int x, unsigned int y,
-      unsigned int w, unsigned int h ) const;
+    bear::visual::sprite get_frame_sprite( const std::string& name ) const;
 
     void common_init();
 
@@ -122,7 +120,6 @@ namespace ptb
 
     /** \brief The control currently highlighted. */
     std::size_t m_current_control;
-
   }; // class frame
 } // namespace ptb
 
