@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -41,6 +41,9 @@ namespace ptb
   class frame_audio:
     public frame
   {
+  public:
+    typedef frame super;
+
   public:
     frame_audio( windows_layer* in_layer );
 
@@ -56,9 +59,11 @@ namespace ptb
     bear::gui::visual_component* create_cancel_button( bear::visual::font f );
 
     void save();
+    void cancel() const;
 
     bool on_ok();
     bool on_cancel();
+    bool on_close();
 
   private:
     /* \brief The sound 'mute' status when the frame was shown. */
@@ -79,6 +84,9 @@ namespace ptb
     /** \brief Slider to control the volume of the music. */
     bear::gui::slider<double>* m_music_volume;
 
+    /** \brief Indicates if ok button has been pressed. */
+    bool m_ok_is_pressed;
+
   }; // class frame_audio
 } // namespace ptb
 
