@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -40,6 +40,9 @@ namespace ptb
   class frame_screen:
     public frame
   {
+  public:
+    typedef frame super;
+
   public:
     frame_screen( windows_layer* in_layer );
 
@@ -51,11 +54,14 @@ namespace ptb
 
     bool on_ok();
     bool on_cancel();
+    bool on_close();
 
   private:
     /* \brief The full screen mode when the frame is shown. */
     const bool m_saved_mode;
 
+    /** \brief Indicates if ok button has been pressed. */
+    bool m_ok_is_pressed;
   }; // class frame_screen
 } // namespace ptb
 
