@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -67,6 +67,8 @@ namespace ptb
     void build();
 
     bool set_bool_field( const std::string& name, bool value );
+    bool set_animation_field
+    ( const std::string& name, const bear::visual::animation& value );
     bool set_item_field
     ( const std::string& name, bear::engine::base_item* value );
 
@@ -77,6 +79,10 @@ namespace ptb
     /** \brief The timer of the level, shown in the status layer. */
     bear::timer* m_timer;
 
+    /** \brief The animation for the corrupting bonus, displayed in the status
+        layer. */
+    bear::visual::animation m_corrupting_animation;
+
   }; // class add_ingame_layers
 } // namespace ptb
 
