@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -36,6 +36,7 @@ namespace ptb
   /**
    * \brief A bonus box.
    *
+   * The valid fields for this item are
    *  - any field supported by the parent classes.
    *
    * \author Sebastien Angibaud
@@ -65,6 +66,7 @@ namespace ptb
 
     void do_set_type(base_bonus_type t);
     void create_honeypot_decoration();
+    void create_level_bonus();
   }; // class bonus_box
 } // namespace ptb
 
