@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -36,6 +36,7 @@
 #include "ptb/layer/balloon_layer.hpp"
 #include "ptb/layer/ingame_menu_layer.hpp"
 #include "ptb/layer/misc_layer.hpp"
+#include "ptb/layer/physics_layer.hpp"
 #include "ptb/layer/player_arrows_layer.hpp"
 #include "ptb/layer/status_layer.hpp"
 #include "ptb/transition_effect/level_starting_effect.hpp"
@@ -71,8 +72,8 @@ void ptb::add_ingame_layers::pre_cache()
   get_level_globals().load_font("font/fixed_white-7x12.fnt");
   get_level_globals().load_font("font/fixed_yellow-10x20.fnt");
   get_level_globals().load_font("font/level_name-42x50.fnt");
-  get_level_globals().load_image("gfx/frame.tga");
-  get_level_globals().load_image("gfx/status.png");
+  get_level_globals().load_image("gfx/ui/frame.png");
+  get_level_globals().load_image("gfx/ui/status/status.png");
 } // add_ingame_layers::pre_cache()
 
 /*----------------------------------------------------------------------------*/
@@ -85,11 +86,14 @@ void ptb::add_ingame_layers::build()
     ( new bear::engine::transition_layer
       (PTB_TRANSITION_EFFECT_DEFAULT_TARGET_NAME) );
 
-  status_layer* status( new status_layer );
+  status_layer* status
+    ( new status_layer(PTB_STATUS_LAYER_DEFAULT_TARGET_NAME) );
 
   if ( m_timer != NULL )
     status->set_timer(m_timer);
 
+  status->set_corrupting_bonus(m_corrupting_animation);
+
   get_level().push_layer( status );
   get_level().push_layer( new player_arrows_layer );
   get_level().push_layer
@@ -103,6 +107,7 @@ void ptb::add_ingame_layers::build()
 
 #ifndef NDEBUG
   get_level().push_layer( new link_layer );
+  get_level().push_layer( new physics_layer );
   get_level().push_layer( new wireframe_layer );
   get_level().push_layer( new item_information_layer );
   get_level().push_layer( new recent_path_layer );
@@ -110,6 +115,8 @@ void ptb::add_ingame_layers::build()
 
   if (m_add_starting_effect)
     transition->push_effect( new level_starting_effect, 1000 );
+
+  kill();
 } // add_ingame_layers::build()
 
 /*----------------------------------------------------------------------------*/
@@ -131,6 +138,25 @@ ptb::add_ingame_layers::set_bool_field( const std::string& name, bool value )
   return result;
 } // add_ingame_layers::set_bool_field()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set a field of type \c animation.
+ * \param name The name of the field.
+ * \param v The value of the field.
+ */
+bool ptb::add_ingame_layers::set_animation_field
+( const std::string& name, const bear::visual::animation& value )
+{
+  bool result(true);
+
+  if ( name == "add_ingame_layers.corrupting_bonus_animation" )
+    m_corrupting_animation = value;
+  else
+    result = super::set_animation_field(name, value);
+
+  return result;
+} // add_ingame_layers::set_animation_field()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set a field of type \c item.
