@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -52,7 +52,7 @@ void ptb::add_main_menu_layer::pre_cache()
 {
   get_level_globals().load_font("font/fixed_white-7x12.fnt");
   get_level_globals().load_font("font/fixed_yellow-10x20.fnt");
-  get_level_globals().load_image("gfx/frame.tga");
+  get_level_globals().load_image("gfx/ui/frame.png");
 } // add_main_menu_layer::pre_cache()
 
 /*----------------------------------------------------------------------------*/
