@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -27,8 +27,9 @@
  * \author Sbastien Angibaud
  */
 #include "ptb/item/air_bubble.hpp"
-#include "ptb/player.hpp"
-#include "engine/export.hpp"
+
+#include "ptb/player_proxy.hpp"
+#include "engine/level_globals.hpp"
 
 #include "universe/forced_movement/forced_translation.hpp"
 #include "universe/physical_item_state.hpp"
@@ -73,7 +74,7 @@ void ptb::air_bubble::progress( bear::universe::time_type elapsed_time )
         {
           double f = (double)(get_mass() * 2000.0 * rand() / RAND_MAX) -
             get_mass() * 1000;
-          add_internal_force(bear::universe::force_type(f,0));
+          add_internal_force(bear::universe::force_type(f, 0));
         }
 
     }
@@ -112,9 +113,9 @@ void ptb::air_bubble::build()
   m_sprite = get_level_globals().auto_sprite("gfx/bubble.png", "bubble");
 
   if ( m_oxygen < 0 )
-    m_sprite.set_intensity(0.8,0.9,0.4);
+    m_sprite.set_intensity(0.8, 0.9, 0.4);
   else
-    m_sprite.set_intensity(1,1,1);
+    m_sprite.set_intensity(1, 1, 1);
 
   m_sprite.set_size( get_size() );
 } // air_bubble::build()
@@ -130,16 +131,16 @@ void ptb::air_bubble::collision
 {
   if ( get_width() >= (unsigned int)s_min_size )
     {
-      player* other = dynamic_cast<player*>(&that);
+      player_proxy other(&that);
 
       if (other != NULL)
         {
           bear::engine::model_mark_placement m;
 
-          if ( other->get_mark_placement("mouth",m) )
+          if ( other.get_mark_placement("mouth", m) )
             if ( get_bounding_box().includes( m.get_position()) )
               {
-                other->receive_oxygen(m_oxygen);
+                other.receive_oxygen(m_oxygen);
                 m_oxygen = 0;
                 kill();
               }
