@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -32,7 +32,7 @@
 #include "universe/forced_movement/forced_translation.hpp"
 #include "universe/physical_item_state.hpp"
 #include "universe/world.hpp"
-#include "ptb/player.hpp"
+#include "ptb/player_proxy.hpp"
 #include "ptb/item/air_bubble.hpp"
 
 BASE_ITEM_EXPORT( air_bubble_generator, ptb )
@@ -65,7 +65,7 @@ void ptb::air_bubble_generator::progress
       m_last_bubble += elapsed_time;
       if ( m_last_bubble >= m_duration_sequence[m_index_duration] )
         create_bubble();
-        
+
       if (  m_duration_decorative_sequence.size() != 0 )
         {
           m_last_decorative_bubble += elapsed_time;
@@ -87,7 +87,7 @@ void ptb::air_bubble_generator::progress
 void ptb::air_bubble_generator::collision
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  ptb::player* other = dynamic_cast<ptb::player*>(&that);
+  player_proxy other(&that);
 
   if (other != NULL)
     m_activated = false;
@@ -113,7 +113,7 @@ ptb::air_bubble_generator::set_real_list_field
   else if (name == "air_bubble_generator.duration_decorative_sequence")
     m_duration_decorative_sequence = value;
   else
-    ok = super::set_real_list_field(name,value);
+    ok = super::set_real_list_field(name, value);
 
   return ok;
 } // air_bubble_generator::set_real_list_field()
@@ -147,9 +147,9 @@ void ptb::air_bubble_generator::create_bubble()
   m_last_bubble = 0;
 
   if ( m_oxygen_sequence[m_index_oxygen] < 0 )
-    get_animation().set_intensity(0.8,0.9,0.4);
+    get_animation().set_intensity(0.8, 0.9, 0.4);
   else
-    get_animation().set_intensity(1,1,1);
+    get_animation().set_intensity(1, 1, 1);
 } // air_bubble_generator::create_bubble()
 
 /*----------------------------------------------------------------------------*/
