@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,11 +28,16 @@
  */
 #include "ptb/item/bonus_box.hpp"
 
+#include "ptb/item/bonus_points/bonus_all_dead.hpp"
+#include "ptb/level_variables.hpp"
+#include "ptb/player_proxy.hpp"
+
 #include "universe/collision_info.hpp"
+
 #include "generic_items/decorative_item.hpp"
-#include "ptb/player.hpp"
-#include "engine/game.hpp"
 #include "generic_items/decorative_effect.hpp"
+
+#include "engine/game.hpp"
 #include "engine/world.hpp"
 #include "engine/layer/layer.hpp"
 #include "engine/export.hpp"
@@ -60,6 +65,8 @@ void ptb::bonus_box::pre_cache()
   get_level_globals().load_animation("animation/powerup/one_more_life.canim");
   get_level_globals().load_animation
     ("animation/powerup/increase_max_energy.canim");
+  get_level_globals().load_animation
+    ("animation/powerup/increase_max_energy-alt.canim");
   //get_level_globals().load_animation
   //  ("animation/powerup/switch_players.canim");
 
@@ -68,7 +75,7 @@ void ptb::bonus_box::pre_cache()
   get_level_globals().load_animation("animation/powerup/small_water.canim");
   get_level_globals().load_animation( "animation/stones/stone.canim" );
 
-  get_level_globals().load_image("gfx/bonus-box-extra.png");
+  get_level_globals().load_image("gfx/bonus-box-2.png");
 } // bonus_box::pre_cache()
 
 /*----------------------------------------------------------------------------*/
@@ -79,6 +86,15 @@ void ptb::bonus_box::build()
 {
   super::build();
 
+  level_variables::set_object_count
+        ( this->get_level(), "bonus_box",
+          level_variables::get_object_count
+          ( this->get_level(), "bonus_box" ) + 1);
+
+  if ( level_variables::get_object_count
+       ( this->get_level(), "bonus_box" ) == 1 )
+    create_level_bonus();
+
   set_size( 50, 80 );
   set_gap_x(-5);
 } // bonus_box::build()
@@ -92,20 +108,22 @@ void ptb::bonus_box::build()
 void ptb::bonus_box::collision_check_and_apply
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
     {
-      if ( !get_bonus_given() &&
-           ( ( info.get_collision_side() ==
-             bear::universe::zone::middle_left_zone ) ||
-           ( info.get_collision_side() ==
-             bear::universe::zone::middle_right_zone ) ) &&
-           p->is_in_offensive_phase() )
+      if ( !get_bonus_given()
+           && ( ( info.get_collision_side()
+                  == bear::universe::zone::middle_left_zone )
+                ||
+                ( info.get_collision_side()
+                  == bear::universe::zone::middle_right_zone ) )
+           && p.is_in_offensive_phase()
+           && can_give_bonus(p) )
         {
           give_bonus(p);
           create_broken_bonus_box();
-          create_broken_glass(p->get_rendering_attributes().is_mirrored());
+          create_broken_glass(p.get_rendering_attributes().is_mirrored());
           create_honeypot_decoration();
         }
       else
@@ -137,7 +155,7 @@ void ptb::bonus_box::create_broken_bonus_box()
 
    item->set_sprite
      ( get_level_globals().auto_sprite
-       ( "gfx/bonus-box-extra.png", "broken box bottom" ) );
+       ( "gfx/bonus-box-2.png", "broken box bottom" ) );
    item->set_z_position(get_z_position());
    item->set_mass(get_mass());
    item->set_density(get_density());
@@ -163,7 +181,7 @@ void ptb::bonus_box::create_broken_glass(bool left_orientation)
 
   item->set_sprite
      ( get_level_globals().auto_sprite
-       ( "gfx/bonus-box-extra.png", "broken box top" ) );
+       ( "gfx/bonus-box-2.png", "broken box top" ) );
   item->get_rendering_attributes().set_angle(get_visual_angle());
   item->set_z_position(get_z_position());
   item->set_mass(5);
@@ -228,8 +246,12 @@ void ptb::bonus_box::do_set_type(base_bonus_type t)
       set_stock(1);
       break;
     case increase_max_energy:
-      set_animation( get_level_globals().get_animation
-                     ("animation/powerup/increase_max_energy.canim") );
+      if ( get_player_index() == 2 )
+        set_animation( get_level_globals().get_animation
+                       ("animation/powerup/increase_max_energy-alt.canim") );
+      else
+        set_animation( get_level_globals().get_animation
+                       ("animation/powerup/increase_max_energy.canim") );
       set_stock(20);
       break;
     case switch_players:
@@ -256,25 +278,24 @@ void ptb::bonus_box::create_honeypot_decoration()
     {
     case fire_power:
       item->set_animation
-     ( get_level_globals().get_animation
-       ("animation/powerup/small_fire.canim") );
+        ( get_level_globals().get_animation
+          ("animation/powerup/small_fire.canim") );
       break;
     case air_power:
       item->set_animation
-     ( get_level_globals().get_animation
-       ("animation/powerup/small_air.canim") );
+        ( get_level_globals().get_animation
+          ("animation/powerup/small_air.canim") );
       break;
     case water_power:
       item->set_animation
-     ( get_level_globals().get_animation
-       ("animation/powerup/small_water.canim") );
+        ( get_level_globals().get_animation
+          ("animation/powerup/small_water.canim") );
       break;
     case stones_stock:
     case stones_big_stock:
       item->set_animation
         (get_level_globals().get_animation
          ("animation/stones/stone.canim" ) );
-      set_stock(20);
       break;
 
     default:
@@ -285,8 +306,9 @@ void ptb::bonus_box::create_honeypot_decoration()
     {
       item->set_z_position(get_z_position()+1);
       item->set_mass(1);
-      item->set_density(0.8*get_layer().get_world().get_average_density
-                  (get_bounding_box()));
+      item->set_density
+        (0.8 * get_layer().get_world().get_average_density
+         (get_bounding_box()));
       item->set_kill_when_leaving(true);
 
       new_item( *item );
@@ -294,7 +316,7 @@ void ptb::bonus_box::create_honeypot_decoration()
       item->set_top_middle(get_top_middle());
 
       CLAW_ASSERT( item->is_valid(),
-                   "In bonus_box class : the decoration of honeypot isn't "
+                   "In bonus_box class: the decoration of honeypot isn't "
                    "correctly initialized" );
 
       bear::decorative_effect* decoration_effect = new bear::decorative_effect;
@@ -309,3 +331,24 @@ void ptb::bonus_box::create_honeypot_decoration()
   else
     delete item;
 } // bonus_box::create_honeypot_decoration()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create level bonus objects.
+ */
+void ptb::bonus_box::create_level_bonus()
+{
+  bonus_all_dead* new_bonus = new bonus_all_dead( "All bonus boxes", 5000 );
+
+  new_bonus->set_picture_filename("gfx/ui/bonus-icons/bonus-icons.png");
+  new_bonus->set_picture_name("bonus boxes");
+
+  std::list<std::string> classes;
+  classes.push_back( get_class_name() );
+  new_bonus->set_class_names(classes);
+
+  new_item( *new_bonus );
+  CLAW_ASSERT(new_bonus->is_valid(),
+              "The bonus isn't correctly initialized" );
+  new_bonus->set_center_of_mass(get_center_of_mass());
+} // bonus_box::create_level_bonus()
