@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -27,12 +27,23 @@
  * \author Sebastien Angibaud
  */
 #include "ptb/item/clingable.hpp"
-#include "ptb/player.hpp"
+
+#include "ptb/player_proxy.hpp"
 
 #include <algorithm>
 
 BASE_ITEM_EXPORT( clingable, ptb )
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Constructor.
+ */
+ptb::clingable::clingable()
+{
+  set_phantom(true);
+  set_weak_collisions(true);
+} // clingable::clingable()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Do post creation actions.
@@ -105,13 +116,13 @@ void ptb::clingable::move( bear::universe::time_type elapsed_time )
 void ptb::clingable::collision_check_and_apply
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
     {
-      p->set_can_cling(true);
+      p.set_can_cling(true);
 
-      if ( p->is_clung() )
+      if ( p.is_clung() )
         m_list_items.push_front(that);
     }
 } // clingable::collision_check_and_apply()
@@ -127,7 +138,7 @@ void ptb::clingable::collision
 {
   collision_check_and_apply(that, info);
 
-  super::collision(that,info);
+  super::collision(that, info);
 } // clingable::collision()
 
 /*----------------------------------------------------------------------------*/
