@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,10 +28,15 @@
  */
 #include "ptb/item/corrupting_bonus.hpp"
 
-#include "ptb/player.hpp"
+#include "ptb/player_proxy.hpp"
 #include "ptb/item/stone/stone.hpp"
 #include "ptb/game_variables.hpp"
 #include "ptb/item/floating_score.hpp"
+#include "ptb/util/player_util.hpp"
+
+#include "universe/forced_movement/base_reference_point.hpp"
+#include "universe/forced_movement/forced_aiming.hpp"
+
 #include "generic_items/decorative_item.hpp"
 
 BASE_ITEM_EXPORT( corrupting_bonus, ptb )
@@ -59,6 +64,31 @@ void ptb::corrupting_bonus::pre_cache()
   get_level_globals().load_sound("sound/corrupting-bonus.ogg");
 } // corrupting_bonus::pre_cache()
 
+/*---------------------------------------------------------------------------*/
+/**
+ * \brief Inform the corrupting bonus that is attracted.
+ * \param attractor The attractor.
+ */
+void ptb::corrupting_bonus::attract(bear::universe::physical_item& attractor)
+{
+  if ( !has_forced_movement() )
+    {
+      set_mass(1);
+      set_global(true);
+
+      bear::universe::forced_aiming movement;
+
+      movement.set_max_angle( 0.05 );
+      movement.set_acceleration( 1000 );
+      movement.set_max_speed( 1000 );
+      movement.set_reference_point_on_center( attractor );
+      movement.set_item( *this );
+      movement.set_auto_remove(true);
+
+      set_forced_movement( movement );
+    }
+} // corrupting_bonus::attract()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Check if the collision is with a player.
@@ -68,22 +98,31 @@ void ptb::corrupting_bonus::pre_cache()
 void ptb::corrupting_bonus::collision_check_and_apply
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
-  stone* s = dynamic_cast<stone*>(&that);
-
-  if ( ( p != NULL ) || ( s != NULL ) )
+  if ( m_bonus_given )
+    default_collision(info);
+  else
     {
-      if ( !m_bonus_given )
+      bool ok(false);
+      stone* s = dynamic_cast<stone*>(&that);
+
+      if ( s != NULL )
+        {
+          ok = true;
+          create_floating_score(s->get_monster_index());
+        }
+      else
+        {
+          player_proxy p(&that);
+          if ( p != NULL )
+            {
+              ok = true;
+              create_floating_score(p.get_index());
+            }
+        }
+
+      if ( ok )
         {
           create_decoration();
-
-          if ( p != NULL )
-            create_floating_score(p->get_index());
-          else if ( s->get_monster_type() == monster::stone_1_monster )
-            create_floating_score(1);
-          else
-            create_floating_score(2);
-
           m_bonus_given = true;
           game_variables::set_corrupting_bonus_count
             (game_variables::get_corrupting_bonus_count() + 1);
@@ -94,8 +133,6 @@ void ptb::corrupting_bonus::collision_check_and_apply
       else
         default_collision(info);
     }
-  else
-    default_collision(info);
 } // corrupting_bonus::collision_check_and_apply()
 
 /*----------------------------------------------------------------------------*/
@@ -148,5 +185,5 @@ void ptb::corrupting_bonus::create_floating_score
   new_item(*s);
 
   s->add_points( index, 10 );
-  s->get_rendering_attributes().set_intensity(1,1,0);
+  s->get_rendering_attributes().set_intensity(1, 1, 0);
 } // corrupting_bonus::create_floating_score()
