@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -205,7 +205,7 @@ void ptb::demo_level_loader::progress
  */
 bool ptb::demo_level_loader::key_pressed( const bear::input::key_info& key )
 {
-  m_elapsed_time = 0;
+  m_elapsed_time = std::numeric_limits<bear::universe::time_type>::infinity();
   return true;
 } // demo_level_loader::key_pressed()
 
@@ -218,7 +218,7 @@ bool ptb::demo_level_loader::key_pressed( const bear::input::key_info& key )
 bool ptb::demo_level_loader::button_pressed
 ( bear::input::joystick::joy_code button, unsigned int joy_index )
 {
-  m_elapsed_time = 0;
+  m_elapsed_time = std::numeric_limits<bear::universe::time_type>::infinity();
   return true;
 } // demo_level_loader::button_pressed()
 
@@ -232,18 +232,6 @@ bool ptb::demo_level_loader::mouse_pressed
 ( bear::input::mouse::mouse_code button,
   const claw::math::coordinate_2d<unsigned int>& pos )
 {
-  m_elapsed_time = 0;
+  m_elapsed_time = std::numeric_limits<bear::universe::time_type>::infinity();
   return true;
 } // demo_level_loader::mouse_pressed()
-
-/*----------------------------------------------------------------------------*/
-/**
- * \brief The mouse is moving. Reset the timer.
- * \param pos The new position of the mouse.
- */
-bool ptb::demo_level_loader::mouse_move
-( const claw::math::coordinate_2d<unsigned int>& pos )
-{
-  m_elapsed_time = 0;
-  return false;
-} // demo_level_loader::mouse_move()
