@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -32,8 +32,7 @@
 
 #include "ptb/defines.hpp"
 #include "ptb/game_variables.hpp"
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 
 #include <sstream>
 #include <limits>
@@ -87,6 +86,8 @@ void ptb::floating_score::add_points
 
   game_variables::set_score( player_index, new_score );
 
+  player_proxy p = util::find_player( get_level_globals(), player_index );
+
   // check if the player wins a new try
 
   if ( (old_score / PTB_ONE_UP_POINTS_COUNT)
@@ -169,16 +170,8 @@ void ptb::floating_score::create_effect()
  */
 void ptb::floating_score::give_one_up_to( unsigned int player_index ) const
 {
-  player* p = util::find_player( get_level_globals(), player_index );
+  player_proxy p = util::find_player( get_level_globals(), player_index );
 
   if ( p != NULL )
-    {
-      floating_score* s = new floating_score;
-
-      new_item(*s);
-
-      s->set_center_of_mass( p->get_center_of_mass() );
-      s->set_z_position( std::numeric_limits<int>::max() );
-      s->one_up(player_index);
-    }
+    p.give_one_up();
 } // floating_score::give_one_up_to()
