@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,9 +28,8 @@
  */
 #include "ptb/item/hideout_revealing.hpp"
 
+#include "ptb/util/player_util.hpp"
 #include "generic_items/decorative_item.hpp"
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
 
 BASE_ITEM_EXPORT( hideout_revealing, ptb )
 
@@ -42,12 +41,11 @@ ptb::hideout_revealing::hideout_revealing()
   : m_player_in_zone(false), m_definitive_disclosure(false),
     m_revealing_opacity(0), m_hideout_opacity(1),
     m_current_revealed(false), m_last_revealed(false),
-    m_hideout_found(false), m_revelation_duration(0.25), m_last_modification(0),
-    m_first_player(NULL), m_second_player(NULL)
+    m_hideout_found(false), m_revelation_duration(0.25),
+    m_last_modification(0)
 {
   set_phantom(true);
   set_can_move_items(false);
-  m_items.clear();
 } // hideout_revealing::hideout_revealing()
 
 /*----------------------------------------------------------------------------*/
@@ -65,17 +63,13 @@ ptb::hideout_revealing::progress( bear::universe::time_type elapsed_time )
     {
       search_players();
 
-      if ( m_first_player.get() != NULL )
+      if ( m_first_player != NULL )
         player_in_zone =
-          m_first_player->get_bounding_box().intersects(get_bounding_box());
+          m_first_player.get_bounding_box().intersects(get_bounding_box());
 
-      if ( !player_in_zone )
-        {
-          if ( m_second_player.get() != NULL )
-            player_in_zone =
-              m_second_player->get_bounding_box().intersects
-              (get_bounding_box());
-        }
+      if ( !player_in_zone && (m_second_player != NULL) )
+        player_in_zone =
+          m_second_player.get_bounding_box().intersects(get_bounding_box());
 
       if ( player_in_zone )
         {
@@ -195,10 +189,10 @@ bool ptb::hideout_revealing::set_real_field
  */
 void ptb::hideout_revealing::search_players()
 {
-  if ( m_first_player == (player*)NULL )
+  if ( m_first_player == NULL )
     m_first_player = util::find_player( get_level_globals(), 1 );
 
-  if ( m_second_player == (player*)NULL )
+  if ( m_second_player == NULL )
     m_second_player = util::find_player( get_level_globals(), 2 );
 } // hideout_revealing::search_players()
 
@@ -225,7 +219,7 @@ void ptb::hideout_revealing::reveal()
           bear::decorative_item*
             deco = dynamic_cast<bear::decorative_item*>(it->get());
           if ( deco != NULL )
-            deco->get_rendering_attributes().set_opacity(opacity) ;
+            deco->get_rendering_attributes().set_opacity(opacity);
         }
     }
 } // hideout_revealing::reveal()
@@ -238,7 +232,7 @@ void ptb::hideout_revealing::hide()
 {
   double opacity =
     m_revealing_opacity + (m_hideout_opacity-m_revealing_opacity) *
-    m_last_modification / m_revelation_duration ;
+    m_last_modification / m_revelation_duration;
 
   if ( opacity <= 0 )
     opacity = 0;
