@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,10 +28,13 @@
  */
 #include "ptb/item/honeypot.hpp"
 
-#include "ptb/player.hpp"
+#include "ptb/item/bonus_points/bonus_points.hpp"
+#include "ptb/game_variables.hpp"
 #include "ptb/level_variables.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 #include "generic_items/decorative_item.hpp"
+#include "engine/function/bool_level_variable_getter.hpp"
+#include "engine/function/linear_level_variable_getter.hpp"
 
 BASE_ITEM_EXPORT( honeypot, ptb )
 
@@ -63,9 +66,36 @@ void ptb::honeypot::build()
 {
   super::build();
 
+  level_variables::set_object_count
+        ( get_level(), "honeypot",
+          level_variables::get_object_count( get_level(), "honeypot" ) + 1);
+  m_id = level_variables::get_object_count( get_level(), "honeypot" );
+
+  std::ostringstream s;
+  s << "honeypot " << m_id;
+  std::string name(s.str());
+
+  create_level_bonus(name);
+
+  level_variables::set_honeypot_found
+    ( get_level(), m_id, game_variables::get_level_object_state
+      (game_variables::get_main_level_name(), name ));
+
+  game_variables::set_level_object_state
+    (name, level_variables::get_honeypot_found(get_level(), m_id));
+  game_variables::set_level_object_filename
+    (name, "gfx/ui/bonus-icons/bonus-icons.png");
+  game_variables::set_level_object_name(name, name);
+
   set_animation
     ( get_level_globals().get_animation("animation/shiny-honey-jar.canim") );
 
+  if ( level_variables::get_honeypot_found(get_level(), m_id) )
+    {
+      get_rendering_attributes().set_intensity( 0.25, 0.25, 1 );
+      get_rendering_attributes().set_opacity( 0.5 );
+    }
+
   set_size( 64, 64 );
 } // honeypot::build()
 
@@ -78,7 +108,7 @@ void ptb::honeypot::build()
 void ptb::honeypot::collision_check_and_apply
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
     {
@@ -89,6 +119,7 @@ void ptb::honeypot::collision_check_and_apply
           level_variables::set_honeypots_found
             ( get_level(),
               level_variables::get_honeypots_found(get_level()) + 1 );
+          level_variables::set_honeypot_found( get_level(), m_id, true);
 
           if ( level_variables::get_honeypots_found(get_level()) % 5 == 0 )
             {
@@ -116,6 +147,7 @@ void ptb::honeypot::collision
 {
   collision_check_and_apply(that, info);
 } // honeypot::collision()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Give a life at each player.
@@ -151,3 +183,37 @@ void ptb::honeypot::create_decoration()
                "The decoration of corrupting_bonus isn't correctly "
                "initialized" );
 } // honeypot::create_decoration()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create level bonus objects.
+ */
+void ptb::honeypot::create_level_bonus(const std::string& name)
+{
+  bonus_points* new_bonus = new bonus_points( name, 0 );
+
+  new_bonus->set_picture_filename("gfx/ui/bonus-icons/bonus-icons.png");
+  new_bonus->set_picture_name(name);
+  new_bonus->set_condition
+    ( bear::engine::bool_level_variable_getter(&get_level(), name) );
+
+  new_item( *new_bonus );
+  CLAW_ASSERT(new_bonus->is_valid(),
+              "The bonus isn't correctly initialized" );
+  new_bonus->set_center_of_mass(get_center_of_mass());
+
+  if ( m_id == 1 )
+    {
+      bonus_points* bonus = new bonus_points( "Honey pots", 5000 );
+
+      bonus->set_points
+        ( 5000
+          * bear::engine::linear_level_variable_getter<unsigned int>
+          (&get_level(), "honeypots_found") );
+
+      new_item( *bonus );
+      CLAW_ASSERT(new_bonus->is_valid(),
+                  "The bonus isn't correctly initialized" );
+      bonus->set_center_of_mass(get_center_of_mass());
+    }
+} // honeypot::create_level_bonus()
