@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -31,8 +31,7 @@
 #include "ptb/defines.hpp"
 #include "ptb/game_variables.hpp"
 #include "ptb/level_variables.hpp"
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 
 #include "ptb/transition_effect/level_ending_effect.hpp"
 #include "engine/message/transition_effect_message.hpp"
@@ -44,12 +43,25 @@ BASE_ITEM_EXPORT( level_exit, ptb )
  * \brief Constructor.
  */
 ptb::level_exit::level_exit()
-: m_timer(NULL)
 {
   set_phantom(true);
   set_can_move_items(false);
 } // level_exit::level_exit()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Initialize the item.
+ */
+void ptb::level_exit::build()
+{
+  super::build();
+
+  game_variables::set_level_name
+    (get_level().get_filename(), get_level().get_name());
+  game_variables::set_level_precedence
+    (get_level().get_filename(), m_level_name);
+} // level_exit::build()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Do one iteration in the progression of the item.
@@ -63,17 +75,19 @@ void ptb::level_exit::progress
     {
       level_variables::set_exiting( get_level() );
       game_variables::set_next_level_name(m_level_name);
+      game_variables::set_finished_level(get_level().get_filename(), true);
 
       for (unsigned int i=1; i<=game_variables::get_players_count(); ++i)
         {
-          player* p = util::find_player( get_level_globals(), i );
+          player_proxy p = util::find_player( get_level_globals(), i );
           if ( p != NULL )
-            p->set_marionette(true);
+            p.set_marionette(true);
         }
 
       bear::engine::transition_effect_message<level_ending_effect> msg;
 
-      msg.get_effect().set_timer(m_timer.get());
+      if ( has_world() )
+        msg.get_effect().set_world( &get_world() );
 
       get_level_globals().send_message
         ( PTB_TRANSITION_EFFECT_DEFAULT_TARGET_NAME, msg );
@@ -113,26 +127,6 @@ bool ptb::level_exit::set_string_field
   return result;
 } // level_exit::set_string_field()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Set a field of type <item>.
- * \param name The name of the field.
- * \param value The new value of the field.
- * \return false if the field "name" is unknow, true otherwise.
- */
-bool ptb::level_exit::set_item_field
-( const std::string& name, bear::engine::base_item* value )
-{
-  bool result(true);
-
-  if ( name == "level_exit.level_timer" )
-    m_timer = value;
-  else
-    result = super::set_item_field( name, value );
-
-  return result;
-} // level_exit::set_item_field()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Check if the collision is with a player.
@@ -142,11 +136,14 @@ bool ptb::level_exit::set_item_field
 void ptb::level_exit::collision_check_and_apply
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
     {
-      game_variables::set_last_level_exit( p->get_index(), m_exit_name );
+      game_variables::set_last_corrupting_bonus_count
+        ( m_level_name, game_variables::get_corrupting_bonus_count() );
+      game_variables::set_last_level_exit
+        ( m_level_name, p.get_index(), m_exit_name );
       level_variables::set_players_on_exit
         ( get_level(), level_variables::get_players_on_exit(get_level()) + 1 );
     }
