@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,7 +30,7 @@
 
 #include "ptb/defines.hpp"
 #include "ptb/game_variables.hpp"
-#include "ptb/player.hpp"
+#include "ptb/player_proxy.hpp"
 
 #include "engine/game.hpp"
 
@@ -109,7 +109,7 @@ bool ptb::level_pusher::is_valid() const
 void ptb::level_pusher::collision_check_and_apply
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
     ++m_players_count;
