@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,10 +28,9 @@
  */
 #include "ptb/item/link_on_players.hpp"
 
+#include "ptb/player.hpp"
 #include "universe/link/link.hpp"
 
-#include "engine/export.hpp"
-
 BASE_ITEM_EXPORT( link_on_players, ptb )
 
 /*----------------------------------------------------------------------------*/
@@ -139,21 +138,26 @@ bool ptb::link_on_players::set_item_field
  * \param p1 The first player.
  * \param p2 The second player.
  */
-void ptb::link_on_players::on_all_players( player* p1, player* p2 )
+void ptb::link_on_players::on_all_players
+( const player_proxy& p1, const player_proxy& p2 )
 {
+  player* player_1(p1.get_player_instance());
+  player* player_2(p2.get_player_instance());
+
   // all players does not mean two players in single player game.
-  if ( (p1 != NULL) && (p2 != NULL) )
+  if ( (player_1 != NULL) && (player_2 != NULL) )
     {
-      if ( !p1->is_linked_to(*p2) )
+      if ( !player_1->is_linked_to(*player_2) )
         {
           bear::universe::link* link
             ( new bear::universe::link
-              ( *p1, *p2, m_strength, m_minimal_length, m_maximal_length ) );
+              ( *player_1, *player_2, m_strength, m_minimal_length,
+                m_maximal_length ) );
 
           if (m_link_visual != NULL)
             {
               bear::base_link_visual* vis(m_link_visual->clone());
-              vis->set_items(p1, p2, link->get_id());
+              vis->set_items(player_1, player_2, link->get_id());
               new_item(*vis);
             }
         }
