@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,8 +29,7 @@
 #include "ptb/item/little_plee.hpp"
 
 #include "ptb/item/floating_score.hpp"
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 
 #include "engine/layer/layer.hpp"
 #include "engine/level.hpp"
@@ -128,7 +127,7 @@ void ptb::little_plee::collision
   if ( m_life_given )
     return;
 
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
     {
@@ -139,7 +138,7 @@ void ptb::little_plee::collision
       s->set_z_position( get_z_position() + 10 );
       s->set_center_of_mass( get_center_of_mass() );
 
-      s->one_up( p->get_index() );
+      s->one_up( p.get_index() );
 
       m_life_given = true;
       kill();
@@ -186,9 +185,9 @@ void ptb::little_plee::progress_run()
               ( !get_rendering_attributes().is_mirrored() );
 
           if ( get_rendering_attributes().is_mirrored() )
-            add_internal_force( bear::universe::force_type(-250000,0) );
+            add_internal_force( bear::universe::force_type(-250000, 0) );
           else
-            add_internal_force( bear::universe::force_type(250000,0) );
+            add_internal_force( bear::universe::force_type(250000, 0) );
         }
     }
   else
@@ -249,14 +248,14 @@ void ptb::little_plee::progress_idle()
         {
           direction_change = true;
           get_rendering_attributes().mirror(true);
-          add_internal_force( bear::universe::force_type(-250000,0) );
+          add_internal_force( bear::universe::force_type(-250000, 0) );
         }
 
       if ( has_left_contact() && can_go_toward(false) )
         {
           direction_change = true;
           get_rendering_attributes().mirror(false);
-          add_internal_force( bear::universe::force_type(250000,0) );
+          add_internal_force( bear::universe::force_type(250000, 0) );
         }
     }
 
@@ -274,19 +273,19 @@ bool ptb::little_plee::can_go_toward( bool left_orientation )
   unsigned int closest = 0;
   bear::universe::coordinate_type dist = 1000;
 
-  player* p1 = util::find_player( get_level_globals(), 1 );
-  player* p2 = util::find_player( get_level_globals(), 2 );
+  const player_proxy p1 = util::find_player( get_level_globals(), 1 );
+  const player_proxy p2 = util::find_player( get_level_globals(), 2 );
 
-  if ( p1 != (player*)NULL )
+  if ( p1 != NULL )
     {
       closest = 1;
-      dist = p1->get_center_of_mass().distance(get_center_of_mass());
+      dist = p1.get_center_of_mass().distance(get_center_of_mass());
     }
 
-  if ( p2 != (player*)NULL )
+  if ( p2 != NULL )
     {
       bear::universe::coordinate_type dist2 =
-        p2->get_center_of_mass().distance(get_center_of_mass());
+        p2.get_center_of_mass().distance(get_center_of_mass());
       if ( (closest == 0) || ((closest == 1) && (dist2 < dist)) )
         {
           closest = 2;
@@ -299,18 +298,18 @@ bool ptb::little_plee::can_go_toward( bool left_orientation )
       if ( closest == 1 )
         {
           if ( left_orientation )
-            result = ( p1->get_left() > get_right() );
+            result = ( p1.get_left() > get_right() );
           else
-            result = ( p1->get_right() < get_left() );
+            result = ( p1.get_right() < get_left() );
         }
       else
         {
           if ( closest == 2 )
             {
               if ( left_orientation )
-                result = ( p2->get_left() > get_right() );
+                result = ( p2.get_left() > get_right() );
               else
-                result = ( p2->get_right() < get_left() );
+                result = ( p2.get_right() < get_left() );
              }
         }
     }
