@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -58,7 +58,7 @@ bool ptb::on_players_activator::set_item_list_field
  * \brief Activation by one player among the two players.
  * \param p The player.
  */
-void ptb::on_players_activator::on_one_player( player* p )
+void ptb::on_players_activator::on_one_player( const player_proxy& p )
 {
   handle_list::iterator it;
   std::list<handle_list::iterator> dead;
@@ -79,7 +79,8 @@ void ptb::on_players_activator::on_one_player( player* p )
  * \param p1 The first player.
  * \param p2 The second player. NULL in a single player game.
  */
-void ptb::on_players_activator::on_all_players( player* p1, player* p2 )
+void ptb::on_players_activator::on_all_players
+( const player_proxy& p1, const player_proxy& p2 )
 {
   handle_list::iterator it;
   std::list<handle_list::iterator> dead;
