@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -27,14 +27,18 @@
  * \author Julien Jorge
  */
 #include "ptb/item/owl.hpp"
+#include "ptb/item/bonus_points/bonus_points.hpp"
 
 #include "ptb/defines.hpp"
+#include "ptb/game_variables.hpp"
 #include "ptb/level_variables.hpp"
 #include "ptb/item/hazelnut.hpp"
-#include "ptb/player.hpp"
 
+#include "engine/function/bool_level_variable_getter.hpp"
 #include "engine/game.hpp"
 
+#include <libintl.h>
+
 BASE_ITEM_EXPORT( owl, ptb )
 
 /*----------------------------------------------------------------------------*/
@@ -42,8 +46,7 @@ BASE_ITEM_EXPORT( owl, ptb )
  * \brief Constructor.
  */
 ptb::owl::owl()
-  : m_action(action_idling), m_progress(NULL), m_first_player(NULL),
-    m_second_player(NULL), m_has_hazelnut(false)
+  : m_action(action_idling), m_progress(NULL), m_has_hazelnut(false)
 {
   set_phantom(true);
 } // owl::owl()
@@ -65,12 +68,14 @@ void ptb::owl::build()
 {
   super::build();
 
+  create_level_bonus();
+
   if ( m_other_player.empty() )
     m_other_player.push_back( gettext("Did you lose your friend?") );
 
   if ( m_already_have.empty() )
     m_already_have.push_back
-      ( gettext("I already have my lucky hazelnut. Go away!") );
+      ( gettext("You already gave me my lucky hazelnut. Stop bothering me!") );
 
   if ( m_happy.empty() )
     m_happy.push_back( gettext("So you found my lucky hazelnut!") );
@@ -80,7 +85,7 @@ void ptb::owl::build()
       ( gettext("I'd like to have my lucky hazelnut back.") );
 
   if ( m_goodbye.empty() )
-    m_goodbye.push_back( gettext("See you in an other world.") );
+    m_goodbye.push_back( gettext("See you in another world.") );
 
   if ( m_receive_hazelnut.empty() )
     m_receive_hazelnut.push_back
@@ -202,7 +207,7 @@ bool ptb::owl::set_string_list_field
  * \brief Activate on with only one player in a two players game.
  * \param p The player activating the owl.
  */
-void ptb::owl::on_one_player( player* p )
+void ptb::owl::on_one_player( const player_proxy& p )
 {
   m_activated = true;
 
@@ -231,8 +236,9 @@ void ptb::owl::on_one_player( player* p )
  * \param p1 The first player.
  * \param p2 The second player, in a two players game.
  */
-void ptb::owl::on_all_players( player* p1, player* p2 )
+void ptb::owl::on_all_players( const player_proxy& p1, const player_proxy& p2 )
 {
+  level_variables::meet_the_owl(get_level());
   m_activated = true;
 
   if ( m_has_hazelnut )
@@ -246,19 +252,20 @@ void ptb::owl::on_all_players( player* p1, player* p2 )
     }
   else if ( m_action != action_start_level_scenario )
     {
-      if ( level_variables::get_hazelnut(get_level()) )
+      if ( level_variables::get_current_hazelnut(get_level()) )
         {
           say( m_happy );
           start_model_action("speak");
           m_action = action_start_level_scenario;
           m_progress = &owl::progress_ask_hazelnut;
 
-          p1->set_marionette(true);
-          if (p2!=NULL)
-            p2->set_marionette(true);
-
           m_first_player = p1;
           m_second_player = p2;
+
+          m_first_player.set_marionette(true);
+          if (p2!=NULL)
+            m_second_player.set_marionette(true);
+
         }
       else if ( m_action != action_speaking )
         {
@@ -281,30 +288,30 @@ void ptb::owl::progress_ask_hazelnut( bear::universe::time_type elapsed_time )
   // move the player to face the owl
   if ( !get_rendering_attributes().is_mirrored() )
     {
-      if ( m_first_player->get_left() < get_right() + 100)
-        m_first_player->do_action(elapsed_time, player_action::move_right);
-      else if (m_first_player->get_speed().x == 0)
+      if ( m_first_player.get_left() < get_right() + 100)
+        m_first_player.do_action(elapsed_time, player_action::move_right);
+      else if (m_first_player.get_speed().x == 0)
         {
           ok = true;
 
-          if ( !m_first_player->get_rendering_attributes().is_mirrored() )
-            m_first_player->do_action(0.001, player_action::move_left);
+          if ( !m_first_player.get_rendering_attributes().is_mirrored() )
+            m_first_player.do_action(0.001, player_action::move_left);
         }
     }
-  else if ( m_first_player->get_right() > get_left() - 100)
-    m_first_player->do_action(elapsed_time, player_action::move_left);
-  else if (m_first_player->get_speed().x == 0)
+  else if ( m_first_player.get_right() > get_left() - 100)
+    m_first_player.do_action(elapsed_time, player_action::move_left);
+  else if (m_first_player.get_speed().x == 0)
     {
       ok = true;
 
-      if ( m_first_player->get_rendering_attributes().is_mirrored() )
-        m_first_player->do_action(0.001, player_action::move_right);
+      if ( m_first_player.get_rendering_attributes().is_mirrored() )
+        m_first_player.do_action(0.001, player_action::move_right);
     }
 
   if ( ok && has_finished_to_chat() )
     {
       start_model_action("idle");
-      m_first_player->throw_hazelnut();
+      m_first_player.throw_hazelnut();
       m_progress = NULL;
     }
 } // owl::progress_ask_hazelnut()
@@ -335,13 +342,14 @@ void ptb::owl::progress_start_level
 {
   if ( has_finished_to_chat() )
     {
-      m_first_player->set_marionette(false);
+      m_first_player.set_marionette(false);
       if (m_second_player != NULL)
-        m_second_player->set_marionette(false);
+        m_second_player.set_marionette(false);
 
       m_progress = NULL;
       start_model_action("idle");
 
+      level_variables::set_secret_level_found(get_level(), true);
       game_variables::set_next_level_name(m_level_name);
       bear::engine::game::get_instance().push_level( PTB_LOADING_LEVEL_NAME );
     }
@@ -380,3 +388,38 @@ void ptb::owl::say( const std::vector<std::string>& s )
   speech.push_back( s[ (((double)rand() / RAND_MAX) * s.size()) ] );
   speak( s );
 } // owl::say()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Create level bonus objects.
+ */
+void ptb::owl::create_level_bonus()
+{
+  bonus_points* new_bonus_owl = new bonus_points( "Meet the owl", 10000 );
+
+  new_bonus_owl->set_picture_filename("gfx/ui/bonus-icons/bonus-icons.png");
+  new_bonus_owl->set_picture_name("owl");
+  new_bonus_owl->set_condition
+    ( bear::engine::bool_level_variable_getter(&get_level(), "met_the_owl") );
+
+  new_item( *new_bonus_owl );
+  CLAW_ASSERT(new_bonus_owl->is_valid(),
+              "The bonus_owl isn't correctly initialized" );
+  new_bonus_owl->set_center_of_mass(get_center_of_mass());
+
+
+  bonus_points* new_bonus_secret_level =
+    new bonus_points( "Secret level found", 10000 );
+
+  new_bonus_secret_level->set_picture_filename
+    ("gfx/ui/bonus-icons/bonus-icons.png");
+  new_bonus_secret_level->set_picture_name("owl and hazelnut");
+  new_bonus_secret_level->set_condition
+    ( bear::engine::bool_level_variable_getter
+      (&get_level(), "secret_level_found") );
+
+  new_item( *new_bonus_secret_level );
+  CLAW_ASSERT(new_bonus_secret_level->is_valid(),
+              "The bonus_secret_level isn't correctly initialized" );
+  new_bonus_secret_level->set_center_of_mass(get_center_of_mass());
+} // owl::create_level_bonus()
