@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,7 +30,7 @@
 
 #include "universe/collision_info.hpp"
 #include "engine/export.hpp"
-#include "ptb/player.hpp"
+#include "ptb/player_proxy.hpp"
 #include "ptb/player_action.hpp"
 
 BASE_ITEM_EXPORT( player_killer, ptb )
@@ -44,8 +44,8 @@ BASE_ITEM_EXPORT( player_killer, ptb )
 void ptb::player_killer::collision
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
-  if ( p )
-    p->start_action( player_action::die );
+  if ( p != NULL )
+    p.start_action( player_action::die );
 } // player_killer::collision()
