@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,11 +30,12 @@
 
 #include "ptb/controller_config.hpp"
 #include "ptb/speaker_item.hpp"
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 
 #include "engine/export.hpp"
 
+#include <libintl.h>
+
 BASE_ITEM_EXPORT( player_speaker_zone, ptb )
 
 /*----------------------------------------------------------------------------*/
@@ -43,8 +44,7 @@ BASE_ITEM_EXPORT( player_speaker_zone, ptb )
  */
 ptb::player_speaker_zone::player_speaker_zone()
   : m_first_player_spoke(false), m_second_player_spoke(false),
-    m_first_player_in_zone(false), m_second_player_in_zone(false),
-    m_first_player(NULL), m_second_player(NULL)
+    m_first_player_in_zone(false), m_second_player_in_zone(false)
 {
   set_phantom(true);
   set_can_move_items(false);
@@ -60,10 +60,10 @@ void ptb::player_speaker_zone::progress
 {
   search_players();
 
-  if ( m_first_player != (player*)NULL )
+  if ( m_first_player != NULL )
     test_player_enter(m_first_player, m_first_player_in_zone);
 
-  if ( m_second_player != (player*)NULL )
+  if ( m_second_player != NULL )
     test_player_enter(m_second_player, m_second_player_in_zone);
 } // player_speaker_zone::progress()
 
@@ -109,10 +109,10 @@ bool ptb::player_speaker_zone::is_valid() const
  */
 void ptb::player_speaker_zone::search_players()
 {
-  if ( m_first_player == (player*)NULL )
+  if ( m_first_player == NULL )
     m_first_player = util::find_player( get_level_globals(), 1 );
 
-  if ( m_second_player == (player*)NULL )
+  if ( m_second_player == NULL )
     m_second_player = util::find_player( get_level_globals(), 2 );
 } // player_speaker_zone::search_players()
 
@@ -121,25 +121,20 @@ void ptb::player_speaker_zone::search_players()
  * \brief Test if a player enter in the zone.
  */
 void ptb::player_speaker_zone::test_player_enter
-( bear::universe::derived_item_handle_maker<player>::handle_type&
-  player, bool& player_in_zone )
+( const player_proxy& p, bool& player_in_zone )
 {
-  bear::universe::rectangle_type bounding_box_1
-    ( player->get_bounding_box() );
+  bear::universe::rectangle_type bounding_box_1( p.get_bounding_box() );
 
   if ( bounding_box_1.intersects(get_bounding_box()) )
     {
       if ( !player_in_zone )
         {
-           ptb::speaker_item* speaker =
-            dynamic_cast<ptb::speaker_item*>(player.get());
-
-           if ( speaker->has_finished_to_chat() )
+           if ( p.has_finished_to_chat() )
              {
                controller_config cfg;
                const controller_layout* layout(NULL);
-               if ( player->get_index() <= 2)
-                 layout = &(cfg.get_layout( player->get_index() ));
+               if ( p.get_index() <= 2)
+                 layout = &(cfg.get_layout( p.get_index() ));
 
                std::vector<std::string> speeches;
                std::vector<std::string>::iterator it;
@@ -154,7 +149,7 @@ void ptb::player_speaker_zone::test_player_enter
                    speeches.push_back(text);
                  }
 
-               speaker->speak(speeches);
+               p.speak(speeches);
              }
 
            player_in_zone = true;
