@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -32,6 +32,7 @@
 #include "ptb/player.hpp"
 #include "ptb/item/player/plee.hpp"
 #include "ptb/item/player/ray.hpp"
+#include "engine/level.hpp"
 
 BASE_ITEM_EXPORT( player_start_position, ptb )
 
@@ -108,8 +109,9 @@ bool ptb::player_start_position::is_valid() const
 void ptb::player_start_position::build()
 {
   if ( game_variables::get_players_count() >= m_player_index)
-    if ( (game_variables::get_last_level_exit(m_player_index) == m_exit_name)
-	 || m_exit_name.empty() )
+    if ( (game_variables::get_last_level_exit
+          (get_level().get_filename(), m_player_index) == m_exit_name)
+         || m_exit_name.empty() )
       {
         player* p(NULL);
 
