@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,8 +29,8 @@
 #include "ptb/item/player_stop_block.hpp"
 
 #include "universe/collision_info.hpp"
-#include "engine/export.hpp"
-#include "ptb/player.hpp"
+
+#include "ptb/player_proxy.hpp"
 
 BASE_ITEM_EXPORT( player_stop_block, ptb )
 
@@ -43,7 +43,7 @@ BASE_ITEM_EXPORT( player_stop_block, ptb )
 void ptb::player_stop_block::collision_check_player_and_align
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if (p != NULL)
     collision_check_and_align(that, info);
