@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,7 +28,7 @@
  */
 #include "ptb/item/power_drop_restriction_zone.hpp"
 
-#include "ptb/player.hpp"
+#include "ptb/player_proxy.hpp"
 
 BASE_ITEM_EXPORT( power_drop_restriction_zone, ptb )
 
@@ -91,18 +91,18 @@ bool ptb::power_drop_restriction_zone::set_bool_field
 void ptb::power_drop_restriction_zone::collision_check_and_apply
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
     {
       if ( m_air )
-        p->set_can_throw_power(false,monster::air_attack);
+        p.set_can_throw_power(false, monster::air_attack);
 
       if ( m_fire )
-        p->set_can_throw_power(false,monster::fire_attack);
+        p.set_can_throw_power(false, monster::fire_attack);
 
       if ( m_water )
-        p->set_can_throw_power(false,monster::water_attack);
+        p.set_can_throw_power(false, monster::water_attack);
     }
 } // power_drop_restriction_zone::collision_check_and_apply()
 
