@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -27,7 +27,9 @@
  * \author Sebastien Angibaud
  */
 #include "ptb/item/power_filter_door.hpp"
-#include "ptb/player.hpp"
+
+#include "ptb/game_variables.hpp"
+#include "ptb/player_proxy.hpp"
 #include "ptb/item/stone/stone.hpp"
 #include "ptb/item/small_honeypot.hpp"
 #include "ptb/item/power_drop_restriction_zone.hpp"
@@ -103,11 +105,10 @@ void ptb::power_filter_door::build()
  */
 void ptb::power_filter_door::progress( bear::universe::time_type elapsed_time )
 {
-  update_player_status(1,m_first_player_status,m_first_player_position);
-  update_player_status(2,m_second_player_status,m_second_player_position);
+  update_player_status(1, m_first_player_status, m_first_player_position);
+  update_player_status(2, m_second_player_status, m_second_player_position);
 } // power_filter_door::progress()
 
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Set a field of type <string>.
@@ -165,23 +166,23 @@ bool ptb::power_filter_door::set_bool_field
 void ptb::power_filter_door::collision_check_and_apply
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
     {
-      if ( p->get_index() == 1 )
+      if ( p.get_index() == 1 )
         apply_collision_player
-          (that,info,p,m_first_player_status, m_first_player_position);
+          (that, info, p, m_first_player_status, m_first_player_position);
       else
         apply_collision_player
-          (that,info,p,m_second_player_status,m_second_player_position);
+          (that, info, p, m_second_player_status, m_second_player_position);
     }
   else
     {
       stone* s = dynamic_cast<stone*>(&that);
 
       if ( s != NULL  )
-        apply_collision_stone(that,info,s);
+        apply_collision_stone(that, info, s);
       else
         default_collision(info);
     }
@@ -261,17 +262,18 @@ bool ptb::power_filter_door::check_power_of_stone( stone* s ) const
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Check if the player has the good power.
+ * \param index The index of the player to check.
  */
-bool ptb::power_filter_door::check_power_of_player( player* p ) const
+bool ptb::power_filter_door::check_power_of_player( unsigned int index ) const
 {
   bool result = false;
 
   if ( m_door_type == air_door )
-    result = game_variables::get_air_power(p->get_index());
+    result = game_variables::get_air_power(index);
   else if ( m_door_type == fire_door )
-    result = game_variables::get_fire_power(p->get_index());
+    result = game_variables::get_fire_power(index);
   else if ( m_door_type == water_door )
-    result = game_variables::get_water_power(p->get_index());
+    result = game_variables::get_water_power(index);
 
   return result;
 } // power_filter_door::check_power_of_player()
@@ -296,7 +298,7 @@ void ptb::power_filter_door::update_player_status
       if ( m_remove_power &&
            ( status == move_right ) && ( pos.x > get_left() ) )
         {
-          create_small_honeypot(status,pos);
+          create_small_honeypot(status, pos);
 
           if ( m_door_type == air_door )
             game_variables::set_air_power(index, false);
@@ -308,7 +310,7 @@ void ptb::power_filter_door::update_player_status
       else if ( m_remove_power &&
                 ( status == move_left ) && ( pos.x < get_right() ) )
         {
-          create_small_honeypot(status,pos);
+          create_small_honeypot(status, pos);
 
           if ( m_door_type == air_door )
             game_variables::set_air_power(index, false);
@@ -327,16 +329,17 @@ void ptb::power_filter_door::update_player_status
  * \brief Apply the collision with a player.
  * \param that The other item of the collision.
  * \param info Some informations about the collision.
- * \param p The pointer on the player.
+ * \param p The the player.
  * \param status The status of the player (in/out).
  * \param pos The last position of the player (in/out).
  */
 void ptb::power_filter_door::apply_collision_player
 ( bear::engine::base_item& that, bear::universe::collision_info& info,
-  player* p, player_status& status, bear::universe::position_type& pos)
+  const player_proxy& p, player_status& status,
+  bear::universe::position_type& pos)
 {
-  pos = p->get_center_of_mass();
-  bool ok(check_power_of_player(p));
+  pos = p.get_center_of_mass();
+  const bool ok(check_power_of_player(p.get_index()));
 
   if ( (info.get_collision_side() == bear::universe::zone::middle_left_zone) ||
        (info.get_collision_side() == bear::universe::zone::middle_right_zone) )
@@ -376,7 +379,6 @@ void ptb::power_filter_door::apply_collision_player
     }
 } // power_filter_door::apply_collision_player()
 
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Apply the collision with a stone.
@@ -438,13 +440,13 @@ void ptb::power_filter_door::create_small_honeypot
     {
       new_small_honeypot->set_right(get_left());
       new_small_honeypot->add_external_force
-        (bear::universe::force_type(-30000,0));
+        (bear::universe::force_type(-30000, 0));
     }
   else
     {
       new_small_honeypot->set_left(get_right());
       new_small_honeypot->add_external_force
-        (bear::universe::force_type(30000,0));
+        (bear::universe::force_type(30000, 0));
     }
 } // ptb::power_filter_door::create_small_honeypot()
 
@@ -461,11 +463,11 @@ void ptb::power_filter_door::create_power_restriction_zone()
   item->set_center_of_mass(get_center_of_mass());
 
   if ( m_door_type == air_door )
-    item->set_powers_restriction(true,false,false);
+    item->set_powers_restriction(true, false, false);
   else if ( m_door_type == fire_door )
-    item->set_powers_restriction(false,true,false);
+    item->set_powers_restriction(false, true, false);
   else
-    item->set_powers_restriction(false,false,true);
+    item->set_powers_restriction(false, false, true);
 
   CLAW_ASSERT
     ( item->is_valid(),
