@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -73,7 +73,7 @@ bool ptb::projectile_enemy_zone::set_string_field
   if ( name == "projectile_enemy_zone.projectile_model" )
     m_projectile_model = value;
   else
-    result = super::set_string_field(name,value);
+    result = super::set_string_field(name, value);
 
   return result;
 } // projectile_enemy_zone::set_string_field()
@@ -93,7 +93,7 @@ bool ptb::projectile_enemy_zone::set_u_integer_field
   if ( name == "projectile_enemy_zone.projectile_number" )
     m_projectile_number = value;
   else
-    result = super::set_u_integer_field(name,value);
+    result = super::set_u_integer_field(name, value);
 
   return result;
 } // projectile_enemy_zone::set_u_integer_field()
@@ -162,8 +162,8 @@ void ptb::projectile_enemy_zone::collision_check_monster
       monster* p = dynamic_cast<ptb::monster*>(&that);
 
       if ( p )
-        if ( ( p->get_monster_type() == monster::player_1_monster ) ||
-             ( p->get_monster_type() == monster::player_2_monster ) ||
+        if ( ( p->get_monster_type() == monster::player_monster ) ||
+             ( p->get_monster_type() == monster::stone_monster ) ||
              ( p->get_monster_type() == monster::enemy_monster ) )
           create_projectile();
     }
