@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,7 +28,7 @@
  */
 #include "ptb/item/save_player_position.hpp"
 
-#include "ptb/player.hpp"
+#include "ptb/player_proxy.hpp"
 
 #include "engine/export.hpp"
 
@@ -151,10 +151,10 @@ void ptb::save_player_position::reactivate()
 void ptb::save_player_position::collision
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
-    if ( p->get_index() == m_player_index )
+    if ( p.get_index() == m_player_index )
       {
         m_collision = true;
 
@@ -162,13 +162,13 @@ void ptb::save_player_position::collision
           {
             if ( !m_activated )
               {
-                p->save_position( get_top_middle() );
+                p.save_position( get_top_middle() );
                 m_activated = true;
                 activate();
               }
             else if (m_can_be_reactivated)
               {
-                p->save_position( get_top_middle() );
+                p.save_position( get_top_middle() );
                 reactivate();
               }
 
