@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,8 +28,7 @@
  */
 #include "ptb/item/shared_camera.hpp"
 
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 
 BASE_ITEM_EXPORT( shared_camera, ptb )
 
@@ -64,10 +63,9 @@ bool ptb::shared_camera::set_placement_message::apply_to( shared_camera& that )
  * \brief Constructor.
  */
 ptb::shared_camera::shared_camera()
-  : m_placement(shared), m_first_player( NULL ), m_second_player( NULL ),
-    m_progress(&shared_camera::progress_no_players)
+  : m_placement(shared), m_progress(&shared_camera::progress_no_players)
 {
-
+  set_active_on_build();
 } // shared_camera::shared_camera()
 
 /*----------------------------------------------------------------------------*/
@@ -77,7 +75,6 @@ ptb::shared_camera::shared_camera()
 void ptb::shared_camera::build()
 {
   super::build();
-  activate();
 } // shared_camera::build()
 
 /*----------------------------------------------------------------------------*/
@@ -140,9 +137,9 @@ void ptb::shared_camera::auto_position
 void
 ptb::shared_camera::set_first_player( bear::universe::time_type elapsed_time )
 {
-  if ( m_first_player != (player*)NULL )
-    adjust_position( m_first_player->hot_spot(), elapsed_time );
-  else if ( m_second_player != (player*)NULL )
+  if ( m_first_player != NULL )
+    adjust_position( m_first_player.hot_spot(), elapsed_time );
+  else if ( m_second_player != NULL )
     set_second_player( elapsed_time );
   else
     m_placement = do_nothing;
@@ -156,9 +153,9 @@ ptb::shared_camera::set_first_player( bear::universe::time_type elapsed_time )
 void
 ptb::shared_camera::set_second_player( bear::universe::time_type elapsed_time )
 {
-  if ( m_second_player != (player*)NULL )
-    adjust_position( m_second_player->hot_spot(), elapsed_time );
-  else if ( m_first_player != (player*)NULL )
+  if ( m_second_player != NULL )
+    adjust_position( m_second_player.hot_spot(), elapsed_time );
+  else if ( m_first_player != NULL )
     set_first_player( elapsed_time );
   else
     m_placement = do_nothing;
@@ -171,22 +168,22 @@ ptb::shared_camera::set_second_player( bear::universe::time_type elapsed_time )
  */
 void ptb::shared_camera::set_shared( bear::universe::time_type elapsed_time )
 {
-  if ( m_first_player != (player*)NULL )
+  if ( m_first_player != NULL )
     {
-      if ( m_second_player != (player*)NULL )
+      if ( m_second_player != NULL )
         {
           bear::universe::position_type center1;
           bear::universe::position_type center2;
 
-          center1 = m_first_player->hot_spot();
-          center2 = m_second_player->hot_spot();
+          center1 = m_first_player.hot_spot();
+          center2 = m_second_player.hot_spot();
 
           adjust_position( (center1 + center2) / 2, elapsed_time );
         }
       else
         set_first_player( elapsed_time );
     }
-  else if ( m_second_player != (player*)NULL )
+  else if ( m_second_player != NULL )
     set_second_player( elapsed_time );
   else
     m_placement = do_nothing;
@@ -198,10 +195,10 @@ void ptb::shared_camera::set_shared( bear::universe::time_type elapsed_time )
  */
 void ptb::shared_camera::search_players()
 {
-  if ( m_first_player == (player*)NULL )
+  if ( m_first_player == NULL )
     m_first_player = util::find_player( get_level_globals(), 1 );
 
-  if ( m_second_player == (player*)NULL )
+  if ( m_second_player == NULL )
     m_second_player = util::find_player( get_level_globals(), 2 );
 } // shared_camera::search_players()
 
@@ -215,20 +212,20 @@ void ptb::shared_camera::progress_no_players
 {
   search_players();
 
-  if ( m_first_player!=(player*)NULL )
+  if ( m_first_player!=NULL )
     {
       m_progress = &shared_camera::progress_with_players;
 
-      if ( m_second_player!=(player*)NULL )
+      if ( m_second_player!=NULL )
         teleport
-          ( (m_first_player->hot_spot() + m_second_player->hot_spot()) / 2 );
+          ( (m_first_player.hot_spot() + m_second_player.hot_spot()) / 2 );
       else
-        teleport( m_first_player->hot_spot() );
+        teleport( m_first_player.hot_spot() );
     }
-  else if ( m_second_player!=(player*)NULL )
+  else if ( m_second_player!=NULL )
     {
       m_progress = &shared_camera::progress_with_players;
-      teleport( m_second_player->hot_spot() );
+      teleport( m_second_player.hot_spot() );
     }
   else
     progress_zoom(elapsed_time);
