@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,7 +30,8 @@
 
 #include "universe/collision_info.hpp"
 #include "generic_items/decorative_item.hpp"
-#include "ptb/player.hpp"
+#include "ptb/game_variables.hpp"
+#include "ptb/player_proxy.hpp"
 #include "engine/game.hpp"
 
 #include "engine/export.hpp"
@@ -71,19 +72,19 @@ void ptb::small_honeypot::pre_cache()
 void ptb::small_honeypot::collision_check_and_apply
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
   if ( p != NULL )
     {
-      if ( !get_bonus_given() &&
-           ( info.get_collision_side() != bear::universe::zone::middle_zone )
-           && ( p->get_index() <= 2 ) &&
-           ( ( get_type() != base_bonus::air_power ) ||
-             ( !game_variables::get_air_power(p->get_index()) ) ) &&
-           ( ( get_type() != base_bonus::fire_power ) ||
-             ( !game_variables::get_fire_power(p->get_index()) ) ) &&
-           ( ( get_type() != base_bonus::water_power ) ||
-             ( !game_variables::get_water_power(p->get_index()) ) ) )
+      if ( !get_bonus_given()
+           && ( info.get_collision_side() != bear::universe::zone::middle_zone )
+           && ( p.get_index() <= 2 )
+           && ( ( get_type() != base_bonus::air_power )
+                || !game_variables::get_air_power(p.get_index()) )
+           && ( ( get_type() != base_bonus::fire_power )
+                || !game_variables::get_fire_power(p.get_index()) )
+           && ( ( get_type() != base_bonus::water_power )
+                || !game_variables::get_water_power(p.get_index()) ) )
         give_bonus(p);
     }
 } // small_honeypot::collision_check_and_apply()
