@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -27,7 +27,7 @@
  * \author Sbastien Angibaud
  */
 #include "ptb/item/soul.hpp"
-#include "ptb/player.hpp"
+#include "ptb/player_proxy.hpp"
 #include "engine/export.hpp"
 
 #include "universe/forced_movement/forced_translation.hpp"
@@ -68,11 +68,11 @@ ptb::soul::~soul()
 void ptb::soul::collision
 ( bear::engine::base_item& that, bear::universe::collision_info& info )
 {
-  ptb::player* other = dynamic_cast<ptb::player*>(&that);
+  player_proxy other(&that);
 
   if (other != NULL)
     {
-      other->receive_energy(m_energy);
+      other.receive_energy(m_energy);
       m_energy = 0;
       kill();
     }
