@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -31,7 +31,6 @@
 #include "ptb/expr/boolean_player_function.hpp"
 #include "ptb/item/player_killer_toggle.hpp"
 #include "ptb/game_variables.hpp"
-#include "ptb/player.hpp"
 
 #include "generic_items/toggle_group.hpp"
 #include "generic_items/trigger.hpp"
@@ -59,7 +58,8 @@ void ptb::timer_kill_players::create_trigger()
   bear::trigger* t = new bear::trigger( bear::trigger::trigger_condition );
   bear::expr::boolean_expression p1_marionette =
     boolean_player_function_maker
-    ( std::mem_fun_ref(&player::is_a_marionette), 1, get_level_globals() );
+    ( std::mem_fun_ref(&player_proxy::is_a_marionette), 1,
+      get_level_globals() );
 
   if ( game_variables::get_players_count() == 1 )
     t->set_condition( !p1_marionette );
@@ -67,7 +67,8 @@ void ptb::timer_kill_players::create_trigger()
     {
       bear::expr::boolean_expression p2_marionette =
         boolean_player_function_maker
-        ( std::mem_fun_ref(&player::is_a_marionette), 2, get_level_globals() );
+        ( std::mem_fun_ref(&player_proxy::is_a_marionette), 2,
+          get_level_globals() );
 
       t->set_condition( !p1_marionette || !p2_marionette );
     }
