@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -34,6 +34,8 @@
 
 #include "engine/export.hpp"
 
+#include <limits>
+
 namespace ptb
 {
   /**
@@ -95,7 +97,6 @@ namespace ptb
     ( bear::input::joystick::joy_code button, unsigned int joy_index );
     bool mouse_pressed( bear::input::mouse::mouse_code button,
                         const claw::math::coordinate_2d<unsigned int>& pos );
-    bool mouse_move( const claw::math::coordinate_2d<unsigned int>& pos );
 
   private:
     /** \brief The names of the levels to load. */
