@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,8 +29,10 @@
  */
 #include "ptb/item/forest/rabbit.hpp"
 
-#include "ptb/player.hpp"
+#include "ptb/game_variables.hpp"
 #include "ptb/item/floating_score.hpp"
+#include "ptb/item/stone/stone.hpp"
+
 #include "engine/layer/layer.hpp"
 #include "engine/world.hpp"
 #include "engine/export.hpp"
@@ -45,7 +47,8 @@ BASE_ITEM_EXPORT( rabbit, ptb )
  */
 ptb::rabbit::rabbit()
 : m_progress(NULL), m_max_distance(500), m_injured(false),
-  m_opacity_effect_duration(0), m_has_carrot(false), m_remaining_action_time(0)
+  m_opacity_effect_duration(0), m_has_carrot(false), m_remaining_action_time(0),
+  m_marionette(false)
 {
   set_z_fixed(false);
   set_mass(10);
@@ -114,19 +117,37 @@ void ptb::rabbit::progress( bear::universe::time_type elapsed_time )
  * \param value The new value of the field.
  * \return false if the field "name" is unknow, true otherwise.
  */
-bool ptb::rabbit::set_real_field
-( const std::string& name, double value )
+bool ptb::rabbit::set_real_field( const std::string& name, double value )
 {
   bool ok = true;
 
   if (name == "rabbit.max_distance")
     m_max_distance = value;
   else
-    ok = super::set_real_field(name,value);
+    ok = super::set_real_field(name, value);
 
   return ok;
 } // rabbit::set_real_field()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Set a field of type <bool>.
+ * \param name The name of the field.
+ * \param value The new value of the field.
+ * \return false if the field "name" is unknow, true otherwise.
+ */
+bool ptb::rabbit::set_bool_field( const std::string& name, bool value )
+{
+  bool ok = true;
+
+  if (name == "rabbit.is_marionette")
+    m_marionette = value;
+  else
+    ok = super::set_bool_field(name, value);
+
+  return ok;
+} // rabbit::set_bool_field()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Inform the item tat he is entering the active region.
@@ -137,35 +158,6 @@ void ptb::rabbit::enters_active_region()
     choose_idle_action();
 } // rabbit::enters_active_region()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Call a function.
- * \param name The function to call.
- */
-void ptb::rabbit::execute_function( const std::string& name )
-{
-  if ( name == "start_idle" )
-    start_idle();
-  else if ( name == "apply_jump" )
-    apply_jump();
-  else if ( name == "start_walk" )
-    start_walk();
-  else if ( name == "start_fall" )
-    start_fall();
-  else if ( name == "start_eat" )
-    start_eat();
-  else if ( name == "start_dig" )
-    start_dig();
-  else if ( name == "start_in_burrow" )
-    start_in_burrow();
-  else if ( name == "start_injured" )
-    start_injured();
-  else if ( name == "try_to_move" )
-    try_to_move();
-  else
-    super::execute_function(name);
-} // rabbit::execute_function()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Process a collision with an other item.
@@ -180,13 +172,13 @@ void ptb::rabbit::collision
   if ( m_injured || (get_current_action_name() == "in_burrow") )
     return;
 
-  player* p = dynamic_cast<player*>(&that);
+  player_proxy p(&that);
 
-  if ( p != NULL )
+  if ( (p != NULL) && (p.get_index() <= 2) )
     {
       if ( is_attacked(p) )
         {
-          create_floating_score(p->get_index());
+          create_floating_score(p.get_index());
           start_model_action("injured");
         }
       else if ( ( game_variables::get_corrupting_bonus_count() > 0 )
@@ -203,10 +195,10 @@ void ptb::rabbit::collision
 
       if ( s != NULL )
         {
-          if ( s->get_monster_type() == monster::stone_1_monster )
-            create_floating_score(1);
-          else if ( s->get_monster_type() == monster::stone_2_monster )
-            create_floating_score(2);
+          if ( ( s->get_monster_type() == monster::stone_monster ) &&
+               ( ( s->get_monster_index() == 1 ) ||
+                 ( s->get_monster_index() == 2 ) ) )
+            create_floating_score(s->get_monster_index());
 
           start_model_action("injured");
         }
@@ -218,21 +210,21 @@ void ptb::rabbit::collision
  * \brief Test if a given player attack the rabbit.
  * \param p A pointer on the player.
  */
-bool ptb::rabbit::is_attacked(player* p)
+bool ptb::rabbit::is_attacked(const player_proxy& p)
 {
   bool result(false);
 
-  if ( p->is_invincible() )
+  if ( p.is_invincible() )
     result = true;
-  else if ( p->is_in_offensive_phase() )
+  else if ( p.is_in_offensive_phase() )
     {
-      if ( p->get_current_action_name() == "start_cling" )
+      if ( p.get_current_action_name() == "start_cling" )
         result = true;
       else
         {
           bear::engine::model_mark_placement m;
 
-          if ( p->get_mark_placement("hand", m) )
+          if ( p.get_mark_placement("hand", m) )
             result = get_bounding_box().includes( m.get_position() );
         }
     }
@@ -447,6 +439,18 @@ void ptb::rabbit::pre_jump()
   start_model_action("jump");
 } // rabbit::pre_jump()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Walk for a given duration.
+ * \param duration The duration.
+ */
+void ptb::rabbit::walk( bear::universe::time_type duration )
+{
+  m_remaining_action_time = duration;
+  m_progress = &rabbit::progress_walk;
+  start_model_action("walk");
+} // rabbit::walk()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Apply the walk.
@@ -454,9 +458,7 @@ void ptb::rabbit::pre_jump()
 void ptb::rabbit::apply_walk()
 {
   // action time in (0.5, 1.5)
-  m_remaining_action_time = 0.5 + ((double)rand() * 1) / RAND_MAX;
-  m_progress = &rabbit::progress_walk;
-  start_model_action("walk");
+  walk( 0.5 + ((double)rand() * 1) / RAND_MAX );
 } // rabbit::apply_walk()
 
 /*----------------------------------------------------------------------------*/
@@ -468,9 +470,9 @@ void ptb::rabbit::apply_jump()
   bear::universe::force_type force(900000, 750000);
 
   if ( get_rendering_attributes().is_mirrored() )
-    add_internal_force( bear::universe::force_type(-force.x, force.y) );
-  else
-    add_internal_force( bear::universe::force_type(force) );
+    force.x *= -1;
+
+  add_internal_force( force );
 
   m_progress = &rabbit::progress_jump;
 } // rabbit::apply_jump()
@@ -535,7 +537,7 @@ bool ptb::rabbit::test_in_sky()
  */
 void ptb::rabbit::try_to_move()
 {
-  if ( !has_bottom_contact() )
+  if ( !has_bottom_contact() || m_marionette )
     return;
 
   double p = (double)rand() / RAND_MAX;
@@ -623,3 +625,26 @@ void ptb::rabbit::create_floating_score( unsigned int index ) const
 
   s->add_points( index, 1 );
 } // rabbit::create_floating_score()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Export the methods of the class.
+ */
+void ptb::rabbit::init_exported_methods()
+{
+  TEXT_INTERFACE_CONNECT_METHOD_0( rabbit, start_idle, void );
+  TEXT_INTERFACE_CONNECT_METHOD_0( rabbit, apply_jump, void );
+  TEXT_INTERFACE_CONNECT_METHOD_0( rabbit, start_walk, void );
+  TEXT_INTERFACE_CONNECT_METHOD_0( rabbit, start_fall, void );
+  TEXT_INTERFACE_CONNECT_METHOD_0( rabbit, start_eat, void );
+  TEXT_INTERFACE_CONNECT_METHOD_0( rabbit, start_dig, void );
+  TEXT_INTERFACE_CONNECT_METHOD_0( rabbit, start_in_burrow, void );
+  TEXT_INTERFACE_CONNECT_METHOD_0( rabbit, start_injured, void );
+  TEXT_INTERFACE_CONNECT_METHOD_0( rabbit, try_to_move, void );
+
+  TEXT_INTERFACE_CONNECT_METHOD_1( rabbit, walk, void,
+                                   bear::universe::time_type );
+} // rabbit::init_exported_methods()
+
+/*----------------------------------------------------------------------------*/
+TEXT_INTERFACE_IMPLEMENT_METHOD_LIST( ptb::rabbit )
