@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,8 +30,7 @@
 
 #include "ptb/item/headstone.hpp"
 #include "ptb/item/forest/sting.hpp"
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 
 #include "engine/export.hpp"
 #include "engine/game.hpp"
@@ -51,10 +50,8 @@ BASE_ITEM_EXPORT( wasp, ptb )
 ptb::wasp::wasp()
   : m_progress(NULL), m_is_in_attack(false), m_come_back(false),
     m_oscillation_angle(0), m_fly_time(0), m_have_attacked(false),
-    m_contact(false), m_first_target(0,0), m_second_target(0,0),
-    m_translation(0,0),
-    m_fly_duration(0),
-    m_first_player(NULL), m_second_player(NULL)
+    m_contact(false), m_first_target(0, 0), m_second_target(0, 0),
+    m_translation(0, 0), m_fly_duration(0)
 {
   set_z_fixed(false);
 
@@ -77,6 +74,7 @@ void ptb::wasp::pre_cache()
   get_level_globals().load_model("model/forest/sting.cm");
   get_level_globals().load_model("model/forest/wasp.cm");
   get_level_globals().load_model("model/headstone.cm");
+  get_level_globals().load_sound("sound/sting.ogg");
 } // wasp::pre_cache()
 
 /*----------------------------------------------------------------------------*/
@@ -130,7 +128,7 @@ bool ptb::wasp::set_real_field
         m_fly_duration = std::numeric_limits<double>::infinity();
     }
   else
-    ok = super::set_real_field(name,value);
+    ok = super::set_real_field(name, value);
 
   return ok;
 } // wasp::set_real_field()
@@ -153,18 +151,15 @@ void ptb::wasp::inform_no_energy(const monster& attacker)
 
 /*----------------------------------------------------------------------------*/
 /**
- * \brief Call a function.
- * \param name The function to call.
+ * \brief Inform the item tat he left the active region.
  */
-void ptb::wasp::execute_function( const std::string& name )
+void ptb::wasp::leaves_active_region()
 {
-  if ( name == "drop_sting" )
-    create_sting();
-  else if ( name == "fly" )
-    start_fly();
-  else
-    super::execute_function(name);
-} // wasp::execute_function()
+  super::leaves_active_region();
+
+  if ( get_current_action_name() == "dead" )
+    kill();
+} // wasp::leaves_active_region()
 
 /*---------------------------------------------------------------------------*/
 /**
@@ -174,7 +169,7 @@ void ptb::wasp::execute_function( const std::string& name )
 void ptb::wasp::progress_fly
 ( bear::universe::time_type elapsed_time )
 {
-  if( ( !m_have_attacked ) && scan_players() )
+  if( !m_have_attacked && scan_players() )
     {
       // we start an offensive
       m_have_attacked = true;
@@ -347,7 +342,7 @@ void ptb::wasp::create_sting()
 {
   bear::engine::model_mark_placement m;
 
-  if ( get_mark_placement("sting",m) )
+  if ( get_mark_placement("sting", m) )
     {
       const bear::universe::position_type pos(m.get_position());
       bear::universe::speed_type speed;
@@ -379,11 +374,13 @@ bool ptb::wasp::scan_players() const
 {
   bool result = false;
 
-  if(m_first_player.get())
-    result = player_in_zone(m_first_player->get_center_of_mass());
+  if(m_first_player != NULL)
+    result =
+      player_in_zone(m_first_player.get_center_of_mass());
 
-  if( !result && m_second_player.get() )
-    result = player_in_zone(m_second_player->get_center_of_mass());
+  if( !result && (m_second_player != NULL) )
+    result =
+      player_in_zone(m_second_player.get_center_of_mass());
 
   return result;
 } // wasp::scan_players()
@@ -394,10 +391,22 @@ bool ptb::wasp::scan_players() const
  */
 void ptb::wasp::search_players()
 {
-  if ( m_first_player == (player*)NULL )
+  if ( m_first_player == NULL )
     m_first_player = util::find_player( get_level_globals(), 1 );
 
-  if ( m_second_player == (player*)NULL )
+  if ( m_second_player == NULL )
     m_second_player = util::find_player( get_level_globals(), 2 );
 } // wasp::search_players()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Export the methods of the class.
+ */
+void ptb::wasp::init_exported_methods()
+{
+  TEXT_INTERFACE_CONNECT_METHOD_0( ptb::wasp, create_sting, void );
+  TEXT_INTERFACE_CONNECT_METHOD_0( ptb::wasp, start_fly, void );
+} // wasp::init_exported_methods()
+
+/*----------------------------------------------------------------------------*/
+TEXT_INTERFACE_IMPLEMENT_METHOD_LIST( ptb::wasp )
