@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -31,15 +31,13 @@
 
 #include "ptb/base_enemy.hpp"
 #include "ptb/monster.hpp"
+#include "ptb/player_proxy.hpp"
 #include "engine/model.hpp"
-#include "universe/derived_item_handle.hpp"
 
 #include "engine/export.hpp"
 
 namespace ptb
 {
-  class player;
-
   /**
    * \brief The class describing a wasp.
    * \author Sbastien Angibaud
@@ -59,6 +57,8 @@ namespace ptb
     /** \brief The type of the parent class. */
     typedef base_enemy< bear::engine::model<bear::engine::base_item> > super;
 
+    TEXT_INTERFACE_DECLARE_METHOD_LIST(super, init_exported_methods)
+
     /** \brief Number of states considered. */
     static const unsigned int states_cardinality = 3;
 
@@ -87,11 +87,9 @@ namespace ptb
     bool set_real_field( const std::string& name, double value );
 
     virtual void inform_no_energy(const monster& attacker);
+    void leaves_active_region();
     void set_bottom_contact(bear::universe::physical_item& item);
 
-  protected:
-      virtual void execute_function( const std::string& name );
-
   private:
     void progress_fly( bear::universe::time_type elapsed_time );
     void progress_attack( bear::universe::time_type elapsed_time );
@@ -109,6 +107,8 @@ namespace ptb
     bool scan_players() const;
     void search_players();
 
+    static void init_exported_methods();
+
   private:
     /** \brief Current progress function. */
     progress_function_type m_progress;
@@ -144,12 +144,11 @@ namespace ptb
     double m_fly_duration;
 
     /** \brief The first player. */
-    bear::universe::const_derived_item_handle_maker<player>::handle_type
-    m_first_player;
+    player_proxy m_first_player;
 
     /** \brief The second player. */
-    bear::universe::const_derived_item_handle_maker<player>::handle_type
-    m_second_player;
+    player_proxy m_second_player;
+
   }; // class wasp
 } // namespace ptb
 
