@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -31,14 +31,13 @@
 #define __PTB_HIDEOUT_REVEALING_HPP__
 
 #include "engine/base_item.hpp"
-#include "universe/derived_item_handle.hpp"
+
+#include "ptb/player_proxy.hpp"
 
 #include "engine/export.hpp"
 
 namespace ptb
 {
-  class player;
-
   /**
    * \brief The class describing an object which reaveal a zone
    * when a player enter.
@@ -109,12 +108,14 @@ namespace ptb
     bear::universe::time_type m_last_modification;
 
     /** \brief The first player. */
-    bear::universe::const_derived_item_handle_maker<player>::handle_type
-    m_first_player;
+    player_proxy m_first_player;
 
     /** \brief The second player. */
-    bear::universe::const_derived_item_handle_maker<player>::handle_type
-    m_second_player;
+    player_proxy m_second_player;
+
+    /** \brief The identifier of the hideout. */
+    std::string m_hideout_name;
+
   }; // class hideout_revealing
 } // namespace ptb
 
