@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -71,10 +71,14 @@ namespace ptb
 
     void give_life(unsigned int index) const;
     void create_decoration();
+    void create_level_bonus(const std::string& name);
 
   private:
     /** \brief Indicates if the honeypot is already given. */
     bool m_given;
+
+    /** \brief The identifier of the honeypot. */
+    unsigned int m_id;
   }; // class honeypot
 } // namespace ptb
 
