@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,8 +29,7 @@
 #ifndef __PTB_LEVEL_EXIT_HPP__
 #define __PTB_LEVEL_EXIT_HPP__
 
-#include "generic_items/timer.hpp"
-#include "universe/derived_item_handle.hpp"
+#include "engine/base_item.hpp"
 
 #include "engine/export.hpp"
 
@@ -55,20 +54,13 @@ namespace ptb
     /** \brief The type of the parent class. */
     typedef bear::engine::base_item super;
 
-  private:
-    /** \brief The type of a handle on a timer. */
-    typedef
-    bear::universe::const_derived_item_handle_maker<bear::timer>::handle_type
-    timer_handle;
-
   public:
     level_exit();
 
+    void build();
     void progress( bear::universe::time_type elapsed_time );
     bool is_valid() const;
     bool set_string_field( const std::string& name, const std::string& value );
-    bool
-    set_item_field( const std::string& name, bear::engine::base_item* value );
 
   private:
     void collision_check_and_apply
@@ -82,10 +74,6 @@ namespace ptb
 
     /** \brief The name of this exit. */
     std::string m_exit_name;
-
-    /** \brief The timer used to compute the time bonuses. */
-    timer_handle m_timer;
-
   }; // class level_exit
 } // namespace ptb
 
