@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -37,8 +37,6 @@
 
 namespace ptb
 {
-  class player;
-
   /**
    * \brief This item adds a link between the players.
    *
@@ -70,7 +68,7 @@ namespace ptb
     ( const std::string& name, bear::engine::base_item* item );
 
   private:
-    void on_all_players( player* p1, player* p2 );
+    void on_all_players( const player_proxy& p1, const player_proxy& p2 );
 
   private:
     /** \brief The strength of the link. */
