@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -698,7 +698,6 @@ void ptb::sequencer::song_finished()
 bear::expr::linear_expression ptb::sequencer::do_get_expression() const
 {
   return bear::expr::linear_function_maker
-    ( bear::universe::const_derived_item_handle_maker<sequencer>::handle_type
-      (this),
+    ( bear::universe::const_derived_item_handle<sequencer>(this),
       std::mem_fun_ref(&sequencer::get_performance) );
 } // sequencer::do_get_expression();
