@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,13 +29,14 @@
 #ifndef __PTB_ON_PLAYERS_ACTIVATOR_HPP__
 #define __PTB_ON_PLAYERS_ACTIVATOR_HPP__
 
-#include "universe/derived_item_handle.hpp"
 #include "ptb/item_brick/item_waiting_for_players.hpp"
 
+#include "universe/derived_item_handle.hpp"
+#include "engine/export.hpp"
+
 namespace ptb
 {
   class activate_on_players;
-  class player;
 
   /**
    * \brief This item activates an item of class activate_on_players.
@@ -58,8 +59,7 @@ namespace ptb
 
     /** \brief The type of an handle on a toggle. */
     typedef
-    bear::universe::derived_item_handle_maker<activate_on_players>::handle_type
-    handle_type;
+    bear::universe::derived_item_handle<activate_on_players> handle_type;
 
     /** \brief The type of a list of toggles. */
     typedef std::list<handle_type> handle_list;
@@ -70,8 +70,8 @@ namespace ptb
       const std::vector<bear::engine::base_item*>& value);
 
   protected:
-    void on_one_player( player* p );
-    void on_all_players( player* p1, player* p2 );
+    void on_one_player( const player_proxy& p );
+    void on_all_players( const player_proxy& p1, const player_proxy& p2 );
 
   private:
     void get_dependent_items
