@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,6 +29,7 @@
 #ifndef __PTB_OWL_HPP__
 #define __PTB_OWL_HPP__
 
+#include "ptb/player_proxy.hpp"
 #include "ptb/item_brick/item_that_speaks.hpp"
 #include "ptb/item_brick/activate_on_players.hpp"
 
@@ -38,8 +39,6 @@
 
 namespace ptb
 {
-  class player;
-
   /**
    * \brief The owl opens a secret level if the player has found the hazelnut.
    *
@@ -95,8 +94,8 @@ namespace ptb
     ( const std::string& name, const std::vector<std::string>& value );
 
   private:
-    void on_one_player( player* p );
-    void on_all_players( player* p1, player* p2 );
+    void on_one_player( const player_proxy& p );
+    void on_all_players( const player_proxy& p1, const player_proxy& p2 );
 
     void progress_ask_hazelnut( bear::universe::time_type elapsed_time );
     void progress_looking_hazelnut( bear::universe::time_type elapsed_time );
@@ -106,6 +105,7 @@ namespace ptb
     ( bear::engine::base_item& that, bear::universe::collision_info& info );
 
     void say( const std::vector<std::string>& s );
+    void create_level_bonus();
 
   private:
     /** \brief The current action of the owl. */
@@ -115,10 +115,10 @@ namespace ptb
     progress_function_type m_progress;
 
     /** \brief The first player, when activating the owl. */
-    player* m_first_player;
+    player_proxy m_first_player;
 
     /** \brief The first player, when activating the owl. */
-    player* m_second_player;
+    player_proxy m_second_player;
 
     /** \brief Tell if the owl has been activated during a progress. */
     bool m_activated;
