@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,15 +29,14 @@
 #ifndef __PTB_PLAYER_SPEAKER_ZONE_HPP__
 #define __PTB_PLAYER_SPEAKER_ZONE_HPP__
 
+#include "ptb/player_proxy.hpp"
+
 #include "engine/base_item.hpp"
-#include "universe/derived_item_handle.hpp"
 
 #include "engine/export.hpp"
 
 namespace ptb
 {
-  class player;
-
   /**
    * \brief The class describing a object when a player speak
    *         when a player go in the zone.
@@ -67,9 +66,7 @@ namespace ptb
   private:
     void search_players();
 
-    void test_player_enter
-    ( bear::universe::derived_item_handle_maker<player>::handle_type&
-      player, bool& player_in_zone  );
+    void test_player_enter( const player_proxy& p, bool& player_in_zone  );
 
   private:
     /** \brief Indicates if the first player spoke. */
@@ -79,7 +76,7 @@ namespace ptb
     bool m_second_player_spoke;
 
     /** \brief The speech. */
-    std::vector< std::string > m_speeches;
+    std::vector<std::string> m_speeches;
 
     /** \brief Indicate if the first player was in the zone. */
     bool m_first_player_in_zone;
@@ -88,12 +85,11 @@ namespace ptb
     bool m_second_player_in_zone;
 
     /** \brief The first player. */
-    bear::universe::derived_item_handle_maker<player>::handle_type
-    m_first_player;
+    player_proxy m_first_player;
 
     /** \brief The second player. */
-    bear::universe::derived_item_handle_maker<player>::handle_type
-    m_second_player;
+    player_proxy m_second_player;
+
   }; // class player_speaker_zone
 } // namespace ptb
 
