@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -54,6 +54,10 @@ namespace ptb
     void collision
     ( bear::engine::base_item& that, bear::universe::collision_info& info );
 
+  private:
+    /** Tell if the player is aligned without setting contacts. */
+    bool m_clear_contact;
+
   }; // class player_stop_block
 } // namespace ptb
 
