@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -37,7 +37,7 @@
 
 namespace ptb
 {
-  class player;
+  class player_proxy;
   class stone;
 
   /**
@@ -105,13 +105,14 @@ namespace ptb
     void create_decoration
     ( bear::universe::collision_info& info, bool push_up );
     bool check_power_of_stone( stone* s ) const;
-    bool check_power_of_player( player* p ) const;
+    bool check_power_of_player( unsigned int index ) const;
     void update_player_status
     (unsigned int index,
      player_status& status, bear::universe::position_type& pos);
     void apply_collision_player
     ( bear::engine::base_item& that, bear::universe::collision_info& info,
-      player* p, player_status& status,bear::universe::position_type& pos );
+      const player_proxy& p, player_status& status,
+      bear::universe::position_type& pos );
     void apply_collision_stone
     ( bear::engine::base_item& that, bear::universe::collision_info& info,
       stone* s );
