@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,17 +29,16 @@
 #ifndef __PTB_SHARED_CAMERA_HPP__
 #define __PTB_SHARED_CAMERA_HPP__
 
+#include "ptb/player_proxy.hpp"
+
 #include "communication/typed_message.hpp"
 #include "engine/messageable_item.hpp"
 #include "generic_items/camera.hpp"
-#include "universe/derived_item_handle.hpp"
 
 #include "engine/export.hpp"
 
 namespace ptb
 {
-  class player;
-
   /**
    * \brief A camera shared among the players.
    * \author Julien Jorge
@@ -120,12 +119,10 @@ namespace ptb
     placement_mode m_placement;
 
     /** \brief The first player. */
-    bear::universe::const_derived_item_handle_maker<player>::handle_type
-    m_first_player;
+    player_proxy m_first_player;
 
     /** \brief The second player. */
-    bear::universe::const_derived_item_handle_maker<player>::handle_type
-    m_second_player;
+    player_proxy m_second_player;
 
     /** \brief The current progress method. */
     progress_type m_progress;
