@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,14 +29,12 @@
 #ifndef __PTB_AIR_FIRE_STONE_HPP__
 #define __PTB_AIR_FIRE_STONE_HPP__
 
+#include "ptb/player_proxy.hpp"
 #include "ptb/item/stone/fire_stone.hpp"
-#include "universe/derived_item_handle.hpp"
 #include "generic_items/reference_item.hpp"
 
 namespace ptb
 {
-  class player;
-
   /**
    * \brief The class describing a stone with the air and fire powers.
    * \author Sbastien Angibaud
@@ -50,6 +48,8 @@ namespace ptb
     /** \brief The type of the parent class. */
     typedef fire_stone super;
 
+    TEXT_INTERFACE_DECLARE_METHOD_LIST(super, init_exported_methods)
+
   public:
     air_fire_stone();
     ~air_fire_stone();
@@ -61,9 +61,6 @@ namespace ptb
     virtual void inform_no_energy(const monster& attacker);
     virtual bool has_air_power() const;
 
-  protected:
-    virtual void execute_function( const std::string& name );
-
   private:
     void blast();
     void create_decorations();
@@ -71,15 +68,18 @@ namespace ptb
     (const std::string& action, const bear::universe::speed_type& speed);
     void create_movement();
 
+    static void init_exported_methods();
+
   private:
     /** \brief Pointer to the player. */
-    bear::universe::derived_item_handle_maker<player>::handle_type m_player;
+    player_proxy m_player;
 
     /** \brief Indicates if the stone blast. */
     bool m_blast;
 
     /** \brief The reference item for the movement. */
     bear::reference_item* m_reference_item;
+
   }; // class air_fire_stone
 } // namespace ptb
 
