@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,14 +29,12 @@
 #ifndef __PTB_AIR_STONE_HPP__
 #define __PTB_AIR_STONE_HPP__
 
+#include "ptb/player_proxy.hpp"
 #include "ptb/item/stone/stone.hpp"
-#include "universe/derived_item_handle.hpp"
 #include "generic_items/reference_item.hpp"
 
 namespace ptb
 {
-  class player;
-
   /**
    * \brief The class describing a stone with the air power.
    * \author Sbastien Angibaud
@@ -50,6 +48,8 @@ namespace ptb
     /** \brief The type of the parent class. */
     typedef stone super;
 
+    TEXT_INTERFACE_DECLARE_METHOD_LIST(super, init_exported_methods)
+
   public:
     air_stone( bool can_explose = true );
     ~air_stone();
@@ -67,16 +67,17 @@ namespace ptb
     virtual void initialize_intensity();
     void blast();
     void create_movement();
-    virtual void execute_function( const std::string& name );
 
   private:
     void create_decorative_blast
     (const std::string& anim_name, const bear::universe::speed_type& speed);
     void create_bubble();
 
+    static void init_exported_methods();
+
   private:
     /** \brief Pointer to the player. */
-    bear::universe::derived_item_handle_maker<player>::handle_type m_player;
+    player_proxy m_player;
 
     /** \brief Indicates if the stone blast. */
     bool m_blast;
