@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -28,8 +28,7 @@
  */
 #include "ptb/item/stone/air_fire_stone.hpp"
 
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 
 #include "generic_items/decorative_item.hpp"
 #include "universe/forced_movement/forced_stay_around.hpp"
@@ -41,8 +40,7 @@ BASE_ITEM_IMPLEMENT( air_fire_stone, ptb )
  * \brief Constructor.
  */
 ptb::air_fire_stone::air_fire_stone()
-  : m_player(NULL), m_blast(false),
-    m_reference_item(NULL)
+  : m_blast(false), m_reference_item(NULL)
 {
   m_offensive_coefficients[air_attack] = 1;
 } // air_fire_stone::air_fire_stone()
@@ -69,13 +67,10 @@ void ptb::air_fire_stone::build()
     ( get_level_globals().get_model("model/stones/air_fire_stone.cm"));
   start_model_action("attack");
 
-  if ( get_monster_type() == monster::stone_1_monster )
-    m_player = util::find_player( get_level_globals(), 1 );
-  else
-    m_player = util::find_player( get_level_globals(), 2 );
+  m_player = util::find_player( get_level_globals(), get_monster_index() );
 
-  if ( m_player != (player*)NULL )
-    m_player->add_air_stone(this);
+  if ( m_player != NULL )
+    m_player.add_air_stone(this);
 } // air_fire_stone::build()
 
 /*---------------------------------------------------------------------------*/
@@ -116,9 +111,9 @@ void ptb::air_fire_stone::kill()
 {
   if ( !m_blast )
     start_model_action("blast");
-  else if ( m_player.get() )
+  else if ( m_player != NULL )
     {
-      m_player->remove_air_stone(this);
+      m_player.remove_air_stone(this);
 
       super::kill();
     }
@@ -143,19 +138,6 @@ bool ptb::air_fire_stone::has_air_power() const
   return true;
 } // air_fire_stone::has_air_power()
 
-/*----------------------------------------------------------------------------*/
-/**
- * \brief Call a function.
- * \param name The function to call.
- */
-void ptb::air_fire_stone::execute_function( const std::string& name )
-{
-  if ( name == "start_blast" )
-    blast();
-  else
-    super::execute_function(name);
-} // air_fire_stone::execute_function()
-
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Blast the stonee.
@@ -165,15 +147,15 @@ void ptb::air_fire_stone::blast()
   if ( !m_blast )
     {
       m_blast = true;
-      set_speed(bear::universe::speed_type(0,0));
-      set_acceleration(bear::universe::force_type(0,0));
+      set_speed(bear::universe::speed_type(0, 0));
+      set_acceleration(bear::universe::force_type(0, 0));
       set_mass(std::numeric_limits<double>::infinity());
       set_phantom(true);
 
       create_decorations();
 
-      if ( m_player.get() )
-        m_player->remove_air_stone(this);
+      if ( m_player != NULL )
+        m_player.remove_air_stone(this);
     }
 } // air_fire_stone::blast()
 
@@ -190,20 +172,20 @@ void ptb::air_fire_stone::create_decorations()
 
   std::vector<bear::universe::speed_type> speeds(5);
 
-  speeds[0] = bear::universe::speed_type(500*b,0);
-  speeds[1] = bear::universe::speed_type(500*b,500);
-  speeds[2] = bear::universe::speed_type(-500*b,300);
-  speeds[3] = bear::universe::speed_type(-500*b,700);
-  speeds[4] = bear::universe::speed_type(100*b,1000);
-  create_decorative_blast("animation/stones/sliver_1.canim",speeds[a]);
+  speeds[0] = bear::universe::speed_type(500*b, 0);
+  speeds[1] = bear::universe::speed_type(500*b, 500);
+  speeds[2] = bear::universe::speed_type(-500*b, 300);
+  speeds[3] = bear::universe::speed_type(-500*b, 700);
+  speeds[4] = bear::universe::speed_type(100*b, 1000);
+  create_decorative_blast("animation/stones/sliver_1.canim", speeds[a]);
   create_decorative_blast
-    ("animation/stones/sliver_2.canim",speeds[(a+1)%5]);
+    ("animation/stones/sliver_2.canim", speeds[(a+1)%5]);
   create_decorative_blast
-    ("animation/stones/sliver_3.canim",speeds[(a+2)%5]);
+    ("animation/stones/sliver_3.canim", speeds[(a+2)%5]);
   create_decorative_blast
-    ("animation/stones/sliver_4.canim",speeds[(a+3)%5]);
+    ("animation/stones/sliver_4.canim", speeds[(a+3)%5]);
   create_decorative_blast
-    ("animation/stones/sliver_5.canim",speeds[(a+4)%5]);
+    ("animation/stones/sliver_5.canim", speeds[(a+4)%5]);
 } // air_fire_stone::create_decorations
 
 /*----------------------------------------------------------------------------*/
@@ -257,8 +239,20 @@ void ptb::air_fire_stone::create_movement()
     ( std::numeric_limits<bear::universe::coordinate_type>::infinity() );
   mvt.set_apply_angle( true );
   set_system_angle_as_visual_angle(true);
-  mvt.set_reference_item(*m_reference_item);
+  mvt.set_reference_point_on_center(*m_reference_item);
   mvt.set_item(*this);
 
   set_forced_movement( mvt );
 } // air_fire_stone::create_movement()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Export the methods of the class.
+ */
+void ptb::air_fire_stone::init_exported_methods()
+{
+  TEXT_INTERFACE_CONNECT_METHOD_0( ptb::air_fire_stone, blast, void );
+} // air_fire_stone::init_exported_methods()
+
+/*----------------------------------------------------------------------------*/
+TEXT_INTERFACE_IMPLEMENT_METHOD_LIST( ptb::air_fire_stone )
