@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -31,8 +31,12 @@
 #include "ptb/item/stone/air_stone.hpp"
 #include "ptb/item/stone/fire_stone.hpp"
 #include "ptb/item/stone/water_stone.hpp"
+
+#include "ptb/reference_point/attack_point_reference_point.hpp"
+
 #include "engine/layer/layer.hpp"
 #include "engine/world.hpp"
+
 #include "universe/forced_movement/forced_aiming.hpp"
 
 /*----------------------------------------------------------------------------*/
@@ -150,27 +154,27 @@ bool ptb::air_fire_water_stone::has_water_power() const
  */
 void ptb::air_fire_water_stone::blast()
 {
-  bear::universe::speed_type speed1(-300,1000);
-  bear::universe::speed_type speed2(0,1200);
-  bear::universe::speed_type speed3(300,1000);
+  bear::universe::speed_type speed1(-300, 1000);
+  bear::universe::speed_type speed2(0, 1200);
+  bear::universe::speed_type speed3(300, 1000);
 
   if ( has_top_contact() )
     {
-      speed1 = bear::universe::speed_type(-500,0);
-      speed2 = bear::universe::speed_type(0,0);
-      speed3 = bear::universe::speed_type(500,0);
+      speed1 = bear::universe::speed_type(-500, 0);
+      speed2 = bear::universe::speed_type(0, 0);
+      speed3 = bear::universe::speed_type(500, 0);
     }
   else if ( has_right_contact() )
     {
-      speed1 = bear::universe::speed_type(-300,1300);
-      speed2 = bear::universe::speed_type(-400,600);
-      speed3 = bear::universe::speed_type(-300,-200);
+      speed1 = bear::universe::speed_type(-300, 1300);
+      speed2 = bear::universe::speed_type(-400, 600);
+      speed3 = bear::universe::speed_type(-300, -200);
     }
   else if ( has_left_contact() )
     {
-      speed1 = bear::universe::speed_type(300,1300);
-      speed2 = bear::universe::speed_type(400,600);
-      speed3 = bear::universe::speed_type(300,-200);
+      speed1 = bear::universe::speed_type(300, 1300);
+      speed2 = bear::universe::speed_type(400, 600);
+      speed3 = bear::universe::speed_type(300, -200);
     }
 
   unsigned int a = (unsigned int)(3.0 * rand() / RAND_MAX);
@@ -215,6 +219,7 @@ void ptb::air_fire_water_stone::create_stone
   new_stone->set_z_position(get_z_position());
   new_stone->set_top_left( get_top_left() );
   new_stone->set_monster_type(get_monster_type());
+  new_stone->set_monster_index(get_monster_index());
   new_stone->set_speed(speed);
   new_item( *new_stone );
 } // create_stone()
@@ -234,26 +239,31 @@ void ptb::air_fire_water_stone::search_enemy()
   bear::universe::world::item_list::const_iterator it;
   for ( it=items.begin(); (it!=items.end()) && !found; ++it)
     {
-      monster* m = dynamic_cast<ptb::monster*>(*it);
+      with_attack_point* m = dynamic_cast<with_attack_point*>(*it);
 
       if ( m != NULL )
-        if ( ( ( ( get_monster_type() == monster::stone_1_monster ) &&
-                 ( m->get_monster_type() != monster::stone_1_monster ) &&
-                 ( m->get_monster_type() != monster::player_1_monster ) ) ||
-               ( ( get_monster_type() == monster::stone_2_monster ) &&
-                 ( m->get_monster_type() != monster::stone_2_monster ) &&
-                 ( m->get_monster_type() != monster::player_2_monster ) ) ) &&
-             ( m->get_monster_type() != monster::nature_monster ) )
+        if ( m->has_attack_point() )
           {
-            found = true;
-            m_enemy_found = true;
-            bear::universe::forced_aiming movement;
+            bool ok(true);
 
-            movement.set_max_angle( 0.05 );
-            movement.set_max_speed( 400 );
+            monster* mo = dynamic_cast<monster*>(*it);
+            if ( mo != NULL )
+              ok = mo->is_vulnerable(*this);
 
-            movement.set_reference_item(**it);
-            set_forced_movement( movement );
+            if ( ok )
+            {
+              found = true;
+              m_enemy_found = true;
+              bear::universe::forced_aiming movement;
+
+              movement.set_max_angle( 0.05 );
+              movement.set_max_speed( 400 );
+
+              movement.set_reference_point
+                ( attack_point_reference_point(**it) );
+
+              set_forced_movement( movement );
+            }
           }
     }
 } // air_fire_water_stone::search_enemy()
