@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -50,6 +50,8 @@ namespace ptb
     /** \brief The type of the parent class. */
     typedef monster_item< bear::engine::model<bear::engine::base_item> > super;
 
+    TEXT_INTERFACE_DECLARE_METHOD_LIST(super, init_exported_methods)
+
   public:
     stone();
 
@@ -65,15 +67,17 @@ namespace ptb
     virtual bool has_fire_power() const;
     virtual bool has_water_power() const;
 
-  protected:
-    virtual void execute_function( const std::string& name );
-
   private:
+    void create_hit_star( const bear::engine::base_item& that ) const;
     void create_bubble();
 
   protected:
     void rotate();
     void default_progress( bear::universe::time_type elapsed_time );
+
+  private:
+    static void init_exported_methods();
+
   }; // class stone
 } // namespace ptb
 
