@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -31,7 +31,7 @@
 
 namespace ptb
 {
-  class player;
+  class player_proxy;
 
   /**
    * \brief An item activated by an event comming from the players.
@@ -43,8 +43,9 @@ namespace ptb
   public:
     virtual ~activate_on_players();
 
-    virtual void on_one_player( player* p );
-    virtual void on_all_players( player* p1, player* p2 );
+    virtual void on_one_player( const player_proxy& p );
+    virtual void on_all_players
+    ( const player_proxy& p1, const player_proxy& p2 );
 
   }; // class activate_on_players
 } // namespace ptb
