@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -27,7 +27,6 @@
  * \author Julien Jorge
  */
 #include "ptb/item_brick/activate_on_players.hpp"
-#include "ptb/player.hpp"
 
 /*----------------------------------------------------------------------------*/
 /**
@@ -44,7 +43,7 @@ ptb::activate_on_players::~activate_on_players()
  * \param p The player.
  * \remark This method is called only in a two players game.
  */
-void ptb::activate_on_players::on_one_player( player* p )
+void ptb::activate_on_players::on_one_player( const player_proxy& p )
 {
   // nothing to do
 } // activate_on_players::on_one_player()
@@ -55,7 +54,8 @@ void ptb::activate_on_players::on_one_player( player* p )
  * \param p1 The first player.
  * \param p2 The second player. NULL in a single player game.
  */
-void ptb::activate_on_players::on_all_players( player* p1, player* p2 )
+void ptb::activate_on_players::on_all_players
+( const player_proxy& p1, const player_proxy& p2 )
 {
   // nothing to do
 } // activate_on_players::on_all_players()
