@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -51,6 +51,8 @@ namespace ptb
   {
     typedef Base super;
 
+    TEXT_INTERFACE_DECLARE_METHOD_LIST(super, init_exported_methods)
+
   public:
     void build();
 
@@ -61,6 +63,9 @@ namespace ptb
     ( const std::string& name, const std::vector<std::string>& value );
     virtual bool set_bool_field( const std::string& name, bool value );
 
+  private:
+    static void init_exported_methods();
+
   private:
     /** \brief Tell if this item has been registered in a balloon layer. */
     bool m_registered_in_layer;
