@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -32,10 +32,10 @@
 #include "engine/item_brick/basic_renderable_item.hpp"
 #include "engine/base_item.hpp"
 
+#include "ptb/player_proxy.hpp"
+
 namespace ptb
 {
-  class player;
-
   /**
    * \brief This item is activated when all players are colliding with it.
    * \author Julien Jorge
@@ -61,26 +61,28 @@ namespace ptb
     bool all_players_present() const;
     bool one_player_present() const;
 
-  protected:
-    void one_player( player* p );
-    void all_players( player* p1, player* p2 );
+  private:
+    void one_player( const player_proxy& p );
+    void all_players( const player_proxy& p1, const player_proxy& p2 );
     void no_player();
 
     void progress_one_player
-    ( bear::universe::time_type elapsed_time, player* p );
+    ( bear::universe::time_type elapsed_time, const player_proxy& p );
     void progress_all_players
-    ( bear::universe::time_type elapsed_time, player* p1, player* p2 );
+    ( bear::universe::time_type elapsed_time, const player_proxy& p1,
+      const player_proxy& p2 );
     void progress_no_player( bear::universe::time_type elapsed_time );
 
-    virtual void on_one_player( player* p );
-    virtual void on_all_players( player* p1, player* p2 );
+    virtual void on_one_player( const player_proxy& p );
+    virtual void on_all_players
+    ( const player_proxy& p1, const player_proxy& p2 );
     virtual void on_no_player();
 
-  private:
     virtual void do_progress_one_player
-    ( bear::universe::time_type elapsed_time, player* p );
+    ( bear::universe::time_type elapsed_time, const player_proxy& p );
     virtual void do_progress_all_players
-    ( bear::universe::time_type elapsed_time, player* p1, player* p2 );
+    ( bear::universe::time_type elapsed_time, const player_proxy& p1,
+      const player_proxy& p2 );
     virtual void
     do_progress_no_player( bear::universe::time_type elapsed_time );
 
@@ -89,16 +91,16 @@ namespace ptb
 
   private:
     /** \brief The first player, if colliding with this item. */
-    player* m_first_player;
+    player_proxy m_first_player;
 
     /** \brief The second player, if colliding with this item. */
-    player* m_second_player;
+    player_proxy m_second_player;
 
     /** \brief The pointer to the first player from the previous progress. */
-    player* m_previous_first_player;
+    player_proxy m_previous_first_player;
 
     /** \brief The pointer to the second player from the previous progress. */
-    player* m_previous_second_player;
+    player_proxy m_previous_second_player;
 
     /** \brief The animation to display when no player is there. */
     bear::visual::animation m_off;
