@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -53,8 +53,7 @@ namespace ptb
     typedef bear::engine::gui_layer::scene_element_list scene_element_list;
 
     /** \brief The type of the pointers on the speaker items. */
-    typedef bear::universe::derived_item_handle_maker<speaker_item>::handle_type
-    handle_type;
+    typedef bear::universe::derived_item_handle<speaker_item> handle_type;
 
     /** \brief The type of the list of all speakers. */
     typedef std::list<handle_type> speaker_list;
