@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -197,7 +197,7 @@ void ptb::balloon_placement::add_speaker
   bool is_visible(false);
 
   if ( rect.intersects(m_view) )
-    is_visible = !( rect.intersection(m_view) ).empty();
+    is_visible = !rect.intersection(m_view).empty() || rect.empty();
 
   m_characters.push_back(scene_character(c, rect, is_visible));
 } // balloon_placement::add_speaker()
@@ -473,7 +473,9 @@ void ptb::balloon_placement::create_candidate_not_visible
           m_view.right() - c.get_balloon_size().x );
       break;
     default:
-      { CLAW_FAIL("Invalid zone for an invisible candidate."); }
+      {
+        CLAW_FAIL("Invalid zone for an invisible candidate.");
+      }
     }
 } // balloon_placement::create_candidate_not_visible()
 
