@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -120,9 +120,7 @@ void ptb::balloon_layer::add_speaker( speaker_item* speaker )
     CLAW_FAIL("The item is already in the balloon layer.");
 #endif
 
-  m_speakers.push_back
-    ( bear::universe::derived_item_handle_maker<speaker_item>::make_from
-      (speaker) );
+  m_speakers.push_back( bear::universe::item_handle_from(speaker) );
 } // balloon_layer::add_speaker()
 
 /*----------------------------------------------------------------------------*/
