@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -84,7 +84,11 @@ bool ptb::base_debugging_layer::key_pressed
   bool result = true;
 
   if ( key.get_code() == m_toggle_key )
-    m_visible = !m_visible;
+    {
+      m_visible = !m_visible;
+      if ( m_visible )
+        on_show();
+    }
   else
     result = false;
 
@@ -106,3 +110,12 @@ void ptb::base_debugging_layer::find_items( item_list& items ) const
 
   items = msg_w.items;
 } // base_debugging_layer::find_items()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Inform the subclasses that the layer is displayed.
+ */
+void ptb::base_debugging_layer::on_show()
+{
+  // nothing to do
+} // base_debugging_layer::on_show()
