@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -42,9 +42,7 @@
  */
 ptb::item_information_layer::info_box::info_box
 ( bear::universe::physical_item& item, const bear::visual::font& font )
-  : m_item(&item),
-    m_delta( 0,0 ),
-    m_text( NULL, font )
+  : m_item(&item), m_delta( 0, 0 ), m_text( font )
 {
   m_text.set_auto_size(true);
 
@@ -114,9 +112,9 @@ void ptb::item_information_layer::info_box::update
   if ( m_item != NULL )
     {
       bear::universe::position_type pos;
-      pos.x = (m_item->get_right()- camera_box.left())/ratio.x + m_delta.x;
-      pos.y = (camera_box.top() - m_item->get_bottom())/ratio.y + m_delta.y;
-      m_text.set_position( pos.cast_value_type_to<unsigned int>() );
+      pos.x = (m_item->get_right() - camera_box.left())/ratio.x + m_delta.x;
+      pos.y = (m_item->get_top() - camera_box.bottom())/ratio.y + m_delta.y;
+      m_text.set_position( pos );
     }
   else
     m_text.set_text("Invalid handle.");
