@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -64,7 +64,7 @@ void ptb::main_menu_layer::build()
 
   m_engine_version =
     new bear::gui::static_text
-    ( NULL, get_level_globals().get_font("font/fixed_white-7x12.fnt") );
+    ( get_level_globals().get_font("font/fixed_white-7x12.fnt") );
 
   m_engine_version->set_auto_size(true);
   m_engine_version->set_text(BEAR_VERSION_STRING);
