@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -34,6 +34,8 @@
 #include "visual/font.hpp"
 #include "visual/scene_sprite.hpp"
 
+#include "ptb/game_variables.hpp"
+
 #include <sstream>
 #include <iomanip>
 #include <claw/bitmap.hpp>
@@ -42,6 +44,11 @@
 
 #include <boost/thread.hpp>
 
+#ifdef PTB_TRACE_FPS
+typedef std::list<unsigned int> fps_list;
+static fps_list g_fps;
+#endif
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Execute the function object to save the image.
@@ -69,7 +76,12 @@ void ptb::misc_layer::screenshot_file_save<ImageWriter>::operator()() const
  * \brief Constructor.
  */
 ptb::misc_layer::misc_layer()
-  : m_fps_text(NULL), m_fps_count(0), m_its_count(0), m_show_fps(false),
+  : m_fps_text(NULL), m_fps_count(0), m_its_count(0),
+#ifdef PTB_TRACE_FPS
+    m_show_fps(true),
+#else
+    m_show_fps(false),
+#endif
     m_cursor_position(-1, -1), m_mouse_idle(0), m_first_screenshot(0),
     m_fps_key(bear::input::keyboard::kc_F2),
     m_screenshot_key(bear::input::keyboard::kc_F5),
@@ -90,6 +102,13 @@ ptb::misc_layer::~misc_layer()
 
   if (m_first_screenshot != 0)
     stop_screenshot_sequence();
+
+#ifdef PTB_TRACE_FPS
+  std::ofstream f("fps.txt");
+  std::size_t i=0;
+  for ( fps_list::const_iterator it=g_fps.begin(); it!=g_fps.end(); ++it, ++i )
+    f << i << '\t' << *it << '\n';
+#endif
 } // misc_layer::~misc_layer()
 
 /*----------------------------------------------------------------------------*/
@@ -100,7 +119,7 @@ void ptb::misc_layer::build()
 {
   m_fps_text =
     new bear::gui::static_text
-    ( NULL, get_level_globals().get_font("font/fixed_white-7x12.fnt") );
+    ( get_level_globals().get_font("font/fixed_white-7x12.fnt") );
 
   m_fps_text->set_auto_size(true);
   m_fps_text->set_text("0");
@@ -109,8 +128,10 @@ void ptb::misc_layer::build()
   m_last_fps_check = bear::systime::get_date_ms();
 
   m_cursor =
-    bear::visual::sprite( get_level_globals().get_image("gfx/frame.tga"),
-                          claw::math::rectangle<unsigned int>(73, 32, 32, 32) );
+    get_level_globals().auto_sprite( "gfx/ui/frame.png", "mouse cursor" );
+
+  if ( game_variables::record_game() )
+    start_screenshot_sequence();
 } // misc_layer::build()
 
 /*----------------------------------------------------------------------------*/
@@ -318,6 +339,10 @@ void ptb::misc_layer::render_fps( scene_element_list& e ) const
           std::ostringstream oss;
           oss << m_fps_count << " fps - " << m_its_count << " its";
 
+#ifdef PTB_TRACE_FPS
+          g_fps.push_back(m_fps_count);
+#endif
+
           m_fps_text->set_text( oss.str() );
           m_fps_count = 0;
           m_its_count = 0;
