@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -35,8 +35,8 @@
 #include "visual/scene_writing.hpp"
 #include "visual/bitmap_writing.hpp"
 
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/game_variables.hpp"
+#include "ptb/util/player_util.hpp"
 
 #include <algorithm>
 #include <claw/algorithm.hpp>
@@ -53,11 +53,11 @@
  */
 ptb::player_arrows_layer::player_data::player_data
 ( const claw::math::coordinate_2d<unsigned int> screen_size,
-  const player* p, const bear::visual::sprite& arrow,
+  const player_proxy& p, const bear::visual::sprite& arrow,
   const bear::visual::font& f )
-  : m_screen_size(screen_size), m_arrow(arrow),
-    m_player(p), m_visible(false)
+  : m_screen_size(screen_size), m_arrow(arrow), m_player(p), m_visible(false)
 {
+
 } // player_arrows_layer::player_data::player_data()
 
 /*----------------------------------------------------------------------------*/
@@ -92,10 +92,10 @@ void ptb::player_arrows_layer::player_data::adjust_arrow
 {
   m_visible = false;
 
-  if (m_player != (player*)NULL)
+  if ( (m_player != NULL) && !m_player.is_a_marionette() )
     {
       const bear::universe::position_type center =
-        m_player->get_center_of_mass();
+        m_player.get_center_of_mass();
 
       if( ( center.x < visible_area.left() ) ||
           ( center.x > visible_area.left() + visible_area.size().x ) ||
@@ -121,11 +121,12 @@ void ptb::player_arrows_layer::player_data::adjust_position
 {
   bear::universe::position_type result;
 
-  bear::universe::position_type pos_player( m_player->get_center_of_mass() );
-  bear::universe::position_type center
+  const bear::universe::position_type pos_player
+    ( m_player.get_center_of_mass() );
+  const bear::universe::position_type center
     ( visible_area.bottom_left() + visible_area.size() / 2 );
 
-  claw::math::vector_2d<double> vect(center, m_player->get_center_of_mass());
+  claw::math::vector_2d<double> vect(center, pos_player);
   vect.normalize();
 
   // intersection betwwen line and ellipse
@@ -158,7 +159,7 @@ void ptb::player_arrows_layer::player_data::adjust_angle
     ( m_position.y + m_arrow.height() / 2 ) * ratio.y;
 
   bear::universe::speed_type v =
-    m_player->get_center_of_mass() - relative_position;
+    m_player.get_center_of_mass() - relative_position;
 
   v.normalize();
 
@@ -190,11 +191,10 @@ void ptb::player_arrows_layer::player_data::adjust_distance
     ( m_screen_size.y - m_position.y - m_arrow.height() / 2 ) * ratio.y;
 
   bear::universe::speed_type vect
-    (m_player->get_center_of_mass(), relative_position);
+    (m_player.get_center_of_mass(), relative_position);
   unsigned int dist = (unsigned int)vect.length() / 100;
 
-  const bear::universe::rectangle_type box =
-    m_player->get_bounding_box();
+  const bear::universe::rectangle_type box = m_player.get_bounding_box();
   bear::visual::font f = glob.get_font("font/bouncy.fnt");
   if ( box.intersects( visible_area ) )
     m_distance.create(f, "");
@@ -282,24 +282,26 @@ void ptb::player_arrows_layer::search_players( )
 {
   if ( m_data_1 == NULL )
     {
-      player const* p( util::find_player( get_level_globals(), 1 ) );
+      player_proxy p( util::find_player( get_level_globals(), 1 ) );
 
       if ( p != NULL )
         m_data_1 = new player_data
           ( get_size(), p,
-            get_level_globals().auto_sprite("gfx/status.png", "arrow 1"),
+            get_level_globals().auto_sprite
+            ("gfx/ui/status/status.png", "arrow 1"),
             get_level_globals().get_font("font/bouncy.fnt") );
     }
 
   if ( game_variables::get_players_count() == 2 )
     if ( m_data_2 == NULL )
       {
-        player const* p( util::find_player( get_level_globals(), 2 ) );
+        player_proxy p( util::find_player( get_level_globals(), 2 ) );
 
         if ( p != NULL )
           m_data_2 = new player_data
             ( get_size(), p,
-              get_level_globals().auto_sprite("gfx/status.png", "arrow 2"),
+              get_level_globals().auto_sprite
+              ("gfx/ui/status/status.png", "arrow 2"),
               get_level_globals().get_font("font/bouncy.fnt") );
       }
 } // player_arrows_layer::search_players( )
