@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -248,10 +248,7 @@ void ptb::windows_layer::render( scene_element_list& e ) const
 void ptb::windows_layer::clear()
 {
   for ( ; !m_windows.empty(); m_windows.pop() )
-    {
-      m_windows.top()->close();
-      delete m_windows.top();
-    }
+    delete m_windows.top();
 } // windows_layer::clear()
 
 /*----------------------------------------------------------------------------*/
@@ -276,6 +273,27 @@ void ptb::windows_layer::show_centered_window( window_item wnd )
   wnd->on_focus();
 } // windows_layer::show_window()
 
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Replace the top window.
+ * \param old_wnd The window to replace.
+ * \param new_wnd The new window.
+ * \post !m_window.empty() && m_window.top() is centered in the screen.
+ */
+void ptb::windows_layer::replace_window
+( window_item old_wnd, window_item new_wnd )
+{
+  CLAW_PRECOND(old_wnd == m_windows.top());
+  CLAW_PRECOND(old_wnd != new_wnd);
+
+  m_windows.top()->close();
+  pop_window();
+
+  new_wnd->set_position( (get_size() - new_wnd->get_size()) / 2 );
+  m_windows.push(new_wnd);
+  new_wnd->on_focus();
+} // windows_layer::replace_window()
+
 /*----------------------------------------------------------------------------*/
 /**
  * \brief Show a window.
@@ -299,8 +317,7 @@ bool ptb::windows_layer::close_window()
   if ( !m_windows.empty() )
     if ( m_windows.top()->close() )
       {
-        m_dying_windows.push_back(m_windows.top());
-        m_windows.pop();
+        pop_window();
 
         if ( !m_windows.empty() )
           m_windows.top()->on_focus();
@@ -321,3 +338,13 @@ bool ptb::windows_layer::process_score_message( const score_message& msg )
   // nothing to do
   return false;
 } // windows_layer::process_score_message()
+
+/*----------------------------------------------------------------------------*/
+/**
+ * \brief Pop the current window.
+ */
+void ptb::windows_layer::pop_window()
+{
+  m_dying_windows.push_back(m_windows.top());
+  m_windows.pop();
+} // windows_layer::pop_window()
