@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,8 +30,7 @@
 #define __PTB_PLAYER_ARROWS_LAYER_HPP__
 
 #include "engine/layer/gui_layer.hpp"
-#include "universe/derived_item_handle.hpp"
-#include "ptb/player.hpp"
+#include "ptb/player_proxy.hpp"
 #include "visual/writing.hpp"
 
 namespace ptb
@@ -54,7 +53,7 @@ namespace ptb
     public:
       player_data
       ( const claw::math::coordinate_2d<unsigned int> screen_size,
-        const player* p, const bear::visual::sprite& arrow,
+        const player_proxy& p, const bear::visual::sprite& arrow,
         const bear::visual::font& f );
 
       void render( scene_element_list& e ) const;
@@ -83,8 +82,7 @@ namespace ptb
       bear::universe::position_type m_distance_text_position;
 
       /** \brief The player. */
-      bear::universe::const_derived_item_handle_maker<player>::handle_type
-      m_player;
+      player_proxy m_player;
 
       /** \brief Tell if the arrow is visible. */
       bool m_visible;
