@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -86,12 +86,16 @@ namespace ptb
     void clear();
     bool empty() const;
     void show_centered_window( window_item wnd );
+    void replace_window( window_item old_wnd, window_item new_wnd );
     void show_window( window_item wnd );
 
     bool close_window();
 
     virtual bool process_score_message( const score_message& msg );
 
+  private:
+    void pop_window();
+
   private:
     /** \brief The pending windows. */
     std::stack<window_item> m_windows;
