@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -44,19 +44,34 @@ namespace ptb
     static void set_players_on_exit
     ( bear::engine::level& lvl, unsigned int c );
 
-    static unsigned int get_killed_enemies( const bear::engine::level& lvl );
-    static void set_killed_enemies
-    ( bear::engine::level& lvl, unsigned int nb );
+    static unsigned int get_object_count
+    ( const bear::engine::level& lvl, const std::string& object_type );
+    static void set_object_count
+    ( bear::engine::level& lvl, const std::string& object_type,
+      unsigned int nb );
 
-    static unsigned int get_enemy_count( const bear::engine::level& lvl );
-    static void set_enemy_count( bear::engine::level& lvl, unsigned int nb );
+    static unsigned int get_killed_object_count
+    ( const bear::engine::level& lvl, const std::string& object_type );
+    static void set_killed_object_count
+    ( bear::engine::level& lvl, const std::string& object_type,
+      unsigned int nb );
 
-    static bool get_hazelnut( const bear::engine::level& lvl);
-    static void set_hazelnut( bear::engine::level& lvl, bool v );
+    static bool get_current_hazelnut( const bear::engine::level& lvl);
+    static void set_current_hazelnut( bear::engine::level& lvl, bool v );
+
+    static bool get_hazelnut_found( const bear::engine::level& lvl);
+    static void set_hazelnut_found( bear::engine::level& lvl, bool v );
+
+    static bool get_secret_level_found( const bear::engine::level& lvl);
+    static void set_secret_level_found( bear::engine::level& lvl, bool v );
 
     static unsigned int get_honeypots_found( const bear::engine::level& lvl );
     static void set_honeypots_found
     ( bear::engine::level& lvl, unsigned int nb );
+    static bool get_honeypot_found
+    ( const bear::engine::level& lvl, unsigned int id );
+    static void set_honeypot_found
+    ( bear::engine::level& lvl, unsigned int id, bool b );
 
     static bool is_exiting( const bear::engine::level& lvl );
     static void set_exiting( bear::engine::level& lvl );
@@ -64,10 +79,7 @@ namespace ptb
     static bool owl_is_met( const bear::engine::level& lvl );
     static void meet_the_owl( bear::engine::level& lvl );
 
-    static bear::universe::time_type
-    get_time_record( const bear::engine::level& lvl );
-    static void
-    set_time_record( bear::engine::level& lvl, bear::universe::time_type t );
+    static void all_hideouts_found( bear::engine::level& lvl );
 
     static bool get_friendly_fire(bear::engine::level& lvl);
     static void set_friendly_fire( bear::engine::level& lvl, bool v );
