@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -46,13 +46,9 @@ namespace ptb
      /** \brief The different categories of monster. */
     enum monster_type
       {
-        player_1_monster = 0,
-        player_2_monster,
-        player_3_monster,
+        player_monster = 0,
         enemy_monster,
-        stone_1_monster,
-        stone_2_monster,
-        stone_3_monster,
+        stone_monster,
         nature_monster
       }; // enum monster_type
 
@@ -68,51 +64,64 @@ namespace ptb
     /** \brief The number of attacks. */
     static const unsigned int s_attack_count;
 
+    /** \brief Duration of injured state. */
+    static const double s_injured_duration;
+
   public:
     monster();
     virtual ~monster();
 
-    bool receive_an_attack( monster& attacker,
-                            const bear::universe::collision_info& info );
-
     virtual void set_invincible(const bool invincible);
     bool is_invincible() const;
     void set_offensive_phase(const bool offensive_phase);
     bool get_offensive_phase() const;
-    void set_defensive_power(const attack_type index, const bool statut);
-    bool get_defensive_power(const attack_type index) const;
-    void set_offensive_coefficient
-    (const attack_type index, const unsigned int coef);
 
-    monster_type get_monster_type() const;
-    void set_monster_type(monster_type m);
+    virtual bool attack( bear::engine::base_item& that ) = 0;
+    bool receive_an_attack
+    ( monster& attacker, bear::universe::zone::position side );
+
+    // The full namespace is used for the return type to ease the automatic
+    // generation of the player_proxy class
+    void set_defensive_power(ptb::monster::attack_type index, bool statut);
+    bool get_defensive_power(ptb::monster::attack_type index) const;
+    void set_offensive_coefficient
+    (ptb::monster::attack_type index, unsigned int coef);
+
+    // The full namespace is used for the return type to ease the automatic
+    // generation of the player_proxy class
+    ptb::monster::monster_type get_monster_type() const;
+    void set_monster_type(ptb::monster::monster_type m);
+
+    unsigned int get_monster_index() const;
+    void set_monster_index(unsigned int index);
     double get_energy() const;
     void set_energy(double energy);
-    double get_initial_energy() const;
+    double get_max_energy() const;
+    void set_max_energy(double energy);
     bool is_injured() const;
-
     bool is_in_offensive_phase() const;
+    bool is_vulnerable( monster& attacker ) const;
+    bool is_stone_vulnerable() const;
 
   protected:
     void to_string( std::string& str ) const;
-
-  private:
-    virtual void remove_energy(const monster& attacker, double energy );
-
-  protected:
-    bool is_vulnerable
-    ( monster& attacker, const bear::universe::collision_info& info ) const;
-    virtual void injure(const monster& attacker,
-                        const bear::universe::collision_info& info);
+    virtual void injure
+    (const monster& attacker, bear::universe::zone::position side,
+     double duration);
     virtual void finish_injure();
     virtual void has_attacked(const monster& other);
     virtual bool get_defensive_power
     ( unsigned int index, const monster& attacker,
-      const bear::universe::collision_info& info ) const;
+      bear::universe::zone::position side ) const;
     virtual unsigned int get_offensive_coefficient
-    ( unsigned int index,
-      const monster& attacker,
-      const bear::universe::collision_info& info ) const;
+    ( unsigned int index, const monster& attacker,
+      bear::universe::zone::position side ) const;
+    virtual void remove_energy(const monster& attacker, double energy );
+    void set_stone_vulnerability(bool vulnerable);
+
+  private:
+    bool player_is_vulnerable( monster& attacker) const;
+    bool stone_is_vulnerable( monster& attacker) const;
 
   protected:
     /** \brief Force of attack. */
@@ -122,7 +131,7 @@ namespace ptb
     double m_energy;
 
     /** \brief The initial energy of the monster. */
-    double m_initial_energy;
+    double m_max_energy;
 
     /** \brief Indicate if the monster is in an offensive phase. */
     bool m_offensive_phase;
@@ -136,9 +145,15 @@ namespace ptb
     /** \brief Indicates if the monster is invincible. */
     bool m_invincible;
 
+    /** \brief Indicates if the monster is vulnerable for stones. */
+    bool m_is_stone_vulnerable;
+
     /** \brief Which kind of monster am I ? */
     monster_type m_monster_type;
 
+    /** \brief The monster index : for player and stone */
+    unsigned int m_monster_index;
+
     /** \brief Indicates if the monster is injured. */
     bool m_is_injured;
 
