@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,6 +30,7 @@
 #define __PTB_MONSTER_ITEM_HPP__
 
 #include "ptb/monster.hpp"
+#include "ptb/item_brick/item_with_attack_point.hpp"
 #include "engine/base_item.hpp"
 #include "universe/collision_info.hpp"
 
@@ -46,24 +47,34 @@ namespace ptb
    */
   template<class Base>
   class monster_item :
-    public Base,
+    public item_with_attack_point<Base>,
     public monster
   {
   public:
     /** \brief The type of the parent class. */
-    typedef Base super;
+    typedef item_with_attack_point<Base> super;
 
   public:
     monster_item();
     monster_item( const std::string& model_file );
 
+    virtual void pre_cache();
     virtual void progress( bear::universe::time_type elapsed_time );
     virtual void build();
+
     bool set_u_integer_field( const std::string& name, unsigned int value );
     bool set_real_field( const std::string& name, double value );
     bool set_bool_field( const std::string& name, bool value );
     bool set_string_field( const std::string& name, const std::string& value );
 
+    virtual bool has_attack_point() const;
+
+    bool attack( bear::engine::base_item& that );
+    bool attack
+    ( bear::engine::base_item& that, bear::universe::zone::position side );
+
+    virtual void create_hit_star( const bear::engine::base_item& that ) const;
+
   protected:
     void to_string( std::string& str ) const;
 
@@ -76,8 +87,19 @@ namespace ptb
     virtual void inform_no_energy(const monster& attacker);
 
     virtual void injure
-    (const monster& attacker,const bear::universe::collision_info& info);
+    ( const monster& attacker, bear::universe::zone::position side,
+      double duration );
     virtual void finish_injure();
+    bear::universe::position_type get_stone_vulnerability_position() const;
+
+    void create_hit_star
+    ( const bear::universe::position_type& pos, double angle ) const;
+
+    void create_hit_star
+    ( const bear::engine::base_item& ref,
+      const bear::engine::base_item& that ) const;
+
+    void play_hit_sound( const bear::universe::position_type& pos ) const;
 
   private:
     /** \brief Transparency of injured frame. */
@@ -86,6 +108,9 @@ namespace ptb
     /** \brief Increment for the transparency when injured. */
     double m_opacity_inc;
 
+    /** \brief Duration of injured state. */
+    double m_injured_duration;
+
   }; // class monster_item
 } // namespace ptb
 
