@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -24,14 +24,18 @@
 /**
  * \file player.hpp
  * \brief The class describing a player.
- * \author Sbastien Angibaud
+ * \author Sebastien Angibaud
  */
 #ifndef __PTB_PLAYER_HPP__
 #define __PTB_PLAYER_HPP__
 
+#include "ptb/gauge.hpp"
 #include "ptb/monster_item.hpp"
+#include "ptb/player_signals.hpp"
 #include "ptb/item_brick/item_with_single_player_control_reader.hpp"
 #include "ptb/item_brick/item_that_speaks.hpp"
+#include "ptb/throwable_item/throwable_items_container.hpp"
+
 #include "engine/messageable_item.hpp"
 #include "engine/model.hpp"
 #include "communication/typed_message.hpp"
@@ -43,15 +47,14 @@
 
 namespace ptb
 {
-  class gauge;
-  class throwable_items_container;
+  class corrupting_bonus_attractor;
   class throwable_item;
   class state_player;
   class stone;
 
   /**
    * \brief The class describing a player.
-   * \author Sbastien Angibaud
+   * \author Sebastien Angibaud
    */
   class player :
     public item_with_single_player_control_reader
@@ -70,6 +73,9 @@ namespace ptb
           < bear::engine::messageable_item
             < bear::engine::base_item > > > > > super;
 
+    TEXT_INTERFACE_DECLARE_METHOD_LIST(super, init_exported_methods)
+
+  protected:
     enum player_state_name
       {
         walk_state = 0,
@@ -97,16 +103,10 @@ namespace ptb
         hang_state,
         swimming_state,
         sink_state,
-        float_state
+        float_state,
+        paralyze_state
       }; // enum player_state_name
 
-    enum gauge_type
-      {
-        oxygen_gauge = 0,
-        fire_gauge,
-        ice_gauge
-      }; // enum gauge_type
-
   private:
     typedef void (player::*progress_function_type)(bear::universe::time_type);
 
@@ -123,25 +123,40 @@ namespace ptb
 
     bool is_valid() const;
     bool set_u_integer_field( const std::string& name, unsigned int value );
+
     void save_position( const bear::universe::position_type& p );
+    void save_current_position();
 
     void start_action( player_action::value_type a );
     void do_action
     ( bear::universe::time_type elapsed_time, player_action::value_type a );
     void stop_action( player_action::value_type a );
     void start_action_model(const std::string& action);
-    void set_autorized_action(player_action::value_type a, bool value);
 
-    const gauge* get_gauge(gauge_type t) const;
+    void set_authorized_action(player_action::value_type a, bool value);
+    void authorize_action( const std::string& a );
+    void authorize_all_actions();
+    void disable_all_actions();
 
+    // The full namespace is used for the return type to ease the automatic
+    // generation of the player_proxy class
+    const ptb::gauge& get_oxygen_gauge() const;
+    const ptb::gauge& get_cold_gauge() const;
+    const ptb::gauge& get_heat_gauge() const;
+
+    ptb::player_signals& get_signals();
     double get_jump_time_ratio() const;
     void update_throw_time_ratio();
     void set_throw_down(bool value);
     void set_throw_up(bool value);
     void throw_hazelnut();
-    const throwable_items_container* get_throwable_items() const;
 
-    bool is_a_marionette() const ;
+    // The full namespace is used for the return type to ease the automatic
+    // generation of the player_proxy class
+    const ptb::throwable_items_container& get_throwable_items() const;
+    ptb::throwable_items_container& get_throwable_items() ;
+
+    bool is_a_marionette() const;
     void set_marionette( bool b);
 
     void set_air_float(bool status);
@@ -160,7 +175,9 @@ namespace ptb
 
     virtual void set_invincible(const bool invincible);
     void receive_energy(double energy);
+    void remove_energy(const monster& attacker, double energy );
     void receive_oxygen(double oxygen);
+    void give_one_up();
 
     void add_air_stone(stone* s);
     void remove_air_stone(stone* s);
@@ -200,6 +217,7 @@ namespace ptb
     void apply_chain();
     void apply_unchain();
     void apply_injured();
+    void apply_paralyze(bear::universe::time_type duration);
     void apply_throw();
     void apply_maintain();
     void apply_throw_object();
@@ -229,32 +247,31 @@ namespace ptb
     virtual void choose_wait_state();
     virtual void choose_idle_state();
     virtual void choose_walk_state();
-    virtual bear::universe::coordinate_type
-    get_vertical_jump_force() const = 0;
+    virtual bear::universe::coordinate_type get_vertical_jump_force() const = 0;
 
   protected:
-    virtual void execute_function( const std::string& name );
     virtual void inform_no_energy(const monster& attacker);
     virtual void injure
-    (const monster& attacker, const bear::universe::collision_info& info);
+    ( const monster& attacker, bear::universe::zone::position side,
+      double duration );
     virtual void finish_injure();
     virtual unsigned int get_offensive_coefficient
     ( unsigned int index, const monster& other,
-      const bear::universe::collision_info& info ) const;
+      bear::universe::zone::position side ) const;
     virtual void progress_in_water(bear::universe::time_type elapsed_time);
 
     virtual bear::universe::coordinate_type
-    get_right_move_force_in_idle() const = 0;
+    get_move_force_in_idle() const = 0;
     virtual bear::universe::coordinate_type
-    get_right_move_force_in_jump() const = 0;
+    get_move_force_in_jump() const = 0;
     virtual bear::universe::coordinate_type
-    get_right_move_force_in_vertical_jump() const = 0;
+    get_move_force_in_vertical_jump() const = 0;
     virtual bear::universe::coordinate_type
-    get_right_move_force_in_run() const = 0;
+    get_move_force_in_run() const = 0;
     virtual bear::universe::coordinate_type
-    get_right_move_force_in_swimming() const = 0;
+    get_move_force_in_swimming() const = 0;
     virtual bear::universe::coordinate_type
-    get_right_move_force_in_walk() const = 0;
+    get_move_force_in_walk() const = 0;
     virtual bear::universe::coordinate_type get_jump_force() const = 0;
     virtual bear::universe::coordinate_type
     get_jump_force_in_float() const = 0;
@@ -291,12 +308,14 @@ namespace ptb
     void progress_sink( bear::universe::time_type elapsed_time );
     void progress_float( bear::universe::time_type elapsed_time );
     void progress_injured( bear::universe::time_type elapsed_time );
+    void progress_paralyze( bear::universe::time_type elapsed_time );
 
     void set_state(player_state_name state);
     bool is_crushed() const;
     void regenerate();
     bool is_in_floating() const;
     bool has_a_power() const;
+    bool has_all_powers() const;
 
     void update_orientation();
     void update_power( bool b, monster::attack_type a);
@@ -306,10 +325,12 @@ namespace ptb
     void do_stop_look_upward();
     void do_stop_crouch();
     void progress_spot( bear::universe::time_type elapsed_time );
+    void progress_corrupting_bonus_attractor
+    ( bear::universe::time_type elapsed_time );
     void progress_gauges( bear::universe::time_type elapsed_time );
     void progress_oxygen_gauge( bear::universe::time_type elapsed_time );
-    void progress_fire_gauge( bear::universe::time_type elapsed_time );
-    void progress_ice_gauge( bear::universe::time_type elapsed_time );
+    void progress_heat_gauge( bear::universe::time_type elapsed_time );
+    void progress_cold_gauge( bear::universe::time_type elapsed_time );
 
     bool test_walk();
     bool test_bottom_contact();
@@ -317,7 +338,10 @@ namespace ptb
     void brake();
     void create_bubble();
     void create_soul_decoration();
-    void shake(double force, bear::universe::time_type duration);
+    void create_corrupting_bonus_attractor();
+    void create_power_effect();
+    void roar_shake();
+    void shake(double force, bear::universe::time_type duration) const;
     virtual bear::visual::sprite get_soul_sprite() const;
     bear::universe::force_type get_object_force() const;
 
@@ -334,15 +358,25 @@ namespace ptb
     void progress_invincibility( bear::universe::time_type elapsed_time );
     void progress_air_float( bear::universe::time_type elapsed_time );
 
-  public:
-   /** \brief Number of oxygen's units. */
-    static const double s_max_oxygen;
+    void create_hit_star( const bear::engine::base_item& that ) const;
+
+    void fill_throwable_items();
+
+    void add_corrupting_item
+    ( double amount, double coeff, const std::string& anim );
+    void remove_corrupting_item();
+
+    static void init_exported_methods();
+
+  private:
+    /** \brief Number of oxygen's units. */
+    static const double s_max_oxygen_gauge;
 
     /** \brief Number of fire's units in gauge. */
-    static const double s_max_fire_gauge;
+    static const double s_max_heat_gauge;
 
     /** \brief Number of ice's units in gauge. */
-    static const double s_max_ice_gauge;
+    static const double s_max_cold_gauge;
 
   protected:
     /** \brief Number of actions of the state named "wait". */
@@ -370,6 +404,9 @@ namespace ptb
     /** \brief The different states of Player. */
     std::vector<state_player*> m_states;
 
+    /** \brief The signals of the player. */
+    player_signals m_signals;
+
     /** \brief Indicates if each action is authorized. */
     std::vector<bool> m_authorized_action;
 
@@ -385,8 +422,14 @@ namespace ptb
     /** \brief Indicates the ratio of the preparation of throw state. */
     double m_throw_time_ratio;
 
-    /** \brief The current powers. */
-    std::vector<gauge*> m_gauges;
+    /** \brief The gauge that manages the oxygen. */
+    gauge m_oxygen_gauge;
+
+    /** \brief The gauge that manages the cold. */
+    gauge m_cold_gauge;
+
+    /** \brief The gauge that manages the heat. */
+    gauge m_heat_gauge;
 
     /** \brief Indicates if Player look up. */
     bool m_status_look_upward;
@@ -403,6 +446,9 @@ namespace ptb
     /** \brief Indicates if Player want to do a clumb jump. */
     bool m_want_clung_jump;
 
+    /** \brief Indicates the duration of the paralyze state. */
+    bear::universe::time_type m_paralyze_duration;
+
     /** \brief The animation of the halo. */
     bear::visual::animation* m_halo_animation;
 
@@ -436,16 +482,16 @@ namespace ptb
     /** \brief The map of current air stones. */
     std::set<stone*> m_air_stones;
 
-    /** \brief Indicates if Player want to move right. */
+    /** \brief Indicates if Player wants to move to the right. */
     bool m_move_right;
 
-    /** \brief Indicates if Player want to move left. */
+    /** \brief Indicates if Player wants to move to the left. */
     bool m_move_left;
 
-    /** \brief The current force in x axis when Player move right. */
-    bear::universe::coordinate_type m_right_move_force;
+    /** \brief The current force in x axis when Player moves. */
+    bear::universe::coordinate_type m_move_force;
 
-    /** \brief The current force in y axis when Player jump. */
+    /** \brief The current force in y axis when Player jumps. */
     bear::universe::coordinate_type m_jump_force;
 
     /** \brief The index of this player. */
@@ -465,13 +511,13 @@ namespace ptb
     bool m_injured_orientation;
 
     /** \brief The set of items that Player can throw */
-    throwable_items_container* m_throwable_items;
+    throwable_items_container m_throwable_items;
 
     /** \brief The time since the last change of air float status. */
     bear::universe::time_type m_air_float_time;
 
     /** \brief The animation to display in the hand. */
-    bear::visual::animation* m_animation_to_throw;
+    bear::visual::animation m_animation_to_throw;
 
     /** \brief Position of the hot spot, relative to the center of mass. */
     bear::universe::position_type m_hot_spot_position;
@@ -486,10 +532,10 @@ namespace ptb
     bear::universe::position_type m_hot_spot_balance_move;
 
     /** \brief A map that indicates if Player can throw a power. */
-    std::map<monster::attack_type,bool> m_can_throw_power;
+    std::map<monster::attack_type, bool> m_can_throw_power;
 
-    /** \brief Number of gauges. */
-    static const unsigned int s_gauges_cardinality;
+    /** \brief Pointer on the corrupting bonus attractor of the player. */
+    corrupting_bonus_attractor* m_corrupting_bonus_attractor;
 
     /** \brief Number of oxygen's units loss in the water during one second. */
     static const double s_oxygen_loss_speed;
