@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -32,8 +32,7 @@
 #include "engine/level.hpp"
 #include "visual/scene_writing.hpp"
 
-#include "ptb/player.hpp"
-#include "ptb/util.hpp"
+#include "ptb/util/player_util.hpp"
 
 #include <libintl.h>
 
@@ -92,10 +91,10 @@ void ptb::game_over_effect::render( scene_element_list& e ) const
 
   std::list<bear::engine::scene_visual> tmp;
 
-  if ( m_first_player != (player*)NULL )
-    m_first_player->get_visual(tmp);
-  if ( m_second_player != (player*)NULL )
-    m_second_player->get_visual(tmp);
+  if ( m_first_player != NULL )
+    m_first_player.get_visual(tmp);
+  if ( m_second_player != NULL )
+    m_second_player.get_visual(tmp);
 
   tmp.sort( bear::engine::scene_visual::z_position_compare() );
 
