@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -34,7 +34,9 @@
 #include "visual/scene_rectangle.hpp"
 #include "visual/scene_sprite.hpp"
 #include "visual/scene_writing.hpp"
+
 #include "ptb/defines.hpp"
+#include "ptb/util/level_util.hpp"
 
 #include <libintl.h>
 #include <algorithm>
@@ -212,13 +214,8 @@ void ptb::level_starting_effect::fill_controls()
   m_act.create(fnt, gettext("act") + (' ' + sub_act));
 
   // get the thumbnail
-  std::string thumb_name = level_name;
-
-  claw::text::replace( thumb_name, std::string(" /"), std::string("_") );
-  std::transform
-    ( thumb_name.begin(), thumb_name.end(), thumb_name.begin(), tolower );
-
-  thumb_name = "gfx/thumb/" + thumb_name + ".png";
+  const std::string thumb_name =
+    util::get_thumbnail(get_layer().get_level().get_filename());
 
   bear::visual::size_box_type s
     ( get_layer().get_size().x - 100, 2 * fnt->get_max_glyph_height() );
