@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -30,14 +30,13 @@
 #ifndef __PTB_GAME_OVER_EFFECT_HPP__
 #define __PTB_GAME_OVER_EFFECT_HPP__
 
+#include "ptb/player_proxy.hpp"
+
 #include "visual/writing.hpp"
-#include "universe/derived_item_handle.hpp"
 #include "engine/transition_effect/fade_effect.hpp"
 
 namespace ptb
 {
-  class player;
-
   /**
    * \brief An effect that displays a text "game over" and start the title
    *        screen.
@@ -50,12 +49,6 @@ namespace ptb
     /** \brief The type of the parent class. */
     typedef bear::engine::fade_effect super;
 
-  private:
-    /** \brief Type of the handles on the player instances. */
-    typedef
-    bear::universe::const_derived_item_handle_maker<player>::handle_type
-    player_handle_type;
-
   public:
     void build();
     bear::universe::time_type
@@ -71,10 +64,10 @@ namespace ptb
     bear::visual::writing m_game_over;
 
     /** \brief Pointer on the first player. */
-    player_handle_type m_first_player;
+    player_proxy m_first_player;
 
     /** \brief Pointer on the second player. */
-    player_handle_type m_second_player;
+    player_proxy m_second_player;
 
   }; // class game_over_effect
 } // namespace ptb
