@@ -1,7 +1,7 @@
 /*
   Plee the Bear
 
-  Copyright (C) 2005-2010 Julien Jorge, Sebastien Angibaud
+  Copyright (C) 20052011 Julien Jorge, Sebastien Angibaud
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the
@@ -29,10 +29,8 @@
 #ifndef __PTB_LEVEL_ENDING_EFFECT_HPP__
 #define __PTB_LEVEL_ENDING_EFFECT_HPP__
 
-#include "generic_items/timer.hpp"
-
 #include "engine/transition_effect/transition_effect.hpp"
-#include "universe/derived_item_handle.hpp"
+#include "engine/world.hpp"
 #include "visual/writing.hpp"
 
 namespace ptb
@@ -47,7 +45,7 @@ namespace ptb
     public bear::engine::transition_effect
   {
   public:
-    /** \brief The type of a list of scene elements retrieved from the layer. */
+    /** \brief The type of a list of scene elements retrieved from the layer.*/
     typedef std::list<bear::visual::scene_element> scene_element_list;
 
   private:
@@ -56,8 +54,9 @@ namespace ptb
     {
     public:
       score_line
-      ( const bear::visual::font& f, const std::string& text,
-        unsigned int points );
+      ( bear::engine::level_globals& glob, const bear::visual::font& f,
+        const std::string& text, unsigned int points,
+        const std::string& picture_filename, const std::string& picture_name );
 
       void render
       ( scene_element_list& e, bear::visual::coordinate_type left,
@@ -70,6 +69,9 @@ namespace ptb
       double get_y_position() const;
       void set_y_position( double y );
 
+      bear::universe::time_type get_time() const;
+      void add_time( bear::universe::time_type t );
+
     private:
       /** \brief The font used for the writings. */
       bear::visual::font m_font;
@@ -80,30 +82,35 @@ namespace ptb
       /** \brief The remaining points, as a text. */
       bear::visual::writing m_points_text;
 
+      /** \brief The sprite of the bonus picture. */
+      bear::visual::sprite m_bonus_sprite;
+
       /** \brief The remaining points. */
       unsigned int m_points;
 
       /** \brief The y-position of the score. */
       bear::visual::coordinate_type m_y;
 
+      /** \brief How long the line has been displayed. */
+      bear::universe::time_type m_time;
+
       /** \brief A delta applied to the text to create shadows. */
       static const bear::visual::coordinate_type s_shadow_delta;
 
+      /** \brief Margin on the right of bonus picture. */
+      static const bear::visual::coordinate_type s_bonus_picture_margin;
+
       /** \brief The scale factor applied to the text. */
       static const double s_scale_factor;
 
     }; // class score_line
 
-    /** \brief The type of a handle on a timer. */
-    typedef
-    bear::universe::const_derived_item_handle_maker<bear::timer>::handle_type
-    timer_handle;
-
   public:
     level_ending_effect();
+    level_ending_effect( const level_ending_effect& that );
     ~level_ending_effect();
 
-    void set_timer( const bear::timer* t );
+    void set_world( const bear::engine::world* w );
 
     bool is_finished() const;
     void build();
@@ -121,6 +128,17 @@ namespace ptb
     ( bear::input::joystick::joy_code button, unsigned int joy_index );
     bool button_maintained
     ( bear::input::joystick::joy_code button, unsigned int joy_index );
+    void check_new_try(unsigned int s);
+
+    void fill_points();
+    void update_bonus_state();
+
+    bool update_lines( bear::universe::time_type elapsed_time );
+    void update_score_bar( bear::universe::time_type elapsed_time );
+    void update_tick( bear::universe::time_type elapsed_time );
+
+    // not implemented
+    level_ending_effect& operator=( const level_ending_effect& that );
 
   private:
     /** \brief The remaining points to give. */
@@ -135,8 +153,8 @@ namespace ptb
     /** \brief The bar displaying the sum of the players' points. */
     horizontal_gauge* m_score_bar;
 
-    /** \brief The timer used to compute the time bonuses. */
-    timer_handle m_timer;
+    /** \brief The world where we search for the bonus points. */
+    const bear::engine::world* m_world;
 
     /** \brief How many points are given per second. */
     static const unsigned int s_points_per_second;
